(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     35549,       1380]*)
(*NotebookOutlinePosition[     79001,       2816]*)
(*  CellTagsIndexPosition[     78871,       2808]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Legal Notice, Disclaimer, and Book Ordering Information:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "(* Legal Notice, Disclaimer, and Book Ordering Information:\n\nLast \
Modified: FIO June 8, 2002\n\n",
  StyleBox["Mathematica For Physics: 2nd Edition",
    FontColor->RGBColor[1, 0, 0]],
  "\n\nRobert L. Zimmerman and Fredrick I. Olness\n",
  "\nWebSite:  \n",
  StyleBox["  www.physics.smu.edu/~olness\n  darkwing.uoregon.edu/~phys600/\n\
\n",
    FontColor->RGBColor[1, 0, 0]],
  "MathSource Number: 0206-862",
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  "\nISBN 0-201-53796-6\nFor ordering information, call 1-800-282-0693\n\
Addison-Wesley Publishing Company\n",
  "\nCommunication with the authors:\nFredrick I. Olness:  \
olness@mail.physics.smu.edu\nRobert L. Zimmerman: bob@zim.uoregon.edu\n\n\
Copyright 2002, Addison-Wesley Publishing Company, Inc. The material in\nthis \
file may be distributed freely  so long as the content remains\nunchanged, \
and the copyright and  reference notices are included. The\npublisher grants \
permission for the noncommercial use of these programs\nand program segments. \
 All other uses require the prior written consent\nof the publisher.    \n\n\
All rights are reserved with regard to the  material in the\n\"Mathematica \
For Physics\" text, and may not be reproduced, stored in a\nretrieval system, \
or transmitted,  in any form or by any means,\nelectronic, mechanical, \
photocopying,  recording, or otherwise, without\nthe prior written permission \
 of the publisher. \n\nThe programs and applications presented in this book \
have been included\nfor  their instructional value. They have been tested \
with care but are\nnot  guaranteed for any particular purpose. The publisher \
does not\noffer any  warranties or representations, nor does it accept any\n\
liabilities with  respect to the programs or applications. \n\n *)\n"
}], "Input",
  Evaluatable->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell["1. Getting Started", "Title",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["1.1 Introduction", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["1.1.1  Computers as a Tool", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["1.1.2 A Note About Notation and Style", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Off[General::spell ]; 
Off[General::spell1];\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "1.1.3 Notation and Symbolize ",
  StyleBox["\t",
    FontSlant->"Italic"],
  StyleBox["(For experts only)",
    FontWeight->"Plain",
    FontSlant->"Italic"]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(x\_1 // FullForm\)], "Input"],

Cell[BoxData[
    \(term\  = a\ \ x\_1\ \  + \ b\ x\_2\  + \ c\ x\)], "Input"],

Cell[BoxData[
    \(term\  /. {x \[Rule] 1}\)], "Input"],

Cell[BoxData[{
    \(\(\(<< Utilities`Notation`\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(?Symbolize\)\)}], "Input"],

Cell[BoxData[
    \(Symbolize[x\_1]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[\(x\_1\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", "//", "FullForm"}], 
      "  ", \( (*\ Entered\ from\ the\ Notation\ Palette\ *) \)}]], "Input"],

Cell[BoxData[{
    RowBox[{"Symbolize", "[", 
      TagBox[\(x\_1\),
        NotationBoxTag,
        TagStyle->"NotationTemplateStyle"], "]"}], "\[IndentingNewLine]", 
    RowBox[{"Symbolize", "[", 
      TagBox[\(x\_2\),
        NotationBoxTag,
        TagStyle->"NotationTemplateStyle"], "]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"term2", " ", "=", 
        RowBox[{
          RowBox[{"a", 
            TagBox[\(x\_1\),
              NotationBoxTag,
              TagStyle->"NotationTemplateStyle"]}], " ", "+", " ", 
          RowBox[{"b", " ", 
            TagBox[\(x\_2\),
              NotationBoxTag,
              TagStyle->"NotationTemplateStyle"]}], " ", "+", 
          " ", \(c\ x\)}]}], ";"}]}], "Input"],

Cell[BoxData[
    \(term2\  /. x \[Rule] 1\)], "Input"]
}, Closed]],

Cell["1.2 Arithmetic and Algebra    ", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["1.2.1 Arithmetic and Notation", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(2*6\ \(\(\((12 + 4)\)/\((\ \ 12 - 4)\)\)\(\ \ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \({2^3, Sqrt[2], \(4!\), \(4!!\)}\)], "Input",
  Hyphenation->False],

Cell["N[Sqrt[2]]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Sqrt[2] // N ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(2\  // Sqrt\)\ \  // N\)], "Input"],

Cell["N[Sqrt[2],50]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Sqrt[2] // N[#,50]&", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(list1\)\(=\)\({I, \ \[Pi]\ , E, Infinity, GoldenRatio, EulerGamma, 
        Catalan, Degree}\)\(\ \ \)\)\)], "Input",
  Hyphenation->False],

Cell["list1 // N", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"Clear", "[", 
      StyleBox["list1",
        FontFamily->"Courier",
        FontWeight->"Bold"], "]"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    StyleBox["list1",
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input",
  Hyphenation->False],

Cell["{Sqrt[-1],I,\[ImaginaryI]}", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["(4 I + 6 I)/(2 - 4I)  ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \({Abs[2 + I], Re[2 + I], Im[2 + I], Conjugate[2 + I]\ }\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2.2 Algebraic Manipulations", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["eq1= Expand[(1+ x^2)^5]      ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["eq1 // Factor ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Factor[eq1,GaussianIntegers->True]    ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Options[Factor]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["eq1= Expand[(x+1)^5 (y+1)^2 , y]", "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Sqrt[\((a\ b\ c\ d\ Cos[\[Theta]])\)^2]\  // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Simplify[\ 
      Sqrt[\((a\ b\ c\ d\ Cos[\[Theta]])\)^2], {\ a > 0, b \[Element] Reals, 
        c \[Element] 
          Complexes, \ \[Pi]\ /2 < \[Theta]\  < \[Pi]\ \ }]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(Simplify[{Cos[\ n\ \ \[Pi]\ ], Sin[n\ \[Pi]\ ]}, \ 
      n \[Element] Integers]\)\)\)], "Input",
  Hyphenation->False],

Cell["Factor[Cos[4 x]^2-2 Cos[4 x] Sin[3 x]+Sin[3 x]^2]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Factor[Cos[4 x]^2-2 Cos[4 x] Sin[3 x]+Sin[3 x]^2,Trig->True]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Cos[4\ x]^2 - 2\ Cos[4\ x]\ Sin[3\ x] + Sin[3\ x]^2\  // 
      TrigFactor\)], "Input"],

Cell["ComplexExpand[Exp[I \[Theta]]]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["ComplexExpand[Exp[I \[Theta]],\[Theta]]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[" Options[ComplexExpand]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ComplexExpand[Exp[I\ \[Theta]], \[Theta], \ 
      TargetFunctions \[Rule] Abs]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2.3 PowerExpand", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \({Sqrt[a^2], Log[a/b], Log[a^b]}\  // PowerExpand\)], "Input"],

Cell[BoxData[
    \(Solve[Sqrt[x^2] \[Equal] a, x]\)], "Input"],

Cell[BoxData[
    \(Solve[Sqrt[x^2] \[Equal] a\  // PowerExpand, x]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2.4 Simple Rules", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \({a, b} /. {\ a \[Rule] \ b, \ b \[Rule] c}\)], "Input"],

Cell[BoxData[
    \({a, b} //. {\ a \[Rule] \ b, \ b \[Rule] c}\)], "Input"],

Cell[BoxData[
    \(\(\(a\)\(\ \)\(//.\)\({a \[Rule] b, b \[Rule] a}\)\(\ \ \)\( (*\ 
        generates\ endless\ loop\ *) \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2.5 A Home-made Complex Conjugate with SuperStar", "Subsection"],

Cell[BoxData[
    \(\(\(2\ I\)\(\ \)\(/.\)\({I\  \[Rule] \ \(-I\)}\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(2\ I // FullForm\)], "Input"],

Cell[BoxData[
    \({I\  \[Rule] \ \(-I\)} // FullForm\)], "Input"],

Cell["conjugateRule= {Complex[re_,im_]->Complex[re,-im]};", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["2 I /. conjugateRule ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Unprotect[SuperStar];\)\)], "Input"],

Cell[BoxData[{
    \(SuperStar\  /: \ \(exp_\^*\) := 
      exp\  /. {Complex[a_, b_] \[RuleDelayed] 
            Complex[a, \(-b\)]}\), "\[IndentingNewLine]", 
    \(\(Protect[SuperStar];\)\)}], "Input"],

Cell[BoxData[
    \(\(\((a + \[ImaginaryI]\ b + \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\))\)\^*\)\)], "Input"],

Cell[BoxData[
    \(SuperStar[
      a + \[ImaginaryI]\ b + \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\)]\)], "Input"],

Cell[BoxData[
    \(Conjugate[
      a + \[ImaginaryI]\ b + \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\)]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2.6 Immediate and Delayed Substitutions", "Subsection"],

Cell[BoxData[
    \(\(\({x, x, \ x}\  /. {x \[Rule] Random[]}\)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[BoxData[
    \(\(\({x, x, \ x}\  /. {x :> Random[]}\)\(\[IndentingNewLine]\)
    \)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2.7 Selecting Parts of Expressions", "Subsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(eq1 = \ a1\ x + \ a2\ x^2\  + \ a3\ x^3\ Sin[x/y];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Part[eq1, 3]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1[\([3]\)]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1[\([3, 1]\)]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1[\([{3, 1}]\)]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"position", "=", 
      RowBox[{"Position", "[", 
        RowBox[{"eq1", ",", 
          StyleBox[\(Sin[x/y]\),
            FontFamily->"Courier",
            FontWeight->"Bold"]}], "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"ReplacePart", "[", 
      RowBox[{"eq1", ",", " ", 
        StyleBox[\(Cos[x/y]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], " ", ",", "position"}], "]"}]], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2.8 Algebraic Equations", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["eq1= a x^2 + b x + c == 0;", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[" sol1= Solve[eq1,x] ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["x /. sol1[[2]]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["eq1 /.sol1 //Simplify ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Roots[eq1, x]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Reduce[eq1, x]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(eq2 = {a\ x + b\ y \[Equal] c, a\ x - b\ y \[Equal] d};\)\)], "Input",\

  Hyphenation->False],

Cell[BoxData[
    \(eq3 = Reduce[eq2, {x, y}]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq3[\([4, {1, 2}]\)]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = 
      Reduce[{eq2, a \[NotEqual] 0, b \[NotEqual] 0} // Flatten, {x, 
          y}]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell["1.3 Functions and Procedures", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["1.3.1 Built-In Functions", "Subsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"list1", "=", 
      RowBox[{"{", 
        StyleBox[\(Sin[x], ArcCos[x], Cosh[x], ArcSinh[x], BesselJ[n, x]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["}",
          FontFamily->"Courier",
          FontWeight->"Bold"]}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(list1\  /. {x \[Rule] 0.5, n \[Rule] 2}\)], "Input"],

Cell["?Sin", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["??Sin", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(list = {0, 45, 90, 180, 270\ , 360}*Degree;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Sin[list]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["1.3.2 User-Defined Functions", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(f1[x_]\  = \ x^2;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(f1[2]\)], "Input"],

Cell[BoxData[{
    \(\(f2[x] = \ x^2;\)\), "\[IndentingNewLine]", 
    \({f2[x], f2[2]}\)}], "Input"],

Cell[BoxData[{
    \(\(a = 1;\)\), "\[IndentingNewLine]", 
    \(\(f3[x_]\  := \ 
        If[x \[LessEqual] a, \(-1\), 1];\)\), "\[IndentingNewLine]", 
    \(\(f4[x_]\ \ \  = \ If[x \[LessEqual] a, \(-1\), 1];\)\)}], "Input"],

Cell[BoxData[
    \({f3[2], f4[2]}\)], "Input"],

Cell[BoxData[{
    \(\(a = 3;\)\), "\[IndentingNewLine]", 
    \({f3[2], f4[2]}\)}], "Input"],

Cell[BoxData[
    \(\(?f3\)\)], "Input"],

Cell[BoxData[
    \(\(?f4\)\)], "Input"],

Cell[BoxData[
    \(Clear[a]\)], "Input"],

Cell[BoxData[
    \(Clear[fac]\)], "Input"],

Cell[BoxData[{
    \(\(fac[1] = 1;\)\), "\[IndentingNewLine]", 
    \(fac[n_Integer?Positive]\  := \ n\ fac[n - 1]\)}], "Input"],

Cell[BoxData[
    \({\(4!\), \ fac[4], fac[4.0], fac[\(-4\)], fac[a]}\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.3.3 Pure Functions", "Subsection",
  Hyphenation->False],

Cell[BoxData[{
    \(\(f1 = \ Function[{x, y}, \ Sin[x\ /y]];\)\), "\[IndentingNewLine]", 
    \(f1[a, b]\)}], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(f2 = \((Sin[#1/#2])\) &;\)\), "\[IndentingNewLine]", 
    \(f2[a, b]\ \)}], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(eq1\  = \ \(x'\)[t]\  + \ a\ x[t];\)\), "\[IndentingNewLine]", 
    \(eq1\  /. {x[t] \[Rule] y[t] + b}\)}], "Input"],

Cell[BoxData[
    \(eq1\  /. {x \[Rule] \((y[#] + b &)\)}\)], "Input"],

Cell[BoxData[
    \(term1 = \ \((1 + x)\)^2\ \((1 + y)\)^2\  // Expand\)], "Input"],

Cell[BoxData[
    \(Select[term1, FreeQ[#, x] &]\)], "Input"],

Cell[BoxData[
    \(Select[\ term1, \(! FreeQ[#, x]\) &]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.3.4 Assigning Rules and Restrictions to Functions  ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
i /: i^2  = -1;
i /: i^3  = -i;
i /: i^4  =  1;\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["i /: i^n_Integer := i^Mod[n,4] /; n<0 || 4<n;", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Table[i^n == I^n,{n,-8,8}] /.{i->I}", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear[step1, step2]\)], "Input"],

Cell["\<\
step1[x_]= 0 /; x<=0;
step1[x_]= 1 /; 0< x;\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
step2[x_ /; x<=0]= 0;
step2[x_ /; 0< x]= 1;\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(step1[\(-0.1\)]\  // Trace\)], "Input"],

Cell[BoxData[
    \(step2[\(-0.1\)]\  // Trace\)], "Input"],

Cell["step3[x_]:=Which[x<=0,0,x>0,1]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(step3[\(-0.1\)]\  // Trace\)], "Input"],

Cell[BoxData[
    \({\(Table[\ step1[x], {x, \(-10000\), 10000, 1}]\  // Timing\)\  // 
        First, \[IndentingNewLine]\(Table[\ 
            step2[x], {x, \(-10000\), 10000, 1}]\  // Timing\)\  // 
        First, \[IndentingNewLine]\(Table[\ 
            step3[x], {x, \(-10000\), 10000, 1}]\  // Timing\)\  // 
        First}\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.3.5 Module", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(shift[list_] := 
      Module[{newList, a = 1, max}, \[IndentingNewLine]newList = 
          list + a; \[IndentingNewLine]max = 
          Max[newList]; \[IndentingNewLine]Print["\<The max of the new list \
is: \>", max]; \[IndentingNewLine]Return[
          newList]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(shift[{1, 2, 3}]\)], "Input"],

Cell[BoxData[
    \({newList, a, max}\)], "Input"],

Cell[BoxData[
    \(shift2[list_, a_:  1] := 
      Module[{newList, max}, \[IndentingNewLine]newList = 
          list + a; \[IndentingNewLine]max = 
          Max[newList]; \[IndentingNewLine]Print["\<The max of the new list \
is: \>", max]; \[IndentingNewLine]Return[
          newList]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(shift2[{1, 2, 3}, 2]\)], "Input"],

Cell[BoxData[
    \(shift2[{1, 2, 3}]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.3.6 rootPlot", "Subsection"],

Cell["\<\
eq1= 0 == 1 + x + 2 x^2 + 3 x^3 + 4 x^4 + 5 x^5;

NSolve[eq1,x]\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((list = {Re[x], Im[x]}\  /. NSolve[eq1, x])\) // 
      TraditionalForm\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[list, PlotStyle \[Rule] PointSize[0.03]];\)\)], "Input"],

Cell[BoxData[
    \(rootPlot[equation_, variable_:  x, opts___] := 
      Module[{nSol, list}, \[IndentingNewLine]nSol = 
          NSolve[equation, 
            variable]; \[IndentingNewLine]list = \ {Re[x], Im[x]}\  /. 
            nSol; \[IndentingNewLine]Return[\ 
          ListPlot[list, PlotStyle \[Rule] PointSize[0.03], 
            opts]];\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(\(rootPlot[x\^15 - 1 \[Equal] 0, x, 
        AspectRatio \[Rule] 1];\)\)], "Input"]
}, Closed]],

Cell["1.4 Packages", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["1.4.1 Loading Packages", "Subsection",
  Hyphenation->False],

Cell[BoxData[
    \($Packages\)], "Input"],

Cell["Needs[\"Graphics`Graphics`\"]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \($Packages\)], "Input"],

Cell[BoxData[
    RowBox[{"?", 
      StyleBox["Graphics`Graphics`*",
        FontFamily->"Courier",
        FontWeight->"Bold"]}]], "Input"],

Cell["?PolarListPlot", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(CoordinatesToCartesian[{r, \[Theta], \[Phi]}, Spherical]\)], "Input",
  Hyphenation->False],

Cell["\<\
x2rRule = Thread[{x,y,z} -> CoordinatesToCartesian[{r,\[Theta],\
\[Phi]},Spherical] ]\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(x^2 + y^2 + z^2 /. x2rRule // Simplify\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["1.4.2 Contexts", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Contexts[]\)], "Input"],

Cell["Context[PolarListPlot]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Context[dummy]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Graphics`Graphics`*\"]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
dummy[x_]=x;
Protect[dummy];
 \
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["?dummy", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["1.4.3 Shadowing", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(EasterSunday[2002]\)], "Input"],

Cell[BoxData[
    \(Needs["\<Miscellaneous`Calendar`\>"]\)], "Input"],

Cell[BoxData[
    \(EasterSunday[2002]\)], "Input"],

Cell[BoxData[
    \(Context[EasterSunday]\)], "Input"],

Cell[BoxData[
    \(Remove[EasterSunday]\)], "Input"],

Cell[BoxData[
    \(Context[EasterSunday]\)], "Input"],

Cell[BoxData[
    \(EasterSunday[2002]\)], "Input"]
}, Closed]],

Cell["1.5 Calculus", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["1.5.1 Derivatives and Integrals", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(\(f[x_] = x^n;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \({D[x^n, {x, 1}], D[x^n, x], D[f[x], x], \(f'\)[x]}\)}], "Input"],

Cell[BoxData[
    \({D[x^n, {x, 2}], D[\(f'\)[x], x], \(f''\)[x]}\)], "Input"],

Cell[BoxData[{
    \(\(\(term1 = x^3\ y^4 + y\ x^5 + x/y^3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(D[term1, {x, 2}, y]\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = 
      Integrate[x\^a, {x, 0, 1}, GenerateConditions \[Rule] True]\)], "Input"],

Cell[BoxData[
    \(eq2 = Integrate[x\^\(-1\), x]\)], "Input"],

Cell[BoxData[
    \(eq1 = 
      Integrate[x\^a, {x, 0, 1}, GenerateConditions \[Rule] False]\)], "Input"],

Cell[BoxData[
    \(Integrate[x\^a, {x, 0, 1}, 
      Assumptions \[Rule] {Re[a] > \(-1\)}]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Integrate[\ 1, {x, 0, 1}, {y, 0, \@\(1 - x\^2\)}]\)], "Input"],

Cell[BoxData[
    \(NIntegrate[
      Sin[z\ Sin[x\ y]], {x, 0, 1}, {y, 0, x\ }, {z, 0, x\ \ y}]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["1.5.2 Differential Equations", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(eq1 = \(y''\)[t] + \[Omega]\^2\ y[t] \[Equal] 0;\)\)], "Input"],

Cell[BoxData[
    \(\(initial = {y[0] \[Equal] y0, \(y'\)[0] \[Equal] v0};\)\)], "Input"],

Cell["eq2= Append[initial,eq1]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq3 = DSolve[eq2, {y[t]}, t] // Flatten\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["1.5.3 Changing Variables and Pure Functions", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(eq1 = a\ \(x''\)[t] + b\ \(x'\)[t] + c\ x[t] \[Equal] 0;\)\)], "Input",\

  Hyphenation->False],

Cell[BoxData[
    \(eq1 /. {x[t] \[Rule] y[t] + 2}\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 /. {x \[Rule] \((y[#] + 2 &)\)}\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 /. {x \[Rule] Function[{t}, y[t] + 2]}\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(DSolve[{x[t] == y[t] + 2}, x, t]\  // Flatten\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.5.4 Numerical Solutions of Differential Equations  ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(eq1 = {\(x''\)[t] \[Equal] \(-x[t]\) - x[t]\ y[t]^2, \ \(y''\)[
              t] \[Equal] \(-y[t]\) - x[t]\ y[t]^2};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(initial = {x[0] \[Equal] 2, \(x'\)[0] \[Equal] 0, 
          y[0] \[Equal] 1, \(y'\)[0] \[Equal] 0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(ndsol = \(NDSolve[
          Join[eq1, initial], {x, y}, {t, 0, 20}]\)[\([1]\)]\)], "Input",
  Hyphenation->False],

Cell["Needs[\"Graphics`Legend`\"]", "Input",
  CellTags->"S5.37.1"],

Cell[BoxData[
    \(Plot[{x[t], y[t]} /. ndsol\  // Evaluate, {t, 0, 20}, 
      PlotStyle \[Rule] {{\ }, {Dashing[{0.02}], 
            Thickness[
              0.008]}}, \[IndentingNewLine]PlotLegend \[Rule] {"\<x[t]\>", \
"\<y[t]\>"}, LegendPosition \[Rule] {1, 0}\[IndentingNewLine]]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(ParametricPlot[{x[t], y[t]} /. ndsol\  // Evaluate, {t, 0, 
          20}];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Plot[{\(x'\)[t], \(y'\)[t]} /. ndsol\  // Evaluate, {t, 0, 20}, 
        PlotStyle \[Rule] {{\ }, {Dashing[{0.02}], 
              Thickness[0.008]}}];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell["1.6 Graphics   ", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["1.6.1 Using the Plot Command", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(Options[Plot]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = \ \ \ Plot[\ 
          1\ /\ \((1 - x^2)\), \ {x, \ \(-10\), \ 
            10}, \n\ \ \ \ \ \ \tPlotStyle -> {\ Hue[0.8], 
              Thickness[0.008]}];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(colors = \({red, green, blue, cyan, magenta, 
            yellow} = {RGBColor[1, 0, 0], RGBColor[0, 1, 0], 
            RGBColor[0, 0, 1], CMYKColor[1, 0, 0, 0], CMYKColor[0, 1, 0, 0], 
            CMYKColor[0, 0, 1, 0]}\);\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(Plot[Table[i\ x\ , {i, 6}]\  // Evaluate\ , {x, 0, 1}, 
        PlotStyle \[Rule] colors\ ];\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\[IndentingNewLine]\(n = 13;\)\), "\[IndentingNewLine]", 
    \(\(hues = Table[Hue[i/n], {i, n}];\)\), "\[IndentingNewLine]", 
    \(\ \(Plot[Table[i\ x\ , {i, n}]\  // Evaluate\ , {x, 0, 1}, 
        PlotStyle \[Rule] hues\ ];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.6.2 Animated Plots", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`Animation`\>"]\)], "Input",
  Hyphenation->False],

Cell["\<\
frames=1;
Animate[
\tPlot[Cos[2 \[Pi] (x-t)],
\t{x,-2,2},
\tPlotRange->{-1,1},
\tAxes-> False],
{t,1/frames,1,1/frames}]\
\>", "Input",
  Hyphenation->False,
  CellTags->"S5.25.1"],

Cell[BoxData[{
    \(\(frames = 1.1;\)\), "\n", 
    \(Animate[
      Plot[{Cos[2  \[Pi] \((x - t)\)], Cos[2  \[Pi] \((x + t)\)], 
          Cos[2  \[Pi] \((x - t)\)] + Cos[2  \[Pi] \((x + t)\)]}, {x, \(-2\), 
          2}, \[IndentingNewLine]PlotRange \[Rule] {\(-2\), 
            2}, \[IndentingNewLine]PlotStyle \[Rule] {blue, 
            green, {red, 
              Thickness[0.008]\ }}, \[IndentingNewLine]Axes \[Rule] 
          False], \[IndentingNewLine]{t, 1/frames, 1, 1/frames}]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.6.3 Vector Field Plots", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(vector = {1/x, 1/y};\)\)], "Input"],

Cell["Needs[\"Graphics`PlotField`\"];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PlotVectorField[
        vector, {x, \(-5\), 5, 2}, {y, \(-5\), 5, 
          2}, \[IndentingNewLine]ScaleFunction \[Rule] \((1 &)\), 
        PlotPoints \[Rule] 20];\)\)], "Input"],

Cell[" Needs[\"Graphics`PlotField3D`\"];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PlotGradientField3D[
        1/Sqrt[x^2 + y^2 + z^2], \[IndentingNewLine]{x, \(-5\), 5, 
          2}, {y, \(-5\), 5, 2}, {z, \(-5\), 5, 
          2}, \[IndentingNewLine]ScaleFunction \[Rule] \((1 &)\), \
\[IndentingNewLine]VectorHeads \[Rule] True];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
1.6.4 Three-dimensional Graphics using Plot3D and \
ParametricPlot3D\
\>", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Plot3D[
        Sqrt[x + I\ y] // Im, {x, \(-1\), 1}, {y, \(-1\), 
          1}, \[IndentingNewLine]PlotPoints \[Rule] 
          25, \[IndentingNewLine]AspectRatio \[Rule] 
          1, \[IndentingNewLine]AxesLabel \[Rule] {"\<Re\>", "\<Im\>", \
"\<\>"}];\)\)], "Input"],

Cell["Needs[\"Graphics`ParametricPlot3D`\"]", "Input",
  CellTags->"S5.39.1"],

Cell[BoxData[
    \(\(CylindricalPlot3D[
        Sqrt[r\ Exp[I\ \[Theta]]] // Im, {r, 0, 
          10}, {\[Theta], \(-\[Pi]\), \[Pi]}, \[IndentingNewLine]PlotPoints \
\[Rule] 25, \[IndentingNewLine]AspectRatio \[Rule] 1];\)\)], "Input"],

Cell[BoxData[
    \(\(SphericalPlot3D[\(SphericalHarmonicY[2, 0, \[Theta], \[Phi]]\  // 
            Abs\) // Evaluate, \[IndentingNewLine]{\[Theta], 
          0, \[Pi]}, {\[Phi], 0, 2  \[Pi]}, PlotPoints \[Rule] 50, 
        Boxed \[Rule] False, Axes \[Rule] False];\)\)], "Input"],

Cell["\<\
ParametricPlot3D[{Cos[2t+\[Pi]/4]+t/100,2 Cos[2 t]+t/200,Cos[3 \
t]},{t,0,100}, PlotPoints-> 3000];\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["1.7 Exercises", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 1: Real Expressions", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 2:  Series", "Subsubsection",
  Hyphenation->False],

Cell["Exercise 3: Integration", "Subsubsection",
  Hyphenation->False],

Cell["Exercise 4: Superposition of Waves", "Subsubsection",
  Hyphenation->False],

Cell["Exercise 5: Tables of Zeros for Several Functions", "Subsubsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell[TextData[{
  "Exercise 6:",
  StyleBox[" ",
    FontSize->12,
    FontColor->RGBColor[0, 0, 1]],
  "Plot of Roots"
}], "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[" eq1= x^7 + x^3 + x^2 + 1==0;  ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Exercise",
    FontColor->GrayLevel[0]],
  " ",
  StyleBox["7",
    FontColor->GrayLevel[0]],
  ":",
  StyleBox[" Coupled Equations",
    FontColor->GrayLevel[0]]
}], "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True,
  FontColor->RGBColor[0.499992, 0, 0.499992]],

Cell[CellGroupData[{

Cell["Exercise 8: Statistical Data", "Subsubsection",
  Hyphenation->False],

Cell["r = Table[Random[Integer,{1,20}], {1000}];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell["Exercise 9: Differential Equation ", "Subsubsection",
  Hyphenation->False],

Cell["Exercise 10: Coupled Differential Equations", "Subsubsection",
  Hyphenation->False],

Cell["\<\
Exercise 11: Trajectories and Vector Field Plots for Coupled \
Differential Equations\
\>", "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {Inherited, 18}},
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 12: Heat Equation", "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {Inherited, 18}},
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 13: Wave Equation", "Subsubsection",
  CellMargins->{{Inherited, Inherited}, {Inherited, 18}},
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Exercise 14: Fit to Data  ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(data = 
        Table[\({x, 5\ Sin[3\ \[Pi]\ \ x] + Random[Real, {\(-0.2\), 0.2}]} // 
              N\) // Chop[#, 10^\(-3\)] &, {x, 0, 0.5, 0.05}];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercise 15: Rules used to solve problems", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(list = \(Random[Integer\ , {0, 100}] &\) /@ Range[13];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercise 16: Procedures to select numbers", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(list = Table[Random[Real, {0, 20}], {i, 30}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercise 17: Procedure to Select certain Pairs of Points", \
"Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["pairs=Table[Random[],{1000},{2}];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell["Exercise 18: Change", "Subsubsection",
  Hyphenation->False],

Cell["Exercise 19: Toss of a Die", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  LineSpacing->{1, 0},
  AspectRatioFixed->True],

Cell["Exercise 20: Three Dice", "Subsubsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell[TextData[{
  "Exercise 21: ",
  StyleBox["Playing Darts and the Calculation of ",
    FontVariations->{"CompatibilityType"->0}],
  "\[Pi] "
}], "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(list = 
        Table[{Random[Real, {\(-1\), 1}], Random[Real, {\(-1\), 1}]}, {i, 
            10}];\)\)], "Input"]
}, Closed]],

Cell["Exercise 22: Dropping Needles", "Subsubsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Exercise 23: Pacal's Wager", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(pairs = Table[Random[Integer, {1, 6}], {1000}, {2}]\)], "Input"]
}, Closed]],

Cell["Exercise 24: The birthday problem", "Subsubsection",
  Hyphenation->False]
}, Closed]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{895, 692},
WindowMargins->{{53, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, 9999},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Hyphenation->False,
SpellingOptions->{"AlwaysStop"->"RepeatedWords"},
SpellingDictionaries->{"CorrectWords"->{
  "descrete", "Poincar\[EAcute]", "Mandelbrot", "xo", "Gfixpt", "Gfixptpt", 
    "Lvalues", "Spoints", "fdata", "rdata", "returnpt", "diff", "Gder", 
    "prob", "Scobweb", "Svalues", "fder", "Lagrange's", "Lagrange", "qi", 
    "Qi", "eq", "eqin", "Ser", "eqs", "vars", "Diff", "zpsol", "zp", 
    "perturbative", "firstorderpert", "xfirst", "ro", "''", "Rx", "Ry", "Rz", 
    "Eq", "Kepler", "Keplerian", "Johannes", "Kepler's", "uo", "ee", "cterm", 
    "plotorbit", "num", "uforce", "ndsol", "ndsol.", "numorbit", "rrule", 
    "Urule", "Lpt", "tmax", "Mgraph", "fx", "fy", "tfinal", "hrule", "vxo", 
    "vyo", "eqlist", "Equi", "Lgraph", "jac", "nonrotating", "accreting", 
    "Lagragian", "rl", "zeropt", "yi", "yrs", "Ll", "freq", "invfreq", "xy", 
    "tmoon", "Descrete", "Poincare", "eigenfrequencies", "eigenfrequency", 
    "eigenmatrix", "nondiagonal", "iv.", "Vol", "km", "clusterdata", "Persus",
     "Cor", "Bor", "dsol", "patt", "patt.", "expr", "simpexp", "seq", "eq.", 
    "ith", "psl", "ei", "crit", "lhs", "rhs.", "rhs", "lhs.", "nonanalytic", 
    "shdw", "fac", "mynsolve", "mysolve", "args", "args.", "wrsym", "optx", 
    "ii", "iii", "solvse", "eq1", "eqn", "bvalue", "bvalue.", "rootplot", 
    "Coord", "zf", "coeflist", "xlist", "myselect", "pts", "ptplot", "lapsol",
     "neq", "nsol", "solset", "solplot", "vecplot", "soly", "solc", "Ext", 
    "sumtrials", "asctrials", "allpoints", "ptcircle", "redpoints", 
    "Buffon's", "datapt", "ptx", "pty", "th", "allneedles", "datalist", "amt",
     "imax", "iterator", "Pi"}},
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        Inherited},
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        Inherited},
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{59, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{108, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{158, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    LanguageCategory->"Formula",
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S5.37.1"->{
    Cell[25988, 1024, 67, 1, 27, "Input",
      CellTags->"S5.37.1"]},
  "S5.25.1"->{
    Cell[28241, 1099, 190, 10, 117, "Input",
      CellTags->"S5.25.1"]},
  "S5.39.1"->{
    Cell[30354, 1173, 77, 1, 27, "Input",
      CellTags->"S5.39.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S5.37.1", 78600, 2795},
  {"S5.25.1", 78686, 2798},
  {"S5.39.1", 78775, 2801}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 116, 2, 42, "Subsubsection"],
Cell[1846, 56, 1886, 33, 657, "Input",
  Evaluatable->False]
}, Closed]],
Cell[3747, 92, 105, 3, 81, "Title",
  Evaluatable->False],
Cell[3855, 97, 105, 3, 60, "Section",
  Evaluatable->False],
Cell[3963, 102, 118, 3, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4106, 109, 129, 3, 45, "Subsection",
  Evaluatable->False],
Cell[4238, 114, 117, 5, 42, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4392, 124, 264, 10, 29, "Subsection",
  Evaluatable->False],
Cell[4659, 136, 49, 1, 27, "Input"],
Cell[4711, 139, 78, 1, 27, "Input"],
Cell[4792, 142, 56, 1, 27, "Input"],
Cell[4851, 145, 141, 3, 59, "Input"],
Cell[4995, 150, 48, 1, 27, "Input"],
Cell[5046, 153, 241, 6, 27, "Input"],
Cell[5290, 161, 733, 20, 59, "Input"],
Cell[6026, 183, 55, 1, 27, "Input"]
}, Closed]],
Cell[6096, 187, 119, 3, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[6240, 194, 121, 3, 45, "Subsection",
  Evaluatable->False],
Cell[6364, 199, 105, 2, 27, "Input"],
Cell[6472, 203, 86, 2, 27, "Input"],
Cell[6561, 207, 75, 2, 27, "Input"],
Cell[6639, 211, 78, 2, 27, "Input"],
Cell[6720, 215, 57, 1, 27, "Input"],
Cell[6780, 218, 78, 2, 27, "Input"],
Cell[6861, 222, 84, 2, 27, "Input"],
Cell[6948, 226, 163, 3, 27, "Input"],
Cell[7114, 231, 75, 2, 27, "Input"],
Cell[7192, 235, 163, 5, 27, "Input"],
Cell[7358, 242, 123, 4, 27, "Input"],
Cell[7484, 248, 91, 2, 27, "Input"],
Cell[7578, 252, 87, 2, 27, "Input"],
Cell[7668, 256, 109, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7814, 263, 121, 3, 29, "Subsection",
  Evaluatable->False],
Cell[7938, 268, 94, 2, 27, "Input"],
Cell[8035, 272, 79, 2, 27, "Input"],
Cell[8117, 276, 103, 2, 27, "Input"],
Cell[8223, 280, 80, 2, 27, "Input"],
Cell[8306, 284, 71, 1, 27, "Input"],
Cell[8380, 287, 70, 2, 27, "Input"],
Cell[8453, 291, 108, 2, 27, "Input"],
Cell[8564, 295, 226, 5, 27, "Input"],
Cell[8793, 302, 149, 3, 27, "Input"],
Cell[8945, 307, 114, 2, 27, "Input"],
Cell[9062, 311, 125, 2, 27, "Input"],
Cell[9190, 315, 107, 2, 27, "Input"],
Cell[9300, 319, 95, 2, 27, "Input"],
Cell[9398, 323, 104, 2, 27, "Input"],
Cell[9505, 327, 88, 2, 27, "Input"],
Cell[9596, 331, 134, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9767, 339, 109, 3, 29, "Subsection",
  Evaluatable->False],
Cell[9879, 344, 81, 1, 27, "Input"],
Cell[9963, 347, 63, 1, 27, "Input"],
Cell[10029, 350, 80, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10146, 356, 110, 3, 29, "Subsection",
  Evaluatable->False],
Cell[10259, 361, 75, 1, 27, "Input"],
Cell[10337, 364, 76, 1, 27, "Input"],
Cell[10416, 367, 140, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10593, 374, 72, 0, 29, "Subsection"],
Cell[10668, 376, 89, 1, 27, "Input"],
Cell[10760, 379, 49, 1, 27, "Input"],
Cell[10812, 382, 67, 1, 27, "Input"],
Cell[10882, 385, 116, 2, 27, "Input"],
Cell[11001, 389, 86, 2, 27, "Input"],
Cell[11090, 393, 58, 1, 27, "Input"],
Cell[11151, 396, 204, 4, 43, "Input"],
Cell[11358, 402, 115, 2, 32, "Input"],
Cell[11476, 406, 120, 3, 32, "Input"],
Cell[11599, 411, 120, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11756, 419, 63, 0, 29, "Subsection"],
Cell[11822, 421, 106, 2, 43, "Input"],
Cell[11931, 425, 101, 2, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[12069, 432, 80, 1, 29, "Subsection"],
Cell[12152, 435, 109, 2, 27, "Input"],
Cell[12264, 439, 67, 2, 27, "Input"],
Cell[12334, 443, 67, 2, 27, "Input"],
Cell[12404, 447, 70, 2, 27, "Input"],
Cell[12477, 451, 72, 2, 27, "Input"],
Cell[12552, 455, 248, 7, 27, "Input"],
Cell[12803, 464, 236, 6, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13076, 475, 117, 3, 29, "Subsection",
  Evaluatable->False],
Cell[13196, 480, 91, 2, 27, "Input"],
Cell[13290, 484, 85, 2, 27, "Input"],
Cell[13378, 488, 79, 2, 27, "Input"],
Cell[13460, 492, 87, 2, 27, "Input"],
Cell[13550, 496, 68, 2, 27, "Input"],
Cell[13621, 500, 69, 2, 27, "Input"],
Cell[13693, 504, 116, 3, 27, "Input"],
Cell[13812, 509, 80, 2, 27, "Input"],
Cell[13895, 513, 75, 2, 27, "Input"],
Cell[13973, 517, 145, 4, 27, "Input"]
}, Closed]],
Cell[14133, 524, 117, 3, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[14275, 531, 68, 1, 45, "Subsection"],
Cell[14346, 534, 323, 9, 27, "Input"],
Cell[14672, 545, 72, 1, 27, "Input"],
Cell[14747, 548, 69, 2, 27, "Input"],
Cell[14819, 552, 70, 2, 27, "Input"],
Cell[14892, 556, 102, 2, 27, "Input"],
Cell[14997, 560, 64, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15098, 567, 120, 3, 29, "Subsection",
  Evaluatable->False],
Cell[15221, 572, 76, 2, 27, "Input"],
Cell[15300, 576, 38, 1, 27, "Input"],
Cell[15341, 579, 101, 2, 43, "Input"],
Cell[15445, 583, 225, 4, 59, "Input"],
Cell[15673, 589, 47, 1, 27, "Input"],
Cell[15723, 592, 93, 2, 43, "Input"],
Cell[15819, 596, 40, 1, 27, "Input"],
Cell[15862, 599, 40, 1, 27, "Input"],
Cell[15905, 602, 41, 1, 27, "Input"],
Cell[15949, 605, 43, 1, 27, "Input"],
Cell[15995, 608, 128, 2, 43, "Input"],
Cell[16126, 612, 82, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16245, 618, 64, 1, 29, "Subsection"],
Cell[16312, 621, 141, 3, 43, "Input"],
Cell[16456, 626, 129, 3, 43, "Input"],
Cell[16588, 631, 139, 2, 43, "Input"],
Cell[16730, 635, 70, 1, 27, "Input"],
Cell[16803, 638, 83, 1, 27, "Input"],
Cell[16889, 641, 61, 1, 27, "Input"],
Cell[16953, 644, 69, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[17059, 650, 145, 3, 29, "Subsection",
  Evaluatable->False],
Cell[17207, 655, 120, 6, 57, "Input"],
Cell[17330, 663, 110, 2, 27, "Input"],
Cell[17443, 667, 100, 2, 27, "Input"],
Cell[17546, 671, 52, 1, 27, "Input"],
Cell[17601, 674, 116, 5, 42, "Input"],
Cell[17720, 681, 116, 5, 42, "Input"],
Cell[17839, 688, 59, 1, 27, "Input"],
Cell[17901, 691, 59, 1, 27, "Input"],
Cell[17963, 694, 95, 2, 27, "Input"],
Cell[18061, 698, 59, 1, 27, "Input"],
Cell[18123, 701, 343, 6, 59, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18503, 712, 104, 3, 29, "Subsection",
  Evaluatable->False],
Cell[18610, 717, 320, 6, 107, "Input"],
Cell[18933, 725, 49, 1, 27, "Input"],
Cell[18985, 728, 50, 1, 27, "Input"],
Cell[19038, 731, 322, 6, 107, "Input"],
Cell[19363, 739, 53, 1, 27, "Input"],
Cell[19419, 742, 50, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19506, 748, 36, 0, 29, "Subsection"],
Cell[19545, 750, 136, 6, 57, "Input"],
Cell[19684, 758, 106, 2, 27, "Input"],
Cell[19793, 762, 87, 1, 27, "Input"],
Cell[19883, 765, 382, 7, 91, "Input"],
Cell[20268, 774, 103, 2, 31, "Input"]
}, Closed]],
Cell[20386, 779, 101, 3, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20512, 786, 66, 1, 45, "Subsection"],
Cell[20581, 789, 42, 1, 27, "Input"],
Cell[20626, 792, 94, 2, 27, "Input"],
Cell[20723, 796, 42, 1, 27, "Input"],
Cell[20768, 799, 141, 4, 27, "Input"],
Cell[20912, 805, 79, 2, 27, "Input"],
Cell[20994, 809, 92, 2, 27, "Input"],
Cell[21089, 813, 111, 2, 27, "Input"],
Cell[21203, 817, 158, 5, 27, "Input"],
Cell[21364, 824, 93, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[21494, 831, 106, 3, 29, "Subsection",
  Evaluatable->False],
Cell[21603, 836, 43, 1, 27, "Input"],
Cell[21649, 839, 87, 2, 27, "Input"],
Cell[21739, 843, 79, 2, 27, "Input"],
Cell[21821, 847, 84, 2, 27, "Input"],
Cell[21908, 851, 95, 2, 27, "Input"],
Cell[22006, 855, 103, 6, 57, "Input"],
Cell[22112, 863, 84, 2, 27, "Input"],
Cell[22199, 867, 71, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[22307, 874, 107, 3, 29, "Subsection",
  Evaluatable->False],
Cell[22417, 879, 51, 1, 27, "Input"],
Cell[22471, 882, 69, 1, 27, "Input"],
Cell[22543, 885, 51, 1, 27, "Input"],
Cell[22597, 888, 54, 1, 27, "Input"],
Cell[22654, 891, 53, 1, 27, "Input"],
Cell[22710, 894, 54, 1, 27, "Input"],
Cell[22767, 897, 51, 1, 27, "Input"]
}, Closed]],
Cell[22833, 901, 101, 3, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[22959, 908, 123, 3, 45, "Subsection",
  Evaluatable->False],
Cell[23085, 913, 167, 3, 59, "Input"],
Cell[23255, 918, 78, 1, 27, "Input"],
Cell[23336, 921, 180, 4, 59, "Input"],
Cell[23519, 927, 105, 2, 27, "Input"],
Cell[23627, 931, 62, 1, 31, "Input"],
Cell[23692, 934, 106, 2, 27, "Input"],
Cell[23801, 938, 126, 3, 27, "Input"],
Cell[23930, 943, 82, 1, 36, "Input"],
Cell[24015, 946, 131, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[24183, 954, 120, 3, 29, "Subsection",
  Evaluatable->False],
Cell[24306, 959, 85, 1, 29, "Input"],
Cell[24394, 962, 89, 1, 27, "Input"],
Cell[24486, 965, 89, 2, 27, "Input"],
Cell[24578, 969, 94, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[24709, 976, 135, 3, 29, "Subsection",
  Evaluatable->False],
Cell[24847, 981, 117, 3, 27, "Input"],
Cell[24967, 986, 85, 2, 27, "Input"],
Cell[25055, 990, 90, 2, 27, "Input"],
Cell[25148, 994, 97, 2, 27, "Input"],
Cell[25248, 998, 78, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[25363, 1004, 145, 3, 29, "Subsection",
  Evaluatable->False],
Cell[25511, 1009, 175, 3, 27, "Input"],
Cell[25689, 1014, 159, 3, 27, "Input"],
Cell[25851, 1019, 134, 3, 27, "Input"],
Cell[25988, 1024, 67, 1, 27, "Input",
  CellTags->"S5.37.1"],
Cell[26058, 1027, 322, 6, 59, "Input"],
Cell[26383, 1035, 134, 3, 27, "Input"],
Cell[26520, 1040, 210, 4, 27, "Input"]
}, Closed]],
Cell[26745, 1047, 104, 3, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[26874, 1054, 120, 3, 45, "Subsection",
  Evaluatable->False],
Cell[26997, 1059, 82, 2, 27, "Input"],
Cell[27082, 1063, 223, 5, 43, "Input"],
Cell[27308, 1070, 260, 4, 59, "Input"],
Cell[27571, 1076, 161, 3, 27, "Input"],
Cell[27735, 1081, 264, 4, 75, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[28036, 1090, 112, 3, 29, "Subsection",
  Evaluatable->False],
Cell[28151, 1095, 87, 2, 27, "Input"],
Cell[28241, 1099, 190, 10, 117, "Input",
  CellTags->"S5.25.1"],
Cell[28434, 1111, 505, 9, 107, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[28976, 1125, 116, 3, 29, "Subsection",
  Evaluatable->False],
Cell[29095, 1130, 57, 1, 27, "Input"],
Cell[29155, 1133, 96, 2, 27, "Input"],
Cell[29254, 1137, 203, 4, 43, "Input"],
Cell[29460, 1143, 99, 2, 27, "Input"],
Cell[29562, 1147, 288, 5, 75, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[29887, 1157, 168, 6, 29, "Subsection",
  Evaluatable->False],
Cell[30058, 1165, 293, 6, 75, "Input"],
Cell[30354, 1173, 77, 1, 27, "Input",
  CellTags->"S5.39.1"],
Cell[30434, 1176, 237, 4, 59, "Input"],
Cell[30674, 1182, 283, 4, 43, "Input"],
Cell[30960, 1188, 172, 5, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[31169, 1198, 102, 3, 60, "Section",
  Evaluatable->False],
Cell[31274, 1203, 123, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[31400, 1208, 66, 1, 42, "Subsubsection"],
Cell[31469, 1211, 70, 1, 42, "Subsubsection"],
Cell[31542, 1214, 81, 1, 42, "Subsubsection"],
Cell[31626, 1217, 96, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[31747, 1222, 210, 9, 42, "Subsubsection",
  Evaluatable->False],
Cell[31960, 1233, 96, 2, 27, "Input"]
}, Closed]],
Cell[32071, 1238, 327, 13, 28, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[32423, 1255, 75, 1, 42, "Subsubsection"],
Cell[32501, 1258, 107, 2, 27, "Input"]
}, Closed]],
Cell[32623, 1263, 81, 1, 28, "Subsubsection"],
Cell[32707, 1266, 90, 1, 42, "Subsubsection"],
Cell[32800, 1269, 246, 7, 42, "Subsubsection",
  Evaluatable->False],
Cell[33049, 1278, 179, 4, 42, "Subsubsection",
  Evaluatable->False],
Cell[33231, 1284, 179, 4, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[33435, 1292, 121, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[33559, 1297, 208, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[33804, 1306, 88, 1, 28, "Subsubsection"],
Cell[33895, 1309, 113, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[34045, 1316, 88, 1, 28, "Subsubsection"],
Cell[34136, 1319, 82, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[34255, 1325, 153, 4, 28, "Subsubsection",
  Evaluatable->False],
Cell[34411, 1331, 98, 2, 27, "Input"]
}, Closed]],
Cell[34524, 1336, 66, 1, 28, "Subsubsection"],
Cell[34593, 1339, 144, 4, 40, "Subsubsection",
  Evaluatable->False],
Cell[34740, 1345, 70, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[34835, 1350, 187, 6, 42, "Subsubsection"],
Cell[35025, 1358, 137, 3, 27, "Input"]
}, Closed]],
Cell[35177, 1364, 76, 1, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[35278, 1369, 73, 1, 42, "Subsubsection"],
Cell[35354, 1372, 84, 1, 27, "Input"]
}, Closed]],
Cell[35453, 1376, 80, 1, 28, "Subsubsection"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

