(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     68633,       2326]*)
(*NotebookOutlinePosition[     71421,       2391]*)
(*  CellTagsIndexPosition[     71348,       2385]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Legal Notice, Disclaimer, and Book Ordering Information:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "(* Legal Notice, Disclaimer, and Book Ordering Information:\n\nLast \
Modified: FIO June 8, 2002\n\n",
  StyleBox["Mathematica For Physics: 2nd Edition",
    FontColor->RGBColor[1, 0, 0]],
  "\n\nRobert L. Zimmerman and Fredrick I. Olness\n",
  "\nWebSite:  \n",
  StyleBox["  www.physics.smu.edu/~olness\n  darkwing.uoregon.edu/~phys600/\n\
\n",
    FontColor->RGBColor[1, 0, 0]],
  "MathSource Number: 0206-862",
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  "\nISBN 0-201-53796-6\nFor ordering information, call 1-800-282-0693\n\
Addison-Wesley Publishing Company\n",
  "\nCommunication with the authors:\nFredrick I. Olness:  \
olness@mail.physics.smu.edu\nRobert L. Zimmerman: bob@zim.uoregon.edu\n\n\
Copyright 2002, Addison-Wesley Publishing Company, Inc. The material in\nthis \
file may be distributed freely  so long as the content remains\nunchanged, \
and the copyright and  reference notices are included. The\npublisher grants \
permission for the noncommercial use of these programs\nand program segments. \
 All other uses require the prior written consent\nof the publisher.    \n\n\
All rights are reserved with regard to the  material in the\n\"Mathematica \
For Physics\" text, and may not be reproduced, stored in a\nretrieval system, \
or transmitted,  in any form or by any means,\nelectronic, mechanical, \
photocopying,  recording, or otherwise, without\nthe prior written permission \
 of the publisher. \n\nThe programs and applications presented in this book \
have been included\nfor  their instructional value. They have been tested \
with care but are\nnot  guaranteed for any particular purpose. The publisher \
does not\noffer any  warranties or representations, nor does it accept any\n\
liabilities with  respect to the programs or applications. \n\n *)\n"
}], "Input",
  Evaluatable->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell["3. Oscillating Systems", "Title",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  " Introduction ",
  StyleBox["  ",
    FontColor->RGBColor[1, 0, 0]]
}], "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Off[General::"\<spell\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Off[General::"\<spell1\>"];\)\)}], "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "3.1 Linear Oscillations  ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Overview of Linear Oscillations  ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Initialization of User-Defined Functions:", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "1. ",
  StyleBox["phasePlot",
    FontFamily->"Courier"],
  " for one-dimensional system  ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(phasePlot[q_, p_, tList_List, 
        opts___]\ \  := \[IndentingNewLine]ParametricPlot[\ {p, q}\  // 
          Evaluate, \[IndentingNewLine]tList, 
        opts, \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]PlotStyle -> {Hue[Random[]], 
            Thickness[ .01]}, \[IndentingNewLine]Axes \[Rule] 
          False, \[IndentingNewLine]PlotLabel \[Rule] "\<Phase Trajectory\>", \
\ \ \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {"\<p\>", "\<q\>"}\ \
]\)], "Input"],

Cell[BoxData[
    \(\(phasePlot[Sin[2\ \[Pi]\ t], D[Sin[2\ \[Pi]\ \ t], t], {t, 0, 3}, 
        GridLines \[Rule] Automatic]\ ;\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "2. ",
  StyleBox["timePhasePlot:",
    FontFamily->"Courier"],
  " Time behavior of phase plot for a one-dimensional system  "
}], "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(timePhasePlot[q_, p_, tList_List, 
        opts___] := \[IndentingNewLine]ParametricPlot3D[\ {p, q, 
            tList[\([1]\)], {\ Hue[ .8], Thickness[ .003]}}\  // 
          Evaluate, \[IndentingNewLine]tList, 
        opts, \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]PlotLabel \[Rule] "\<     Phase[t]\>", \
\[IndentingNewLine]AxesLabel \[Rule] {"\<p[t]\>", "\<q[t]\>", "\<t \>"}, \
\[IndentingNewLine]PlotPoints \[Rule] 
          300, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 1}]\)], "Input"],

Cell[BoxData[
    \(\(timePhasePlot[Sin[2\ \[Pi]\ t], 
        D[Sin[2\ \[Pi]\ \ t], t], {t, 0, 3}];\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "3. ",
  StyleBox["doublePlot:",
    FontFamily->"Courier"],
  " Combination of the phase plot and the time behavior of the phase plot"
}], "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(doublePlot[q_, p_, 
          tList_List] \
:= \[IndentingNewLine]Show[\[IndentingNewLine]GraphicsArray[\ {\ \
\[IndentingNewLine]phasePlot[q, p, tList, DisplayFunction -> Identity, 
                FrameTicks \[Rule] None]\ , 
              timePhasePlot[q, p, tList, DisplayFunction -> Identity, 
                Ticks \[Rule] 
                  None]\ }\ \[IndentingNewLine]]\ \
\[IndentingNewLine]];\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(doublePlot[Sin[2\ \[Pi]\ t], 
        D[Sin[2\ \[Pi]\ t], t], {t, 0, 3}];\)\(\ \)\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["4.  Protect Commands", "Subsubsection",
  Hyphenation->False],

Cell["Protect[ phasePlot,timePhasePlot,doublePlot];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 1: Linear Oscillator ",
  StyleBox["      ",
    FontColor->RGBColor[0, 1, 0]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq1", "=", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["x", "\[DoublePrime]",
                MultilineFunction->None], "[", "t", "]"}], 
            "+", \(\[Omega]0\^2\ \ x[t]\)}], "==", "0"}]}], " ", 
      ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"initial1", "=", 
        RowBox[{"{", 
          RowBox[{\(x[0] \[Equal] x0\), ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], "==", "v0"}]}], 
          "}"}]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(dSol1 = \ \(\(DSolve[\ {eq1\ , initial1} // Flatten, x[t], 
          t]\)\(//\)\(Flatten\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Needs["\<Graphics`Arrow`\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(?Graphics`Arrow`*\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(?Arrow\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(arrow = \ {\[IndentingNewLine]{Hue[0.2], 
            Arrow[{0, 0}, {0.5, 0.5}]}, \[IndentingNewLine]{Hue[0.4], 
            Arrow[{0, 0}, {2, 0}]}, \[IndentingNewLine]{Hue[0.6], 
            Arrow[{0, 0}, {0, 
                0.5}]}\[IndentingNewLine]};\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\(x[t] /. dSol1\) /. {x0 \[Rule] 0, \[Omega]0 \[Rule] 1, \ 
            v0 \[Rule] 1}, {t, \(-2\)\ \[Pi], 
          2\ \[Pi]}, \[IndentingNewLine]Epilog \[Rule] arrow];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(initial2 = {x[0] == 
            A\ Cos[\[Delta]], \(x'\)[
              0] == \(-A\)\ \[Omega]0\ Sin[\[Delta]]};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(dSol2 = \(DSolve[{eq1, initial2} // Flatten, x[t], t] // Flatten\)\  // 
        Simplify\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(lapTx = LaplaceTransform[eq1, t, s]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(lapSol\)\(=\)\(\(Solve[lapTx, 
          LaplaceTransform[x[t], t, s]]\)[\([1]\)]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(\(InverseLaplaceTransform[
        LaplaceTransform[x[t], t, s] /. lapSol, s, 
        t]\)\(//\)\(Apart\)\(\ \ \)\)\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 2: Series expansion Solution      ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(\(Clear["\<Global`*\>"]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(diffSeriesOne[eq_, z_, t_, initialx_, initialv_, order_]\  := \ 
      Module[\ {tempser, tempeq\ , \ tempvar, \ tempsol, 
          tempinit\ }, \[IndentingNewLine]tempser = \ 
          z -> Series[
              z, {t, 0, 
                order}]; \[IndentingNewLine]tempeq = \((\ \((eq[\([1]\)] - 
                    eq[\([2]\)])\)\  //. tempser)\) == 0\ ; 
        tempvar = \ \((Table[D[z, {t, j}], {j, 2, order + 2}] /. t -> 0)\) // 
            Flatten; \[IndentingNewLine]tempsol = 
          Solve[tempeq, \ tempvar] // 
            Flatten; \[IndentingNewLine]tempinit = \ {\(Head[z]\)[0] -> 
              initialx, \(Head[z]'\)[0] -> 
              initialv}; \[IndentingNewLine]\(\(z /. tempser\) /. tempsol\) /. 
          tempinit\ ]\ \)}], "Input"],

Cell[BoxData[
    \(\(Protect[diffSeriesOne\ ];\)\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a  ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(\(Clear["\<Global`*\>"]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(diffSeriesOne2[eq_, z_, t_, initialx_, initialv_, order_]\  := \ 
      Module[\ {\ }, \[IndentingNewLine]tempser = \ 
          z -> Series[
              z, {t, 0, 
                order}]; \[IndentingNewLine]tempeq = \((\ \((eq[\([1]\)] - 
                    eq[\([2]\)])\)\  //. tempser)\) == 0\ ; 
        tempvar = \ \((Table[D[z, {t, j}], {j, 2, order + 2}] /. t -> 0)\) // 
            Flatten; \[IndentingNewLine]tempsol = 
          Solve[tempeq, \ tempvar] // 
            Flatten; \[IndentingNewLine]tempinit = \ {\(Head[z]\)[0] -> 
              initialx, \(Head[z]'\)[0] -> 
              initialv}; \[IndentingNewLine]\(\(z /. tempser\) /. tempsol\) /. 
          tempinit\ ]\ \)}], "Input"],

Cell[BoxData[
    \(\(eq1 = \(y''\)[t] + \[Gamma]\ \(y'\)[t]^2 + \ w^2\ y[t] \[Equal] 
          a\ \(y'\)[t]^2\ \ y[t];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(diffSeriesOne2[eq1, y[t], t, \ \ y0, \ v0, 2]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(tempser\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(\(tempeq\)\(//\)\(Short[#, 3] &\)\(\ \)\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \ \ \)\(tempvar\)\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\ \ \ \)\(tempsol // Short[#, 7] &\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \ \ \ \)\(\(\(y[t] /. tempser\) /. tempsol\) /. 
      tempinit\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(diffSeriesOne[eq1, y[t], t, \ \ y0, \ v0, 2]\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq2", "=", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["x", "\[DoublePrime]",
                MultilineFunction->None], "[", "t", "]"}], 
            "+", \(\[Omega]0\^2\ \ x[t]\)}], "==", "0"}]}], " ", 
      ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(approxsol = \(\(diffSeriesOne[eq2, x[t], t, \ \ x0, \ v0\ , 
          9]\)\(//\)\(Collect[#1, {x0, v0}] &\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(termX[n_]\), "=", " ", 
        FormBox[\(\(\((\(-1\))\)\^n\ \((t\ \[Omega]0)\)\^\(2\ n\)\)\/\(\((2\ \
n)\)!\)\),
          "TraditionalForm"]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(termV[n_]\), "=", " ", 
        FormBox[\(\(\((\(-1\))\)\^n\ \((t\ \[Omega]0)\)\^\(2\ n + 1\)\)\/\(\
\[Omega]0\ \(\((2\ n + 1)\)!\)\)\),
          "TraditionalForm"]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(finitesum = 
        Sum[\((x0\ termX[n] + v0\ termV[n])\), {n, 0, 
            4}];\)\(\ \ \ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(finitesum\  == approxsol\)\(//\)\(Simplify\)\(\ \)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[BoxData[
    \(exactSum = \(Sum[\((x0\ termX[n] + v0\ termV[n])\), {n, 0, Infinity}] // 
          PowerExpand\)\  // Apart\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 3: Potential and Phase Diagrams for the Linear Oscillator ",
  StyleBox["  ",
    FontColor->RGBColor[0, 1, 0]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Force", "=", 
        RowBox[{"m", " ", 
          RowBox[{
            SuperscriptBox["x", "\[DoublePrime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(Spring = \ \ \(-k\)\ x[
            t];\), "\[IndentingNewLine]", \(eq1 = \ 
      Force\  == \ Spring\)}], "Input"],

Cell[BoxData[
    RowBox[{"energy", "=", 
      RowBox[{"Integrate", "[", " ", 
        RowBox[{
          RowBox[{\(\(x'\)[t]\), 
            RowBox[{"(", " ", 
              RowBox[{
                RowBox[{"m", " ", 
                  RowBox[{
                    SuperscriptBox["x", "\[DoublePrime]",
                      MultilineFunction->None], "[", "t", "]"}]}], " ", 
                "+", \(k\ x[t]\)}], ")"}]}], " ", ",", "t"}], "]"}], 
      " "}]], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(T = \ Integrate[\ \(x'\)[t] Force\ , t];\)\), "\n", 
    \(\(V = \(-Integrate[\ \(x'\)[t] Spring\ , t]\);\)\), "\n", 
    \({T, V}\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(energy = T + V\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Needs["\<Graphics`FilledPlot`\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(?FilledPlot\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(FilledPlot[
        V /. {x[t] \[Rule] x, k \[Rule] 1, m \[Rule] 1}, {x, \(-1\), 
          1}, \[IndentingNewLine]PlotStyle -> {Thickness[ .02]\ }, \
\[IndentingNewLine]Fills -> {Hue[ .8]}, \[IndentingNewLine]Frame \[Rule] 
          True\ , \[IndentingNewLine]RotateLabel \[Rule] 
          False\ , \[IndentingNewLine]PlotLabel \[Rule] "\<V\>", \
\[IndentingNewLine]FrameLabel \[Rule] {"\<x-axis\>", "\<Potential\>"}\ \ \ ];\
\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c  ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"values", "=", 
          RowBox[{"{", 
            
            RowBox[{\(m \[Rule] 1\), ",", \(k \[Rule] 1\), 
              ",", \(x[t] \[Rule] x\), ",", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
                "v"}]}], "}"}]}], ";"}], " "}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = 
        ContourPlot[
          Evaluate[energy /. values], {x, \(-1\), 1}, {v, \(-1\), 
            1}, \[IndentingNewLine]ColorFunction -> 
            Hue, \ \ \[IndentingNewLine]Contours -> 
            30, \[IndentingNewLine]PlotPoints -> 
            30, \[IndentingNewLine]ContourStyle\  -> {\ 
              Thickness[0.006]}, \[IndentingNewLine]Axes \[Rule] 
            True, \ \[IndentingNewLine]AxesLabel \[Rule] {"\<x[t]\>", "\<v[t]\
\>"}];\)\)], "Input"],

Cell[BoxData[
    \(Needs["\<Graphics`Graphics3D`\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(?ShadowPlot3D\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(ShadowPlot3D[
        energy /. values, {x, \(-1\), 1}, {v, \(-1\), 
          1}, \[IndentingNewLine]PlotLabel \[Rule] "\<Energy Surface\>", \
\[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]AxesLabel \[Rule] {"\<x[t]\>", "\<v[t]\>", \
"\<energy\>"}, \[IndentingNewLine]ShadowPosition \[Rule] \ 1];\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 4: Damped Linear Oscillator  ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq1", "=", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["x", "\[DoublePrime]",
                MultilineFunction->None], "[", "t", "]"}], "+", 
            RowBox[{"\[Gamma]", " ", 
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            " ", \(\[Omega]0^2\ \ x[t]\)}], "==", "0"}]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"xsol", "=", 
      RowBox[{
        RowBox[{\(x[t]\), "/.", 
          RowBox[{
            RowBox[{"DSolve", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"eq1", ",", \(x[0] == x0\), ",", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox["x", "\[Prime]",
                          MultilineFunction->None], "[", "0", "]"}], "==", 
                      "v0"}]}], "}"}], ",", \(x[t]\), ",", "t"}], "]"}], 
            "[", \([1]\), "]"}]}], " ", "//", "Simplify"}]}]], "Input"],

Cell[BoxData[
    RowBox[{"\[Omega]Rule", "=", " ", 
      RowBox[{
        RowBox[{"Solve", "[", 
          RowBox[{
            RowBox[{
              FormBox[\(\@\(\[Omega]0\^2 - \[Gamma]\^2\/4\)\),
                "TraditionalForm"], "==", "  ", "\[Omega]"}], ",", 
            "\[Omega]0"}], "]"}], "[", \([2]\), "]"}]}]], "Input"],

Cell[BoxData[
    \(xsol = \(xsol\  /. \[Omega]Rule // ExpToTrig\)\  // 
        FullSimplify\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(\(xsol /. \[Gamma] -> 0 // PowerExpand\) // 
      ExpandAll\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \ \)\(Limit[xsol, \[Gamma] -> 2  \[Omega]0]\)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {x0 \[Rule] 1, \ \[Omega]0 \[Rule] 1, 
          v0 -> 0, \[Omega] -> \@\(\[Omega]0\^2 - \[Gamma]\^2\/4\)}\ ;\)\)], \
"Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(pt[\[Gamma]1_ /; 
          0 <= \[Gamma]1 < 
            2]\  := \[IndentingNewLine]Plot[\(xsol //. 
              values\) /. {\[Gamma] -> \[Gamma]1\ } // 
          Evaluate, \[IndentingNewLine]{t, 0, 
          15}\ , \[IndentingNewLine]PlotStyle -> {Hue[Random[]], 
            Thickness[ .03]}, \[IndentingNewLine]PlotRange -> 
          All, \[IndentingNewLine]DisplayFunction -> Identity\ ]\)], "Input"],

Cell[BoxData[
    \(\(Show[\[IndentingNewLine]GraphicsArray[\[IndentingNewLine]{{pt[0], 
              pt[ .2], \ pt[ .4]}, \[IndentingNewLine]{\ pt[ .8], pt[1.4], 
              pt[1.9]}}\[IndentingNewLine]]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\ \((xsol //. values)\) /. \[Gamma] -> 
              Range[2.0001, 6.0001\ , 0.4]\  // 
          Evaluate, \[IndentingNewLine]{t, 0, 
          15}\ , \[IndentingNewLine]PlotStyle -> 
            Table[\ Hue[i], {i, 0, 1, 1/12}] // 
          Evaluate\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \({x, 
        v} = \ \({xsol, D[xsol, t]} //. 
          values\) /. {\[Gamma] \[Rule] 0.2}\)], "Input"],

Cell[BoxData[
    \(\(doublePlot[x, v, {t, 0.01, 30}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(values2 = {\[Gamma] \[Rule] 0.1, \[Omega]0 \[Rule] 1, x0 \[Rule] 1, 
          v0 \[Rule] 
            0, \[Omega] -> \@\(\[Omega]0\^2 - \[Gamma]\^2\/4\)};\)\)], "Input",\

  Hyphenation->False],

Cell[BoxData[
    \(\(traj\  = 
        ParametricPlot[{\ xsol, D[xsol, t]\ } //. values2\  // 
            Evaluate, \[IndentingNewLine]{t, 0, 
            60}, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[ .008], 
              GrayLevel[0]}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField`\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(\(Clear[x, v];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\ \(pt1 = 
        PlotVectorField[{\ v, \ \(-0.5\)\ v\ \  - \ x\ }\  // 
            Evaluate, \[IndentingNewLine]{x, \(-1\), 1}, {v, \(-1\)\ , 
            1}, \[IndentingNewLine]DefaultColor \[Rule] 
            Hue[0.6], \[IndentingNewLine]PlotPoints \[Rule] 
            20, \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]Axes \[Rule] 
            Automatic, \[IndentingNewLine]AxesOrigin \[Rule] {0, 
              0}, \[IndentingNewLine]ScaleFunction \[Rule] \((1 &)\), \
\[IndentingNewLine]Epilog \[Rule] traj[\([1]\)]];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part e", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(lapTx = LaplaceTransform[eq1, t, s]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(lapSol = \(\(\(Solve[lapTx, 
            LaplaceTransform[x[t], t, 
              s]]\)[\([1]\)]\)\(//\)\(Simplify\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(sol = \ 
      InverseLaplaceTransform[LaplaceTransform[x[t], t, s] /. lapSol, s, 
        t]\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 5: Damped Harmonic Oscillator and Driving Forces  ",
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]]
}], "Subsection",
  Hyphenation->False],

Cell["Remarks and outline  ", "Subsubsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq1", "=", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["x", "\[DoublePrime]",
                MultilineFunction->None], "[", "t", "]"}], "+", 
            RowBox[{"\[Gamma]", "  ", 
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], 
            "+", \(\[Omega]0\^2\ \ x[t]\)}], 
          "==", \(Q0\ \ Cos[\[Omega]d\ t]\)}]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq2 = \(x[t] /. DSolve[eq1, x[t], t] // First\) // Simplify\)], "Input"],

Cell[BoxData[
    \(eq3 = eq2 /. Q0 -> 0\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq4 = \((eq2 - eq3)\) // FullSimplify\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"cRule", "=", 
      RowBox[{
        RowBox[{"Solve", "[", 
          RowBox[{
            FormBox[
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    SubscriptBox[
                      TagBox["c",
                        C], "1"], 
                    "==", \(1\/2\ \((A0 + \[ImaginaryI]\ B0)\)\)}], ",", 
                  RowBox[{
                    SubscriptBox[
                      TagBox["c",
                        C], "2"], 
                    "==", \(1\/2\ \((A0 - \[ImaginaryI]\ B0)\)\)}]}], "}"}],
              "TraditionalForm"], ",", \({C[1], C[2]}\)}], "]"}], 
        "[", \([1]\), "]"}]}]], "Input"],

Cell[BoxData[
    RowBox[{"\[Omega]Rule", "=", " ", 
      RowBox[{
        RowBox[{"Solve", "[", 
          RowBox[{
            RowBox[{
              FormBox[\(\@\(\[Omega]0\^2 - \[Gamma]\^2\/4\)\),
                "TraditionalForm"], "==", "  ", "\[Omega]"}], ",", 
            "\[Omega]0"}], "]"}], "[", \([2]\), "]"}]}]], "Input"],

Cell[BoxData[
    \(homogSol = \(\(\(eq3\  //. cRule\)\  /. \[Omega]Rule\  // 
            ComplexExpand\) // Simplify\)\  // PowerExpand\)], "Input"],

Cell[BoxData[
    \(eq5 = \ A\ Cos[\[Omega]d\ t + \[Phi]] // TrigExpand\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq6 = eq4 - eq5 == 0\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(eq7\)\(=\)\({\[IndentingNewLine]eq6 /. {Sin[_\ t] -> 0, 
            Cos[_\ t] -> 1}, \[IndentingNewLine]eq6 /. {Cos[_\ t] -> 0, 
            Sin[_\ t] -> 1}}\)\(\ \ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq8 = \ \(\(\(Solve[eq7, {A, \[Phi]}\ ]\)[\([4]\)] // 
          Simplify\)\(//\)\(PowerExpand\)\(\ \ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"rule", "=", 
        FormBox[\({\(cos\^\(-1\)\)(
                x_) \[Rule] \(tan\^\(-1\)\)(\@\(1 - x\^2\)\/x)}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(solA\[Phi] = \ \(eq8 /. rule // \ Simplify\)\  // 
        PowerExpand\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(partSol = \ \ A\ Cos[\[Omega]d\ t + \[Phi]] /. solA\[Phi]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(genSol = \(\(partSol\)\(+\)\(homogSol\)\(\ \)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"values", "=", 
        FormBox[\({A \[Rule] 3, Q0 \[Rule] 1, \[Omega]d \[Rule] 1, 
            A0 \[Rule] 0, 
            B0 \[Rule] 
              1, \[Omega] \[Rule] \@\(\[Omega]0\^2 - \[Gamma]\^2\/4\)}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(Plot3D[\(genSol //. values\) //. {\[Gamma] \[Rule] 0.1} // 
          Evaluate, \[IndentingNewLine]{t, 0, 30}, {\[Omega]0, 0.5, 
          1.5}, \[IndentingNewLine]PlotPoints \[Rule] 
          40, \[IndentingNewLine]AxesLabel \[Rule] {"\<Time\>", \
"\<\[Omega]0\>", "\<x[t]\>"}, \[IndentingNewLine]FaceGrids \[Rule] {{0, 1, 
              0}, {0, \(-1\), 0}}, \[IndentingNewLine]ViewPoint \[Rule] {1, 
            0.4, 0.6}];\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(Plot3D[\ \(A /. solA\[Phi]\) /. values\  // 
          Evaluate, \[IndentingNewLine]{\[Gamma], \  .001,  .5}, {\[Omega]0,  \
.5, 1.5}, \[IndentingNewLine]PlotPoints \[Rule] 
          25, \[IndentingNewLine]PlotRange \[Rule] {0, 
            15}, \[IndentingNewLine]AxesLabel \[Rule] {"\<\[Gamma]\>", "\<\
\[Omega]0\>", "\<Amplitude\>"}, \[IndentingNewLine]FaceGrids \[Rule] \
{{\(-1\), 0, 0}}, \[IndentingNewLine]ViewPoint \[Rule] {\  .5, \ 1, 
            0.4}\ \ ];\)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt[name_, 
          opts___] := \[IndentingNewLine]Plot[\(name //. 
                values\) //. {\[Gamma] \[Rule] 0.1, \[Omega]0 \[Rule] 2}\  // 
            Evaluate, \[IndentingNewLine]{t, 0, 
            80}, \[IndentingNewLine]opts, \ \[IndentingNewLine]Ticks \[Rule] 
            None, \[IndentingNewLine]DisplayFunction -> 
            Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(\(Show[\[IndentingNewLine]Graphics[{\[IndentingNewLine]Rectangle[{0, \
\ \ 0}, {\ 1, \ \ 1}, \[IndentingNewLine]pt[genSol, 
                PlotStyle -> Hue[0.8], \ \ Ticks \[Rule] 
                  Automatic\ ]], \[IndentingNewLine]Rectangle[{0.6, 0.7}, {1, 
                1}, \[IndentingNewLine]pt[partSol, 
                PlotStyle -> Hue[0.4], \ \ Background \[Rule] 
                  GrayLevel[0.9]]], \[IndentingNewLine]Rectangle[{0.6, 
                0}, {1, 0.3}, \[IndentingNewLine]pt[homogSol, 
                PlotStyle -> Hue[0.8], 
                Background \[Rule] 
                  GrayLevel[
                    0.9]]]\[IndentingNewLine]}]\[IndentingNewLine]];\)\(\ \
\)\)\)], "Input"],

Cell[BoxData[
    \(\(?Rectangle\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(q = \(genSol //. 
            values\) //. {\[Gamma] \[Rule] 0.1, \[Omega]0 \[Rule] 
              2};\)\), "\n", 
    \(\(p = D[q, t];\)\), "\n", 
    \(\(doublePlot[q, p, {t, 0, 80}\ ];\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(phasePlot[q, p, {t, 200, 250}, 
        AspectRatio \[Rule] Automatic];\)\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[TextData[{
  "3.2 Small Oscillations ",
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]]
}], "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Overview of  Small Oscillations and Normal Modes  ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Initialization of User-Defined Funtions for Small Oscillations and \
Normal Modes  \
\>", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "1 Eigenvalues and eigenvectors for small oscillating systems ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(smallOsc[T_, V_, coord_List, equlib_List, 
        t_:  t] := \[IndentingNewLine]Module[{q, p, dim, equlibRule, Vij, 
          Tij, matrix, \[Omega]2Sol, freq, vector, eqs, 
          vSol}, \[IndentingNewLine]q = coord; \[IndentingNewLine]p = 
          D[coord, t]; 
        dim = Length[q]; \[IndentingNewLine]equlibRule = 
          Thread[coord \[Rule] equlib]; \[IndentingNewLine]Vij = 
          Outer[D[V, #1, #2] &, q, q\ ]; \[IndentingNewLine]Tij = 
          Outer[D[T, #1, #2] &, \ p, p\ ]; \[IndentingNewLine]matrix = 
          Vij - \[Omega]2\ Tij /. 
            equlibRule; \[IndentingNewLine]\[Omega]2Sol = 
          Simplify[
            Solve[Det[matrix] == 
                0, \[Omega]2]]; \[IndentingNewLine]freq = \[Omega]2 /. \
\[Omega]2Sol; 
        vector = Array[a, dim]; \[IndentingNewLine]eqs = 
          Simplify[
            ExpandAll[
              Thread[0 == matrix . vector]]]; \[IndentingNewLine]vSol = 
          Table[\[IndentingNewLine]\(Solve[
                Join[eqs /. \[Omega]2Sol[\([i]\)], {vector . vector == 
                      1}]\[IndentingNewLine], vector]\)[\([2]\)], {i, 1, 
              dim}]; \[IndentingNewLine]{freq, vSol}\ ]\)], "Input"],

Cell["Protect[smallOsc ];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        FormBox[
          RowBox[{
            RowBox[{\(1\/2\), " ", "m", " ", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], "2"]}], "+", 
            RowBox[{\(1\/2\), " ", "m", " ", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], "2"]}]}],
          "TraditionalForm"]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"V", "=", 
        FormBox[\(1\/2\ k1\ \((q2(t) - q1(t))\)\^2\),
          "TraditionalForm"]}], ";"}]}], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(smallOsc[T, V, {q1[t], q2[t]}, {0, 0}, t]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 1: Two Coupled Oscillators along a Line  ",
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", " ", 
        FormBox[\(1\/2\ m\ \(x[1]'\)[t]\^2 + 1\/2\ m\ \(x[2]'\)[t]\^2\),
          "TraditionalForm"]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"V", "=", " ", 
        FormBox[\(1\/2\ k2\ \(x[1]\)[t]\^2 + 1\/2\ k2\ \(x[2]\)[t]\^2 + 
            1\/2\ k1\ \((\(x[2]\)[t] - \(x[1]\)[t])\)\^2\),
          "TraditionalForm"]}], ";"}]}], "Input"],

Cell[BoxData[{
    \(\(q = {\(x[1]\)[t], \(x[2]\)[t]};\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(p = D[q, t];\)\)}], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Tij = Outer[D[T, #1, #2] &, p, p]\), "\n", 
    \(Vij = Outer[D[V, #1, #2] &, q, q]\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\((matrix = 
          Vij - \[Omega]2\ Tij)\)\(//\)\(MatrixForm\)\(\ \)\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\[Omega]2Sol = Simplify[Solve[Det[matrix] == 0, \[Omega]2]]\)], "Input",\

  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(vector = Array[a, 2];\)\), "\n", 
    \(eq = Thread[0 == matrix . vector]\)}], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1 = Simplify[ExpandAll[eq /. \[Omega]2Sol[\([1]\)]]]\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(eqNorm = {vector . vector == 1};\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ev1rule = \(Solve[Join[eq1, eqNorm], vector]\)[\([2]\)]\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq2 = Simplify[ExpandAll[eq /. \[Omega]2Sol[\([2]\)]]]\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ev2rule = \(Solve[Join[eq2, eqNorm], vector]\)[\([2]\)]\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = Thread[0 == matrix . vector]\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\((sol = \ \(Reduce[
              Flatten[{eq3, eqNorm\ }], {\[Omega]2, a[1], a[2]}]\)[\([{8, 
                10}]\)])\)\(//\)\(ColumnForm\)\(\ \)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(eq4 = smallOsc[T, V, {\(x[1]\)[t], \(x[2]\)[t]}, {0, 0}, t]\)], "Input",\

  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(eigenmatrix = vector //. {ev1rule, ev2rule}\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(xRule = \({x1[t], x2[t]} \[Rule] 
            Transpose[eigenmatrix] . {c1\ Cos[\[Omega]1\ t + \[Phi]1], 
                c2\ Cos[\[Omega]2\ t + \[Phi]2]} // Thread\)\  // 
        Simplify\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(freqrule = \ 
      Thread[{\[Omega]1, \[Omega]2} \[Rule] \((Sqrt[\[Omega]2] /. \
\[Omega]2Sol)\)]\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values = {k1 \[Rule] 1, k2 \[Rule] 1, 
          m \[Rule] 1, \[Phi]1 \[Rule] 0, \[Phi]2 \[Rule] 0};\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(allRules = Join[xRule, freqrule, values];\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(pt1a = 
        Plot[\({x1[t] + 1, x2[t] - 1} //. allRules\) //. {c1 \[Rule] 1, 
                c2 \[Rule] 0}\  // Evaluate, \[IndentingNewLine]{t, 0, 
            20}, \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[0.010], 
                Hue[ .6]}, {Thickness[0.005], 
                Hue[ .9]}}\ \[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(pt1b = 
        ParametricPlot[\({x1[t], x2[t]} //. allRules\) //. {c1 \[Rule] 1, 
                c2 \[Rule] 0}\  // Evaluate, \[IndentingNewLine]{t, 0, 
            20}, \[IndentingNewLine]AxesLabel \[Rule] {x1, x2}];\)\)], "Input"],

Cell[BoxData[
    \(\(pt2a = 
        Plot[\({x1[t] + 1, x2[t] - 1} //. allRules\) //. {c1 \[Rule] 0, 
                c2 \[Rule] 1}\  // Evaluate, \[IndentingNewLine]{t, 0, 
            20}, \ \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[0.010], 
                Hue[ .6]}, {Thickness[0.005], 
                Hue[ .9]}}, \[IndentingNewLine]DisplayFunction -> 
            Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(pt2b = 
        ParametricPlot[\({x1[t], x2[t]} //. allRules\) //. {c1 \[Rule] 0, 
                c2 \[Rule] 1}\  // Evaluate, \[IndentingNewLine]{t, 0, 
            20}, \[IndentingNewLine]DisplayFunction -> 
            Identity]\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[{pt2a, pt2b}]];\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(pt3a = 
        Plot[\({x1[t] + 1, x2[t] - 1} //. allRules\) //. {c1 \[Rule] 1, 
                c2 \[Rule] 1}\  // Evaluate, \[IndentingNewLine]{t, 0, 
            20}, \ \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[0.010], 
                Hue[ .6]}, {Thickness[0.005], Hue[ .9]}}\ ];\)\)], "Input"],

Cell[BoxData[
    \(\(pt3b = 
        ParametricPlot[\({x1[t], x2[t]} //. allRules\) //. {c1 \[Rule] 1, 
                c2 \[Rule] 1}\  // Evaluate, {t, 0, 50}\ ];\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 2: Three Coupled Oscillators along a Line  ",
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{
          RowBox[{\(1\/2\), " ", "m", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox[\(x[1]\), "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox[\(x[3]\), "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}], 
              ")"}]}], "+", 
          RowBox[{\(1\/2\), " ", "M", " ", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox[\(x[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}], " ", 
      ";", "\n", \(V = 
        1\/2\ k\ \((\((\(x[2]\)[t] - \(x[1]\)[t])\)\^2 + \((\(x[3]\)[t] - \
\(x[2]\)[t])\)\^2)\)\), " ", ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(solution\)\(=\)\(smallOsc[T, 
        V, {\(x[1]\)[t], \(x[2]\)[t], \(x[3]\)[t]}, {0, 0, 0}, 
        t]\)\(\ \)\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(eigenmatrix = \(\(Array[a, 
          3]\)\(/.\)\(solution[\([2]\)]\)\(\ \)\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(xRule = {x1[t], x2[t], x3[t]} \[Rule] 
          Transpose[eigenmatrix] . {c1\ t + \[Phi]1, 
              c2\ Cos[\[Omega]2\ t + \[Phi]2], 
              c3\ Cos[\[Omega]3\ t + \[Phi]3]}\  // Thread\)], "Input"],

Cell[BoxData[
    \(freqrule = {\[Omega]1, \[Omega]2, \[Omega]3} \[Rule] \
\@solution[\([1]\)]\  // Thread\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values = {k \[Rule] 1, m \[Rule] 1, 
          M \[Rule] 3, \[Phi]1 \[Rule] 0, \[Phi]2 \[Rule] 0, \[Phi]3 \[Rule] 
            0};\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(allRules = Join[xRule, freqrule, values];\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(xPlot[C1_, C2_, C3_] := 
        Plot[\({x1[t] + 2, x2[t], x3[t] - 2} //. 
                allRules\) //. {c1 \[Rule] C1, c2 \[Rule] C2, 
                c3 \[Rule] C3}\  // Evaluate, \[IndentingNewLine]{t, 0, 
            20}, \[IndentingNewLine]PlotStyle \[Rule] \
{\[IndentingNewLine]{Thickness[0.010], 
                Hue[ .3]}, \[IndentingNewLine]{Thickness[0.009], 
                Hue[ .6]}, \[IndentingNewLine]{Thickness[0.007], 
                Hue[ .9]}}, \[IndentingNewLine]AxesLabel \[Rule] {t\ , 
              x}, \[IndentingNewLine]DisplayFunction -> 
            Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(xLPlot[C1_, C2_, C3_, opts___] := 
        ParametricPlot3D[\({x1[t], x2[t], x3[t]} //. 
                allRules\) //. {c1 \[Rule] C1, c2 \[Rule] C2, 
                c3 \[Rule] C3}\  // Evaluate, \[IndentingNewLine]{t, 0, 
            20}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
              1}, \[IndentingNewLine]AxesLabel \[Rule] {x1, x2, 
              x3}, \[IndentingNewLine]opts, \
\[IndentingNewLine]DisplayFunction -> Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xPlot[1, 0, 0], \ 
            xLPlot[1, 0, 0\ \ , Ticks \[Rule] None\ ]}]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xPlot[0, 1, 0], \ 
            xLPlot[0, 1, 0\ , Ticks \[Rule] None, 
              ViewPoint \[Rule] {1, 1, 
                  1}]}\[IndentingNewLine]]\[IndentingNewLine]];\)\)], "Input",\

  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xPlot[0, 0, 1], 
            xLPlot[0, 0, 1\ , Ticks \[Rule] None\ ]}]];\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Show[\ \ xPlot[0, 1, 1]\ , 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Show[
        xLPlot[0, 1, 1, 
          ViewPoint \[Rule] {1\ , 1, 
              1\ }], \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(number = 1\ \ \  (*\ 
        for\ more\ frames\ make\ number\ larger\ *) ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(Do[
        ListPlot[\[IndentingNewLine]\({{x1[t] - 2, 0}, {x2[t], 
                    0}, {x3[t] + 2, 0}} //. 
                allRules\)\[IndentingNewLine] //. {c1 \[Rule] 0, 
                c2 \[Rule] 1, c3 \[Rule] 1}\ \[IndentingNewLine] // 
            Evaluate, \[IndentingNewLine]PlotStyle \[Rule] {PointSize[
                0.05]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-4\), 
                4}, {\(-1\), 1}}], \[IndentingNewLine]{t, 0, 1 - 1/number, \ 
          1/number}];\)\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 3: Three Coupled Oscillators along a Circle  ",
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), "    ", \(r^2\), 
          RowBox[{"(", " ", 
            RowBox[{
              RowBox[{"m", "   ", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox[\(\[Theta][1]\), "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
              
              RowBox[{"m", "     ", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox[\(\[Theta][2]\), "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
              
              RowBox[{"m1", "    ", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox[\(\[Theta][3]\), "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
            ")"}]}]}], " ", ";", 
      "\n", \(V = 
        1\/2\ k\ \ r^2\ \((\((\(\[Theta][2]\)[t] - \(\[Theta][1]\)[t])\)\^2 + \
\ \ \((\(\[Theta][3]\)[t] - \(\[Theta][2]\)[t])\)\^2\  + \ \ \((\(\[Theta][1]\
\)[t] - \(\[Theta][3]\)[t])\)\^2\ )\)\), ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = \(smallOsc[T, 
            V, {\(\[Theta][1]\)[t], \(\[Theta][2]\)[t], \(\[Theta][3]\)[
                t]}, {0, 0, 0}, t]\  // Simplify\) // PowerExpand\)], "Input",\

  Hyphenation->False],

Cell[BoxData[
    \(solution = Limit[\ eq1, m1 -> m\ \ ] // PowerExpand\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b  ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(eigenmatrix = Array[a, 3] /. solution[\([2]\)]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(solrule = {\[Theta]1[t], \[Theta]2[t], \[Theta]3[t]} \[Rule] 
            Transpose[eigenmatrix] . {c1\ t + phase1, 
                c2\ Cos[freq2\ t + phase2], c3\ Cos[freq3\ t + phase3]}\  // 
          Thread;\)\)], "Input"],

Cell[BoxData[
    \(freqrule = \ {freq1, freq2, freq3} \[Rule] \ Sqrt[solution[\([1]\)]]\  // 
        Thread\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(valuerule = {k \[Rule] 1, m \[Rule] 1\ , phase1 \[Rule] 0, 
          phase2 \[Rule] 0, phase3 \[Rule] 0}\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(solrule\)], "Input"],

Cell[BoxData[
    \(\(xPlot[C1_, C2_, 
          C3_] := \[IndentingNewLine]Plot[\(\(\({\[Theta]1[t] + 2, \[Theta]2[
                        t], \[Theta]3[t] - 2}\  /. solrule\) /. freqrule\) //. 
                valuerule\) //. {c1 \[Rule] C1, c2 \[Rule] C2, 
                c3 \[Rule] C3}\  // Evaluate, \[IndentingNewLine]{t, 0, 
            20}, \[IndentingNewLine]PlotStyle \[Rule] \
{\[IndentingNewLine]{Thickness[0.012]}, \[IndentingNewLine]{Thickness[
                  0.008]}, \[IndentingNewLine]{Thickness[
                  0.004]}}, \[IndentingNewLine]DisplayFunction -> 
            Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{\ xPlot[0, 1, 0], xPlot[0, 0, 1]\ }]];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 4:  Double Pendulum  ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(x1 = L1\ Sin[\[Theta]1[#]\ ] &;\)\), "\n", 
    \(\(y1 = L1\ Cos[\[Theta]1[#]\ ] &;\)\), "\n", 
    \(\(x2 = x1[#] + L2\ Sin[\[Theta]2[#]] &;\)\), "\n", 
    \(\(y2 = y1[#] + L2\ Cos[\[Theta]2[#]] &\ ;\)\)}], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(L1 = \(L2 = len\);\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(T1 = 1/2\ \ \ m1 \((\ \(x1'\)[t]^2 + \(y1'\)[t]^2)\);\)\), "\n", 
    \(\(T2 = 1/2\ \ \ m2 \((\ \(x2'\)[t]^2 + \(y2'\)[t]^2)\)\t;\)\ \), "\n", 
    \(\(V1 = \(-\ m1\)\ g\ y1[t];\)\), "\n", 
    \(\(V2 = \(-\ m2\)\ g\ y2[t];\)\), "\n", 
    \(\(T = T1 + T2;\)\), "\n", 
    \(\(V = V1 + V2;\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(solution\)\(=\)\(smallOsc[T, 
        V, {\[Theta]1[t], \[Theta]2[t]}, {0, 0}, t]\)\(\ \)\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eigenmatrix = Array[a, 2] //. solution[\([2]\)]\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(thetaRule = \({\[Theta]1[t], \[Theta]2[t]} \[Rule] 
            Transpose[eigenmatrix] . {c1\ Cos[\[Omega]1\ t + \[Phi]1], 
                c2\ Cos[\[Omega]2\ t + \[Phi]2]}\  // Thread\)\  // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(freqrule = {\[Omega]1, \[Omega]2} \[Rule] Sqrt[solution[\([1]\)]]\  // 
        Thread\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {m1 \[Rule] 3, m2 \[Rule] 1, len \[Rule] 1, 
          g \[Rule] 1, \[Phi]1 \[Rule] 0, \[Phi]2 \[Rule] 0};\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(allRules = Join[thetaRule, values, freqrule]\ ;\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(line[c1_, c2_] = 
        Line[{{0, 0}, {x1[t], \(-y1[t]\)}, {x2[t], \(-y2[t]\)}}] //. 
          allRules;\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Show[Graphics[Table[N[line[1, 0]], {t, 0, 4, 0.1}]]];\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Show[Graphics[Table[N[line[0, 1]], {t, 0, 2.5, 0.2}]]];\)\)], "Input",\

  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Show[
        Graphics[Table[N[line[0.5, 0.5]], {t, 0, 6, 0.2}]]];\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell["\<\
frames = 1 ; 
Do[Show[Graphics[N[line[0.5, 0.5]], PlotRange -> {{-2, 2}, {0, -2}}]], {t, 1, \
25, 25/frames}]; \
\>", "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 5:  Understanding the User-defined procedure smallOsc[]",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(smallOsc2[T_, V_, coord_List, equlib_List, 
        t_:  t] := \[IndentingNewLine]Module[{}, \[IndentingNewLine]q = 
          coord; \[IndentingNewLine]p = D[coord, t]; 
        dim = Length[q]; \[IndentingNewLine]equlibRule = 
          Thread[coord \[Rule] equlib]; \[IndentingNewLine]Vij = 
          Outer[D[V, #1, #2] &, q, q\ ]; \[IndentingNewLine]Tij = 
          Outer[D[T, #1, #2] &, \ p, p\ ]; \[IndentingNewLine]matrix = 
          Vij - \[Omega]2\ Tij /. 
            equlibRule; \[IndentingNewLine]\[Omega]2Sol = 
          Simplify[
            Solve[Det[matrix] == 
                0, \[Omega]2]]; \[IndentingNewLine]freq = \[Omega]2 /. \
\[Omega]2Sol; 
        vector = Array[a, dim]; \[IndentingNewLine]eqs = 
          Simplify[
            ExpandAll[
              Thread[0 == matrix . vector]]]; \[IndentingNewLine]vSol = 
          Table[\[IndentingNewLine]\(Solve[
                Join[eqs /. \[Omega]2Sol[\([i]\)], {vector . vector == 
                      1}]\[IndentingNewLine], vector]\)[\([2]\)], {i, 1, 
              dim}]; \[IndentingNewLine]{freq, vSol}\ ]\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"T", "=", 
          RowBox[{
            RowBox[{\(1\/2\), " ", "m", " ", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
            RowBox[{\(1\/2\), " ", "m", " ", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}], 
        ";"}], " "}], "\[IndentingNewLine]", \(V = 
        1\/2\ k1\ \((q2[t] - q1[t])\)\^2;\)}], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(smallOsc2[T, V, {q1[t], q2[t]}, {0, 0}, t]\)\(\ \ \ \)\)\)], "Input",\

  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \({q, p, dim} // ColumnForm\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(equlibRule\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \({Vij, Tij} // ColumnForm\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\[Omega]2Sol\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Solve[Join[eqs /. \[Omega]2Sol[\([1]\)], {vector . vector == 1}], 
      vector]\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \({freq, vSol}\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell["3.3 Oscillating Circuits ", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[" Overview of Circuits   ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Problem 1:  Series RC  Circuit     ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = V[t] \[Equal] R\ \(q'\)[t] + \(\(q[t]/C\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(dsol = \(DSolve[eq1, q[t], t]\)[\([1]\)]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    \(\(V[t_] = V0\ Cos[\[Omega]\ t];\)\), "\[IndentingNewLine]", 
    \(q[t_] = \(\(q[t] /. dsol\)\(//\)\(Simplify\)\(\ \)\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(c1Sol = \(Solve[q[0] \[Equal] q0, C[1]]\)[\([1]\)]\)], "Input",
  Hyphenation->False],

Cell["q[t_]= q[t] /.c1Sol//FullSimplify", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(values1 = {q0 \[Rule] 1, V0 \[Rule] 1, C \[Rule] 1, 
          R \[Rule] 1, \[Omega] \[Rule] 6};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{\(q[t] /. values1\  // Evaluate\), ",", 
          "\[IndentingNewLine]", \({t, 0, 6}\), ",", "\[IndentingNewLine]", 
          RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
              StyleBox[" ",
                FontFamily->"BLADES"], \("\<time\>", "\<charge\>"\), "}"}]}], 
          ",", "\[IndentingNewLine]", \(PlotLabel \[Rule] \ "\<RC Loop\>"\)}],
         "]"}], ";"}]], "Input"],

Cell[BoxData[
    \(\(values2 = {q0 \[Rule] 1, V0 \[Rule] 1, 
          R \[Rule] 1, \[Omega] \[Rule] 6};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Plot3D[
        q[t] /. values2\  // Evaluate, \[IndentingNewLine]{t, 0, 
          6}, \[IndentingNewLine]{C, 0.01, 
          0.25}, \[IndentingNewLine]AxesLabel \[Rule] {"\<Time\>", \
"\<Capacitance\>", "\<Charge\>"}, \[IndentingNewLine]Ticks \[Rule] \
{Automatic, { .01,  .1,  .2\ }, 
            Automatic}, \[IndentingNewLine]FaceGrids \[Rule] {{0, \(-1\), 
              0}}, \[IndentingNewLine]ViewPoint \[Rule] { .3, \(-1\),  .3}, \
\[IndentingNewLine]PlotPoints \[Rule] 35];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2:   Series RL Loop ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = 
      V[t] \[Equal] 
        L\ \ \(q''\)[t] + \(\(R\)\(\ \ \)\(\(q'\)[t]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(\(V[t_] = V0\ Cos[\[Omega]\ t];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(initial = {q[0] == q0, \(q'\)[0] == i0};\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(qsol = 
      q[t] /. \((\(DSolve[{eq1, initial} // Flatten, q[t], t] // 
              Flatten\) // \ Simplify)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(isol = D[qsol, t] // FullSimplify\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {R \[Rule] 0.1, L \[Rule] 2, 
          V0 \[Rule] 1, \[Omega] \[Rule] 1, i0 \[Rule] 0.1, 
          q0 \[Rule] 0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Plot[{qsol, isol} /. values\  // Evaluate, \[IndentingNewLine]{t, 0, 
          20}, \[IndentingNewLine]PlotStyle \[Rule] {\[IndentingNewLine]{Hue[ \
.3], \ Thickness[0.01]}, {Hue[ .9], Dashing[{0.03}], 
              Thickness[0.02]}}, \[IndentingNewLine]Frame \[Rule] 
          True, \ \[IndentingNewLine]FrameLabel \[Rule] {\ "\<Time\>"\ , \ \
"\< \>"\ \ }, \[IndentingNewLine]GridLines \[Rule] Automatic];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell["<<Statistics`NormalDistribution`", "Input",
  CellTags->"S6.9.1"],

Cell[BoxData[
    \(\(fourierdata = 
        Table[qsol\ \(RandomArray[NormalDistribution[1, 0.1], 
                    1]\)[\([1]\)]\  /. values // N, {t, 0, 100\ \[Pi], 
            100\ \[Pi]/300}]\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(ListPlot[\[IndentingNewLine]Abs[
          Fourier[fourierdata]], \[IndentingNewLine]PlotJoined \[Rule] 
          True, \[IndentingNewLine]PlotStyle \[Rule] 
          Hue[Random], \[IndentingNewLine]PlotRange \[Rule] {0, 
            5}];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3 :   RLC  Loop     ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and Outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(eq1 = L\ \(q''\)[t] + R\ \(q'\)[t] + q[t]/C \[Equal] 0;\)\)], "Input",\

  Hyphenation->False],

Cell[BoxData[
    \(eq2 = LaplaceTransform[eq1, t, s] // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(sol0 = \(Solve[eq2, 
          LaplaceTransform[q[t], t, s]]\)[\([1]\)]\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(initial = {q[0] \[Rule] q0, \(q'\)[0] \[Rule] i0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = 
      InverseLaplaceTransform[\(LaplaceTransform[q[t], t, s] /. sol0\) /. 
            initial, s, t] // FullSimplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"freqrule", "=", 
        FormBox[\(C\ R\^2 - 4\ L \[Rule] \(-4\)\ C\ L\^2\ \[Omega]0\^2\),
          "TraditionalForm"]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(charge\  = \ \ \(\(eq3 //. freqrule // PowerExpand\)\  // 
          ExpToTrig\) // \ FullSimplify\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(current\  = \ D[charge\ , t] // FullSimplify\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {R \[Rule] 1, C \[Rule] 1, L \[Rule] 4, q0 \[Rule] 1, 
          i0 \[Rule] 0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"\[Omega]rule", "=", 
      RowBox[{
        RowBox[{"Solve", "[", 
          RowBox[{
            
            FormBox[\(\@\(C\ R\^2 - 4\ L\) == 
                2\ \[ImaginaryI]\ \@C\ L\ \[Omega]0\),
              "TraditionalForm"], ",", "\[Omega]0"}], "]"}], "[", \([1]\), 
        "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(text = {Text[
            StyleForm["\<Charge\>"\ , FontFamily -> "\<Times-Bold\>", 
              FontSize -> 15]\ \ , {5, 0.8}]\ , \[IndentingNewLine]Text[
            StyleForm["\<Current\>"\ , FontFamily -> "\<Times-Bold\>", 
              FontSize -> 15\ ], {8, 0.3}]};\)\(\ \ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\({charge, current} /. \[Omega]rule\) /. values // 
          Evaluate, \[IndentingNewLine]{t,  .001, 
          20}, \[IndentingNewLine]PlotStyle \[Rule] {\[IndentingNewLine]{Hue[
                0.3], Dashing[{0.01}], Thickness[0.010]}, {Hue[0.9], 
              Dashing[{0.02}], 
              Thickness[0.008]}}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]FrameLabel \[Rule] {"\<Time\>", "\<\>"}, \
\[IndentingNewLine]GridLines \[Rule] 
          Automatic, \[IndentingNewLine]Epilog \[Rule] text];\)\)], "Input"],

Cell[BoxData[
    \(\(values2 = {R \[Rule] 1, C \[Rule] 1, q0 \[Rule] 1, 
          i0 \[Rule] 1};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(p1 = 
        Plot3D[\(charge /. \[Omega]rule\) /. values2\  // 
            Evaluate, \[IndentingNewLine]{t, 0.01, 
            30}, \[IndentingNewLine]{L, 1, 
            4}, \[IndentingNewLine]ViewPoint \[Rule] {1, \(+3\), 
              1}, \[IndentingNewLine]FaceGrids \[Rule] {{0, 0, 
                1}, {0, \(-1\), 0}}, 
          AxesLabel \[Rule] {"\<Time\>", "\<Inductance\>", "\<Charge\>"}, \
\[IndentingNewLine]PlotPoints \[Rule] 30];\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.4 Exercises  ", "Section",
  Hyphenation->False],

Cell["Exercise 1: Blocks connect with a Spring on a Table", "Subsubsection",
  Hyphenation->False],

Cell["Exercise 2: Falling Blocks connect with a Spring", "Subsubsection",
  Hyphenation->False],

Cell[TextData[{
  StyleBox["Exercise 3:",
    FontWeight->"Bold"],
  " Parabolic coordinates and Harmonic Oscillator"
}], "Subsubsection",
  Hyphenation->False],

Cell[TextData[{
  StyleBox["Exercise 4:",
    FontWeight->"Bold"],
  " Forced Oscillator"
}], "Subsubsection",
  Hyphenation->False],

Cell[TextData[{
  StyleBox["Exercise 5:",
    FontWeight->"Bold"],
  " Pendulums and Spring"
}], "Subsubsection",
  Hyphenation->False],

Cell[TextData[{
  StyleBox["Exercise 6:",
    FontWeight->"Bold"],
  " Five Particles connected with Springs"
}], "Subsubsection",
  Hyphenation->False],

Cell[TextData[{
  StyleBox["Exercise 7",
    FontWeight->"Bold"],
  ": Vibrating Atoms on an Equilateral Triangle"
}], "Subsubsection",
  Hyphenation->False],

Cell[TextData[{
  StyleBox["Exercise 8:",
    FontWeight->"Bold"],
  " Vibrating Charged Spheres"
}], "Subsubsection",
  Hyphenation->False],

Cell[TextData[{
  StyleBox["Exercise 9:",
    FontWeight->"Bold"],
  "  Quadratic Damping"
}], "Subsubsection",
  Hyphenation->False],

Cell["\<\
Exercise 10: Motion of a Charged Particle in a Harmonic Potential\
\
\>", "Subsubsection",
  Hyphenation->False]
}, Closed]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
AutoGeneratedPackage->None,
WindowToolbars->"EditBar",
CellGrouping->Manual,
PageWidth->PaperWidth,
WindowSize->{760, 632},
WindowMargins->{{Automatic, 112}, {Automatic, 17}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowSelection->True,
ShowCellLabel->True,
ShowCellTags->False,
SpellingOptions->{"AlwaysStop"->"RepeatedWords"},
SpellingDictionaries->{"CorrectWords"->{
  "descrete", "Poincar\[EAcute]", "Mandelbrot", "xo", "Gfixpt", "Gfixptpt", 
    "Lvalues", "Spoints", "fdata", "rdata", "returnpt", "diff", "Gder", 
    "prob", "Scobweb", "Svalues", "fder", "Lagrange's", "Lagrange", "qi", 
    "Qi", "eq", "eqin", "Ser", "eqs", "vars", "Diff", "zpsol", "zp", 
    "perturbative", "firstorderpert", "xfirst", "ro", "''", "Rx", "Ry", "Rz", 
    "Eq", "Kepler", "Keplerian", "Johannes", "Kepler's", "uo", "ee", "cterm", 
    "plotorbit", "num", "uforce", "ndsol", "ndsol.", "numorbit", "rrule", 
    "Urule", "Lpt", "tmax", "Mgraph", "fx", "fy", "tfinal", "hrule", "vxo", 
    "vyo", "eqlist", "Equi", "Lgraph", "jac", "nonrotating", "accreting", 
    "Lagragian", "rl", "zeropt", "yi", "yrs", "Ll", "freq", "invfreq", "xy", 
    "tmoon", "Descrete", "Poincare", "xsol", "traj", "df.", "tempsol", 
    "tempinit", "tempser", "tempeq", "tempvar", "initialx", "initialv", 
    "wrsym", "Acc", "energy", "and", "homog", "eigenmode", "Osc", 
    "eigenfrequencies", "coord", "equlib", "Vij", "Tij", "Osc.", "where", 
    "eigenfrequency.", "eigenfrequency", "vector", "eigenfrequencies.", 
    "eigenmatrix", "the", "xRule", "xp", "solution", "eigenfunctions", 
    "smallOsc2", "dsol", "isol", "qsol", "values", "fourierdata", "tlist", 
    "List", "phasePlot", "timePhasePlot", "doublePlot", "initialz", 
    "approxsol", "finitesum", "ii.", "iii.", "df", "wd", "Adf", "freqrule", 
    "solrule", "valuerule", "equilb", "wrule", "vo", "unstretched", "xmin", 
    "xmax", "ymin", "ymax", "var", "varmin", "varmax", "freg"}},
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1,
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S6.9.1"->{
    Cell[62680, 2110, 71, 1, 27, "Input",
      CellTags->"S6.9.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S6.9.1", 71253, 2378}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 116, 2, 42, "Subsubsection"],
Cell[1846, 56, 1886, 33, 657, "Input",
  Evaluatable->False]
}, Closed]],
Cell[3747, 92, 109, 3, 81, "Title",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3881, 99, 171, 7, 60, "Section",
  Evaluatable->False],
Cell[4055, 108, 180, 4, 43, "Input"]
}, Closed]],
Cell[4250, 115, 181, 7, 40, "Section",
  Evaluatable->False],
Cell[4434, 124, 192, 7, 45, "Subsection",
  Evaluatable->False],
Cell[4629, 133, 133, 3, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4787, 140, 204, 8, 42, "Subsubsection"],
Cell[4994, 150, 558, 10, 155, "Input"],
Cell[5555, 162, 190, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5782, 171, 236, 8, 28, "Subsubsection",
  Evaluatable->False],
Cell[6021, 181, 550, 9, 139, "Input"],
Cell[6574, 192, 163, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6774, 201, 196, 6, 28, "Subsubsection"],
Cell[6973, 209, 450, 9, 123, "Input"],
Cell[7426, 220, 168, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7631, 229, 67, 1, 28, "Subsubsection"],
Cell[7701, 232, 110, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7848, 239, 193, 7, 29, "Subsection",
  Evaluatable->False],
Cell[8044, 248, 66, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[8135, 253, 55, 1, 42, "Subsubsection"],
Cell[8193, 256, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[8294, 262, 53, 1, 42, "Subsubsection"],
Cell[8350, 265, 333, 10, 29, "Input"],
Cell[8686, 277, 354, 10, 27, "Input"],
Cell[9043, 289, 154, 3, 27, "Input"],
Cell[9200, 294, 83, 2, 27, "Input"],
Cell[9286, 298, 76, 2, 27, "Input"],
Cell[9365, 302, 65, 2, 27, "Input"],
Cell[9433, 306, 301, 5, 91, "Input"],
Cell[9737, 313, 233, 4, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10007, 322, 53, 1, 42, "Subsubsection"],
Cell[10063, 325, 172, 4, 27, "Input"],
Cell[10238, 331, 144, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10419, 339, 53, 1, 42, "Subsubsection"],
Cell[10475, 342, 90, 2, 27, "Input"],
Cell[10568, 346, 150, 3, 27, "Input"],
Cell[10721, 351, 183, 4, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10965, 362, 201, 7, 29, "Subsection",
  Evaluatable->False],
Cell[11169, 371, 878, 16, 155, "Input"],
Cell[12050, 389, 84, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[12159, 395, 52, 1, 45, "Subsection"],
Cell[12214, 398, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[12315, 404, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[12421, 409, 819, 15, 139, "Input"],
Cell[13243, 426, 157, 3, 27, "Input"],
Cell[13403, 431, 100, 2, 27, "Input"],
Cell[13506, 435, 62, 2, 27, "Input"],
Cell[13571, 439, 108, 2, 27, "Input"],
Cell[13682, 443, 106, 3, 27, "Input"],
Cell[13791, 448, 97, 2, 27, "Input"],
Cell[13891, 452, 128, 3, 27, "Input"],
Cell[14022, 457, 125, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14184, 465, 53, 1, 42, "Subsubsection"],
Cell[14240, 468, 76, 2, 27, "Input"],
Cell[14319, 472, 333, 10, 29, "Input"],
Cell[14655, 484, 149, 2, 27, "Input"],
Cell[14807, 488, 436, 10, 89, "Input"],

Cell[CellGroupData[{
Cell[15268, 502, 157, 4, 27, "Input"],
Cell[15428, 508, 111, 2, 27, "Input"]
}, Closed]],
Cell[15554, 513, 163, 3, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15778, 523, 226, 7, 29, "Subsection",
  Evaluatable->False],
Cell[16007, 532, 66, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[16098, 537, 55, 1, 42, "Subsubsection"],
Cell[16156, 540, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[16257, 546, 53, 1, 42, "Subsubsection"],
Cell[16313, 549, 369, 9, 59, "Input"],
Cell[16685, 560, 492, 13, 27, "Input"],
Cell[17180, 575, 189, 4, 59, "Input"],
Cell[17372, 581, 69, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[17478, 588, 53, 1, 42, "Subsubsection"],
Cell[17534, 591, 88, 2, 27, "Input"],
Cell[17625, 595, 70, 2, 27, "Input"],
Cell[17698, 599, 466, 8, 123, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18201, 612, 55, 1, 42, "Subsubsection"],
Cell[18259, 615, 468, 13, 27, "Input"],
Cell[18730, 630, 496, 10, 123, "Input"],
Cell[19229, 642, 88, 2, 27, "Input"],
Cell[19320, 646, 72, 2, 27, "Input"],
Cell[19395, 650, 356, 6, 91, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19812, 663, 129, 3, 29, "Subsection",
  Evaluatable->False],
Cell[19944, 668, 115, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20084, 675, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[20190, 680, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[20291, 686, 53, 1, 42, "Subsubsection"],
Cell[20347, 689, 503, 13, 27, "Input"],
Cell[20853, 704, 593, 14, 27, "Input"],
Cell[21449, 720, 336, 8, 50, "Input"],
Cell[21788, 730, 106, 2, 27, "Input"],
Cell[21897, 734, 129, 3, 27, "Input"],
Cell[22029, 739, 108, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[22174, 746, 54, 1, 42, "Subsubsection"],
Cell[22231, 749, 205, 5, 50, "Input"],
Cell[22439, 756, 431, 8, 107, "Input"],
Cell[22873, 766, 244, 3, 107, "Input"],
Cell[23120, 771, 316, 6, 75, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23473, 782, 53, 1, 42, "Subsubsection"],
Cell[23529, 785, 123, 3, 27, "Input"],
Cell[23655, 790, 69, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23761, 796, 53, 1, 42, "Subsubsection"],
Cell[23817, 799, 216, 5, 50, "Input"],
Cell[24036, 806, 329, 6, 75, "Input"],
Cell[24368, 814, 87, 2, 27, "Input"],
Cell[24458, 818, 682, 12, 187, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[25177, 835, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[25281, 840, 58, 2, 27, "Input"],
Cell[25342, 844, 90, 2, 27, "Input"],
Cell[25435, 848, 179, 4, 27, "Input"],
Cell[25617, 854, 126, 3, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[25804, 864, 169, 5, 29, "Subsection"],
Cell[25976, 871, 68, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[26069, 876, 55, 1, 42, "Subsubsection"],
Cell[26127, 879, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[26228, 885, 53, 1, 42, "Subsubsection"],
Cell[26284, 888, 535, 14, 29, "Input"],
Cell[26822, 904, 92, 1, 27, "Input"],
Cell[26917, 907, 75, 2, 27, "Input"],
Cell[26995, 911, 92, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[27124, 918, 53, 1, 42, "Subsubsection"],
Cell[27180, 921, 698, 19, 44, "Input"],
Cell[27881, 942, 336, 8, 50, "Input"],
Cell[28220, 952, 150, 2, 27, "Input"],
Cell[28373, 956, 106, 2, 27, "Input"],
Cell[28482, 960, 75, 2, 27, "Input"],
Cell[28560, 964, 229, 4, 59, "Input"],
Cell[28792, 970, 161, 3, 27, "Input"],
Cell[28956, 975, 206, 5, 53, "Input"],
Cell[29165, 982, 125, 3, 27, "Input"],
Cell[29293, 987, 112, 2, 27, "Input"],
Cell[29408, 991, 102, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[29547, 998, 53, 1, 42, "Subsubsection"],
Cell[29603, 1001, 298, 7, 50, "Input"],
Cell[29904, 1010, 463, 7, 107, "Input"],
Cell[30370, 1019, 532, 8, 139, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[30939, 1032, 53, 1, 42, "Subsubsection"],
Cell[30995, 1035, 391, 7, 107, "Input"],
Cell[31389, 1044, 731, 13, 171, "Input"],
Cell[32123, 1059, 69, 2, 27, "Input"],
Cell[32195, 1063, 248, 6, 59, "Input"],
Cell[32446, 1071, 140, 3, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[32625, 1079, 179, 7, 40, "Section",
  Evaluatable->False],
Cell[32807, 1088, 142, 3, 45, "Subsection",
  Evaluatable->False],
Cell[32952, 1093, 183, 6, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[33160, 1103, 281, 10, 42, "Subsubsection",
  Evaluatable->False],
Cell[33444, 1115, 1221, 23, 251, "Input"],
Cell[34668, 1140, 84, 2, 27, "Input"],
Cell[34755, 1144, 795, 21, 80, "Input"],
Cell[35553, 1167, 96, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[35686, 1174, 208, 7, 29, "Subsection",
  Evaluatable->False],
Cell[35897, 1183, 115, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[36037, 1190, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[36143, 1195, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[36244, 1201, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[36348, 1206, 419, 9, 80, "Input"],
Cell[36770, 1217, 174, 4, 43, "Input"],
Cell[36947, 1223, 140, 3, 43, "Input"],
Cell[37090, 1228, 157, 4, 27, "Input"],
Cell[37250, 1234, 142, 4, 27, "Input"],
Cell[37395, 1240, 158, 4, 43, "Input"],
Cell[37556, 1246, 135, 3, 27, "Input"],
Cell[37694, 1251, 117, 3, 27, "Input"],
Cell[37814, 1256, 136, 3, 27, "Input"],
Cell[37953, 1261, 135, 3, 27, "Input"],
Cell[38091, 1266, 136, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[38264, 1274, 53, 1, 42, "Subsubsection"],
Cell[38320, 1277, 115, 3, 27, "Input"],
Cell[38438, 1282, 207, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[38682, 1291, 53, 1, 42, "Subsubsection"],
Cell[38738, 1294, 142, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[38917, 1303, 53, 1, 42, "Subsubsection"],
Cell[38973, 1306, 124, 3, 27, "Input"],
Cell[39100, 1311, 270, 6, 27, "Input"],
Cell[39373, 1319, 179, 5, 27, "Input"],
Cell[39555, 1326, 185, 4, 27, "Input"],
Cell[39743, 1332, 126, 3, 27, "Input"],
Cell[39872, 1337, 361, 6, 75, "Input"],
Cell[40236, 1345, 256, 4, 59, "Input"],
Cell[40495, 1351, 403, 7, 75, "Input"],
Cell[40901, 1360, 272, 5, 59, "Input"],
Cell[41176, 1367, 119, 3, 27, "Input"],
Cell[41298, 1372, 327, 5, 59, "Input"],
Cell[41628, 1379, 179, 3, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[41868, 1389, 210, 7, 29, "Subsection",
  Evaluatable->False],
Cell[42081, 1398, 115, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[42221, 1405, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[42327, 1410, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[42428, 1416, 53, 1, 42, "Subsubsection"],
Cell[42484, 1419, 968, 24, 80, "Input"],
Cell[43455, 1445, 199, 5, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[43691, 1455, 53, 1, 42, "Subsubsection"],
Cell[43747, 1458, 158, 4, 27, "Input"],
Cell[43908, 1464, 232, 4, 27, "Input"],
Cell[44143, 1470, 167, 4, 31, "Input"],
Cell[44313, 1476, 215, 5, 27, "Input"],
Cell[44531, 1483, 126, 3, 27, "Input"],
Cell[44660, 1488, 627, 11, 139, "Input"],
Cell[45290, 1501, 483, 8, 107, "Input"],
Cell[45776, 1511, 164, 4, 27, "Input"],
Cell[45943, 1517, 289, 8, 59, "Input"],
Cell[46235, 1527, 186, 5, 27, "Input"],
Cell[46424, 1534, 137, 3, 27, "Input"],
Cell[46564, 1539, 190, 5, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[46791, 1549, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[46895, 1554, 134, 3, 27, "Input"],
Cell[47032, 1559, 537, 9, 123, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[47630, 1575, 212, 7, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[47867, 1586, 55, 1, 42, "Subsubsection"],
Cell[47925, 1589, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[48026, 1595, 54, 1, 42, "Subsubsection"],
Cell[48083, 1598, 1179, 28, 80, "Input"],
Cell[49265, 1628, 216, 5, 27, "Input"],
Cell[49484, 1635, 106, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[49627, 1642, 55, 1, 42, "Subsubsection"],
Cell[49685, 1645, 101, 2, 27, "Input"],
Cell[49789, 1649, 249, 4, 27, "Input"],
Cell[50041, 1655, 144, 3, 27, "Input"],
Cell[50188, 1660, 167, 3, 27, "Input"],
Cell[50358, 1665, 40, 1, 27, "Input"],
Cell[50401, 1668, 623, 10, 139, "Input"],
Cell[51027, 1680, 126, 3, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[51214, 1690, 188, 7, 29, "Subsection",
  Evaluatable->False],
Cell[51405, 1699, 115, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[51523, 1704, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[51629, 1709, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[51730, 1715, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[51834, 1720, 288, 6, 75, "Input"],
Cell[52125, 1728, 103, 3, 27, "Input"],
Cell[52231, 1733, 350, 7, 107, "Input"],
Cell[52584, 1742, 176, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52797, 1751, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[52901, 1756, 128, 3, 27, "Input"],
Cell[53032, 1761, 242, 4, 27, "Input"],
Cell[53277, 1767, 141, 3, 27, "Input"],
Cell[53421, 1772, 200, 4, 27, "Input"],
Cell[53624, 1778, 132, 3, 27, "Input"],
Cell[53759, 1783, 192, 5, 27, "Input"],
Cell[53954, 1790, 138, 3, 27, "Input"],
Cell[54095, 1795, 142, 4, 27, "Input"],
Cell[54240, 1801, 151, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[54428, 1810, 53, 1, 42, "Subsubsection"],
Cell[54484, 1813, 158, 5, 42, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[54691, 1824, 280, 10, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[54996, 1838, 55, 1, 42, "Subsubsection"],
Cell[55054, 1841, 76, 2, 27, "Input"],
Cell[55133, 1845, 1144, 22, 251, "Input"],
Cell[56280, 1869, 701, 18, 80, "Input"],
Cell[56984, 1889, 143, 4, 27, "Input"],
Cell[57130, 1895, 80, 2, 27, "Input"],
Cell[57213, 1899, 91, 3, 27, "Input"],
Cell[57307, 1904, 79, 2, 27, "Input"],
Cell[57389, 1908, 93, 3, 27, "Input"],
Cell[57485, 1913, 161, 4, 27, "Input"],
Cell[57649, 1919, 93, 3, 27, "Input"]
}, Closed]]
}, Closed]],
Cell[57769, 1926, 114, 3, 40, "Section",
  Evaluatable->False],
Cell[57886, 1931, 116, 3, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[58027, 1938, 127, 3, 45, "Subsection",
  Evaluatable->False],
Cell[58157, 1943, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[58296, 1950, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[58402, 1955, 85, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[58512, 1961, 53, 1, 42, "Subsubsection"],
Cell[58568, 1964, 110, 2, 27, "Input"],
Cell[58681, 1968, 95, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[58813, 1975, 53, 1, 42, "Subsubsection"],
Cell[58869, 1978, 176, 3, 43, "Input"],
Cell[59048, 1983, 105, 2, 27, "Input"],
Cell[59156, 1987, 98, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[59291, 1994, 53, 1, 42, "Subsubsection"],
Cell[59347, 1997, 155, 3, 27, "Input"],
Cell[59505, 2002, 476, 10, 75, "Input"],
Cell[59984, 2014, 142, 3, 27, "Input"],
Cell[60129, 2019, 543, 10, 139, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[60733, 2036, 120, 3, 29, "Subsection",
  Evaluatable->False],
Cell[60856, 2041, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[60995, 2048, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[61101, 2053, 85, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[61211, 2059, 53, 1, 42, "Subsubsection"],
Cell[61267, 2062, 145, 4, 27, "Input"],
Cell[61415, 2068, 183, 4, 59, "Input"],
Cell[61601, 2074, 169, 4, 27, "Input"],
Cell[61773, 2080, 88, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[61898, 2087, 53, 1, 42, "Subsubsection"],
Cell[61954, 2090, 183, 4, 27, "Input"],
Cell[62140, 2096, 447, 6, 123, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[62624, 2107, 53, 1, 42, "Subsubsection"],
Cell[62680, 2110, 71, 1, 27, "Input",
  CellTags->"S6.9.1"],
Cell[62754, 2113, 240, 5, 27, "Input"],
Cell[62997, 2120, 299, 6, 91, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[63357, 2133, 120, 3, 29, "Subsection",
  Evaluatable->False],
Cell[63480, 2138, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[63619, 2145, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[63725, 2150, 85, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[63835, 2156, 53, 1, 42, "Subsubsection"],
Cell[63891, 2159, 116, 3, 27, "Input"],
Cell[64010, 2164, 100, 2, 27, "Input"],
Cell[64113, 2168, 140, 3, 27, "Input"],
Cell[64256, 2173, 109, 2, 27, "Input"],
Cell[64368, 2177, 179, 4, 27, "Input"],
Cell[64550, 2183, 203, 5, 29, "Input"],
Cell[64756, 2190, 167, 3, 27, "Input"],
Cell[64926, 2195, 99, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[65062, 2202, 53, 1, 42, "Subsubsection"],
Cell[65118, 2205, 147, 3, 27, "Input"],
Cell[65268, 2210, 352, 10, 36, "Input"],
Cell[65623, 2222, 325, 5, 43, "Input"],
Cell[65951, 2229, 570, 9, 139, "Input"],
Cell[66524, 2240, 135, 3, 27, "Input"],
Cell[66662, 2245, 484, 9, 107, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[67207, 2261, 56, 1, 40, "Section"],
Cell[67266, 2264, 98, 1, 42, "Subsubsection"],
Cell[67367, 2267, 95, 1, 42, "Subsubsection"],
Cell[67465, 2270, 160, 5, 42, "Subsubsection"],
Cell[67628, 2277, 132, 5, 42, "Subsubsection"],
Cell[67763, 2284, 135, 5, 42, "Subsubsection"],
Cell[67901, 2291, 152, 5, 42, "Subsubsection"],
Cell[68056, 2298, 157, 5, 42, "Subsubsection"],
Cell[68216, 2305, 140, 5, 42, "Subsubsection"],
Cell[68359, 2312, 133, 5, 42, "Subsubsection"],
Cell[68495, 2319, 122, 4, 42, "Subsubsection"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

