(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     88363,       3001]*)
(*NotebookOutlinePosition[     89057,       3026]*)
(*  CellTagsIndexPosition[     89013,       3022]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Legal Notice, Disclaimer, and Book Ordering Information:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "(* Legal Notice, Disclaimer, and Book Ordering Information:\n\nLast \
Modified: FIO June 8, 2002\n\n",
  StyleBox["Mathematica For Physics: 2nd Edition",
    FontColor->RGBColor[1, 0, 0]],
  "\n\nRobert L. Zimmerman and Fredrick I. Olness\n",
  "\nWebSite:  \n",
  StyleBox["  www.physics.smu.edu/~olness\n  darkwing.uoregon.edu/~phys600/\n\
\n",
    FontColor->RGBColor[1, 0, 0]],
  "MathSource Number: 0206-862",
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  "\nISBN 0-201-53796-6\nFor ordering information, call 1-800-282-0693\n\
Addison-Wesley Publishing Company\n",
  "\nCommunication with the authors:\nFredrick I. Olness:  \
olness@mail.physics.smu.edu\nRobert L. Zimmerman: bob@zim.uoregon.edu\n\n\
Copyright 2002, Addison-Wesley Publishing Company, Inc. The material in\nthis \
file may be distributed freely  so long as the content remains\nunchanged, \
and the copyright and  reference notices are included. The\npublisher grants \
permission for the noncommercial use of these programs\nand program segments. \
 All other uses require the prior written consent\nof the publisher.    \n\n\
All rights are reserved with regard to the  material in the\n\"Mathematica \
For Physics\" text, and may not be reproduced, stored in a\nretrieval system, \
or transmitted,  in any form or by any means,\nelectronic, mechanical, \
photocopying,  recording, or otherwise, without\nthe prior written permission \
 of the publisher. \n\nThe programs and applications presented in this book \
have been included\nfor  their instructional value. They have been tested \
with care but are\nnot  guaranteed for any particular purpose. The publisher \
does not\noffer any  warranties or representations, nor does it accept any\n\
liabilities with  respect to the programs or applications. \n\n *)\n"
}], "Input",
  Evaluatable->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell["6. Lagrangians and Hamiltonians", "Title",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Introduction    ", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Off[General::spell];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Off[General::spell1];\)\)}], "Input",
  Hyphenation->False]
}, Closed]],

Cell["6.1 Lagrangian Problems without Lagrange Multipliers", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Overview of  Lagrangian Problems without Lagrange Multipliers\
\>", \
"Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Initialization for Lagrangian Problems", "Subsection"],

Cell[BoxData[
    \(Needs["\<Calculus`VariationalMethods`\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(?EulerEquations\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(L = m/2\ \ \(x'\)[t]^2\  - k/2\ \ \(\(x[t]^2\)\(\ \ \ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(EulerEquations[L, x[t], t] // ExpandAll\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(?FirstIntegrals\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(FirstIntegrals[L, x[t], t] // ExpandAll\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 1: Particle Sliding on a Movable Incline", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a  ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{
          RowBox[{\(1\/2\), " ", "M", " ", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["x1", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
          RowBox[{\(1\/2\), " ", "m", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}], 
              ")"}]}]}]}], 
      ";"}], "\[IndentingNewLine]", \(V = m\ g\ y[t];\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(change = {x \[Rule] \((\((x1[#] + \((L0 - s[#])\) 
                      Cos[\[Theta]])\) &)\), \ \ \ \[IndentingNewLine]\ \ \ \ \
\ \ \ \ \ \ \ \ \ y \[Rule] \((\((\((L0 - 
                        s[#])\)\ Sin[\[Theta]])\) &)\)};\)\)], "Input",
  Hyphenation->False],

Cell["  L=T-V /.change //Simplify ", "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = EulerEquations[L, {x1[t], s[t]}, t]\)], "Input",
  Hyphenation->False],

Cell[" eqMotion=Solve[eq1, {x1''[t],s''[t]}] //Flatten   ", "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(xmomentum = 
      M\ \(x1'\)[t] + m\ \(x'\)[t] /. change\  // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(D[xmomentum, t]\  /. eqMotion // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(energy = T + V /. change // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(D[energy, t] /. change\) /. eqMotion // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(FirstIntegrals[L, {x1[t], s[t]}, t]\)\(\ \)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Sol = \(DSolve[\[IndentingNewLine]{\((\ 
                  eqMotion /. Rule \[Rule] Equal)\), \[IndentingNewLine]s[
                    0] \[Equal] 0, \(s'\)[0] == 0, 
                x1[0] == 0, \(x1'\)[0] == 0} // Flatten, {x1[t], s[t]}, 
            t\ \ ] // Simplify\)\  // Flatten\)], "Input"],

Cell[BoxData[
    \(\((\(\((\(\((s[t]\  /. Sol)\)\ \  \[Equal] L0\  // 
                  Simplify\)\[IndentingNewLine] // 
                Solve[# /. t^2 \[Rule] x, x] &\[IndentingNewLine])\) /. 
            x \[Rule] t^2\  // Flatten\)\ \  // FullSimplify\ )\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Bead Sliding on a Rotating Wire   ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(x2rRule = {x, y, 
              z} \[Rule] {\((r[#]\ Sin[\[Theta]] 
                    Cos[\[Omega]\ #])\) &, \((r[#]\ Sin[\[Theta]] 
                    Sin[\[Omega]\ #])\) &, \((r[#]\ Cos[\[Theta]])\) &} // 
          Thread;\)\)], "Input"],

Cell[BoxData[
    \(\(\[Psi]Rule = \[Theta] \[Rule] \ \((\[Pi] - \[Psi])\)\ ;\)\)], "Input",\

  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["z", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
            ")"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(V = 
        m\ g\ z[t];\), "\[IndentingNewLine]", \(L = \(T - V\  /. 
            x2rRule\)\  /. \[Psi]Rule\  // Simplify\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = EulerEquations[L, r[t], t]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(rSol = \((\ \(Solve[eq1, \(r''\)[t]]\)[\([1, 1]\)] // ExpandAll\ )\) //. 
        Rule \[Rule] Equal\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq2 = \ \(\(\(DSolve[\ {rSol, 
                  r[0] \[Equal] 0, \(r'\)[0] \[Equal] v0}\ , r[t], t]\)[\([1, 
                1]\)]\  // Simplify\)\  // PowerExpand\)\ \  // 
        ExpandAll\)], "Input"],

Cell[BoxData[
    \(\(\(rRule\)\(=\)\(\ \)\(MapAt[\ Collect[#, {Exp[\(-x_\)]\ \ }]\  &, \ 
        eq2, \ 2]\)\(\ \)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(tRule = \((\ \(\(Solve[Len \[Equal] r[t] /. rRule\ , t\ , 
                InverseFunctions \[Rule] True]\)[\([2]\)]\  // 
            Simplify\)\[IndentingNewLine] // 
          PowerExpand\ \[IndentingNewLine])\)\)], "Input"],

Cell[BoxData[
    \(\(\(Series[t /. tRule, {\[Psi], 0, 0}\ ]\  // 
        Normal\)\(//\)\(Simplify\)\(\ \)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values = {\[Psi] \[Rule] \[Pi]/13, g \[Rule] 1, \[Omega] \[Rule] 2, 
          v0 \[Rule] 0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(position = \(\(\({x[t], y[t], z[t]} //. x2rRule\) //. 
              rRule\) /. \[Psi]Rule\) //. values;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(p1 = 
        ParametricPlot3D[
          position // Evaluate, {t, 0, 6}, \[IndentingNewLine]Boxed \[Rule] 
            True, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
              1}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell[BoxData[{
    \(\(discretePoints = 
        Table[position, {t, 0, 6, 0.5}];\)\), "\[IndentingNewLine]", 
    \(\(discreteGraphics = 
        Graphics3D[{PointSize[0.03], Point /@ discretePoints}];\)\)}], "Input",\

  Hyphenation->False],

Cell[BoxData[
    \(\(Show[discreteGraphics, p1, BoxRatios \[Rule] {1, 1, 1}];\)\)], "Input",\

  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: Bead on a Rotating Hoop  ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(x2rRule = {x, y, 
              z} \[Rule] {\((r\ Sin[\[Theta][#]] 
                    Cos[\[Omega]\ #])\) &, \((r\ Sin[\[Theta][#]] 
                    Sin[\[Omega]\ #])\) &, \((r\ Cos[\[Theta][#]])\) &} // 
          Thread;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \ \)\(\[Psi]Rule = {\[Theta] \[Rule] \((\[Pi] - \ \
\[Psi][#] &\ )\)};\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"T", "=", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{\(1\/2\), " ", "m", " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{
                      SuperscriptBox["x", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                  
                  SuperscriptBox[
                    RowBox[{
                      SuperscriptBox["y", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                  
                  SuperscriptBox[
                    RowBox[{
                      SuperscriptBox["z", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                ")"}]}], "//.", "x2rRule"}], " ", "/.", "\[Psi]Rule"}], "//", 
        "Simplify"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(V = \(m\ g\ z[t] //. x2rRule\)\  /. \[Psi]Rule // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \ \)\(\(L\)\(=\)\((T - V)\)\(\ \)\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = EulerEquations[L, \ \[Psi][t], t]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\[Psi]Sol = \ \(\(\((Solve[eq1, \(\[Psi]''\)[t]] // 
              Flatten)\) /. {g \[Rule] \[Omega]c\^2\ \
r}\)\(//\)\(ExpandAll\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(energy = \((\(\[Psi]'\)[t]\ D[L, \(\[Psi]'\)[t]] - 
              L)\) /. {g \[Rule] \[Omega]c\^2\ r} // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(D[energy, t] /. \[Psi]Sol\) /. {g \[Rule] \[Omega]c^2\ r}\ \  // 
      Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \ \)\(FirstIntegrals[L, \ \[Psi][t], 
          t] /. {g \[Rule] \[Omega]c\^2\ r} // Simplify\)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Veff = energy //. {\(\[Psi]'\)[t] \[Rule] 0} // ExpandAll\)], "Input"],

Cell["dVeff= D[Veff,\[Psi][t]]  ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(sol\)\(=\)\(Solve[dVeff\  \[Equal] 0, \[Psi][t], 
        InverseFunctions \[Rule] True\ ]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(eqRule\)\(=\)\(Join[{{\[Psi][t] \[Rule] \[Pi]}}, 
        sol]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(dVeff \[Equal] 0 //. eqRule\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(values1 = {r \[Rule] 1, \ \[Omega]c \[Rule] 1, \ 
          m \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[
        Veff /. values1 // 
          Evaluate, \[IndentingNewLine]{\[Psi][
            t], \(-\[Pi]\), \[Pi]}, {\[Omega], 1, 
          3}, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue\ , \[IndentingNewLine]Ticks \[Rule] {\[Pi]\ Range[\(-1\), 1, 
                1/2], Automatic, \ Automatic\ }];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\(\((\(Veff //. 
                    values1\) /. \[Omega] \[Rule] #)\) &\)\ \  /@ \ \ {2, 
              0.2} // Evaluate, \[IndentingNewLine]{\[Psi][
            t], \(-\[Pi]\), \[Pi]}, \[IndentingNewLine]Ticks \[Rule] {{\ \ \
\(-\[Pi]\)\ \ , 0, \ \[Pi]}, 
            Automatic}, \[IndentingNewLine]Epilog \[Rule] \
{\[IndentingNewLine]Hue[ .6], AbsolutePointSize[6], 
            Map[Point, \ \(\({\ \[Psi][t]\ , Veff} /. eqRule\)\  /. 
                  values1\) /. \[Omega] \[Rule] 
                  2]\ }\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = \(ContourPlot[\ \(\(energy /. values1\) /. {m \[Rule] 2, 
                      r \[Rule] 1\ }\) /. \((\[Omega] \[Rule] #)\)\ \  // 
                Evaluate, \ {\[Psi][t], \(-4\) \[Pi], \ 
                4\ \ \[Pi]}, {\(\[Psi]'\)[t], \(-3\), 
                3}\ , \ \[IndentingNewLine]FrameTicks \[Rule] {\[Pi]\ \
Range[\(-4\), 4, 2], Automatic}, \ \[IndentingNewLine]ColorFunction \[Rule] 
                Hue, \ \ \[IndentingNewLine]PlotPoints \[Rule] 
                100, \ \[IndentingNewLine]FrameLabel \[Rule] {"\<\[Psi]\>", "\
\<\[Psi]'\>"}\ , \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\ ] &\)\ \  /@ \ \ {2, 0.2\ };\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[\ pt1\ ]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(cylind = \ 
        ParametricPlot3D[{v, Sin[u], 
            Cos[u]}, \[IndentingNewLine]{u, \(-\[Pi]\), \[Pi]}, {v, \(-3\), 
            3}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity\ ];\)\)], "Input"],

Cell[BoxData[
    \(\(\(Show[\ 
        cylind, \[IndentingNewLine]Graphics3D[\[IndentingNewLine]{\
AbsoluteThickness[
              3], \[IndentingNewLine]Cases[Graphics[pt1[\([1]\)]], _Line, 
                Infinity] /. \[IndentingNewLine]{x_\ , y_} :> {y, 
                  1.02\ \ Cos[x\ ], 
                  1.02  Sin[
                      x]\ }}\[IndentingNewLine]]\ , \
\[IndentingNewLine]ViewPoint \[Rule] {1, 1, 
            1}, \[IndentingNewLine]DisplayFunction \[Rule] $DisplayFunction];\
\)\(\ \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values2 = {\[Omega] \[Rule] 2, \ \[Omega]c \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(eqRule /. values2 // N\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \({g \[RightArrow] \[Omega]c2\ r}\  // FullForm\)], "Input"],

Cell[BoxData[
    \(eq1 = \(\[Psi]Sol //. {g \[Rule] \ \(\[Omega]c\^2\) r}\) /. 
        Rule \[Rule] Equal\)], "Input"],

Cell[BoxData[
    \(eq2 = {eq1 /. {\(\[Psi]''\)[t] \[Rule] \(d\[Psi]'\)[t]}, \(\[Psi]'\)[
              t] \[Equal] d\[Psi][t]} // Flatten\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(ndsol1 = \(\(NDSolve[{eq2 //. values2, \[Psi][0] \[Equal] 1.1318, 
                  d\[Psi][0] \[Equal] #} // Flatten, {\[Psi][t], 
                d\[Psi][t]}, {t, 0, 10}]\)[\([1]\)] &\)\ \  /@ \ \ {\ \ 1, 
          2.5}\)], "Input"],

Cell["\<\
 \[Psi][1][t_]= \[Psi][t] /.ndsol1[[1,1]];
d\[Psi][1][t_]= d\[Psi][t]/.ndsol1[[1,2]];
 \[Psi][2][t_]= \[Psi][t] /.ndsol1[[2,1]];
d\[Psi][2][t_]= d\[Psi][t]/.ndsol1[[2,2]];\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(pt2 = \(Plot[\ \ {\(d\[Psi][#]\)[t], \(\[Psi][#]\)[t]}\  // 
                Evaluate, {t, 0, 
                10}, \[IndentingNewLine]PlotStyle \[Rule] {Dashing[{0.04}\ ], 
                  AbsoluteThickness[
                    2]\ }, \[IndentingNewLine]Ticks \[Rule] {\ \ Automatic, \
\[Pi]/2\ \ \ Range[1, 12, 3]\ }, \ \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\ \ ]\  &\)\  /@ \ \ Range[\ 2]\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[pt2]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt3 = \(ParametricPlot[\ \ {\ \(\[Psi][#]\)[t], \ \(d\[Psi][#]\)[
                    t]}\  // Evaluate, {t, 0, 
                10}, \[IndentingNewLine]PlotStyle \[Rule] \ 
                AbsoluteThickness[
                  2], \ \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\ ] &\)\ \  /@ \ \ {1, 2}\ \ \ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[\ pt1[\([1]\)], pt3, \ 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part e", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
bead[t_]:= 
  Graphics[
    { PointSize[0.03],
      Point[{Sin[\[Psi][1][t]],Cos[\[Psi][1][t]]} ]
    }];\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(frames = 2;\)\), "\n", 
    \(Do[\[IndentingNewLine]Show[{bead[t], 
          Graphics[{Hue[0.1], Circle[{0, 0}, 1]}, 
            PlotRange \[RightArrow] {{\(-2\), 2}, {\(-2\), 
                  2}}, \[IndentingNewLine]AspectRatio \[Rule] 
              1\[IndentingNewLine]]}\[IndentingNewLine]]\n, {t, 0, 10, 
        10/\((frames - 1)\)}]\)}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 4: Springs Mounted on Top of a Carriage ", "Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a  ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["xi", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["yi", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
            ")"}]}]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(V = 
        1\/2\ K\ \((\(-r0\) + xb[t])\)\^2 + 1\/2\ k\ yb[t]\^2;\)\)\)], "Input",\

  Hyphenation->False],

Cell[BoxData[
    \(\(change = {\[IndentingNewLine]xi \[Rule] \((\((\((xb[#])\) 
                      Cos[\[Omega]\ #] - yb[#]\ Sin[\[Omega]\ #])\) &)\), 
          yi \[Rule] \((\((\((xb[#])\) Sin[\[Omega]\ #] + 
                    yb[#]\ Cos[\[Omega]\ #])\) &)\)};\)\)], "Input",
  Hyphenation->False],

Cell["L =T-V  /.change  //FullSimplify", "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eqmotion\  = \ 
      EulerEquations[L, {xb[t], yb[t]}, t] // \ 
        Solve[#, \ {\(xb''\)[t], \(yb''\)[t]}] &\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {K \[Rule] \ 1, k \[Rule] 1\ , m \[Rule] 1, 
          r0 \[Rule] 1};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \({eq1, 
        eq2} = \((\(eqmotion[\([1]\)] /. values\) /. 
          Rules \[Rule] Equal)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = \(xb''\)[t] + 
          I\ \(yb''\)[t]\  \[Equal] \((\(\(xb''\)[t] + I\ \(yb''\)[t] /. 
              eq1\) /. eq2)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq4 = 
      eq3 /. xb \[Rule] \((\((u[#] - I\ \ yb[#])\) &)\) // 
        Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(uSol = \(\(u[
                t] /. \(DSolve[{eq4, \ 
                    u[0] \[Equal] 1, \(u'\)[0] == 0\ }\ , \ u[t], 
                  t]\)[\([1]\)] // \ \ ExpToTrig\) // Simplify\) // 
        Expand\)], "Input"],

Cell[BoxData[
    \(xSol = \ \ \(\(uSol /. \ 
          Complex[a_, b_] \[Rule] 
            Complex[a, 0]\)\(//\)\(Simplify\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(ySol = \((uSol - xSol\  // Together)\) /. I \[Rule] 1 // 
        Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(wvalues = {0.2, 0.4, 0.6, 0.8};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(listb\  = \(ParametricPlot[\ {xSol, ySol} /. \[Omega] \[Rule] #\  // 
                Evaluate, {t, 0, 100}, 
              PlotPoints \[Rule] 100, \[IndentingNewLine]AspectRatio \[Rule] 
                1, \[IndentingNewLine]AxesLabel \[Rule] {"\<xb\>", "\<yb\>"}, \
\[IndentingNewLine]Ticks \[Rule] 
                False, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity] &\)\ \  /@ \ wvalues;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[Partition[listb\ , 2]]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(change\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq2 = \(\({xi[t], yi[t]} /. change\) /. xb[t] \[Rule] xSol\) /. 
          yb[t] \[Rule] ySol\  // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(listi\  = \(ParametricPlot[
              eq2 /. \[Omega] \[Rule] # // Evaluate, {t, 0, 
                100}, \[IndentingNewLine]AxesLabel \[Rule] {"\<xi\>", \
"\<yi\>"}, \[IndentingNewLine]AspectRatio \[Rule] 
                1, \[IndentingNewLine]Ticks \[Rule] 
                False, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity] &\) /@ \ wvalues\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[Partition[listi\ , 2]]];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(listpb\  = \(ParametricPlot[\ {ySol, 
                    D[ySol, t]}\ \  /. \[Omega] \[Rule] # // Evaluate, {t, 0, 
                100}, \[IndentingNewLine]AspectRatio \[Rule] 
                1, \[IndentingNewLine]AxesLabel \[Rule] {"\<yb\>", "\< \
yb'\>"}, \[IndentingNewLine]Ticks \[Rule] 
                False, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity] &\)\  /@ \ \ wvalues;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[Partition[listpb\ , 2]]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(listpi\  = \(ParametricPlot[\ {eq2[\([2]\)], 
                    D[eq2[\([2]\)], t]}\ \  /. \[Omega] \[Rule] # // 
                Evaluate, {t, 0, 
                100}, \ \[IndentingNewLine]AspectRatio \[Rule] 
                1, \[IndentingNewLine]AxesLabel \[Rule] {"\<yb\>", "\< \
yb'\>"}, \[IndentingNewLine]Ticks \[Rule] 
                False, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity] &\)\  /@ \ \ wvalues;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[Partition[listpi\ , 2]]];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 5: Mass Falling Through a Hole in a Table     ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T1", "=", 
        RowBox[{\(1\/2\), " ", "m1", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["r", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              RowBox[{\(r[t]\^2\), " ", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
            ")"}]}]}], ";"}], "\n", \(V1 = 0;\)}], "Input"],

Cell[BoxData[
    \(\(zRule = {z \[Rule] \((\((len - r[#])\) &)\)};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T2", "=", 
        RowBox[{
          RowBox[{\(1\/2\), " ", "m2", " ", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["z", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}], "/.", 
          "zRule"}]}], 
      ";"}], "\n", \(V2 = \(-m2\)\ g\ z[t] /. zRule;\)}], "Input"],

Cell["L=(T1+T2)-(V1+V2) ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(eq1\)\(=\)\(\ \)\(EulerEquations[L, {r[t], \[Phi][t]}, 
        t]\)\(\ \ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(eq2 = \ 
        Solve[eq1, {\(\[Phi]''\)[t], \(r''\)[t]}] // 
          Flatten;\)\), "\[IndentingNewLine]", 
    \(eq2 // ColumnForm\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(FirstIntegrals[L, {r[t], \[Phi][t]}, t] // 
      ColumnForm\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq\[Phi]", "=", " ", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Rule]", \(h\/r[t]\^2\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
              RowBox[{"-", 
                FractionBox[
                  RowBox[{"2", " ", "h", " ", 
                    RowBox[{
                      SuperscriptBox["r", "\[Prime]",
                        MultilineFunction->None], "[", "t", 
                      "]"}]}], \(r[t]\^3\)]}]}]}], "}"}]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eqR = \ \(eq2[\([1]\)] /. eq\[Phi] // Simplify\) // 
        ExpandAll\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(eqMotion = {eq\[Phi][\([1]\)], eqR} /. Rule \[Rule] Equal // 
          Flatten;\)\), "\[IndentingNewLine]", 
    \(eqMotion // ColumnForm\)}], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(energy = \(T1 + T2 + V1 + V2 /. eq\[Phi] // Simplify\) // 
        ExpandAll\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Effpot\  = \((\(+g\)\ \ len\ \ m2 + energy)\) /. {\(r'\)[t] \[Rule] 0, 
            r[t] \[Rule] r} // Apart\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(min = 
      D[Effpot, r\ ] \[Equal] 0 // \(Solve[#, r\ ]\)[\([1]\)] &\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {h \[Rule] 1, m1 \[Rule] 1, m2 \[Rule] 1, 
          g \[Rule] 1\ };\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Plot[Effpot /. values // Evaluate, {r\ , 0.2, 3}];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(ContourPlot[\ \(energy /. values\) /. len \[Rule] 10\  // 
          Evaluate, \[IndentingNewLine]{r[t], 0.2, 6}, {\(r'\)[t], \(-1\), 
          1}, \[IndentingNewLine]ContourShading \[Rule] 
          True, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue\ \ ];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values = {h \[Rule] 1, m1 \[Rule] 1, m2 \[Rule] 1, 
          g \[Rule] 1};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(ndsol\  = \(NDSolve[{\ eqMotion /. values\ , \[Phi][0] \[Equal] 0, 
                r[0] \[Equal] \ 2, \(r'\)[0] \[Equal] 0} // 
              Flatten, {\[Phi][t], r[t]}, {t, 0, 
              70}]\)[\([1]\)]\ ;\)\)], "Input"],

Cell["\<\
\[Phi]1[t_]= \[Phi][t] /.ndsol; 
r1[t_]= r[t] /.ndsol; \
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ParametricPlot[\ 
        r1[t]\ {Cos[\[Phi]1[t]], Sin[\ \[Phi]1[t]]}\ \  // Evaluate, {t, 0, 
          70}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \[IndentingNewLine]Epilog \[Rule] {AbsoluteThickness[3], 
            Circle[{0, 0}, 2], 
            Circle[{0, 0},  .55]}\[IndentingNewLine]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 6: Spring Pendulum  ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(lsrule = 
        lst \[Rule] \((\@\(x[#1]\^2 + y[#1]\^2\) &)\);\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", " ", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
            ")"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(Vsp = \ 
        1\/2\ k\ \((\(-L0\) + lst[t])\)\^2;\), "\[IndentingNewLine]", \(Vgr = \
\(\(-\ m\)\(\ \)\(g\)\(\ \)\(x[t]\)\(\ \ \ \)\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(polarrule = {x \[Rule] \((\((r[#]\ Cos[\[Theta][#]])\) &)\), 
          y \[Rule] \((\((r[#]\ Sin[\[Theta][#]])\) &)\)};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(L = \(\(\(T - Vsp - Vgr /. lsrule\) /. polarrule // 
          Simplify\)\(//\)\(PowerExpand\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(eqMotion = \((\((\ \ EulerEquations[L, {r[t], \[Theta][t]}, 
                    t]\[IndentingNewLine] // \((\ \(Solve[#, {\(r''\)[
                              t], \(\[Theta]''\)[
                              t]}]\)[\([1]\)] &\ )\)\[IndentingNewLine])\) /. 
              Rule \[Rule] Equal\ \[IndentingNewLine] // 
            ExpandAll\[IndentingNewLine])\);\)\), "\[IndentingNewLine]", 
    \(eqMotion\  // ColumnForm\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(vertical = \ \ {\[Theta] \[Rule] \((0 &)\)};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(vertMotion = \(\(eqMotion /. 
          Rule \[Rule] Equal\)\(/.\)\(vertical\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(vertSol = \(DSolve[vertMotion[\([1]\)]\ , \ r[t], t] // Flatten\) // 
        ExpandAll\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(vertSol /. C[1] \[Rule] 0\) /. C[2] \[Rule] 0 // Flatten\) // 
      ExpandAll\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c   ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(valuesc = {L0 \[Rule] 40/9, n \[Rule] 1, k \[Rule] 4, \ g \[Rule] 1, 
          m \[Rule] 1};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(initialc = {r[0] \[Equal] \((L0 + \ g\ m/k)\) + 1\ , \(r'\)[
                0] \[Equal]  .1, \[Theta][0] \[Equal] 
              1/2\ \ \ \[Pi], \(\[Theta]'\)[0] \[Equal] \  .0} /. 
          valuesc;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(neqc = \({eqMotion, initialc} /. Rule \[Rule] Equal\)\  /. valuesc // 
          Flatten\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(nSolc = 
        NDSolve[neqc, {r[t], \[Theta][t]}, {t, 0, 110}, 
            MaxSteps \[Rule] 2000\ ] // Flatten;\)\)], "Input",
  Hyphenation->False],

Cell["\<\
rc[t_]= r[t]/.nSolc; 
\[Theta]c[t_]= \[Theta][t]/.nSolc; \
\>", "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Plot[\ {rc[t], \[Theta]c[t]\ \ } // Evaluate, {t, 0, 
          110}, \[IndentingNewLine]PlotStyle \[Rule] {Hue[ .7], 
            Hue[ .9]}\ \ , \[IndentingNewLine]Ticks \[Rule] {Automatic, \ \
\[Pi]\ Range[\(-1\), 2, 1\ \ ]\ }\ , \[IndentingNewLine]Epilog \[Rule] 
          Map[Line, \ \({{0, #  \[Pi]}, {125, #  \[Pi]}\ } &\)\  /@ \ \ \
Range[\(-1\), 2]]\ \[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(\(ParametricPlot[\ 
        rc[t] {Sin[\[Theta]c[t]], \(-Cos[\[Theta]c[t]]\)}\  // Evaluate, {t, 
          0, 110}, \[IndentingNewLine]PlotStyle \[Rule] 
          Hue[0.9], \ \[IndentingNewLine]AspectRatio \[Rule] 
          1, \[IndentingNewLine]PlotRange \[Rule] {Automatic, {\(-8\), 
              8}}, \ \[IndentingNewLine]Epilog \[Rule] {\ \(Circle[{0, 
                    0}, #] &\) /@ {6, 4, 
                2}\ }\[IndentingNewLine]];\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    \(\(\(pt1 = \(ParametricPlot[\ {#[t], \(#'\)[t]\ \ } // Evaluate, {t, 0, 
                110}, \[IndentingNewLine]PlotStyle \[Rule] {Hue[ .7], 
                  Hue[ .9]}, \[IndentingNewLine]Ticks \[Rule] 
                False, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\ \[IndentingNewLine]] &\)\  /@ \ \ {rc, \
\[Theta]c};\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[pt1]];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d   ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(valuesd = {L0 \[Rule] 5, n \[Rule] 1, k \[Rule] 2, \ g \[Rule] 1, 
          m \[Rule] 1};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(initiald = {r[0] \[Equal] \((L0 + \ g\ m/k +  .01)\)\ \ , \(r'\)[
                0] \[Equal] 
              0, \[Theta][0] \[Equal] \[Pi]\  -  .07, \(\[Theta]'\)[
                0] \[Equal] \ 0} /. valuesd\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(neqd = \({eqMotion, initiald} /. Rule \[Rule] Equal\)\  /. valuesd // 
          Flatten;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(nSold = 
        NDSolve[neqd, {r[t], \[Theta][t]}, {t, 0, 110}, 
            MaxSteps \[Rule] 2000] // Flatten;\)\)], "Input"],

Cell["\<\
rd[t_]= r[t] /. nSold;
\[Theta]d[t_]= \[Theta][t] /. nSold; \
\>", "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Plot[\ {rd[t], \[Theta]d[t]\ \ } // Evaluate, {t, 0, 
          110}, \[IndentingNewLine]PlotStyle \[Rule] {Hue[ .7], 
            Hue[ .9]}\ , \[IndentingNewLine]Ticks \[Rule] {Automatic, \ \[Pi]\
\ Range[\(-5\), 2, 1\ \ ]\ }\ , \[IndentingNewLine]Epilog \[Rule] 
          Map[Line, \({{0, #  \[Pi]}, {125, #  \[Pi]}\ } &\)\ \  /@ \ \ \
Range[\(-5\), 2]]\ \[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[\ 
        rd[t] {Sin[\[Theta]d[t]], \(-Cos[\[Theta]d[t]]\)} // Evaluate, {t, 0, 
          110}, \[IndentingNewLine]PlotStyle \[Rule] 
          Hue[ .9], \ \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic, \ \ \[IndentingNewLine]Epilog \[Rule] {\ \(Circle[{0, 
                    0}, #] &\) /@ {8, 6, 
                4}}\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[{
    \(\(\(pt1 = \[IndentingNewLine]\(ParametricPlot[\ {#[t], \(#'\)[t]\ \ } // 
                Evaluate, {t, 0, 
                110}, \[IndentingNewLine]PlotStyle \[Rule] {Hue[ .7], 
                  Hue[ .9]}\ , \[IndentingNewLine]Ticks \[Rule] 
                False, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\ \[IndentingNewLine]] &\)\  /@ \ {rd, \
\[Theta]d};\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[pt1]];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part e ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(line[
        t_] := \[IndentingNewLine]Show[\ \[IndentingNewLine]Graphics[\
\[IndentingNewLine]{{Line[{{0, 0}, 
                  rc[t] {Sin[\[Theta]c[
                          t]], \(-Cos[\[Theta]c[
                            t]]\)}}], \[IndentingNewLine]{PointSize[0.1], 
                Point[\ rd[
                      t] {Sin[\[Theta]c[
                          t]], \(-Cos[\[Theta]c[
                            t]]\)}]}}}, \[IndentingNewLine]PlotRange \[Rule] \
{{\(-10\), 10}, {\(-13\), 
                13}}\[IndentingNewLine]]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[{
    \(\(frames = 2;\)\), "\[IndentingNewLine]", 
    \(\(movie = \(line[#] &\)\  /@ \ 
          Range[0, 30, 30/\((\ frames - 1)\)];\)\ \)}], "Input",
  Hyphenation->False,
  AnimationDisplayTime->0.459482]
}, Closed]]
}, Closed]],

Cell[TextData[{
  "6.2 Lagrangian Problems with Lagrange Multipliers",
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]]
}], "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Overview of Nonholonomic Constraints and Lagrange Multipliers  \
\
\>", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Lag[qi_,L_ ,Qi_,t_:t] := 
D[ D[L,(D[qi[t],t])],t]-D[L,qi[t]]==Qi;
  
Lag[qi_List,L_,Qi_List,t_:t] :=
(D[ D[L,(D[qi[[#]][t],t])],t]-D[L,qi[[#]][t]]==Qi[[#]]
)&  /@  Range[1,Length[qi]];\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Protect[Lag];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 1: Atwood Machine  ",
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline: ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution    ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", 
          RowBox[{"Sum", "[", 
            RowBox[{
              RowBox[{\(m[i]\), " ", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox[\(x[i]\), "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}], 
              ",", \({i, 1, 2}\)}], "]"}]}]}], 
      ";"}], "\n", \(V = \((\(-g\))\)\ Sum[
            m[i]\ \(x[i]\)[t], {i, 1, 2}];\)}], "Input"],

Cell["L= T-V", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["f[1]=x[1][t]+x[2][t]-Len;", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(Qeq = \(D[f[1], \(x[#]\)[t]]\ \[Lambda][1] &\)\  /@ \ {1, 
          2}\)\(\ \)\(\[IndentingNewLine]\)
    \(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(eq2\)\(=\)\(Lag[{x[1], x[2]}, L, Qeq]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(f[1] \[Equal] 0\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = D[f[1] \[Equal] 0, {t, 2}]\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(eq4 = \((\((\(Solve[{eq2, \ eq3} // 
                      Flatten\ , {\ \[Lambda][1], \(\((x[2])\)''\)[
                        t], \(\((x[1])\)''\)[t]\ }, t]\  // 
                  Simplify\)\[IndentingNewLine] // 
                Flatten\ \[IndentingNewLine])\) /. {Rule \[Rule] 
                Equal}\[IndentingNewLine])\);\)\), "\[IndentingNewLine]", 
    \(eq4 // ColumnForm\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(initial = {\(x[1]\)[0] \[Equal] x0, \(\((x[1])\)'\)[0] \[Equal] 
            v0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(sol1 = \ \(\(DSolve[{eq4[\([{3}]\)], initial}\  // 
              Flatten, {\((x[1])\)[t]}, t] // 
          FullSimplify\)\(\ \)\(//\)\(Flatten\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(sol2 = {\(x[2]\)[t] \[Rule] Len - \(x[1]\)[t] /. sol1}\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Hoop Rolling on an Incline    ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              RowBox[{\(r\^2\), " ", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["\[Theta]", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
            ")"}]}]}], 
      ";"}], "\[IndentingNewLine]", \(V = 
        m\ g\ \((Len - x[t])\)\ Sin[\[Phi]];\), "\[IndentingNewLine]", \(L = 
      T - V\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(eq1 = r\ \[Theta][t] - x[t] \[Equal] 0;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(constraintForce = \[IndentingNewLine]{Q[
            1] \[Rule] \[Lambda]\ D[eq1[\([1]\)], x[t]], \[IndentingNewLine]Q[
            2] \[Rule] \[Lambda]\ D[eq1[\([1]\)], \[Theta][t]]}\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\({eqX, eq\[Theta]} = 
        Lag[{x, \[Theta]}, L, {Q[1], Q[2]}] //. 
          constraintForce;\)\), "\[IndentingNewLine]", 
    \({eqX, eq\[Theta]} // ColumnForm\)}], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(initial = {x[0] \[Equal] x0, \(x'\)[0] \[Equal] 
            v0, \[Theta][0] \[Equal] x0/r, \(\[Theta]'\)[0] \[Equal] 
            v0/r};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(xtSol = \(DSolve[{eqX, eq\[Theta], initial} // 
            Flatten, {x[t], \[Theta][t]}, t]\)[\([1]\)]\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\[Lambda]Sol = Solve[eq1 /. xtSol, \[Lambda]]\)], "Input",
  Hyphenation->False],

Cell["\<\
xtSol2= xtSol /.\[Lambda]Sol //ExpandAll //Flatten\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values = {x0 \[Rule] 0, v0 \[Rule] 0, 
          g \[Rule] \(-0.1\), \[Phi] \[Rule] \[Pi]/4, 
          r \[Rule] 2.0};\)\)], "Input"],

Cell["\<\
posx = ( x[t] Sin[\[Phi]]+ r Sin[\[Theta][t]]);
posy = ( x[t] Cos[\[Phi]]+ r Cos[\[Theta][t]]);\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["point={posx,posy} /.xtSol2 //.values;", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ParametricPlot[point // Evaluate, {t, 0, 70}, 
        AspectRatio \[Rule] 1\ ];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: Sphere Rolling on a Fixed Sphere   ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Tcm", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["r", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              RowBox[{\(r[t]\^2\), " ", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["\[Theta]1", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
            ")"}]}]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"Trot", "=", 
        RowBox[{\(1\/2\), " ", "I1", " ", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Theta]1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "+", 
                RowBox[{
                  SuperscriptBox["\[Theta]2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], ")"}], 
            "2"]}]}], ";"}]], "Input",
  Hyphenation->False],

Cell["T=Tcm+Trot; ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["V= m g r[t] Cos[\[Theta]1[t]]; ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["L=T-V", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
constraints= {b \[Theta]1[t] - a \[Theta]2[t]==0, r[t]-a-b==0 \
}\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(constraintRule\)\(=\)\(\ \)\(DSolve[constraints\ , {\[Theta]2, r}, 
        t]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(vars = {r[t], \[Theta]1[t], \[Theta]2[t]};\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Qeq = \(Sum[\[Lambda][j]*D[constraints[\([j, 1]\)], vars[\([#]\)]], {j, 
              1, 2}] &\)\  /@ \ {1, 2, 3}\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(eqMotion = \ 
        Lag[{r, \[Theta]1, \[Theta]2}, L, Qeq];\)\), "\[IndentingNewLine]", 
    \(eqMotion // ColumnForm\ \)}], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(\({\[Lambda]2Sol, \[Theta]Sol, \[Lambda]1Sol} = \((Solve[
                eqMotion //. constraintRule // 
                  Flatten, {\(\[Theta]1''\)[t], \[Lambda][1], \[Lambda][
                    2]}]\[IndentingNewLine] /. 
              Rule \[Rule] Equal\[IndentingNewLine] // 
            Flatten\[IndentingNewLine])\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \({\[Lambda]2Sol, \[Theta]Sol, \[Lambda]1Sol} // 
      ColumnForm\ \ \)}], "Input"],

Cell[BoxData[
    \(\(\(eq\[Theta]\)\(=\)\((\ \[Theta]Sol[\([1]\)] - \
\[Theta]Sol[\([2]\)])\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(int\[Theta] = \(Integrate[
              eq\[Theta]\ \ \(\[Theta]1'\)[t], {t, 0, 
                t}]\  //. {\[Theta]1[0] \[Rule] 0, \(\[Theta]1'\)[0] \[Rule] 
                0} // Simplify\) // Apart\)], "Input"],

Cell[BoxData[
    \(sol\[Theta] = \(Solve[
            int\[Theta] \[Equal] 
              0, {\(\[Theta]1'\)[
                t]}]\)[\([1]\)]\  /. \@\(\(-1\) + Cos[x_]\) \[Rule] \
\[ImaginaryI]\ \@\(1 - Cos[x]\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1 = \(\[Lambda]2Sol /. \[Lambda][2] \[Rule] 0\) //. 
        sol\[Theta]\)], "Input",
  Hyphenation->False],

Cell["\<\
sol2=Solve[eq1,Cos[\[Theta]1[t]]] //Flatten  \
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(sol3 = \(\(Solve[sol2 //. {Rule \[Rule] Equal}, \[Theta]1[t], 
          InverseFunctions \[Rule] 
            True]\)\(//\)\(Flatten\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\((\[Theta]1[t]/Degree)\) //. 
          sol3[\([2]\)]\) //. {I1 \[Rule] \(2\ a\^2\ m\)\/5} // N\)], "Input"]
}, Closed]]
}, Closed]],

Cell[TextData[{
  "6.3 Hamiltonian Problems ",
  StyleBox["  ",
    FontColor->RGBColor[1, 0, 0]]
}], "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Overview of Hamilton's Equations", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Hamilton[L_, xList_List, pList_List, 
        t_:  t] := \[IndentingNewLine]Module[{xx, vv, pp, sol, ham, eqp, eqx, 
          eqs}, \[IndentingNewLine]xx = 
          Through[xList[t]]; \[IndentingNewLine]vv = 
          D[xx, t]; \[IndentingNewLine]pp = 
          Through[pList[t]]; \[IndentingNewLine]sol = 
          Solve[\((\(D[L, #] &\) /@ vv)\) \[Equal] pp, vv] // 
            Flatten; \[IndentingNewLine]ham = \(pp . vv - L //. sol // 
              Simplify\) // Expand; \[IndentingNewLine]eqp = 
          D[pp, t] \[Equal] \(-Map[D[ham, #] &, xx]\) // 
            Thread; \[IndentingNewLine]eqx = 
          D[xx, t] \[Equal] \(+Map[D[ham, #] &, pp]\) // 
            Thread; \[IndentingNewLine]eqs = 
          Join[eqp, eqx]; \[IndentingNewLine]Return[{sol, ham, 
            eqs}]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(Clear[L, x, V]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{\(-V[x[t]]\), "+", 
          RowBox[{\(1\/2\), " ", "m", " ", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}], 
      ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\({pRule, hamiltonian, eqMotion} = 
        Hamilton[L, {x}, {px}];\)\), "\[IndentingNewLine]", 
    \(pRule\), "\[IndentingNewLine]", 
    \(hamiltonian\), "\[IndentingNewLine]", 
    \(eqMotion\)}], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{\(-V[x[t], y[t]]\), "+", 
          RowBox[{\(1\/2\), " ", "m", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}], 
              ")"}]}]}]}], ";"}], "\n", \(Hamilton[
      L, {x, y}, {px, py}]\)}], "Input"],

Cell["Protect[Hamilton];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 1: Harmonic Oscillator", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          SuperscriptBox[
            RowBox[{
              SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{" ", \(V = 1\/2\ k\ x[t]\^2;\)}]}], "Input"],

Cell[BoxData[
    \(L = T - V\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = p[t] \[Equal] D[L, \(x'\)[t]]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(xpRule = \(Solve[eq1, \(x'\)[t]]\)[\([1]\)]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(H = \((p[t]\ \(x'\)[t] - L)\) //. xpRule\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq2 = \[IndentingNewLine]{\(p'\)[
            t] \[Equal] \(-D[H, x[t]]\), \[IndentingNewLine]\(x'\)[
            t] \[Equal] \(+D[H, p[t]]\)}\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Hamilton[L, {x}, {p}] // ColumnForm\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(initial = {p[0] \[Equal] p0, x[0] \[Equal] x0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(dsol = \(DSolve[eq2~Join~initial, {p[t], x[t]}, t] // Flatten\)\  // 
        FullSimplify\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Nonlinear Oscillator    ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Remarks and Outline", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(firstDiffSeries[eqin_, {z_, p_}, initRule_List, order_, 
        t_:  t] := \[IndentingNewLine]Module[{eq, zSer, pSer, eSer, vars, 
          sol, zpsol}, \[IndentingNewLine]eq = 
          Table[eqin[\([i, 1]\)] - eqin[\([i, 2]\)] \[Equal] 0, {i, 
              2}]; \[IndentingNewLine]zSer = 
          Series[z[t], {t, 0, order}]; \[IndentingNewLine]pSer = 
          Series[p[t], {t, 0, order}]; \[IndentingNewLine]eSer = 
          eq //. \(({z[t] \[Rule] zSer, p[t] \[Rule] pSer})\) // 
            ExpandAll; \[IndentingNewLine]vars = \((Table[{D[z[t], {t, j}], 
                    D[p[t], {t, j}]}, {j, 1, order + 1}] /. t \[Rule] 0)\) // 
            Flatten; \ \ \ \ \ sol = 
          Solve[eSer, vars] // 
            Flatten; \[IndentingNewLine]zpSol = \({zSer, pSer} //. sol\) //. 
            initRule; \[IndentingNewLine]Return[
          zpSol]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"eq1", "=", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{\(w\^2\ x[t]\), "+", 
                RowBox[{
                  SuperscriptBox["p", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "==", "0"}], 
            ",", 
            RowBox[{\(p[t]\), "==", 
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], "}"}]}], 
      ";"}], "\[IndentingNewLine]", \(firstDiffSeries[
        eq1, {x, p}, {x[0] \[Rule] x0, p[0] \[Rule] p0}, 4, t] // 
      ColumnForm\)}], "Input"],

Cell[BoxData[
    \(firstOrderPert[eq1_, x_, {x0_, v0_}, eps_:  eps, 
        t_:  t] := \[IndentingNewLine]Module[{xRule, eq2, eqEps, initCon0, 
          initCon1, dsol1, 
          dsol2}, \[IndentingNewLine]xRule = {x \[Rule] \((\(x[0]\)[#] + 
                    eps\ \(x[1]\)[#] &)\)}; \[IndentingNewLine]eq2 = 
          eq1[\([1]\)] - eq1[\([2]\)] /. xRule; \[IndentingNewLine]eqEps = 
          CoefficientList[eq2, eps] \[Equal] 0 // 
            Thread; \[IndentingNewLine]initCon0 = {\(x[0]\)[0] \[Equal] 
              x0, \(\((x[0])\)'\)[0] \[Equal] 
              v0}; \[IndentingNewLine]initCon1 = {\(x[1]\)[0] \[Equal] 
              0, \(\((x[1])\)'\)[0] \[Equal] 
              0}; \[IndentingNewLine]dsol1 = \((DSolve[
                Join[{eqEps[\([1]\)]}, initCon0], {\(x[0]\)[t]}, t] // 
              Flatten)\); \[IndentingNewLine]dsol2 = \((DSolve[
                Join[{eqEps[\([2]\)]}, initCon1] //. dsol1, {\(x[1]\)[t]}, 
                t] // Flatten)\); \[IndentingNewLine]Return[\(x[t] /. 
              xRule\) //. Join[dsol1, dsol2]]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq1", "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "==", \(\(-k\^2\)\ x[t] + eps\ x[t]\^2\)}]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(firstOrderPert[eq1, x, {x0, 0}, eps, t] // Simplify\)\  // 
      Collect[#, eps] &\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          SuperscriptBox[
            RowBox[{
              SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
      ";"}], "\n", \(V = 
        1\/2\ k\ x[t]\^2 - 1\/4\ \[Epsilon]\ x[t]\^4;\)}], "Input"],

Cell[BoxData[
    \(\(L\  = T - V;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\({xprule, hamiltonian, eqMotion} = 
        Hamilton[L, {x}, {p}];\)\), "\[IndentingNewLine]", 
    \({xprule, hamiltonian, eqMotion} // ColumnForm\)}], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {k \[Rule] \ 1, \ \[Epsilon] \[Rule] 1/2, 
          m \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(\(pt1 = 
        Plot[V\  /. values // Evaluate, {x[t], \(-2\)\ , 2\ }, 
          DisplayFunction \[Rule] Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(pt2 = \ 
        ContourPlot[
          hamiltonian\  /. values // Evaluate, {x[t], \(-2\), 
            2\ }, \[IndentingNewLine]{p[t], \(-1\), 
            1}, \[IndentingNewLine]ColorFunction \[Rule] 
            Hue, \[IndentingNewLine]Contours \[Rule] 
            15, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity]\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[{pt2, pt1}]];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(solt = \(firstDiffSeries[
            eqMotion, {x, p}, {x[0] \[Rule] x0, p[0] \[Rule] 0}, 6] // 
          Normal\)\  // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = \((eqMotion // First)\) /. {\(p'\)[t] \[Rule] 
            m\ \(x''\)[t]}\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(sol\[Epsilon]\  = \(firstOrderPert[eq1, x, {x0, 0}, \[Epsilon]] // 
          Collect[#, {x0, \[Epsilon], \ \ Cos[x_]\ }] &\)\  // 
        Short[#, 1] &\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(test1 = \(solt[\([1]\)] /. \[Epsilon]^n_ /; n > 1 \[Rule] 0 // Apart\) // 
        Collect[#, t] &\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(test2 = \ 
      Series[sol\[Epsilon], {t, 0, 6}] // Normal\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(test1 \[Equal] test2\)], "Input"],

Cell[BoxData[
    \(\(values = {x0 \[Rule] 1.2\ , p0 \[Rule] 0, k \[Rule] 1, 
          m \[Rule] 1, \[Epsilon] \[Rule] 1/2};\)\)], "Input"],

Cell[BoxData[
    \(\(nsol = 
        NDSolve[{eqMotion /. values, p[0] \[Equal] 0, 
              x[0] \[Equal] 1.2\ \ }, {p[t], x[t]}, {t, 0\ , 30\ }] // 
          Flatten;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Plot[\({\ sol\[Epsilon]\ , solt[\([1]\)], x[t]} /. nsol\) /. 
            values\ \ \  // Evaluate, {t, 0, 
          30}, \[IndentingNewLine]PlotStyle \[Rule] {Dashing[{0.01}], 
            Dashing[{0.05}], \ 
            Thickness[0.005]}, \[IndentingNewLine]GridLines \[Rule] 
          Automatic]\ ;\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: Cylindrical Coordinates  ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Remarks and outline ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(firstDiffSeries[eqin_, {z_, p_}, initRule_List, order_, 
        t_:  t] := \[IndentingNewLine]Module[{eq, zSer, pSer, eSer, vars, 
          sol, zpsol}, \[IndentingNewLine]eq = 
          Table[eqin[\([i, 1]\)] - eqin[\([i, 2]\)] \[Equal] 0, {i, 
              2}]; \[IndentingNewLine]zSer = 
          Series[z[t], {t, 0, order}]; \[IndentingNewLine]pSer = 
          Series[p[t], {t, 0, order}]; \[IndentingNewLine]eSer = 
          eq //. \(({z[t] \[Rule] zSer, p[t] \[Rule] pSer})\) // 
            ExpandAll; \[IndentingNewLine]vars = \((Table[{D[z[t], {t, j}], 
                    D[p[t], {t, j}]}, {j, 1, order + 1}] /. t \[Rule] 0)\) // 
            Flatten; \ \ \ \ \ sol = 
          Solve[eSer, vars] // 
            Flatten; \[IndentingNewLine]zpSol = \({zSer, pSer} //. sol\) //. 
            initRule; \[IndentingNewLine]Return[
          zpSol]\[IndentingNewLine]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]],
  "Needs[\"Calculus`VectorAnalysis`\"]"
}], "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(rRule = 
      rVector \[Rule] \((Evaluate[
              CoordinatesToCartesian[{r[#], \[Theta][#], z[#]}, 
                Cylindrical]] &)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(T = \((1\/2\ m\ \(rVector'\)[t] . \(rVector'\)[t])\) //. rRule // 
        Simplify\), "\[IndentingNewLine]", 
    \(L = T - V[r[t], \[Theta][t], z[t]] // Simplify\)}], "Input"],

Cell[BoxData[
    \(\({pRule, hamiltonian, eqMotion} = 
        Hamilton[L, {r, \[Theta], z}, {pr, p\[Theta], pz}];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(pRule\)], "Input"],

Cell[BoxData[
    \(hamiltonian\)], "Input"],

Cell[BoxData[
    \(eqMotion // ColumnForm\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    \(\(vRule = {V \[Rule] \((\(-\(k\/\@\(#1\^2 + #3\^2\)\)\) &)\)};\)\), "\
\[IndentingNewLine]", 
    \(V[r[t], \[Theta][t], z[t]] //. vRule\)}], "Input"],

Cell[BoxData[
    \(\(zRule = {z \[Rule] \((0 &)\), pz \[Rule] \((0 &)\)};\)\)], "Input"],

Cell[BoxData[{
    \(\(eq1 = \(eqMotion //. vRule\) /. zRule // 
          PowerExpand;\)\), "\[IndentingNewLine]", 
    \(eq1 // ColumnForm\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq2 = eq1 //. p\[Theta] \[Rule] \((m\ h &)\)\)], "Input"],

Cell[BoxData[{
    \(\(rEq = eq2[\([{1, 4}]\)];\)\), "\[IndentingNewLine]", 
    \(rEq // ColumnForm\)}], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(initial = {r[0] \[Rule] r0, pr[0] \[Rule] 0};\)\)], "Input"],

Cell[BoxData[
    \(pert = \ \(\(firstDiffSeries[rEq, {r, pr}, initial, 4, 
          t]\)\(//\)\(Simplify\)\(\ \)\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 4: Swinging Atwood Machine   ", "Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    \(\(T = \(m\/2\) {\(x1'\)[t], \(y1'\)[t]} . \ {\(x1'\)[t], \(y1'\)[
                  t]} + \ M\/2\ \(x2'\)[t]\^2;\)\), "\[IndentingNewLine]", 
    \(\ \(V = \(-g\)\ \ m\ x1[t] - g\ \ \ M\ x2[t];\)\)}], "Input"],

Cell[BoxData[
    \(\(change = \[IndentingNewLine]{x1 \[Rule] \((r[#]\ Cos[\[Theta][#]] \
&)\), \[IndentingNewLine]y1 \[Rule] \((r[#]\ Sin[\[Theta][#]] &)\)};\)\)], \
"Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(L0Rule = x2 \[Rule] \((L0 - r[#] &)\);\)\)], "Input"],

Cell["L=T-V /.L0Rule /.change //Simplify ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\({xpRule, ham, eqMotion} = 
        Hamilton[L\ , {\[Theta], r}, {p\[Theta], pr}] // 
          Simplify;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(xpRule\)], "Input"],

Cell[BoxData[
    \(ham\)], "Input"],

Cell[BoxData[
    \(eqMotion // ColumnForm\)], "Input"],

Cell[BoxData[
    \(\(eqMotion /. {p\[Theta][t] \[Rule] 0, \ \[Theta][t] \[Rule] 
            0}\) /. \(\(r\)\(\ \)\(\[Rule]\)\((x1[#] &\ )\)\(\ \)\)\)], \
"Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {m \[Rule] 1, M \[Rule] 1.05, g \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(\(initial = {r[0] \[Equal] 10, 
          pr[0] \[Equal] 0, \[Theta][0] \[Equal] \[Pi]/12, 
          p\[Theta][0] \[Equal] 0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(eq1 = {eqMotion, initial} /. values // Flatten;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(nSol = 
        NDSolve[eq1, {r\ , pr, \[Theta]\ , p\[Theta]}, {t, 0, 250\ }\ \ ] // 
          Flatten\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\({r1[t_], \[Theta]1[t_], pr1[t_], 
          p\[Theta]1[t_]} = {r[t], \[Theta][t], pr[t], \ p\[Theta][t]} /. 
          nSol;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(Plot[{\ r1[t], \ \[Theta]1[t]} // Evaluate, {t, 0, 
          250}, \[IndentingNewLine]PlotStyle \[Rule] {Dashing[{0.01}], 
            Thickness[0.008]}\ ];\)\)\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[{\ 
            r1[t]\ Sin[\[Theta]1[t]], \(-r1[t]\)\ Cos[\[Theta]1[t]]} // 
          Evaluate, {t, 0, 80}];\)\)], "Input"],

Cell[BoxData[
    \(\(pt1 = \[IndentingNewLine]\(ParametricPlot[# // Evaluate, {t, 0, 
                250}, \[IndentingNewLine]Ticks \[Rule] 
                False, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\[IndentingNewLine]] &\)\  /@ \ \ {{\ r1[t]\ \ , \ 
              pr1[t]\ \ }, {\ \[Theta]1[t]\ \ , \ 
              p\[Theta]1[t]\ \ }};\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[pt1]];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 5: Spherical Pendulum ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages  ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`Shapes`\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution  ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{" ", 
      RowBox[{
        RowBox[{"T", "=", 
          RowBox[{\(1\/2\), " ", "m", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["z", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}], 
              ")"}]}]}], ";"}]}], "\[IndentingNewLine]", 
    RowBox[{\(V = m\ g\ z[t]\ ;\), " "}]}], "Input"],

Cell[BoxData[
    \(\(change = \[IndentingNewLine]{x\  \[Rule] \((L0\ \
Cos[\[Phi][#]]\ \ Sin[\ \[Theta][#]] &)\), \[IndentingNewLine]y\  \[Rule] \
\((L0\ Sin[\[Phi][#]]\ \ Sin[\ \[Theta][#]] &)\), \[IndentingNewLine]z\  \
\[Rule] \((L0\ Cos[\[Theta][#]] &)\)};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\[Psi]Rule = \ \[Theta] \[Rule] \((\[Pi] - \[Psi][#] &)\);\)\)], \
"Input",
  Hyphenation->False],

Cell[BoxData[
    \(L = \(T - V /. change\) /. \[Psi]Rule // Simplify\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(eq1 = \ \({prule, ham, eqMotion} = 
          Hamilton[L, {\[Psi], \[Phi]}, {p\[Psi], p\[Phi]}, 
            t]\);\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(prule\)], "Input"],

Cell[BoxData[
    \(ham\)], "Input"],

Cell[BoxData[
    \(eqMotion\  // ColumnForm\)], "Input"]
}, Closed]],

Cell[BoxData[
    \(eqMotion // ColumnForm\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(p\[Phi]Rule = {p\[Phi] \[Rule] \((m\ h &)\)};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(eqMotion /. p\[Phi]Rule // ColumnForm\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \ \)\(\(\(eqMotion\  /. \ p\[Phi]Rule\) /. h \[Rule] 0 // 
        ExpandAll\)\(//\)\(Flatten\)\(\ \ \)\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\(\(Solve[{eqMotion[\([1]\)], \ 
                  D[eqMotion[\([3]\)], t]}\ , \(\[Psi]''\)[t]]\  /. 
              Rule \[Rule] Equal\) /. \ p\[Phi]Rule\) /. h \[Rule] 0 // 
        ExpandAll\)\(//\)\(Flatten\)\(\ \ \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(eqMotion\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {L0 \[Rule] 1, g \[Rule] 1, m \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(\(initial = {\[Phi][0] == 0, 
          p\[Phi][0] \[Equal] 0.1, \[Psi][0] \[Equal] \[Pi]/2, 
          p\[Psi][0] \[Equal] 0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \ \)\(nSol\  = \ 
        NDSolve[\ \ {eqMotion, initial} /. values // 
              Flatten\ , {\[Psi], \[Phi], p\[Psi], p\[Phi]}, \ {t, \ 0, \ 
              25}]\  // Flatten\ ;\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\({\[Psi]1[t_]\ , \[Phi]1[t_]\ } = \ \ {\ \[Psi][t], \ \ \[Phi][t]\ } /. 
          nSol;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = \
\[IndentingNewLine]ParametricPlot3D[\[IndentingNewLine]\(\(\(\({x[t], y[t], 
                        z[t], Thickness[ .01]}\  /. change\) /. \[Psi]Rule\) /. 
                  values\) /. \[Psi] \[Rule] \[Psi]1\) /. \[Phi] \[Rule] \
\[Phi]1\  // Evaluate, \[IndentingNewLine]{t, 0, 
            25}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(Needs["\<Graphics`Shapes`\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(sphere = \ Graphics3D[Sphere[0.96]]\ \ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = 
        Show[\ sphere, pt1, Boxed \[Rule] False\ , Shading \[Rule] False, 
          ViewPoint \[Rule] {1, 1, 0}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[pt1 /. Polygon[x_] \[Rule] {Hue[0.8], Line[x]}, \ 
        ViewPoint \[Rule] {1, 0, 1/2}];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell["6.4 Hamilton-Jacobi Problems  ", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Overview", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(HamiltonJacobi[L_, xList_List, pList__List, wList_List, a_, 
        t_:  t] := \[IndentingNewLine]Module[{xx, vv, pp, sol, ham, ww, 
          hamPrincFunc, pNewRule, HJeq}, \[IndentingNewLine]xx = 
          Map[#[t] &, xList]; \[IndentingNewLine]vv = 
          Map[\(#'\)[t] &, xList]; \[IndentingNewLine]pp = 
          Map[#[t] &, pList]; \[IndentingNewLine]sol = 
          Solve[\((\(D[L, #] &\) /@ vv)\) \[Equal] pp, vv] // 
            Flatten; \[IndentingNewLine]ham = \(\((pp . vv - L)\) //. sol // 
              Simplify\) // Expand; \[IndentingNewLine]ww = 
          Map[#[t] &, 
            wList, {2}]; \[IndentingNewLine]hamPrincFunc = \((Plus @@ ww)\) - 
            a\ t; \[IndentingNewLine]pNewRule = {pp \[Rule] \((\(D[
                          hamPrincFunc, #] &\) /@ xx)\) // Thread} // 
            Flatten; \[IndentingNewLine]HJeq = \((ham //. pNewRule)\) - 
              a \[Equal] 0; \ \ \ \ \ \ \ \[IndentingNewLine]Return[{sol, 
            hamPrincFunc, HJeq}]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{
          RowBox[{\(+\(1\/2\)\), " ", "m", " ", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}], 
          "-", \(V[x[t]]\)}]}], 
      ";"}], "\[IndentingNewLine]", \({pRule, hamPrincFunc, eqHamJac} = 
        HamiltonJacobi[L, {x}, {p}, {W[x]}, a];\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(pRule\)], "Input"],

Cell[BoxData[
    \(hamPrincFunc\)], "Input"],

Cell[BoxData[
    \(eqHamJac\  // ColumnForm\)], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"L", "=", 
        RowBox[{
          RowBox[{\(+\(1\/2\)\), " ", "m", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}], 
              ")"}]}], "-", \(V[x[t], y[t]]\)}]}], 
      ";"}], "\[IndentingNewLine]", \(HamiltonJacobi[
      L, {x, y}, {px, py}, {W1[x], W2[y]}, a]\)}], "Input",
  Hyphenation->False],

Cell["Protect[ HamiltonJacobi ];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 1: Harmonic Oscillator   ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          SuperscriptBox[
            RowBox[{
              SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
      ";"}], "\[IndentingNewLine]", \(V = 
        1\/2\ k\ x[t]\^2;\), "\[IndentingNewLine]", \(L = T - V\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({xpRule, ham, eqMotion} = 
        Hamilton[L, {x}, {p}] //. {x_[t] \[Rule] x};\)\)], "Input"],

Cell[BoxData[
    \(xpRule\)], "Input"],

Cell[BoxData[
    \(ham\)], "Input"],

Cell[BoxData[
    \(eqMotion\)], "Input"]
}, Closed]],

Cell[BoxData[
    \(\(pRule = {p \[Rule] D[S[x, t], x]};\)\)], "Input"],

Cell["eqHJ = (ham + D[S[x,t],t]) ==0  //. pRule", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(sRule = {S \[Rule] \((W[#1] - P\ #2 &)\)};\)\)], "Input"],

Cell["eqW= eqHJ //.sRule", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell["dWRule= Solve[eqW,W'[x]][[2]]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(wRule = 
      W[x] \[Rule] \ \ \@\(2  m\ P\)\ \ Integrate[\@\(1 - x\^2\ \[Lambda]\), 
              x] /. \[Lambda] \[Rule] k\/\(2\ P\)\)], "Input"],

Cell["eq1= Q== D[S[x,t] /.sRule /.wRule,P] //Simplify ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
xSol= Solve[eq1,x ] //Simplify //PowerExpand //Simplify //Flatten \
\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq2 = \(xpRule /. Rule \[Rule] Equal // Solve[#, p] &\)\  // 
        Flatten\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq2 /. x' \[Rule] D[x /. xSol, t]\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Particle in a Constant Gravity Field  ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    StyleBox[\(Clear["\<Global`*\>"]\),
      FontFamily->"Courier",
      FontWeight->"Bold"]], "Input"],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["z", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
            ")"}]}]}], ";"}], "\n", \(V = g\ m\ z[t];\), "\n", \(L = 
      T - V\)}], "Input"],

Cell[BoxData[
    \({prule, S, Chareq} = 
      HamiltonJacobi[L, {x, z}, {px, pz}, {Wx[x]\ , Wz[z]}, P] // 
        ExpandAll\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(eq1a = 
      Chareq[\([1, {1, 2, 4}]\)] \[Equal] A\  /. 
        z[t] \[Rule] z\), "\[IndentingNewLine]", 
    \(eq1b = 
      Chareq[\([1, 3]\)] \[Equal] \(-A\)\ \ \  /. x[t] \[Rule] x\)}], "Input",\

  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    \(Wxsol = \(DSolve[eq1a, Wz[z], z]\)[\([2]\)]\), "\[IndentingNewLine]", 
    \(Wzsol = \(DSolve[eq1b, Wx[x], x]\)[\([2]\)]\)}], "Input"],

Cell[BoxData[
    \(Ssol = \(\(\(-P\)\ t + Wx[x] + Wz[z] /. \ 
          Wxsol\)\(/.\)\(Wzsol\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Qeq = \(\({Qx, 
              Qz} \[Equal] \((\ \(D[Ssol, #] &\) /@ {A, P} // Flatten)\) // 
          Thread\)\(\ \)\(//\)\(Simplify\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Sol = \(Solve[Qeq, {x, z}] /. {x \[Rule] x[t], z \[Rule] z[t]}\) /. 
          Rule \[Rule] Equal // Flatten\)], "Input"],

Cell[BoxData[
    \(\(\(\(Solve[{Sol, \((Sol /. t \[Rule] 0)\), \((D[Sol, t] /. 
                  t \[Rule] 0)\)} // Flatten, {x[t], z[t]}, {A, P, Qx, Qz}] // 
        Flatten\) // ExpandAll\)\(\n\)
    \)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3:  Kepler's Problem and Hamilton-Jacobi Equations ", \
"Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required package", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(rRule = 
      rvector \[Rule] \((Evaluate[
              CoordinatesToCartesian[{r[#], \[Theta][#], z[#]}, 
                Cylindrical]] &)\)\)], "Input"],

Cell[BoxData[{
    \(\(T = \(m\/2\ \(rvector'\)[t] . \(rvector'\)[t] //. 
              rRule\)\  //. {\(z'\)[t] \[Rule] 0}\  // 
          Simplify;\)\), "\[IndentingNewLine]", 
    \(\(V = \(-\(k\/r[t]\)\);\)\)}], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(L = T - V\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(\({momRule, hamPF, eqMotion} = 
        HamiltonJacobi[
          L, {r, \[Theta]}, {pr, p\[Theta]}, {Wr[r], W\[Theta][\[Theta]]}, 
          En];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \({momRule, hamPF, eqMotion} // ColumnForm\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(w\[Theta]rule = \(DSolve[{\(W\[Theta]'\)[\[Theta]] \[Equal] \(+el\), 
            W\[Theta][0] \[Equal] 
              0}, {W\[Theta]}, \[Theta]]\)[\([1]\)]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = \((eqMotion //. 
                w\[Theta]rule // \(Solve[#, \(Wr'\)[
                      r[t]]]\)[\([1]\)] &)\) /. \ \ r[t] \[Rule] r\  // 
        PowerExpand\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq2 = D[eq1[\([1, 2]\)], el]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = 
      Integrate[\ 1\/\(r\ \@\(\(-1\) + a\ r + b\ r\^2\)\), 
          r\ ] /. \ {a \[Rule] \(2\ k\ m\)\/el\^2, 
          b \[Rule] \(2\ En\ m\)\/el\^2}\)], "Input"],

Cell[BoxData[
    \(\(\(\ \ \)\(Qeq = \ 
      Q == \(\(\[Theta]\)\(\ \)\(+\)\(eq3\)\(\ \)\)\)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(ueq = Qeq /. r \[Rule] 1\/u\)], "Input"],

Cell[BoxData[
    \(usol = \(\(\(u\  /. \(Solve[ueq, u]\)[\([2]\)]\)\  /. {Q \[Rule] \[Pi]/
                    2\ } // Simplify\) // PowerExpand\) // 
        Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq4 = 
      usol \[Equal] \(1 + e\ Cos[\[Theta]]\)\/\(a\ \((1 - e\^2)\)\)\)], \
"Input"],

Cell[BoxData[
    \(eq5 = \ eq4 /. {\[Theta] \[Rule] {0, \[Pi]/2\ }}\  // Thread\)], "Input",\

  Hyphenation->False],

Cell[" Solve[eq5 ,{a,e}]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.5 Exercises", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 1: Atwood Machine  ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 2:  Double Atwood machine     ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Exercise 3: Spherical Pendulum ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 4: Double Pendulum", "Subsubsection",
  Hyphenation->False],

Cell["Exercise 5:  Spring Pendulum  ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 6:  Hamilton-Jacobi in parabolic coordinates", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Exercise 7:  How Hamilton Works",
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Exercise 8:  How HamiltonJacobi Works",
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Exercise 9:  How firstDiffSeries Works",
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Exercise 10: How firstOrderPert Works",
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{870, 688},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 116, 2, 42, "Subsubsection"],
Cell[1846, 56, 1886, 33, 657, "Input",
  Evaluatable->False]
}, Closed]],
Cell[3747, 92, 118, 3, 81, "Title",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3890, 99, 105, 3, 60, "Section",
  Evaluatable->False],
Cell[3998, 104, 144, 3, 43, "Input"]
}, Closed]],
Cell[4157, 110, 141, 3, 40, "Section",
  Evaluatable->False],
Cell[4301, 115, 163, 6, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4489, 125, 60, 0, 45, "Subsection"],
Cell[4552, 127, 96, 2, 27, "Input"],
Cell[4651, 131, 74, 2, 27, "Input"],
Cell[4728, 135, 113, 2, 24, "Input"],
Cell[4844, 139, 94, 2, 24, "Input"],
Cell[4941, 143, 74, 2, 24, "Input"],
Cell[5018, 147, 94, 2, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5149, 154, 140, 3, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5314, 161, 55, 1, 42, "Subsubsection"],
Cell[5372, 164, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5485, 171, 55, 1, 42, "Subsubsection"],
Cell[5543, 174, 872, 22, 62, "Input"],
Cell[6418, 198, 289, 5, 43, "Input"],
Cell[6710, 205, 67, 1, 27, "Input"],
Cell[6780, 208, 96, 2, 24, "Input"],
Cell[6879, 212, 90, 1, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7006, 218, 53, 1, 42, "Subsubsection"],
Cell[7062, 221, 126, 3, 27, "Input"],
Cell[7191, 226, 96, 2, 24, "Input"],
Cell[7290, 230, 91, 2, 24, "Input"],
Cell[7384, 234, 105, 2, 24, "Input"],
Cell[7492, 238, 110, 2, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7639, 245, 54, 1, 42, "Subsubsection"],
Cell[7696, 248, 319, 5, 59, "Input"],
Cell[8018, 255, 275, 4, 56, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8342, 265, 137, 3, 29, "Subsection",
  Evaluatable->False],
Cell[8482, 270, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[8621, 277, 103, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[8727, 282, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8840, 289, 102, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[8945, 294, 265, 5, 27, "Input"],
Cell[9213, 301, 116, 3, 27, "Input"],
Cell[9332, 306, 897, 22, 78, "Input"],
Cell[10232, 330, 87, 2, 24, "Input"],
Cell[10322, 334, 155, 3, 24, "Input"],
Cell[10480, 339, 225, 4, 24, "Input"],
Cell[10708, 345, 153, 3, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10898, 353, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[11002, 358, 247, 4, 59, "Input"],
Cell[11252, 364, 144, 3, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11433, 372, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[11537, 377, 152, 3, 27, "Input"],
Cell[11692, 382, 163, 3, 27, "Input"],
Cell[11858, 387, 345, 7, 91, "Input"],
Cell[12206, 396, 242, 6, 43, "Input"],
Cell[12451, 404, 117, 3, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12617, 413, 128, 3, 29, "Subsection",
  Evaluatable->False],
Cell[12748, 418, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[12887, 425, 103, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[12993, 430, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13106, 437, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[13210, 442, 287, 6, 27, "Input"],
Cell[13500, 450, 143, 3, 27, "Input"],
Cell[13646, 455, 944, 24, 44, "Input"],
Cell[14593, 481, 113, 2, 24, "Input"],
Cell[14709, 485, 98, 2, 27, "Input"],
Cell[14810, 489, 94, 2, 24, "Input"],
Cell[14907, 493, 194, 4, 28, "Input"],
Cell[15104, 499, 168, 3, 28, "Input"],
Cell[15275, 504, 137, 3, 24, "Input"],
Cell[15415, 509, 158, 3, 28, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15610, 517, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[15714, 522, 90, 1, 27, "Input"],
Cell[15807, 525, 91, 2, 24, "Input"],
Cell[15901, 529, 159, 3, 24, "Input"],
Cell[16063, 534, 131, 3, 24, "Input"],
Cell[16197, 539, 82, 2, 24, "Input"],
Cell[16282, 543, 110, 2, 24, "Input"],
Cell[16395, 547, 353, 7, 75, "Input"],
Cell[16751, 556, 576, 10, 104, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[17364, 571, 53, 1, 42, "Subsubsection"],
Cell[17420, 574, 695, 10, 107, "Input"],
Cell[18118, 586, 88, 2, 27, "Input"],
Cell[18209, 590, 248, 5, 56, "Input"],
Cell[18460, 597, 528, 11, 139, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19025, 613, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[19129, 618, 91, 1, 27, "Input"],
Cell[19223, 621, 77, 2, 27, "Input"],
Cell[19303, 625, 78, 1, 24, "Input"],
Cell[19384, 628, 120, 2, 28, "Input"],
Cell[19507, 632, 173, 3, 24, "Input"],
Cell[19683, 637, 256, 4, 24, "Input"],
Cell[19942, 643, 244, 7, 69, "Input"],
Cell[20189, 652, 463, 7, 75, "Input"],
Cell[20655, 661, 84, 2, 27, "Input"],
Cell[20742, 665, 370, 6, 56, "Input"],
Cell[21115, 673, 138, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[21290, 681, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[21394, 686, 179, 8, 87, "Input"],
Cell[21576, 696, 380, 7, 123, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22005, 709, 92, 1, 29, "Subsection"],

Cell[CellGroupData[{
Cell[22122, 714, 55, 1, 42, "Subsubsection"],
Cell[22180, 717, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[22293, 724, 55, 1, 42, "Subsubsection"],
Cell[22351, 727, 559, 15, 44, "Input"],
Cell[22913, 744, 138, 4, 44, "Input"],
Cell[23054, 750, 305, 5, 43, "Input"],
Cell[23362, 757, 71, 1, 27, "Input"],
Cell[23436, 760, 168, 4, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23641, 769, 53, 1, 42, "Subsubsection"],
Cell[23697, 772, 137, 3, 27, "Input"],
Cell[23837, 777, 148, 4, 27, "Input"],
Cell[23988, 783, 179, 4, 24, "Input"],
Cell[24170, 789, 138, 4, 24, "Input"],
Cell[24311, 795, 237, 5, 24, "Input"],
Cell[24551, 802, 169, 4, 24, "Input"],
Cell[24723, 808, 129, 3, 24, "Input"],
Cell[24855, 813, 90, 2, 24, "Input"],
Cell[24948, 817, 453, 7, 91, "Input"],
Cell[25404, 826, 102, 2, 27, "Input"],
Cell[25509, 830, 61, 2, 24, "Input"],
Cell[25573, 834, 162, 3, 24, "Input"],
Cell[25738, 839, 414, 7, 88, "Input"],
Cell[26155, 848, 102, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[26294, 855, 53, 1, 42, "Subsubsection"],
Cell[26350, 858, 446, 7, 91, "Input"],
Cell[26799, 867, 103, 2, 27, "Input"],
Cell[26905, 871, 481, 8, 88, "Input"],
Cell[27389, 881, 103, 2, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[27541, 889, 146, 3, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[27712, 896, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[27818, 901, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[27931, 908, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[28035, 913, 614, 15, 62, "Input"],
Cell[28652, 930, 104, 2, 27, "Input"],
Cell[28759, 934, 381, 10, 62, "Input"],
Cell[29143, 946, 83, 2, 27, "Input"],
Cell[29229, 950, 137, 3, 24, "Input"],
Cell[29369, 955, 193, 5, 40, "Input"],
Cell[29565, 962, 129, 3, 24, "Input"],
Cell[29697, 967, 837, 21, 43, "Input"],
Cell[30537, 990, 125, 3, 27, "Input"],
Cell[30665, 995, 197, 4, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[30899, 1004, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[31003, 1009, 131, 3, 27, "Input"],
Cell[31137, 1014, 163, 3, 24, "Input"],
Cell[31303, 1019, 125, 3, 24, "Input"],
Cell[31431, 1024, 136, 3, 24, "Input"],
Cell[31570, 1029, 109, 2, 27, "Input"],
Cell[31682, 1033, 306, 5, 72, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[32025, 1043, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[32129, 1048, 134, 3, 27, "Input"],
Cell[32266, 1053, 248, 4, 27, "Input"],
Cell[32517, 1059, 128, 5, 42, "Input"],
Cell[32648, 1066, 352, 6, 75, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[33049, 1078, 120, 3, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[33194, 1085, 55, 1, 42, "Subsubsection"],
Cell[33252, 1088, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[33365, 1095, 54, 1, 42, "Subsubsection"],
Cell[33422, 1098, 133, 3, 43, "Input"],
Cell[33558, 1103, 736, 18, 98, "Input"],
Cell[34297, 1123, 179, 3, 24, "Input"],
Cell[34479, 1128, 157, 3, 27, "Input"],
Cell[34639, 1133, 460, 7, 104, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[35136, 1145, 54, 1, 42, "Subsubsection"],
Cell[35193, 1148, 103, 2, 27, "Input"],
Cell[35299, 1152, 141, 3, 27, "Input"],
Cell[35443, 1157, 142, 3, 24, "Input"],
Cell[35588, 1162, 137, 3, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[35762, 1170, 56, 1, 42, "Subsubsection"],
Cell[35821, 1173, 152, 3, 27, "Input"],
Cell[35976, 1178, 260, 5, 27, "Input"],
Cell[36239, 1185, 150, 3, 27, "Input"],
Cell[36392, 1190, 173, 4, 27, "Input"],
Cell[36568, 1196, 104, 4, 42, "Input"],
Cell[36675, 1202, 418, 6, 91, "Input"],
Cell[37096, 1210, 490, 8, 104, "Input"],
Cell[37589, 1220, 481, 8, 120, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[38107, 1233, 56, 1, 42, "Subsubsection"],
Cell[38166, 1236, 149, 3, 27, "Input"],
Cell[38318, 1241, 269, 5, 27, "Input"],
Cell[38590, 1248, 148, 3, 27, "Input"],
Cell[38741, 1253, 149, 3, 27, "Input"],
Cell[38893, 1258, 107, 4, 42, "Input"],
Cell[39003, 1264, 416, 6, 91, "Input"],
Cell[39422, 1272, 461, 8, 104, "Input"],
Cell[39886, 1282, 517, 9, 136, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[40440, 1296, 54, 1, 42, "Subsubsection"],
Cell[40497, 1299, 594, 12, 139, "Input"],
Cell[41094, 1313, 222, 5, 43, "Input"]
}, Closed]]
}, Closed]],
Cell[41343, 1322, 205, 7, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[41573, 1333, 165, 6, 45, "Subsection",
  Evaluatable->False],
Cell[41741, 1341, 257, 9, 102, "Input"],
Cell[42001, 1352, 78, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[42116, 1359, 187, 7, 29, "Subsection",
  Evaluatable->False],
Cell[42306, 1368, 116, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[42447, 1375, 107, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[42557, 1380, 76, 2, 27, "Input"],
Cell[42636, 1384, 513, 13, 62, "Input"],
Cell[43152, 1399, 71, 2, 27, "Input"],
Cell[43226, 1403, 90, 2, 24, "Input"],
Cell[43319, 1407, 174, 4, 43, "Input"],
Cell[43496, 1413, 106, 2, 24, "Input"],
Cell[43605, 1417, 70, 2, 24, "Input"],
Cell[43678, 1421, 87, 2, 24, "Input"],
Cell[43768, 1425, 441, 8, 88, "Input"],
Cell[44212, 1435, 140, 3, 24, "Input"],
Cell[44355, 1440, 187, 3, 27, "Input"],
Cell[44545, 1445, 109, 2, 24, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[44703, 1453, 133, 3, 29, "Subsection",
  Evaluatable->False],
Cell[44839, 1458, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[44978, 1465, 103, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[45084, 1470, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[45197, 1477, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[45301, 1482, 744, 19, 78, "Input"],
Cell[46048, 1503, 98, 2, 24, "Input"],
Cell[46149, 1507, 238, 4, 59, "Input"],
Cell[46390, 1513, 222, 5, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[46649, 1523, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[46753, 1528, 196, 4, 27, "Input"],
Cell[46952, 1534, 172, 3, 27, "Input"],
Cell[47127, 1539, 100, 2, 24, "Input"],
Cell[47230, 1543, 123, 4, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[47390, 1552, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[47494, 1557, 156, 3, 27, "Input"],
Cell[47653, 1562, 168, 5, 42, "Input"],
Cell[47824, 1569, 102, 2, 27, "Input"],
Cell[47929, 1573, 117, 2, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[48095, 1581, 138, 3, 29, "Subsection",
  Evaluatable->False],
Cell[48236, 1586, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[48375, 1593, 103, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[48481, 1598, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[48594, 1605, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[48698, 1610, 618, 16, 44, "Input"],
Cell[49319, 1628, 541, 14, 44, "Input"],
Cell[49863, 1644, 77, 2, 27, "Input"],
Cell[49943, 1648, 96, 2, 27, "Input"],
Cell[50042, 1652, 70, 2, 27, "Input"],
Cell[50115, 1656, 138, 5, 24, "Input"],
Cell[50256, 1663, 147, 3, 24, "Input"],
Cell[50406, 1668, 111, 2, 24, "Input"],
Cell[50520, 1672, 169, 3, 27, "Input"],
Cell[50692, 1677, 180, 4, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[50909, 1686, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[51013, 1691, 496, 9, 107, "Input"],
Cell[51512, 1702, 137, 3, 24, "Input"],
Cell[51652, 1707, 234, 4, 24, "Input"],
Cell[51889, 1713, 225, 5, 28, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52151, 1723, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[52255, 1728, 129, 3, 27, "Input"],
Cell[52387, 1733, 118, 4, 24, "Input"],
Cell[52508, 1739, 176, 3, 24, "Input"],
Cell[52687, 1744, 131, 2, 43, "Input"]
}, Closed]]
}, Closed]],
Cell[52845, 1750, 182, 7, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[53052, 1761, 124, 3, 45, "Subsection",
  Evaluatable->False],
Cell[53179, 1766, 851, 15, 203, "Input"],
Cell[54033, 1783, 69, 2, 27, "Input"],
Cell[54105, 1787, 349, 10, 44, "Input"],
Cell[54457, 1799, 230, 5, 75, "Input"],
Cell[54690, 1806, 653, 16, 62, "Input"],
Cell[55346, 1824, 83, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[55466, 1831, 122, 3, 29, "Subsection",
  Evaluatable->False],
Cell[55591, 1836, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[55730, 1843, 103, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[55836, 1848, 76, 2, 27, "Input"],
Cell[55915, 1852, 351, 9, 80, "Input"],
Cell[56269, 1863, 64, 2, 27, "Input"],
Cell[56336, 1867, 90, 2, 24, "Input"],
Cell[56429, 1871, 98, 2, 24, "Input"],
Cell[56530, 1875, 95, 2, 24, "Input"],
Cell[56628, 1879, 197, 4, 56, "Input"],
Cell[56828, 1885, 90, 2, 24, "Input"],
Cell[56921, 1889, 106, 2, 24, "Input"],
Cell[57030, 1893, 145, 3, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[57224, 1902, 127, 3, 29, "Subsection",
  Evaluatable->False],
Cell[57354, 1907, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[57455, 1913, 66, 1, 42, "Subsubsection"],
Cell[57524, 1916, 915, 15, 171, "Input"],
Cell[58442, 1933, 668, 17, 48, "Input"],
Cell[59113, 1952, 1100, 17, 184, "Input"],
Cell[60216, 1971, 272, 7, 29, "Input"],
Cell[60491, 1980, 140, 3, 27, "Input"]
}, Closed]],
Cell[60646, 1986, 55, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[60726, 1991, 53, 1, 42, "Subsubsection"],
Cell[60782, 1994, 351, 9, 80, "Input"],
Cell[61136, 2005, 71, 2, 27, "Input"],
Cell[61210, 2009, 205, 4, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[61452, 2018, 53, 1, 42, "Subsubsection"],
Cell[61508, 2021, 112, 2, 27, "Input"],
Cell[61623, 2025, 152, 3, 27, "Input"],
Cell[61778, 2030, 379, 8, 91, "Input"],
Cell[62160, 2040, 91, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[62288, 2047, 53, 1, 42, "Subsubsection"],
Cell[62344, 2050, 185, 4, 27, "Input"],
Cell[62532, 2056, 134, 3, 24, "Input"],
Cell[62669, 2061, 208, 4, 24, "Input"],
Cell[62880, 2067, 153, 3, 24, "Input"],
Cell[63036, 2072, 128, 3, 24, "Input"],
Cell[63167, 2077, 53, 1, 24, "Input"],
Cell[63223, 2080, 140, 2, 24, "Input"],
Cell[63366, 2084, 212, 5, 27, "Input"],
Cell[63581, 2091, 340, 6, 59, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[63970, 2103, 128, 3, 29, "Subsection",
  Evaluatable->False],
Cell[64101, 2108, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[64202, 2114, 115, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[64320, 2119, 915, 15, 171, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[65272, 2139, 112, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[65387, 2144, 167, 6, 27, "Input"]
}, Closed]],
Cell[65569, 2153, 103, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[65697, 2160, 53, 1, 42, "Subsubsection"],
Cell[65753, 2163, 198, 5, 27, "Input"],
Cell[65954, 2170, 198, 3, 62, "Input"],
Cell[66155, 2175, 152, 3, 27, "Input"],
Cell[66310, 2180, 38, 1, 27, "Input"],
Cell[66351, 2183, 44, 1, 27, "Input"],
Cell[66398, 2186, 77, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[66512, 2193, 53, 1, 42, "Subsubsection"],
Cell[66568, 2196, 171, 3, 69, "Input"],
Cell[66742, 2201, 89, 1, 27, "Input"],
Cell[66834, 2204, 176, 4, 43, "Input"],
Cell[67013, 2210, 77, 1, 27, "Input"],
Cell[67093, 2213, 136, 3, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[67266, 2221, 53, 1, 42, "Subsubsection"],
Cell[67322, 2224, 82, 1, 27, "Input"],
Cell[67407, 2227, 151, 3, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[67607, 2236, 81, 1, 29, "Subsection"],

Cell[CellGroupData[{
Cell[67713, 2241, 55, 1, 42, "Subsubsection"],
Cell[67771, 2244, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[67884, 2251, 53, 1, 42, "Subsubsection"],
Cell[67940, 2254, 230, 3, 61, "Input"],
Cell[68173, 2259, 197, 4, 59, "Input"],
Cell[68373, 2265, 75, 1, 27, "Input"],
Cell[68451, 2268, 100, 2, 27, "Input"],
Cell[68554, 2272, 163, 4, 27, "Input"],
Cell[68720, 2278, 39, 1, 27, "Input"],
Cell[68762, 2281, 36, 1, 27, "Input"],
Cell[68801, 2284, 55, 1, 27, "Input"],
Cell[68859, 2287, 186, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[69082, 2296, 53, 1, 42, "Subsubsection"],
Cell[69138, 2299, 89, 1, 27, "Input"],
Cell[69230, 2302, 184, 4, 27, "Input"],
Cell[69417, 2308, 106, 2, 27, "Input"],
Cell[69526, 2312, 165, 4, 27, "Input"],
Cell[69694, 2318, 183, 4, 27, "Input"],
Cell[69880, 2324, 204, 3, 43, "Input"],
Cell[70087, 2329, 161, 3, 27, "Input"],
Cell[70251, 2334, 386, 6, 91, "Input"],
Cell[70640, 2342, 84, 2, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[70773, 2350, 189, 7, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[70987, 2361, 114, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[71104, 2366, 84, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[71225, 2373, 105, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[71333, 2378, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[71446, 2385, 53, 1, 42, "Subsubsection"],
Cell[71502, 2388, 839, 20, 62, "Input"],
Cell[72344, 2410, 298, 5, 75, "Input"],
Cell[72645, 2417, 119, 3, 27, "Input"],
Cell[72767, 2422, 104, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[72896, 2428, 183, 4, 27, "Input"],
Cell[73082, 2434, 38, 1, 27, "Input"],
Cell[73123, 2437, 36, 1, 27, "Input"],
Cell[73162, 2440, 57, 1, 27, "Input"]
}, Closed]],
Cell[73234, 2444, 77, 2, 27, "Input"],
Cell[73314, 2448, 104, 2, 27, "Input"],
Cell[73421, 2452, 106, 2, 27, "Input"],
Cell[73530, 2456, 168, 3, 27, "Input"],
Cell[73701, 2461, 258, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[73996, 2470, 53, 1, 42, "Subsubsection"],
Cell[74052, 2473, 63, 2, 27, "Input"],
Cell[74118, 2477, 87, 1, 27, "Input"],
Cell[74208, 2480, 184, 4, 27, "Input"],
Cell[74395, 2486, 246, 5, 27, "Input"],
Cell[74644, 2493, 146, 3, 27, "Input"],
Cell[74793, 2498, 430, 7, 107, "Input"],
Cell[75226, 2507, 84, 2, 27, "Input"],
Cell[75313, 2511, 99, 2, 27, "Input"],
Cell[75415, 2515, 158, 3, 27, "Input"],
Cell[75576, 2520, 132, 2, 27, "Input"]
}, Closed]]
}, Closed]],
Cell[75735, 2526, 119, 3, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[75879, 2533, 100, 3, 45, "Subsection",
  Evaluatable->False],
Cell[75982, 2538, 76, 2, 27, "Input"],
Cell[76061, 2542, 1047, 16, 219, "Input"],
Cell[77111, 2560, 477, 12, 62, "Input"],
Cell[77591, 2574, 38, 1, 27, "Input"],
Cell[77632, 2577, 45, 1, 27, "Input"],
Cell[77680, 2580, 57, 1, 27, "Input"],
Cell[77740, 2583, 728, 18, 62, "Input"],
Cell[78471, 2603, 91, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[78599, 2610, 125, 3, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[78749, 2617, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[78855, 2622, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[78968, 2629, 53, 1, 42, "Subsubsection"],
Cell[79024, 2632, 378, 9, 98, "Input"],

Cell[CellGroupData[{
Cell[79427, 2645, 116, 2, 27, "Input"],
Cell[79546, 2649, 39, 1, 27, "Input"],
Cell[79588, 2652, 36, 1, 27, "Input"],
Cell[79627, 2655, 41, 1, 27, "Input"]
}, Closed]],
Cell[79683, 2659, 71, 1, 27, "Input"],
Cell[79757, 2662, 106, 2, 27, "Input"],
Cell[79866, 2666, 79, 1, 27, "Input"],
Cell[79948, 2669, 83, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[80068, 2676, 53, 1, 42, "Subsubsection"],
Cell[80124, 2679, 94, 2, 27, "Input"],
Cell[80221, 2683, 169, 3, 44, "Input"],
Cell[80393, 2688, 113, 2, 27, "Input"],
Cell[80509, 2692, 141, 5, 27, "Input"],
Cell[80653, 2699, 132, 3, 27, "Input"],
Cell[80788, 2704, 88, 2, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[80925, 2712, 141, 3, 29, "Subsection",
  Evaluatable->False],
Cell[81069, 2717, 55, 1, 42, "Subsubsection"],
Cell[81127, 2720, 119, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[81271, 2727, 53, 1, 42, "Subsubsection"],
Cell[81327, 2730, 592, 15, 78, "Input"],
Cell[81922, 2747, 161, 4, 24, "Input"],
Cell[82086, 2753, 245, 7, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[82368, 2765, 53, 1, 42, "Subsubsection"],
Cell[82424, 2768, 155, 2, 43, "Input"],
Cell[82582, 2772, 138, 3, 24, "Input"],
Cell[82723, 2777, 198, 4, 24, "Input"],
Cell[82924, 2783, 141, 2, 24, "Input"],
Cell[83068, 2787, 219, 4, 40, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[83336, 2797, 153, 4, 29, "Subsection",
  Evaluatable->False],
Cell[83492, 2803, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[83631, 2810, 111, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[83745, 2815, 92, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[83874, 2822, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[83980, 2827, 76, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[84093, 2834, 53, 1, 42, "Subsubsection"],
Cell[84149, 2837, 92, 2, 27, "Input"],
Cell[84244, 2841, 176, 4, 27, "Input"],
Cell[84423, 2847, 224, 4, 76, "Input"],
Cell[84650, 2853, 78, 2, 27, "Input"],
Cell[84731, 2857, 311, 7, 56, "Input"],
Cell[85045, 2866, 211, 4, 24, "Input"],
Cell[85259, 2872, 223, 5, 24, "Input"],
Cell[85485, 2879, 83, 2, 24, "Input"],
Cell[85571, 2883, 192, 4, 46, "Input"],
Cell[85766, 2889, 131, 3, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[85934, 2897, 53, 1, 42, "Subsubsection"],
Cell[85990, 2900, 60, 1, 44, "Input"],
Cell[86053, 2903, 203, 4, 24, "Input"],
Cell[86259, 2909, 109, 3, 43, "Input"],
Cell[86371, 2914, 117, 3, 24, "Input"],
Cell[86491, 2919, 83, 2, 24, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[86623, 2927, 102, 3, 40, "Section",
  Evaluatable->False],
Cell[86728, 2932, 123, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[86854, 2937, 134, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[86991, 2942, 193, 7, 28, "Subsubsection",
  Evaluatable->False],
Cell[87187, 2951, 74, 1, 28, "Subsubsection"],
Cell[87264, 2954, 125, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[87392, 2959, 148, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[87543, 2964, 194, 7, 28, "Subsubsection",
  Evaluatable->False],
Cell[87740, 2973, 200, 7, 28, "Subsubsection",
  Evaluatable->False],
Cell[87943, 2982, 201, 7, 28, "Subsubsection",
  Evaluatable->False],
Cell[88147, 2991, 200, 7, 28, "Subsubsection",
  Evaluatable->False]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

