(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     64385,       2056]*)
(*NotebookOutlinePosition[     65079,       2081]*)
(*  CellTagsIndexPosition[     65035,       2077]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Legal Notice, Disclaimer, and Book Ordering Information:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "(* Legal Notice, Disclaimer, and Book Ordering Information:\n\nLast \
Modified: FIO June 8, 2002\n\n",
  StyleBox["Mathematica For Physics: 2nd Edition",
    FontColor->RGBColor[1, 0, 0]],
  "\n\nRobert L. Zimmerman and Fredrick I. Olness\n",
  "\nWebSite:  \n",
  StyleBox["  www.physics.smu.edu/~olness\n  darkwing.uoregon.edu/~phys600/\n\
\n",
    FontColor->RGBColor[1, 0, 0]],
  "MathSource Number: 0206-862",
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  "\nISBN 0-201-53796-6\nFor ordering information, call 1-800-282-0693\n\
Addison-Wesley Publishing Company\n",
  "\nCommunication with the authors:\nFredrick I. Olness:  \
olness@mail.physics.smu.edu\nRobert L. Zimmerman: bob@zim.uoregon.edu\n\n\
Copyright 2002, Addison-Wesley Publishing Company, Inc. The material in\nthis \
file may be distributed freely  so long as the content remains\nunchanged, \
and the copyright and  reference notices are included. The\npublisher grants \
permission for the noncommercial use of these programs\nand program segments. \
 All other uses require the prior written consent\nof the publisher.    \n\n\
All rights are reserved with regard to the  material in the\n\"Mathematica \
For Physics\" text, and may not be reproduced, stored in a\nretrieval system, \
or transmitted,  in any form or by any means,\nelectronic, mechanical, \
photocopying,  recording, or otherwise, without\nthe prior written permission \
 of the publisher. \n\nThe programs and applications presented in this book \
have been included\nfor  their instructional value. They have been tested \
with care but are\nnot  guaranteed for any particular purpose. The publisher \
does not\noffer any  warranties or representations, nor does it accept any\n\
liabilities with  respect to the programs or applications. \n\n *)\n"
}], "Input",
  Evaluatable->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell["7. Orbiting Bodies", "Title",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  Hyphenation->False],

Cell[BoxData[{
    \(\(Off[General::"\<spell\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Off[General::"\<spell1\>"];\)\)}], "Input",
  Hyphenation->False]
}, Closed]],

Cell["7.1 Two Body Problem ", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Overview of the Two-Body Problem", "Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 1: Equivalent One-body Problem  ",
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(eq1 = {M0 == m1 + m2, \[Mu] == \(m1\ m2\)\/M0};\)\)], "Input",
  Hyphenation->False],

Cell["mSol= Solve[eq1,{m1,m2}][[1]] ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(eq2 = {R[t] == \(m1\ r1[t] + m2\ r2[t]\)\/M0, 
          r[t] == r1[t] - r2[t]};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(sol1 = \((\((\(\(Solve[eq2, {r1[t], r2[t]}]\)[\([1]\)] //. 
                Rule \[Rule] Equal\) //. {M0 \[Rule] m1 + m2})\) // 
          MapAll[Apart, #] &)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(rSol = {r1 \[Rule] \((\(m2\ r[#1]\)\/\(m1 + m2\) + R[#1] &)\), 
          r2 \[Rule] \((\(-\(\(m1\ r[#1]\)\/\(m1 + m2\)\)\) + 
                  R[#1] &)\)};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{
          RowBox[{\(1\/2\), " ", "m1", " ", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["r1", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
          RowBox[{\(1\/2\), " ", "m2", " ", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["r2", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}], 
      ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(La = \ \(T - V[r0[t]] /. \ rSol\) /. mSol // Simplify\)], "Input",
  Hyphenation->False],

Cell[TextData[{
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]],
  "Needs[\"Calculus`VectorAnalysis`\"]  "
}], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(rRule = 
      r \[Rule] \((\((CoordinatesToCartesian[{r0[#], \[Theta][#], \[Phi][#]}, 
                  Spherical] // Evaluate)\) &)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(RRule = {R \[Rule] \(({Rx[#], Ry[#], Rz[#]} &)\)};\)\)], "Input",
  Hyphenation->False],

Cell["\<\
r/:VectorQ[r]=True; 
R/:VectorQ[R]=True;\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(vectorRule = \[IndentingNewLine]{x_[\ \ \ t_]^2 \[RuleDelayed] 
            x[\ \ \ t] . x[\ \ \ t] /; 
              VectorQ[x], \[IndentingNewLine]\(x_'\)[
                t_]^2 \[RuleDelayed] \(x'\)[t] . \(x'\)[t] /; 
              VectorQ[x]};\)\)], "Input",
  Hyphenation->False],

Cell["La //.vectorRule ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Lb= La //.vectorRule //.rRule //.RRule //Simplify", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Calculus`VariationalMethods`\>"]\)], "Input",
  Hyphenation->False],

Cell["EulerEquations[Lb,{Rx[t],Ry[t],Rz[t]},t]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(L = 
      Lb /. {Rx \[Rule] \((0 &)\), Ry \[Rule] \((0 &)\), 
            Rz \[Rule] \((0 &)\)} // Simplify\)], "Input"],

Cell[BoxData[{
    \(\(eqMotion = \((\(\(EulerEquations[Lb, {r0[t], \[Theta][t], \[Phi][t]}, 
                    t] // Solve[#, {\(r0''\)[t], \(\[Theta]''\)[
                          t], \(\[Phi]''\)[t]}] &\)\  // Flatten\)\  // 
              Simplify\ )\) /. 
          Rule \[Rule] Equal;\)\), "\[IndentingNewLine]", 
    \(eqMotion // ColumnForm\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\[Theta]Rule = \[Theta] \[Rule] \((\[Pi]/2 &)\);\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(eqMotion = \ eqMotion //. \[Theta]Rule;\)\), "\[IndentingNewLine]", 
    \(eqMotion // ColumnForm\ \)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(dSol = \(\(DSolve[{eqMotion[\([3]\)], 
              r0[0] \[Equal] Sqrt[el/\((\[Mu]\ \(\[Phi]'\)[0])\)]}, {r0[t]}, 
            t] // PowerExpand\)\(\ \)\(//\)\(Flatten\)\(\ \)\)\)], "Input"],

Cell["\<\
\[Phi]Rule= Solve[dSol /.{Rule->Equal} ,\[Phi]'[t]][[1]]\
\>", \
"Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
rEq=eqMotion[[1]] /.\[Phi]Rule //ExpandAll\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["energy= Integrate[(rEq[[1]]-rEq[[2]]) r0'[t],t]", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(eq3 = \(FirstIntegrals[L /. \ \[Theta]Rule, {r0[t], \ \ \[Phi][t]}\ , 
                t] /. {FirstIntegral[\[Phi]] \[Rule] \(-el\)\ , 
                FirstIntegral[t] \[Rule] En\ \ \[Mu]}\) /. 
            Rule \[Rule] Equal // ExpandAll;\)\), "\[IndentingNewLine]", 
    \(eq3 // ColumnForm\)}], "Input"],

Cell[BoxData[
    \(\(\(Solve[eq3\ , {\(\[Phi]'\)[t], En}] // Flatten\) // ExpandAll\) // 
      ColumnForm\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(uRule = {r0 \[Rule] \((1\/u[\[Phi][#1]] &)\)};\)\)], "Input"],

Cell[BoxData[
    \(\[Phi]Rule1 = {\[Phi]Rule, D[\[Phi]Rule, t]}\  //. uRule\  // 
        Flatten\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = \(\((\ \(Solve[\(rEq //. uRule\) //. \[Phi]Rule1, \(u''\)[\[Phi][
                      t]]]\)[\([1]\)]\ )\)\  /. 
            Rule \[Rule] Equal\) /. \[Phi][t] \[Rule] \[Phi] // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(eq4 = \(\(eq3\)\(//.\)\({\(V'\)[
              x_] \[Rule] \(-f[x]\)}\)\(\ \)\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Kepler Orbits      ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(\(Clear[diffSeriesOne];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(diffSeriesOne[eqin_, z_, t_, order_, 
          initList__List] := \[IndentingNewLine]Module[{eq, zSer, eSer, eqs, 
            vars, sol, zSol}, \[IndentingNewLine]eq = 
            eqin[\([1]\)] - eqin[\([2]\)] \[Equal] 
              0; \[IndentingNewLine]zSer = 
            Series[z[t], {t, 0, order}]; \[IndentingNewLine]eSer = 
            eq /. \((z[t] \[Rule] zSer)\) // 
              ExpandAll; \[IndentingNewLine]eqs = 
            Thread[CoefficientList[eSer[\([1]\)], t] \[Equal] 
                0]; \[IndentingNewLine]vars = \((Table[
                  D[z[t], {t, j}], {j, 2, order + 2}] /. 
                t \[Rule] 0)\); \ \ \ \ \ sol = \(Solve[eqs, 
                vars]\)[\([1]\)]; \[IndentingNewLine]zSol = \(zSer /. sol\) /. 
              initList; \[IndentingNewLine]Return[
            zSol]\[IndentingNewLine]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Protect[diffSeriesOne];\)\)}], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq1", "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox["u", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "\[Phi]", "]"}], 
          "==", \(\(-\(\(m\ f[1\/u[\[Phi]]]\)\/\(el\^2\ u[\[Phi]]\^2\)\)\) - 
            u[\[Phi]]\)}]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"forceRule", "=", 
        RowBox[{"{", 
          RowBox[{\(V \[Rule] \((\(-\(k\/#1\)\) &)\)\), ",", 
            RowBox[{\(f[1\/u[\[Phi]]]\), "\[Rule]", 
              RowBox[{"-", 
                RowBox[{
                  SuperscriptBox["V", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], 
            ",", \(r \[Rule] 1\/u[\[Phi]]\)}], "}"}]}], ";"}]], "Input"],

Cell["eq2= eq1 //.forceRule ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq3 = \(\(DSolve[{eq2, \(u'\)[0] \[Equal] 
                  0\ }, {u[\[Phi]]}, \[Phi]]\)[\([1]\)] // ExpandAll\) // 
        Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq4 = eq3 /. C[1] \[Rule] \(e\ k\ m\)\/el\^2 // Simplify\)], "Input"],

Cell[BoxData[
    \(eq5 = eq4 //. {el \[Rule] \@\(a\ \((1 - e\^2)\)\ k\ m\)}\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`Graphics`\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(?PolarPlot\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(plotOrbit[a_, e_, opts___] := 
        PolarPlot[
          a \((1 - e^2)\)/\((1 + e\ Cos[\[Phi]])\), {\[Phi], 0, 2\ \[Pi]}, 
          opts, DisplayFunction \[Rule] Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(list = 
        Table[plotOrbit[1, 
            eIn\ , \[IndentingNewLine]PlotStyle \[Rule] \ {Thickness[0.008], 
                Hue[eIn\ ]}], \ {eIn, 0.1, 0.9, 0.2}\ ];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[\ list\ , DisplayFunction -> $DisplayFunction];\)\)], "Input",
  Hyphenation->False],

Cell["plotOrbit[1,1.3,DisplayFunction->$DisplayFunction];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq2\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"initial", "=", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["u", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0"}],
             ",", \(u[0] \[Rule] \(\((1 + e)\)\ k\ m\)\/el\^2\)}], "}"}]}], 
      ";"}]], "Input"],

Cell[BoxData[
    \(seriesSol = \(diffSeriesOne[eq2, u, \[Phi], 6, initial] // Normal\) // 
        ExpandAll\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(cterm[
          n_] = \(\((\(-1\))\)\^n\ e\ k\ m\ \[Phi]\^\(2\ n\)\)\/\(el\^2\ \
\(\((2\ n)\)!\)\);\)\)], "Input"],

Cell[BoxData[
    \(seriesSol \[Equal] \((\(k\ m\)\/el\^2 + 
          Sum[cterm[i], {i, 0, 3}])\)\)], "Input"],

Cell[BoxData[
    \(answer = \(\(k\ m\)\/el\^2 + \[Sum]\+\(n = 0\)\%\[Infinity] cterm[
                n]\ \  // PowerExpand\) // Simplify\)], "Input"]
}, Closed]],

Cell[BoxData[
    \(\((u[\[Phi]]\  /. eq4\ )\) \[Equal] answer\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 3: Precessing Ellipse     ",
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(\(firstOrderPert[eq1_, x_, {x0_, v0_}, eps_:  eps, 
          t_:  t] := \[IndentingNewLine]Module[{xRule, eq2, eqEps, initCon0, 
            initCon1, dsol1, 
            dsol2}, \[IndentingNewLine]xRule = {x \[Rule] \((\(x[0]\)[#] + 
                      eps\ \(x[1]\)[#] &)\)}; \[IndentingNewLine]eq2 = 
            eq1[\([1]\)] - eq1[\([2]\)] /. xRule; \[IndentingNewLine]eqEps = 
            CoefficientList[eq2, eps] \[Equal] 0 // 
              Thread; \[IndentingNewLine]initCon0 = {\(x[0]\)[0] \[Equal] 
                x0, \(\((x[0])\)'\)[0] \[Equal] 
                v0}; \[IndentingNewLine]initCon1 = {\(x[1]\)[0] \[Equal] 
                0, \(\((x[1])\)'\)[0] \[Equal] 
                0}; \[IndentingNewLine]dsol1 = \((DSolve[
                  Join[{eqEps[\([1]\)]}, initCon0], {\(x[0]\)[t]}, t] // 
                Flatten)\); \[IndentingNewLine]dsol2 = \((DSolve[
                  Join[{eqEps[\([2]\)]}, initCon1] //. dsol1, {\(x[1]\)[t]}, 
                  t] // Flatten)\); \[IndentingNewLine]Return[\(x[t] /. 
                xRule\) //. 
              Join[dsol1, 
                dsol2]]\[IndentingNewLine]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Protect[firstOrderPert];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq1", "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox["u", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "\[Phi]", "]"}], 
          "==", \(\(-\(\(m\ f[1\/u[\[Phi]]]\)\/\(el\^2\ u[\[Phi]]\^2\)\)\) - 
            u[\[Phi]]\)}]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"forceRule", "=", 
        RowBox[{"{", 
          RowBox[{\(V \[Rule] \((\(-\(k\/#1\)\) - b\/#1\^2 &)\)\), ",", 
            RowBox[{\(f[1\/u[\[Phi]]]\), "\[Rule]", 
              RowBox[{"-", 
                RowBox[{
                  SuperscriptBox["V", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], 
            ",", \(r \[Rule] 1\/u[\[Phi]]\)}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
    \(eq2 = eq1 //. forceRule // ExpandAll\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = \ \(\((DSolve[{\ eq2, \(u'\)[0] \[Equal] 0}\ , 
              u[\[Phi]], \[Phi]])\)\  // Simplify\)\  // Flatten\)], "Input"],

Cell[BoxData[{
    \(\(CRule = \ 
        C[1] \[Rule] \ \(e\ k\ m\)\/\(\(\ \)\(el\^2 - 2\ b\ m\)\);\)\), "\
\[IndentingNewLine]", 
    \(uSol = \ eq3 /. CRule // Simplify\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"shiftRule", "=", 
        FormBox[\({\@\(el\^2 - 2\ b\ m\)\/el \[Rule] 1 - \[CapitalDelta]}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(eq3 /. CRule\) /. shiftRule // FullSimplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(elRule = \(Solve[{\(k\ m\)\/\(el\^2 - 2\ b\ m\) == 
                1\/\(a\ \((1 - e\^2)\)\)}, el]\)[\([2]\)]\  // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(\(\(eq3 /. CRule\) /. shiftRule\) /. elRule // Simplify\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(plotorbit[start_, finish_, {a_, e_, \[CapitalDelta]_}, opts___\ ] := 
      ParametricPlot[\ {\(a\ \((1 - e\^2)\)\ Cos[\[Phi]]\)\/\(1 + e\ Cos[\((1 \
- \[CapitalDelta])\)\ \[Phi]]\), \(a\ \((1 - e\^2)\)\ Sin[\[Phi]]\)\/\(1 + e\ \
Cos[\((1 - \[CapitalDelta])\)\ \[Phi]]\)} // Evaluate\ , {\[Phi], start, 
          finish}, opts\ ]\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(values = {\ 1, 0.5, 0.1\ \ };\)\)\)], "Input"],

Cell[BoxData[
    \(\(plotorbit[0, 6\ \[Pi], values, 
        PlotStyle \[Rule] {Thickness[0.008], Hue[0.8]}];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq2\)], "Input"],

Cell[BoxData[
    \(eq4 = \(\(firstOrderPert[eq2, 
                u, {\(\((1 + e)\)\ k\ m\)\/\(el\^2 - 2\ b\ m\), 0}, 
                b, \[Phi]]\ \  + O[b]\^2\  // Normal\) // Simplify\)\  // 
        Expand\)], "Input"],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \ \ \ \ \ \ \ \)\(\(u[\[Phi]]\)\(/.\)\(\ \)\(uSol\)\(\ \)\
\)\)\)], "Input"],

Cell[BoxData[
    \(eq5 = \(\(\(\((\ u[\[Phi]] /. \ uSol)\) + O[b]\^2\  // Normal\) // 
          ExpandAll\)\(//\)\(PowerExpand\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(eq4 \[Equal] eq5 // Simplify\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 4: Numerical Solution   ",
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq1", "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox["u", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "\[Phi]", "]"}], 
          "==", \(\(-\(\(m\ f[1\/u[\[Phi]]]\)\/\(el\^2\ u[\[Phi]]\^2\)\)\) - 
            u[\[Phi]]\)}]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"forceRule", "=", 
        RowBox[{"{", 
          RowBox[{\(V \[Rule] \((\(-\(k\/#1\)\) &)\)\), ",", 
            RowBox[{\(f[1\/u[\[Phi]]]\), "\[Rule]", 
              RowBox[{"-", 
                RowBox[{
                  SuperscriptBox["V", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], 
            ",", \(r \[Rule] 1\/u[\[Phi]]\)}], "}"}]}], ";"}]], "Input"],

Cell["eq2= eq1 //. forceRule ", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values = {k \[Rule] 1, el \[Rule] 1, m \[Rule] 1};\)\)], "Input"],

Cell["initial1={u[0]==1.6, u'[0]==0};", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ndsol1 = 
        NDSolve[{eq2 /. values, initial1} // Flatten, 
            u[\[Phi]], {\[Phi], 0, 2\ \[Pi]}] // Flatten;\)\)], "Input"],

Cell["\<\
u1[\[Phi]_]=u[\[Phi]]/.ndsol1;
u1[1.1]\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`Graphics`\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(PolarPlot[
        1\/u1[\[Phi]] // Evaluate, {\[Phi], 0, 2\ \[Pi]}];\)\)], "Input"],

Cell["initial2= {u[0]==3, u'[0]==0};", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ndsol2 = 
        NDSolve[{eq2 /. values, initial2} // Flatten, 
            u[\[Phi]], {\[Phi], 0, 2\ \[Pi]}] // Flatten;\)\)], "Input"],

Cell["\<\
u2[\[Phi]_]=u[\[Phi]] //.ndsol2;
u2[1.1]\
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PolarPlot[
        1\/u2[\[Phi]] // Evaluate, {\[Phi], 0, 2\ \[Pi]}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(numOrbit[V_, r_, {r0_:  1, dr0_:  0, el_:  1, m_:  1}, angle_\ , 
        opts___] := 
      Module[{u, \[Phi], uforce, eq1, initial, eqs, 
          ndsol}, \[IndentingNewLine]uforce = \(-D[V, r]\) /. 
            r \[Rule] 
              1/u[\[Phi]]; \[IndentingNewLine]eq1 = \((\(u''\)[\[Phi]] \
\[Equal] \(-u[\[Phi]]\) - m\ uforce/\((el^2\ u[\[Phi]]^2)\) // 
              ExpandAll)\); \[IndentingNewLine]initial = {u[0] \[Equal] 
              1/r0, \(u'\)[0] \[Equal] \ \(-dr0\)/
                r0^2\ }; \[IndentingNewLine]eqs = 
          Join[{eq1}, initial]; \[IndentingNewLine]ndsol = 
          NDSolve[eqs, u[\[Phi]], {\[Phi], 0, angle}] // 
            Flatten; \ \ PolarPlot[
          1/u[\[Phi]] /. ndsol // Evaluate, {\[Phi], 0, angle}, 
          opts, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(\(numOrbit[\(-\(1\/r\)\), r, { .6, 0, 1, 1}, 2\ \[Pi], 
        PlotStyle \[Rule] {Thickness[ .008], Hue[0.6]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(lista = \(numOrbit[#, r, {0.6, 0, 1, 1}, 6\ \[Pi], 
              PlotStyle \[Rule] {Thickness[0.008], 
                  Hue[0.6]}\ ] &\) /@ \ {\(-\(1\/r\^1.1`\)\), \(-\(1\/r\^0.9`\
\)\)};\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[lista]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(listb = \(numOrbit[#, r, {0.6, 0, 1, 1}, 6\ \[Pi], 
              PlotStyle \[Rule] {Thickness[0.008], 
                  Hue[0.6]}\ ] &\) /@ {\(-\(0.02`\/r\^3\)\) - 1\/r, 
            0.02`\/r\^3 - 1\/r};\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[listb]];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell["7.2 Restricted Three Body Problem", "Section",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["\<\
Overview of the Three Body Problem and Initialization of PMotion \
and Mgraph\
\>", "Subsection",
  Hyphenation->False],

Cell[BoxData[
    \(PMotion[\[Mu]1_, {x0_, y0_, vx0_, vy0_}, tmax_, 
        step_:  1000] := \[IndentingNewLine]Module[{rrule, Urule, eqMotion, 
          r1, r2, \[Mu], 
          U}, \[IndentingNewLine]rrule = {r1 \[Rule] \@\(\((\[Mu] + \
x[t])\)\^2 + y[t]\^2\), 
            r2 \[Rule] \@\(\((\(-1\) + \[Mu] + x[t])\)\^2 + y[t]\^2\)}; \
\[IndentingNewLine]Urule = {U \[Rule] \(1 - \[Mu]\)\/r1 + \[Mu]\/r2 + 
                1\/2\ \((x[t]\^2 + 
                      y[t]\^2)\)}; \[IndentingNewLine]eqMotion = \
\[IndentingNewLine]{\(x''\)[t] - 2\ \(y'\)[t] \[Equal] 
              D[\(U /. Urule\) /. rrule, x[t]], \(y''\)[t] + 
                2\ \(x'\)[t] \[Equal] 
              D[\(U /. Urule\) /. rrule, 
                y[t]]}; \[IndentingNewLine]NDSolve[{eqMotion /. \[Mu] \[Rule] \
\[Mu]1, x[0] \[Equal] x0, 
                y[0] \[Equal] y0, \(x'\)[0] \[Equal] vx0, \(y'\)[0] \[Equal] 
                  vy0} // Flatten, {x, y}, {t, 0, tmax}, 
            MaxSteps \[Rule] step] // Flatten]\)], "Input"],

Cell[BoxData[
    \(\(Mgraph[fx_, fy_, t_, tfinal_, 
          Opts___] := \[IndentingNewLine]ParametricPlot[{fx[t], fy[t]} // 
            Evaluate, \[IndentingNewLine]{t, 0, 
            tfinal}, \[IndentingNewLine]Opts, \[IndentingNewLine]AspectRatio \
\[Rule] Automatic, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell["Protect[PMotion,Mgraph];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell["\<\
Problems on the Equal Mass Primaries (\[Mu]=1/2 )\
\>", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Problem 1: Lagrangian Points for Equal Mass Binaries (\[Mu]=1/2 ) \
\
\>", "Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(Urule = 
        U \[Rule] \(1 - \[Mu]\)\/r1 + \[Mu]\/r2 + 
            1\/2\ \((x[t]\^2 + y[t]\^2)\);\)\)], "Input"],

Cell[BoxData[
    \(\(rrule = {r1 \[Rule] \@\(\((\[Mu] + x[t])\)\^2 + y[t]\^2\), 
          r2 \[Rule] \@\(\((\(-1\) + \[Mu] + x[t])\)\^2 + y[t]\^2\)};\)\)], \
"Input"],

Cell[BoxData[{
    \(\(\(\((eq1 = D[\(U\  /. Urule\) /. rrule, x[t]] \[Equal] 0\ )\) // 
      TraditionalForm\)\(\ \ \)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\((eq2 = D[\(U\  /. Urule\) /. rrule, y[t]] \[Equal] 0\ )\) // 
      TraditionalForm\ \ \ \ \)}], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\({L[2], L[3], L[4], L[5], 
          L[1]} = {eq1, eq2}\  /. \[Mu] \[Rule] 1\/2\  // 
          NSolve[#, {x[t], y[t]}] &;\)\), "\[IndentingNewLine]", 
    \({L[2], L[3], L[4], L[5], L[1]}\  // ColumnForm\)}], "Input"],

Cell[BoxData[
    \(\(CLpt = \(L[#] &\)\  /@ \ Range[5];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \({x[t], y[t]}\  /. {L[1\ ], L[2], L[3]}\  // 
      TableForm[#, 
          TableHeadings \[Rule] {\ {"\<L[1]\>", "\<L[2]\>", "\<L[3]\>"}\ , {\ 
                x[t], y[t]}\ }] &\)], "Input"],

Cell[BoxData[
    \({L[4], L[5]} // ColumnForm\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(\(\(r1 \[Equal] r2 \[Equal] 1 /. rrule\) /. 
        L[4]\) /. \[Mu] \[Rule] 1/2\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Lgraph = \ 
        Graphics[{{PointSize[0.02], 
              Hue[0.9], \ \ Map[
                Point, {x[t], y[t]} /. 
                  CLpt\ ]}\ , \[IndentingNewLine]\ \ \ \ \ \(Text[\ 
                  L\_#\ \ , {x[t] + 0.1, y[t]} /. CLpt[\([#]\)]\ ] &\) /@ \ 
              Range[5]}\ ];\)\)], "Input"],

Cell[BoxData[
    \(\(equilateral = \ 
        Graphics[{{PointSize[0.02], \ \ \ Point[{\(-\ 1\)/2, 0}\ \ ], \ 
              Point[{\ 1/2, 0}\ \ ]}, \[IndentingNewLine]{Thickness[0.002], 
              Hue[ .4], \ \ \ Line[\ {{\(-1\)/2, 0}\ , {x[t], y[t]} /. 
                    L[4], {1/2, 0}, {\(-1\)/2, 0}, {x[t], y[t]} /. 
                    L[5]\ \ \ , {\ 1/2, 0}}\ ]\ \ \ \ \ }, \(Text[\ 
                  L\_#\ \ , {x[t] + 0.1, y[t]} /. CLpt[\([#]\)]\ ] &\) /@ 
              Range[5]}\ ];\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(Show[Lgraph, equilateral, 
        AspectRatio \[Rule] Automatic];\)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = r1 \[Equal] r2 \[Equal] 1\ \  /. rrule\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(eq4\)\(=\)\(Solve[eq3, {x[t], y[t]}\ , 
        InverseFunctions \[Rule] True]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\({eq1, eq2} /. eq4\)\(//\)\(Simplify\)\(\ \ \)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"jacobi", " ", "=", 
      RowBox[{
        RowBox[{"C", "\[Equal]", " ", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"(", " ", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{
                      SuperscriptBox["x", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                  
                  SuperscriptBox[
                    RowBox[{
                      SuperscriptBox["y", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                ")"}]}], "+", \(2\ \ U\)}]}], "  ", "/.", "Urule", 
        "   "}]}]], "Input"],

Cell[BoxData[
    \(\(jacGC = 
        ContourPlot[\ \(\(2\ \ U\ \  /. Urule\) /. rrule\) /. \[Mu] \[Rule] 
                1/2 // Evaluate, \[IndentingNewLine]{x[t], \(-2\), 
            2}\ , {y[t], \(-2\)\ , 
            2\ }, \ \[IndentingNewLine]ContourShading \[Rule] 
            False, \[IndentingNewLine]Contours \[Rule] 
            Range[3, 4.5\ , 0.1], \[IndentingNewLine]PlotPoints \[Rule] 
            66, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity\ ];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[jacGC, Lgraph, equilateral, 
        DisplayFunction \[Rule] $DisplayFunction\ ];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 2: Looping Motion in an Equal Mass Binary System \
(\[Mu]=1/2) \
\>", "Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(sol = 
        PMotion[1/2, \ {0.3, 0, 0, 1.781\ }, 6\ \[Pi]\ , 1000];\)\)], "Input",\

  Hyphenation->False],

Cell[BoxData[{
    \(\(fx[t_] := x[t] /. sol;\)\ \ \), "\[IndentingNewLine]", 
    \(\(fy[t_] := y[t] /. sol\ ;\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = \ \ Mgraph[fx, fy, t, 
          6\ \[Pi]\ \ , \[IndentingNewLine]PlotPoints \[Rule] 
            100, \[IndentingNewLine]PlotStyle \[Rule] 
            Hue[0.9]\ , \ \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]Epilog \[Rule] {AbsolutePointSize[
                7], Point[{1/2, 
                  0}\ ]}, \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[pt1, PlotRange \[Rule] {{0.692, 0.709}, {\(-0.01\), 0.01\ }}, 
        Ticks \[Rule] False];\)\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[{{1\/2\ Cos[t], 
              1\/2\ Sin[t]\ }, {fx[t] Cos[t] - fy[t]\ Sin[t], 
              fx[t] Sin[t] + fy[t]\ Cos[t]}} // Evaluate, {t, 
          0, \ \ \ 2\ \[Pi]}, \[IndentingNewLine]PlotStyle \[Rule] {GrayLevel[
              0.3], Hue[0.6]}\ , \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(sol\)\(=\)\(PMotion[1/2, \ {\ 1.35\ , 0\ , 0, \(-\ 1.568\)\ }, 
        10\ \[Pi]\ , 1000]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(fx[t_] := x[t] /. sol;\)\ \ \), "\[IndentingNewLine]", 
    \(\(fy[t_] := y[t] /. sol\ ;\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Mgraph[fx, fy, t, 
        10\ \[Pi]\ , \[IndentingNewLine]PlotPoints \[Rule] 
          100, \[IndentingNewLine]PlotStyle \[Rule] 
          Hue[0.8], \[IndentingNewLine]PlotRange \[Rule] {{\ \(-0.5\)\ , 
              1.5\ }, {\(-1\), 
              1}}, \[IndentingNewLine]Epilog \[Rule] {AbsolutePointSize[7], 
            Point[{1/2, 
                0}\ ]\ }, \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction];\)\)], "Input"],

Cell[BoxData[
    \(\(pt1 = \[IndentingNewLine]\(ParametricPlot[\[IndentingNewLine]{{\(1\/2\
\) Cos[t], 1\/2\ Sin[t]\ }, 1.35 {\ \ Cos[t], \ Sin[t]\ }, 
                  1.1 {\ \ Cos[t], \ 
                      Sin[t]\ }, \[IndentingNewLine]{fx[t] Cos[t] - 
                      fy[t]\ Sin[t], fx[t] Sin[t] + fy[t]\ Cos[t]}} // 
                Evaluate, \[IndentingNewLine]{t, 
                0, #\ \[Pi]}, \[IndentingNewLine]PlotStyle \[Rule] {GrayLevel[
                    0.3], Hue[0.6], 
                  Hue[0.9]}, \[IndentingNewLine]AspectRatio \[Rule] 
                Automatic, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\[IndentingNewLine]] &\)\  /@ \ {2, 10};\)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[pt1]];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(sol\)\(=\)\(PMotion[1/2, {\(-0.01112\)\ , 0, 0, \ \(+1.538\)\ }, 
        10\ \[Pi], 1000]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(fx[t_] := x[t] /. sol\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(fy[t_] := y[t] /. sol\ ;\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(Mgraph[fx, fy, t, 
        10\ \ \[Pi]\ , \[IndentingNewLine]PlotPoints \[Rule] 
          100, \[IndentingNewLine]PlotStyle \[Rule] 
          Hue[0.6]\ \ , \[IndentingNewLine]Epilog \[Rule] {AbsolutePointSize[
              7], Point[{1/2, 
                0}\ ]}, \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction];\)\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 3: Symmetric orbits about the y-axis for \[Mu]=1/2 ",
  StyleBox["  ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(sol = 
        PMotion[1/2, {\ 0, 0.12067\ , \(-1.0600745428\)\ , 0\ }, 6\ \[Pi]\ , 
          1000]\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(fx[t_] := x[t] /. sol\ ;\)\ \ \), "\[IndentingNewLine]", 
    \(\(fy[t_] := y[t] /. sol\ ;\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(CLpt = \[IndentingNewLine]{{y[t] \[Rule] 0. , 
            x[t] \[Rule] 0. }, \[IndentingNewLine]{y[t] \[Rule] 0. , 
            x[t] \[Rule] \(-1.1984\)}, \[IndentingNewLine]{y[t] \[Rule] 0. , 
            x[t] \[Rule] 1.1984}, \[IndentingNewLine]{y[t] \[Rule] 0.8660, 
            x[t] \[Rule] 0. }, \[IndentingNewLine]{y[t] \[Rule] \(-0.8660\), 
            x[t] \[Rule] 0. }};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Mgraph[fx, fy, t, 
        6\ \[Pi], \[IndentingNewLine]PlotPoints \[Rule] 
          100, \[IndentingNewLine]PlotStyle \[Rule] 
          Hue[ .8], \ \[IndentingNewLine]Epilog \[Rule] {AbsolutePointSize[
              7], Point[{1/2\ , 0}\ ], 
            Point[{\ \(-1\)/2, 
                0}\ ], \(Point[{x[t], y[t]} /. CLpt[\([#]\)]\ ] &\)\  /@ \ 
              Range[4]\ }\ , \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 4: Mass exchange Between Equal Mass Binaries ", "Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(sol = 
        PMotion[1/2, {\ 0.044\ \ , 0\ , 0\ , 0\ \ }, 8\ , 
          1000]\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(fx[t_] := x[t] /. sol;\)\ \ \), "\[IndentingNewLine]", 
    \(\(fy[t_] := y[t] /. sol\ ;\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = \ 
        Mgraph[fx, fy, t, \ 
          8\ , \[IndentingNewLine]PlotPoints \[Rule] 
            100, \[IndentingNewLine]PlotStyle \[Rule] 
            Hue[ .8], \ \[IndentingNewLine]Epilog \[Rule] {AbsolutePointSize[
                7], Point[{0, 0}]\ , 
              Point[{1/2, 
                  0}]}, \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"jacobi", " ", "=", 
        RowBox[{"C", "\[Equal]", " ", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"(", " ", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{
                      SuperscriptBox["x", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                  
                  SuperscriptBox[
                    RowBox[{
                      SuperscriptBox["y", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                ")"}]}], "+", \(2\ \ U\)}]}]}], " ", ";"}]], "Input"],

Cell[BoxData[
    \(\(Urule = 
        U \[Rule] \(1 - \[Mu]\)\/r1 + \[Mu]\/r2 + 
            1\/2\ \((x[t]\^2 + y[t]\^2)\);\)\)], "Input"],

Cell[BoxData[
    \(\(rrule = {r1 \[Rule] \@\(\((\[Mu] + x[t])\)\^2 + y[t]\^2\), 
          r2 \[Rule] \@\(\((\(-1\) + \[Mu] + x[t])\)\^2 + y[t]\^2\)};\)\)], \
"Input"],

Cell[BoxData[
    \(\(\(\((\ \(\(\(\(\(\(jacobi /. Urule\) /. rrule\) /. \[Mu] -> 1\/2\) /. 
                y[t] \[Rule] 0\) /. \(x'\)[t] \[Rule] 0\)\  /. 
            x[t] \[Rule] 0.044\)\  /. \(y'\)[t] \[Rule] 
            0\ \ )\)[\([2]\)]\)\(\ \ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt2 = \ 
        ContourPlot[\ \(\(2\ \ U\ \  /. Urule\) /. rrule\) /. \[Mu] \[Rule] 
                1/2 // Evaluate, \[IndentingNewLine]{x[t], \(-1\), 
            1}\ , {y[t], \(- .5\)\ ,  .5\ }, \[IndentingNewLine]\ 
          ContourShading \[Rule] 
            False, \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]Contours \[Rule] {\ \ 4.033, \ 
              3.9\ , 3.5\ }, \ \[IndentingNewLine]PlotPoints \[Rule] 
            66, \ \ \[IndentingNewLine]Epilog \[Rule] \ 
            pt1[\([1]\)]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(sol = 
        PMotion[1/2, \ {\ 0.044\ \ , 0\ , 0.6\ \ , 0\ \ \ }, 35\ , 
          4000]\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(fx[t_] := x[t] /. sol\ \ ;\)\), "\[IndentingNewLine]", 
    \(\(fy[t_] := y[t] /. sol;\)\ \)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1\  = \ 
        Mgraph[fx, fy, t, \ 35\ , PlotPoints \[Rule] 100, 
          PlotStyle \[Rule] Hue[0.8]\ \ \ ];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt2 = \ 
        ContourPlot[\ \(\(2\ \ U\ \  /. Urule\) /. rrule\) /. \[Mu] \[Rule] 
                1/2 // Evaluate, \[IndentingNewLine]{x[t], \(-1.1\), 
            1.1}\ , {y[t], \(-0.6\)\ , 0.6\ }, \[IndentingNewLine]\ 
          ContourShading \[Rule] 
            False, \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]Contours \[Rule] {4, 3.6105, \ 
              3.5, \ 3.4\ , 3.3\ }, \ \[IndentingNewLine]PlotPoints \[Rule] 
            66, \ \ \[IndentingNewLine]Epilog \[Rule] \ 
            pt1[\([1]\)]];\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell["\<\
Problems on the Sun-Jupiter System (\[Mu]=.000954)  \
\>", \
"Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Problem 5:  Lagrangian Points for the Sun-Jupiter System  ", \
"Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      " ", \(Urule = 
          U \[Rule] \(1 - \[Mu]\)\/r1 + \[Mu]\/r2 + 
              1\/2\ \((x[t]\^2 + y[t]\^2)\);\)}], "\[IndentingNewLine]", 
    RowBox[{" ", 
      RowBox[{
        RowBox[{"jacobi", " ", "=", 
          RowBox[{
            RowBox[{"C", "\[Equal]", " ", 
              RowBox[{
                RowBox[{"-", 
                  RowBox[{"(", " ", 
                    RowBox[{
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["x", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"], 
                      "+", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["y", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}],
                     ")"}]}], "+", \(2\ \ U\)}]}], "  ", "/.", "Urule"}]}], 
        ";"}]}]}], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(rrule = {r1 \[Rule] \@\(\((\[Mu] + x[t])\)\^2 + y[t]\^2\), 
          r2 \[Rule] \@\(\((\(-1\) + \[Mu] + x[t])\)\^2 + y[t]\^2\)};\)\)\)], \
"Input"],

Cell[BoxData[
    \(\(jacGJ = 
        ContourPlot[\ \(\(2\ \ U\ \  /. Urule\) /. rrule\) /. \[Mu] \[Rule] 
                0.000954 // Evaluate, \[IndentingNewLine]{x[t], \(-1.2\), 
            1.2}\ , {y[t], \(-1.2\)\ , 
            1.2\ }\ , \ \[IndentingNewLine]ContourShading \[Rule] 
            False\ , \[IndentingNewLine]Contours \[Rule] 
            Range[3, 3.05\ , 0.01], \[IndentingNewLine]PlotPoints \[Rule] 
            150\ ];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \({L[5], 
        L[4]} = {{x[t] \[Rule] \ 1\/2\ \((1 - 2\ \[Mu])\), 
            y[t] \[Rule] \(-\(\@3\/2\)\)}, {x[t] \[Rule] 
              1\/2\ \((1 - 2\ \[Mu])\), 
            y[t] \[Rule] \ \@3\/2}} /. {\[Mu] \[Rule] 0.000954\ }\)], "Input"],

Cell[BoxData[{
    \(eq1 = \(D[\(U\ \  /. Urule\) /. rrule, x[t]] \[Equal] 
            0\  /. \ \[Mu] \[Rule]  .000954\) /. \(\(y[t] \[Rule] \ 
          0\)\(\[IndentingNewLine]\)
        \)\), "\[IndentingNewLine]", 
    \(eq2 = \(D[\(U\ \  /. Urule\) /. rrule, y[t]] \[Equal] 
            0\  /. \ \[Mu] \[Rule]  .000954\) /. \(\(y[
            t]\)\(\[Rule]\)\(0\)\(\ \ \ \ \)\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = \(\(\(FindRoot[\(eq1[\([1]\)] /. \ \[Mu] \[Rule] 0.000954\) /. 
              y[t] \[Rule] 0, {x[t], \ #\ }] &\)\  /@ \ {1, 
          0.9, \(-1\)\ }\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \({L[3], L[1], 
        L[2]} = \[IndentingNewLine]\(\(Outer[\ List, 
            eq3, \ {y[t] \[Rule] 0}\ ] // 
          Flatten\)\(//\)\(Partition[#, 2] &\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(JLpt = \(L[#] &\)\  /@ \ Range[5];\)\), "\[IndentingNewLine]", 
    \(JLpt\  // ColumnForm\)}], "Input"],

Cell[BoxData[
    \(\(Lgraph = \[IndentingNewLine]Graphics[\[IndentingNewLine]{PointSize[
                0.02], {Point[{\[Mu], 0}], 
                Point[{\ 1 - \[Mu], 0}]}, {PointSize[0.02], Hue[0.9], 
                Map[Point, {x[t], y[t]} /. JLpt\ ]}, \(Text[\ 
                    L\_#\ \ , {x[t]\ , y[t] + 0.1} /. \ 
                      JLpt[\([#]\)]\ ] &\)\  /@ \ \ Range[
                  5]\ \ \[IndentingNewLine]}\ \[IndentingNewLine]] /. \[Mu] \
\[Rule] 0.000954\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[jacGJ, \ Lgraph\ ];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 6: Numerical Solution for the Trojan Asteroids   ", "Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a  ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(initial = \ \({\ R\ Cos[\[Theta]], \ R\ Sin[\[Theta]], 0, 0} /. 
          R -> 1\/2\ \@\(3 + \((1 - 2\ \[Mu])\)\^2\)\) /. \[Mu] -> \ 
          0.000954\)], "Input"],

Cell[BoxData[
    \(\(\(sol = 
        PMotion[\ 0.000953875\ , 
          initial /. \[Theta] \[Rule] 35\ Degree\ \  // Flatten, 200\ , 
          1000];\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    \(\(fx[t_] := x[t] /. sol\ ;\)\), "\[IndentingNewLine]", 
    \(\(fy[t_] := y[t] /. sol\ ;\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = 
        Mgraph[fx, fy, t, 200\ , PlotPoints \[Rule] 100, 
          PlotStyle \[Rule] Hue[0.8]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(Urule = 
        U \[Rule] \(1 - \[Mu]\)\/r1 + \[Mu]\/r2 + 
            1\/2\ \((x[t]\^2 + y[t]\^2)\);\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(rrule = {r1 \[Rule] \@\(\((\[Mu] + x[t])\)\^2 + y[t]\^2\), 
          r2 \[Rule] \@\(\((\(-1\) + \[Mu] + x[t])\)\^2 + y[t]\^2\)};\)\)\)], \
"Input"],

Cell[BoxData[
    \(\(jacGJ = 
        ContourPlot[\ \(\(2\ \ U\ \  /. Urule\) /. rrule\) /. \[Mu] \[Rule] 
                0.000954 // Evaluate, \[IndentingNewLine]{x[t], \(-1.2\), 
            1.2}\ , {y[t], \(-1.2\)\ , 
            1.2\ }\ , \ \[IndentingNewLine]ContourShading \[Rule] 
            False\ , \[IndentingNewLine]Contours \[Rule] 
            Range[3, 3.05\ , 0.01], \[IndentingNewLine]PlotPoints \[Rule] 
            150\ , \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(JLpt = \[IndentingNewLine]{{x[t] \[Rule] 0.9324, 
            y[t] \[Rule] 0}, \[IndentingNewLine]{x[t] \[Rule] \(-1.0004\), 
            y[t] \[Rule] 0}, \[IndentingNewLine]{x[t] \[Rule] 1.0688\ , 
            y[t] \[Rule] 0}, \[IndentingNewLine]{x[t] \[Rule] 0.4990, 
            y[t] \[Rule] \@3\/2}, \[IndentingNewLine]{x[t] \[Rule] 0.4990, 
            y[t] \[Rule] \(-\(\@3\/2\)\)}};\)\)], "Input"],

Cell[BoxData[
    \(\(Lgraph = \[IndentingNewLine]Graphics[\[IndentingNewLine]{PointSize[
                0.02], {Point[{\[Mu], 0}], 
                Point[{\ 1 - \[Mu], 0}]}, \[IndentingNewLine]{PointSize[
                  0.02], Hue[0.9], 
                Map[Point, {x[t], y[t]} /. JLpt\ ]}, \(Text[\ 
                    L\_#\ \ , {x[t]\ , y[t] + 0.1} /. \ 
                      JLpt[\([#]\)]\ ] &\) /@ \ 
                Range[5]\ \ \[IndentingNewLine]}\ \[IndentingNewLine]]\ \  /. \
\[Mu] \[Rule]  .000954\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[jacGJ\ , pt1, 
        Lgraph, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.3\), 1.2}, {0, 
              1.2}}\ , \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[
        pt1, \[IndentingNewLine]PlotRange\  -> {{0.5, 0.85}, {0.55, 
              0.9}}, \[IndentingNewLine]Ticks \[Rule] 
          False, \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b  ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(sol = 
        PMotion[\ 0.000953875\ , 
          initial /. \[Theta] \[Rule] \ 20\ Degree\ \  // Flatten, 200\ , 
          1000]\ ;\)\)], "Input"],

Cell[BoxData[{
    \(\(fx[t_] := x[t] /. sol\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(fy[t_] := y[t] /. sol\ ;\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Mgraph[fx, fy, t, 
        160\ , \[IndentingNewLine]PlotPoints \[Rule] 
          100, \[IndentingNewLine]PlotStyle \[Rule] 
          Hue[0.8]\ , \[IndentingNewLine]Epilog \[Rule] 
          Lgraph[\([1]\)], \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction\ ];\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 7: Perturbative Solution for the Trojan Asteroids ", \
"Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a   ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(rrule = {r1 \[Rule] \@\(\((\[Mu] + x[t])\)\^2 + y[t]\^2\), 
          r2 \[Rule] \@\(\((\(-1\) + \[Mu] + x[t])\)\^2 + y[t]\^2\)};\)\)], \
"Input"],

Cell[BoxData[
    \(\(Urule = 
        U \[Rule] \(1 - \[Mu]\)\/r1 + \[Mu]\/r2 + 
            1\/2\ \((x[t]\^2 + y[t]\^2)\);\)\)], "Input"],

Cell[BoxData[{
    \(\(\(eqMotion = \[IndentingNewLine]{\(x''\)[t] - 2\ \(y'\)[t] \[Equal] 
            D[\(U /. Urule\) /. rrule\ , 
              x[t]], \[IndentingNewLine]\(y''\)[t] + 2\ \(x'\)[t] \[Equal] 
            D[\(U /. Urule\) /. rrule\ , y[t]]};\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(eqMotion // \ ColumnForm\) // TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(\(pert = \[IndentingNewLine]{y\  \[Rule] \((y0 + \[Eta]y[#] &)\), \
\[IndentingNewLine]x\  \[Rule] \((x0 + \[Eta]x[#] &)\)}\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(zeropt = {x0 \[Rule] 1\/2\ \((1 - 2\ \[Mu])\), 
          y0 \[Rule] \@3\/2};\)\)], "Input"],

Cell[BoxData[
    \(\(eq1 = eqMotion\  /. pert;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(\(eqPer = \(\((\((\(MapAt[\ 
                        Series[#\ , {\[Eta]x[t]\ , 0, 1}, {\[Eta]y[t]\ , 0, 
                              1}\ ] &\ , eq1[\([#]\)] /. zeropt\ , 2] // 
                      Normal\) // 
                    ExpandAll)\)\ \  /. \ \[Eta]x[t]\ \[Eta]y[t] \[Rule] 
                  0\ \ \[IndentingNewLine])\) &\)\ \  /@ \ \ {1, 
            2};\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(eqPer // ColumnForm\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(perSol = {\ \[Eta]x[t], \[Eta]y[t]} /. 
            DSolve[{eqPer, \[Eta]x[0] \[Equal] xi, \ \[Eta]y[0] \[Equal] 
                    yi, \[IndentingNewLine]\(\[Eta]x'\)[0] \[Equal] 
                    0, \ \(\[Eta]y'\)[0] \[Equal] 0} // 
                Flatten, \ {\[Eta]x[t], \[Eta]y[t]}, t] // 
          Flatten\ ;\)\)], "Input"],

Cell[BoxData[
    \(Short[perSol, 4]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\({\[CapitalOmega]1, \[CapitalOmega]2} = {\@\(\(-\(1\/2\)\) - 1\/2\ \
\@\(1 - 27\ \[Mu] + 27\ \[Mu]\^2\)\), \@\(\(-\(1\/2\)\) + 1\/2\ \@\(1 - 27\ \
\[Mu] + 27\ \[Mu]\^2\)\)};\)\)], "Input"],

Cell[BoxData[
    \({\[CapitalOmega]1, \[CapitalOmega]2} /. \[Mu] \[Rule] \ 
        0.000954\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Abs[{\[CapitalOmega]1, \[CapitalOmega]2} /. \[Mu] \[Rule] \ 
          0.000954]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \ \)\(\(11.86\)\(\ \)\({\ \(\(1\)\(\ \)\)\/0.997\ , \(\(1\)\(\ \)\
\)\/0.0805\ \ }\)\(\ \)\(yrs\)\(\ \ \ \)\)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(zeropt /. \(\(\[Mu]\)\(\[Rule]\)\(0.000954\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(\(trojanpert = \(\(\({0.499\  + perSol[\([1\ ]\)], \@3\/2 + 
                      perSol[\([2]\)]} /. {xi \[Rule] 0.0001, 
                    yi \[Rule] 0.0001}\) /. \[Mu] \[Rule] 0.000954\  // 
              ExpandAll\) // ExpToTrig\)\  // Chop;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(trojanpert // Short[#, 6] &\)}], "Input"],

Cell[BoxData[
    \(\(pt1 = 
        ParametricPlot[\ 
          trojanpert // Evaluate, \ {t, 0, 80}\ ];\)\)], "Input"],

Cell[BoxData[
    \(\(nSol = 
        PMotion[\ 
          0.000954\ , \ {\ 0.499\  + 0.0001, \ \ \@3\/2 + 0.0001, 0\ \ \ , \ 
              0\ \ } // Flatten, 80\ , 1000];\)\)], "Input"],

Cell[BoxData[{
    \(\(fx[t_] := x[t] /. nSol;\)\ \ \), "\[IndentingNewLine]", 
    \(\(fy[t_] := y[t] /. nSol\ ;\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Mgraph[fx, fy, t, 80\ , \[IndentingNewLine]PlotPoints \[Rule] 100, 
        PlotStyle \[Rule] {Hue[0.8], Thickness[0.01], 
            Dashing[{0.03}]}\ , \[IndentingNewLine]Epilog \[Rule] 
          pt1[\([1]\)], \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction\ \ ];\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell["\<\
Problems on the Earth-Moon System (\[Mu]= .01215)  \
\>", \
"Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Problem 8:  Lagrangian Points for the Earth-Moon System ", "Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(Urule = 
        U \[Rule] \(1 - \[Mu]\)\/r1 + \[Mu]\/r2 + 
            1\/2\ \((x[t]\^2 + y[t]\^2)\);\)\)], "Input"],

Cell[BoxData[
    RowBox[{"jacobi", " ", "=", 
      RowBox[{
        RowBox[{"C", "\[Equal]", " ", 
          RowBox[{
            RowBox[{"-", 
              RowBox[{"(", " ", 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{
                      SuperscriptBox["x", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                  
                  SuperscriptBox[
                    RowBox[{
                      SuperscriptBox["y", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                ")"}]}], "+", \(2\ \ U\)}]}], "  ", "/.", 
        "Urule"}]}]], "Input"],

Cell[BoxData[
    \(\(rrule = {r1 \[Rule] \@\(\((\[Mu] + x[t])\)\^2 + y[t]\^2\), 
          r2 \[Rule] \@\(\((\(-1\) + \[Mu] + x[t])\)\^2 + y[t]\^2\)};\)\)], \
"Input"],

Cell[BoxData[
    \(\(jacGE = 
        ContourPlot[\ \(\(2\ \ U\ \  /. Urule\) /. rrule\) /. \[Mu] \[Rule] 
                0.01215\  // Evaluate, \[IndentingNewLine]{x[t], \(-1.2\), 
            1.2}\ , {y[t], \(-1.2\)\ , 
            1.2\ }, \ \[IndentingNewLine]ContourShading \[Rule] 
            False, \[IndentingNewLine]Contours \[Rule] 
            Range[3, 3.55\ , 0.05], \[IndentingNewLine]PlotPoints \[Rule] 
            150\ ];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b ", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    \(\ eq1 = \(\(D[\(U\  /. Urule\) /. rrule, 
          x[t]]\)\(\[Equal]\)\(0\)\(\ \)\)\), "\[IndentingNewLine]", 
    \(\ eq2 = \(\(D[\(U\  /. Urule\) /. rrule, 
          y[t]]\)\(\[Equal]\)\(0\)\(\ \ \ \ \ \)\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = \(\(\(FindRoot[\(eq1[\([1]\)] /. \[Mu] \[Rule] 0.01215\)\  /. 
              y[t] \[Rule] 0, {x[t], \ #\ }] &\)\ \  /@ {1, 
          0.9, \(-1\)\ }\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \({L[1], L[2], 
        L[3]} = \[IndentingNewLine]\(\(Outer[\ List, 
            eq3, \ {y[t] \[Rule] 0}\ ] // 
          Flatten\)\(//\)\(Partition[#, 2] &\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(eq4 = \[IndentingNewLine]{{x[t] \[Rule] 1\/2\ \((1 - 2\ \[Mu])\), 
            y[t] \[Rule] \(-\(\@3\/2\)\)}, \[IndentingNewLine]{x[t] \[Rule] 
              1\/2\ \((1 - 2\ \[Mu])\), y[t] \[Rule] \@3\/2}};\)\)], "Input"],

Cell[BoxData[
    \({L[4], L[5]} = 
      eq4 /. \(\(\[Mu]\)\(\[Rule]\)\(0.01215\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(LptE = \(L[#] &\)\  /@ \ Range[5]\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Lgraph = \[IndentingNewLine]Graphics[\[IndentingNewLine]{PointSize[ \
.02], {Point[{\[Mu], 0}], 
                Point[{\ 1 - \[Mu], 
                    0}]}, \[IndentingNewLine]{PointSize[ .02], Hue[ .9], 
                Map[Point, {x[t], y[t]} /. 
                    LptE]}\ \[IndentingNewLine]}\ \[IndentingNewLine]]\ \  /. \
\[Mu] \[Rule] 0.01215;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[jacGE, \ Lgraph\ ];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 9: Motion about L[4] in the Earth-Moon System  ", "Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"eqPer", "=", "\[IndentingNewLine]", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{\(-2\), " ", 
                  RowBox[{
                    SuperscriptBox["\[Eta]y", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}]}], "+", 
                RowBox[{
                  SuperscriptBox["\[Eta]x", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], 
              "==", \(\(3\ \[Eta]x[t]\)\/4 + 
                3\/4\ \@3\ \((1 - 2\ \[Mu])\)\ \[Eta]y[t]\)}], ",", 
            RowBox[{
              RowBox[{
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["\[Eta]x", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}]}], "+", 
                RowBox[{
                  SuperscriptBox["\[Eta]y", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], 
              "==", \(3\/4\ \@3\ \((1 - 2\ \[Mu])\)\ \[Eta]x[
                    t] + \(9\ \[Eta]y[t]\)\/4\)}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
    \(perSol = \(\(\(\(\({\[Eta]x[t], \[Eta]y[
                        t]} /. \[IndentingNewLine]DSolve[{eqPer, \[Eta]x[
                              0] \[Equal] 0.0001, \[Eta]y[0] \[Equal] 
                            0.0001, \ \(\[Eta]x'\)[0] \[Equal] 
                            0, \(\[Eta]y'\)[0] \[Equal] 0} // 
                        Flatten, {\[Eta]x[t], \[Eta]y[t]}, 
                      t\[IndentingNewLine]]\) /. \[Mu] \[Rule] 0.01215\  // 
                Flatten\) // ExpandAll\) // ExpToTrig\)\  // Simplify\) // 
        Chop\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(zeropt = {x0 \[Rule] 1\/2\ \((1 - 2\ \[Mu])\), 
          y0 \[Rule] \@3\/2} /. \[Mu] \[Rule]  .01215\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(position\  = {x0, y0} + perSol /. zeropt\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = 
        ParametricPlot[\ position // Evaluate, {t, 0, 80}\ ];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(nSol\)\(=\)\(PMotion[\ 
        0.01215\ , \ {0.48785 + 0.0001, \@3\/2 + 0.0001, 0\ , 0\ } // 
          Flatten, 80\ , 1000]\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    \(\(fx[t_] := x[t] /. nSol\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(fy[t_] := y[t] /. nSol\ ;\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(Mgraph[fx, fy, t, 
        80\ , \[IndentingNewLine]PlotPoints \[Rule] 100, 
        PlotStyle \[Rule] {Thickness[0.008], Dashing[{0.05}], Hue[0.8]\ }, 
        DisplayFunction \[Rule] $DisplayFunction, \[IndentingNewLine]Epilog \
\[Rule] pt1[\([1]\)]\ \ ];\)\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 10:  Orbit  around  the  Earth and Moon", "Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(sol = 
        PMotion[0.01215\ , {1.2\ , 0\ , 0\ , \(-1.5\)\ \ \ \ }, 2  \[Pi]\ , 
          3000]\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(fx[t_] := x[t] /. sol\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(fy[t_] := y[t] /. sol\ ;\)\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = 
        Mgraph[fx, fy, t, 
          2\ \[Pi], \[IndentingNewLine]PlotPoints \[Rule] 
            100, \[IndentingNewLine]PlotStyle \[Rule] 
            Hue[0.8], \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction\ ];\)\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[\[IndentingNewLine]{{\ \ Cos[t], \ \ Sin[
                t]\ }, \[IndentingNewLine]{fx[t] Cos[t] - 
                fy[t]\ Sin[t], \ \[IndentingNewLine]fx[t] Sin[t] + 
                fy[t]\ Cos[t]}} // Evaluate, \[IndentingNewLine]{t, 
          0, \ \ \ 2\ \[Pi]}, \[IndentingNewLine]PlotStyle \[Rule] {GrayLevel[
              0.3], Hue[0.6], 
            Hue[0.9]}, \[IndentingNewLine]AspectRatio \[Rule] 
          Automatic];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3 Exercises  ", "Section",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 1: Central force problems", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 2: Central force procedure", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 3: Central forces and elliptical solutions", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 4 : Attractive Inverse fifth power force", "Subsection",
  Hyphenation->False],

Cell["Exercise 5: Eccentric Anomaly", "Subsection",
  Hyphenation->False],

Cell["Exercise 6: Eccentric Anomaly", "Subsection",
  Hyphenation->False],

Cell["Exercise 7: Kepler problem with drag", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 8: Lagrange points  ", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 9:  Orbit around the Sun and Jupiter  ", "Subsection",
  Hyphenation->False],

Cell["Exercise 10: Exact Solution for the Three-Body Problem", "Subsection",
  Hyphenation->False]
}, Closed]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{763, 688},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 116, 2, 42, "Subsubsection"],
Cell[1846, 56, 1886, 33, 657, "Input",
  Evaluatable->False]
}, Closed]],
Cell[3747, 92, 105, 3, 81, "Title",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3877, 99, 53, 1, 60, "Section"],
Cell[3933, 102, 154, 3, 43, "Input"]
}, Closed]],
Cell[4102, 108, 110, 3, 40, "Section",
  Evaluatable->False],
Cell[4215, 113, 76, 1, 45, "Subsection"],

Cell[CellGroupData[{
Cell[4316, 118, 199, 7, 45, "Subsection",
  Evaluatable->False],
Cell[4518, 127, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4657, 134, 103, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[4763, 139, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[4864, 145, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[4968, 150, 106, 2, 44, "Input"],
Cell[5077, 154, 95, 2, 27, "Input"],
Cell[5175, 158, 139, 3, 41, "Input"],
Cell[5317, 163, 215, 4, 27, "Input"],
Cell[5535, 169, 216, 4, 41, "Input"],
Cell[5754, 175, 552, 15, 44, "Input"],
Cell[6309, 192, 108, 2, 27, "Input"],
Cell[6420, 196, 169, 6, 24, "Input"],
Cell[6592, 204, 191, 4, 27, "Input"],
Cell[6786, 210, 109, 2, 24, "Input"],
Cell[6898, 214, 113, 5, 42, "Input"],
Cell[7014, 221, 306, 6, 59, "Input"],
Cell[7323, 229, 82, 2, 27, "Input"],
Cell[7408, 233, 114, 2, 24, "Input"],
Cell[7525, 237, 96, 2, 24, "Input"],
Cell[7624, 241, 105, 2, 27, "Input"],
Cell[7732, 245, 141, 3, 24, "Input"],
Cell[7876, 250, 365, 6, 56, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8278, 261, 102, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[8383, 266, 107, 2, 27, "Input"],
Cell[8493, 270, 158, 3, 43, "Input"],
Cell[8654, 275, 212, 3, 24, "Input"],
Cell[8869, 280, 131, 5, 24, "Input"],
Cell[9003, 287, 115, 4, 24, "Input"],
Cell[9121, 293, 112, 2, 24, "Input"],
Cell[9236, 297, 330, 5, 40, "Input"],
Cell[9569, 304, 142, 3, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9748, 312, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[9852, 317, 83, 1, 46, "Input"],
Cell[9938, 320, 133, 3, 27, "Input"],
Cell[10074, 325, 235, 4, 24, "Input"],
Cell[10312, 331, 134, 3, 24, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10507, 341, 122, 3, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[10654, 348, 114, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[10771, 353, 1085, 20, 235, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11893, 378, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[11999, 383, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[12100, 389, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[12204, 394, 328, 8, 55, "Input"],
Cell[12535, 404, 440, 10, 46, "Input"],
Cell[12978, 416, 87, 2, 27, "Input"],
Cell[13068, 420, 189, 4, 24, "Input"],
Cell[13260, 426, 89, 1, 42, "Input"],
Cell[13352, 429, 89, 1, 33, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13478, 435, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[13582, 440, 86, 2, 27, "Input"],
Cell[13671, 444, 69, 2, 27, "Input"],
Cell[13743, 448, 213, 4, 27, "Input"],
Cell[13959, 454, 207, 4, 43, "Input"],
Cell[14169, 460, 111, 2, 27, "Input"],
Cell[14283, 464, 116, 2, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14436, 471, 102, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[14541, 476, 58, 2, 27, "Input"],
Cell[14602, 480, 369, 10, 42, "Input"],
Cell[14974, 492, 144, 3, 27, "Input"],
Cell[15121, 497, 137, 3, 46, "Input"],
Cell[15261, 502, 111, 2, 45, "Input"],
Cell[15375, 506, 151, 2, 47, "Input"]
}, Closed]],
Cell[15541, 511, 75, 1, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15665, 518, 193, 7, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[15883, 529, 114, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[16000, 534, 1265, 21, 219, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[17302, 560, 103, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[17408, 565, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[17509, 571, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[17613, 576, 328, 8, 55, "Input"],
Cell[17944, 586, 451, 10, 46, "Input"],
Cell[18398, 598, 91, 2, 27, "Input"],
Cell[18492, 602, 151, 2, 24, "Input"],
Cell[18646, 606, 185, 4, 59, "Input"],
Cell[18834, 612, 185, 4, 45, "Input"],
Cell[19022, 618, 100, 2, 27, "Input"],
Cell[19125, 622, 165, 3, 43, "Input"],
Cell[19293, 627, 110, 2, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19440, 634, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[19544, 639, 363, 5, 66, "Input"],
Cell[19910, 646, 76, 1, 27, "Input"],
Cell[19989, 649, 147, 3, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20185, 658, 79, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[20267, 662, 36, 1, 27, "Input"],
Cell[20306, 665, 222, 4, 42, "Input"],
Cell[20531, 671, 110, 2, 24, "Input"],
Cell[20644, 675, 151, 2, 26, "Input"],
Cell[20798, 679, 61, 1, 24, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20908, 686, 191, 7, 29, "Subsection",
  Evaluatable->False],
Cell[21102, 695, 114, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[21241, 702, 103, 3, 28, "Subsubsection",
  Evaluatable->False],
Cell[21347, 707, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[21448, 713, 102, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[21553, 718, 328, 8, 55, "Input"],
Cell[21884, 728, 440, 10, 46, "Input"],
Cell[22327, 740, 88, 2, 27, "Input"],
Cell[22418, 744, 87, 1, 24, "Input"],
Cell[22508, 747, 96, 2, 27, "Input"],
Cell[22607, 751, 159, 3, 27, "Input"],
Cell[22769, 756, 111, 5, 42, "Input"],
Cell[22883, 763, 86, 2, 24, "Input"],
Cell[22972, 767, 106, 2, 46, "Input"],
Cell[23081, 771, 95, 2, 24, "Input"],
Cell[23179, 775, 159, 3, 27, "Input"],
Cell[23341, 780, 113, 5, 42, "Input"],
Cell[23457, 787, 106, 2, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23600, 794, 102, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[23705, 799, 891, 16, 171, "Input"],
Cell[24599, 817, 220, 4, 44, "Input"],
Cell[24822, 823, 226, 4, 41, "Input"],
Cell[25051, 829, 86, 2, 27, "Input"],
Cell[25140, 833, 242, 4, 41, "Input"],
Cell[25385, 839, 86, 2, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[25510, 846, 74, 1, 40, "Section"],

Cell[CellGroupData[{
Cell[25609, 851, 129, 4, 45, "Subsection"],
Cell[25741, 857, 1016, 18, 178, "Input"],
Cell[26760, 877, 356, 6, 107, "Input"],
Cell[27119, 885, 89, 2, 27, "Input"]
}, Closed]],
Cell[27223, 890, 149, 5, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[27397, 899, 120, 4, 45, "Subsection"],

Cell[CellGroupData[{
Cell[27542, 907, 52, 1, 45, "Subsection"],
Cell[27597, 910, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[27698, 916, 54, 1, 42, "Subsubsection"],
Cell[27755, 919, 139, 3, 44, "Input"],
Cell[27897, 924, 168, 3, 37, "Input"],
Cell[28068, 929, 313, 6, 59, "Input"],
Cell[28384, 937, 240, 4, 59, "Input"],
Cell[28627, 943, 93, 2, 24, "Input"],
Cell[28723, 947, 210, 4, 27, "Input"],
Cell[28936, 953, 81, 2, 24, "Input"],
Cell[29020, 957, 149, 3, 24, "Input"],
Cell[29172, 962, 332, 7, 40, "Input"],
Cell[29507, 971, 515, 8, 59, "Input"],
Cell[30025, 981, 135, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[30197, 989, 53, 1, 42, "Subsubsection"],
Cell[30253, 992, 99, 2, 27, "Input"],
Cell[30355, 996, 147, 3, 24, "Input"],
Cell[30505, 1001, 106, 2, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[30648, 1008, 53, 1, 42, "Subsubsection"],
Cell[30704, 1011, 708, 18, 31, "Input"],
Cell[31415, 1031, 503, 9, 104, "Input"],
Cell[31921, 1042, 145, 3, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[32127, 1052, 123, 4, 29, "Subsection"],

Cell[CellGroupData[{
Cell[32275, 1060, 55, 1, 42, "Subsubsection"],
Cell[32333, 1063, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[32434, 1069, 53, 1, 42, "Subsubsection"],
Cell[32490, 1072, 131, 4, 27, "Input"],
Cell[32624, 1078, 149, 3, 43, "Input"],
Cell[32776, 1083, 449, 8, 107, "Input"],
Cell[33228, 1093, 134, 2, 24, "Input"],
Cell[33365, 1097, 368, 6, 94, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[33770, 1108, 53, 1, 42, "Subsubsection"],
Cell[33826, 1111, 159, 3, 27, "Input"],
Cell[33988, 1116, 149, 3, 40, "Input"],
Cell[34140, 1121, 466, 9, 107, "Input"],
Cell[34609, 1132, 717, 11, 182, "Input"],
Cell[35329, 1145, 84, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[35450, 1152, 53, 1, 42, "Subsubsection"],
Cell[35506, 1155, 159, 3, 27, "Input"],
Cell[35668, 1160, 149, 3, 40, "Input"],
Cell[35820, 1165, 377, 7, 91, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[36258, 1179, 171, 5, 29, "Subsection"],

Cell[CellGroupData[{
Cell[36454, 1188, 55, 1, 42, "Subsubsection"],
Cell[36512, 1191, 76, 2, 27, "Input"],
Cell[36591, 1195, 162, 4, 27, "Input"],
Cell[36756, 1201, 151, 3, 43, "Input"],
Cell[36910, 1206, 439, 7, 107, "Input"],
Cell[37352, 1215, 482, 9, 91, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[37883, 1230, 97, 1, 29, "Subsection"],

Cell[CellGroupData[{
Cell[38005, 1235, 55, 1, 42, "Subsubsection"],
Cell[38063, 1238, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[38164, 1244, 54, 1, 42, "Subsubsection"],
Cell[38221, 1247, 143, 4, 27, "Input"],
Cell[38367, 1253, 149, 3, 43, "Input"],
Cell[38519, 1258, 414, 9, 91, "Input"],
Cell[38936, 1269, 681, 17, 28, "Input"],
Cell[39620, 1288, 139, 3, 44, "Input"],
Cell[39762, 1293, 168, 3, 37, "Input"],
Cell[39933, 1298, 290, 5, 44, "Input"],
Cell[40226, 1305, 578, 10, 120, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[40841, 1320, 54, 1, 42, "Subsubsection"],
Cell[40898, 1323, 152, 4, 27, "Input"],
Cell[41053, 1329, 149, 3, 43, "Input"],
Cell[41205, 1334, 173, 4, 27, "Input"],
Cell[41381, 1340, 589, 10, 123, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[42009, 1355, 154, 6, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[42188, 1365, 104, 2, 45, "Subsection"],

Cell[CellGroupData[{
Cell[42317, 1371, 55, 1, 42, "Subsubsection"],
Cell[42375, 1374, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[42476, 1380, 53, 1, 42, "Subsubsection"],
Cell[42532, 1383, 975, 24, 66, "Input"],
Cell[43510, 1409, 178, 3, 37, "Input"],
Cell[43691, 1414, 457, 8, 91, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[44185, 1427, 54, 1, 42, "Subsubsection"],
Cell[44242, 1430, 265, 5, 48, "Input"],
Cell[44510, 1437, 419, 8, 56, "Input"],
Cell[44932, 1447, 220, 4, 24, "Input"],
Cell[45155, 1453, 220, 5, 40, "Input"],
Cell[45378, 1460, 127, 2, 40, "Input"],
Cell[45508, 1464, 496, 8, 104, "Input"],
Cell[46007, 1474, 83, 2, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[46151, 1483, 101, 1, 29, "Subsection"],

Cell[CellGroupData[{
Cell[46277, 1488, 55, 1, 42, "Subsubsection"],
Cell[46335, 1491, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[46436, 1497, 55, 1, 42, "Subsubsection"],
Cell[46494, 1500, 186, 3, 44, "Input"],
Cell[46683, 1505, 177, 4, 24, "Input"],
Cell[46863, 1511, 147, 3, 43, "Input"],
Cell[47013, 1516, 162, 4, 27, "Input"],
Cell[47178, 1522, 149, 3, 44, "Input"],
Cell[47330, 1527, 178, 3, 37, "Input"],
Cell[47511, 1532, 523, 9, 107, "Input"],
Cell[48037, 1543, 426, 6, 161, "Input"],
Cell[48466, 1551, 532, 9, 107, "Input"],
Cell[49001, 1562, 219, 4, 59, "Input"],
Cell[49223, 1568, 269, 6, 72, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[49529, 1579, 55, 1, 42, "Subsubsection"],
Cell[49587, 1582, 171, 4, 27, "Input"],
Cell[49761, 1588, 149, 3, 43, "Input"],
Cell[49913, 1593, 312, 6, 91, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[50286, 1606, 104, 2, 29, "Subsection"],

Cell[CellGroupData[{
Cell[50415, 1612, 55, 1, 42, "Subsubsection"],
Cell[50473, 1615, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[50574, 1621, 56, 1, 42, "Subsubsection"],
Cell[50633, 1624, 168, 3, 37, "Input"],
Cell[50804, 1629, 139, 3, 44, "Input"],
Cell[50946, 1634, 385, 6, 91, "Input"],
Cell[51334, 1642, 183, 3, 56, "Input"],
Cell[51520, 1647, 114, 2, 48, "Input"],
Cell[51637, 1651, 84, 2, 27, "Input"],
Cell[51724, 1655, 492, 9, 91, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52253, 1669, 53, 1, 42, "Subsubsection"],
Cell[52309, 1672, 357, 6, 43, "Input"],
Cell[52669, 1680, 71, 2, 27, "Input"],
Cell[52743, 1684, 209, 3, 47, "Input"],
Cell[52955, 1689, 128, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[53120, 1697, 53, 1, 42, "Subsubsection"],
Cell[53176, 1700, 135, 3, 27, "Input"],
Cell[53314, 1705, 172, 3, 41, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[53523, 1713, 53, 1, 42, "Subsubsection"],
Cell[53579, 1716, 107, 2, 27, "Input"],
Cell[53689, 1720, 378, 6, 79, "Input"],
Cell[54070, 1728, 120, 3, 24, "Input"],
Cell[54193, 1733, 187, 4, 45, "Input"],
Cell[54383, 1739, 151, 3, 43, "Input"],
Cell[54537, 1744, 318, 5, 75, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[54894, 1754, 153, 6, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[55072, 1764, 100, 1, 45, "Subsection"],

Cell[CellGroupData[{
Cell[55197, 1769, 55, 1, 42, "Subsubsection"],
Cell[55255, 1772, 76, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[55356, 1778, 53, 1, 42, "Subsubsection"],
Cell[55412, 1781, 139, 3, 44, "Input"],
Cell[55554, 1786, 701, 18, 31, "Input"],
Cell[56258, 1806, 168, 3, 34, "Input"],
Cell[56429, 1811, 454, 8, 91, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[56920, 1824, 54, 1, 42, "Subsubsection"],
Cell[56977, 1827, 267, 5, 43, "Input"],
Cell[57247, 1834, 219, 4, 24, "Input"],
Cell[57469, 1840, 220, 5, 40, "Input"],
Cell[57692, 1847, 243, 3, 106, "Input"],
Cell[57938, 1852, 125, 3, 27, "Input"],
Cell[58066, 1857, 95, 2, 24, "Input"],
Cell[58164, 1861, 391, 7, 107, "Input"],
Cell[58558, 1870, 83, 2, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[58702, 1879, 99, 1, 29, "Subsection"],

Cell[CellGroupData[{
Cell[58826, 1884, 55, 1, 42, "Subsubsection"],
Cell[58884, 1887, 76, 2, 27, "Input"],
Cell[58963, 1891, 1162, 26, 62, "Input"],
Cell[60128, 1919, 571, 9, 59, "Input"],
Cell[60702, 1930, 170, 3, 48, "Input"],
Cell[60875, 1935, 95, 2, 24, "Input"],
Cell[60973, 1939, 127, 3, 24, "Input"],
Cell[61103, 1944, 172, 3, 45, "Input"],
Cell[61278, 1949, 151, 3, 40, "Input"],
Cell[61432, 1954, 304, 5, 59, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[61785, 1965, 91, 1, 29, "Subsection"],

Cell[CellGroupData[{
Cell[61901, 1970, 55, 1, 42, "Subsubsection"],
Cell[61959, 1973, 76, 2, 27, "Input"],
Cell[62038, 1977, 161, 4, 27, "Input"],
Cell[62202, 1983, 149, 3, 43, "Input"],
Cell[62354, 1988, 272, 6, 75, "Input"],
Cell[62629, 1996, 484, 8, 120, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[63162, 2010, 104, 3, 40, "Section",
  Evaluatable->False],
Cell[63269, 2015, 126, 3, 45, "Subsection",
  Evaluatable->False],
Cell[63398, 2020, 127, 3, 29, "Subsection",
  Evaluatable->False],
Cell[63528, 2025, 143, 3, 29, "Subsection",
  Evaluatable->False],
Cell[63674, 2030, 93, 1, 29, "Subsection"],
Cell[63770, 2033, 73, 1, 29, "Subsection"],
Cell[63846, 2036, 73, 1, 29, "Subsection"],
Cell[63922, 2039, 128, 3, 29, "Subsection",
  Evaluatable->False],
Cell[64053, 2044, 121, 3, 29, "Subsection",
  Evaluatable->False],
Cell[64177, 2049, 91, 1, 29, "Subsection"],
Cell[64271, 2052, 98, 1, 29, "Subsection"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

