(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     80411,       2971]*)
(*NotebookOutlinePosition[     81105,       2996]*)
(*  CellTagsIndexPosition[     81061,       2992]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Legal Notice, Disclaimer, and Book Ordering Information:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "(* Legal Notice, Disclaimer, and Book Ordering Information:\n\nLast \
Modified: FIO June 8, 2002\n\n",
  StyleBox["Mathematica For Physics: 2nd Edition",
    FontColor->RGBColor[1, 0, 0]],
  "\n\nRobert L. Zimmerman and Fredrick I. Olness\n",
  "\nWebSite:  \n",
  StyleBox["  www.physics.smu.edu/~olness\n  darkwing.uoregon.edu/~phys600/\n\
\n",
    FontColor->RGBColor[1, 0, 0]],
  "MathSource Number: 0206-862",
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  "\nISBN 0-201-53796-6\nFor ordering information, call 1-800-282-0693\n\
Addison-Wesley Publishing Company\n",
  "\nCommunication with the authors:\nFredrick I. Olness:  \
olness@mail.physics.smu.edu\nRobert L. Zimmerman: bob@zim.uoregon.edu\n\n\
Copyright 2002, Addison-Wesley Publishing Company, Inc. The material in\nthis \
file may be distributed freely  so long as the content remains\nunchanged, \
and the copyright and  reference notices are included. The\npublisher grants \
permission for the noncommercial use of these programs\nand program segments. \
 All other uses require the prior written consent\nof the publisher.    \n\n\
All rights are reserved with regard to the  material in the\n\"Mathematica \
For Physics\" text, and may not be reproduced, stored in a\nretrieval system, \
or transmitted,  in any form or by any means,\nelectronic, mechanical, \
photocopying,  recording, or otherwise, without\nthe prior written permission \
 of the publisher. \n\nThe programs and applications presented in this book \
have been included\nfor  their instructional value. They have been tested \
with care but are\nnot  guaranteed for any particular purpose. The publisher \
does not\noffer any  warranties or representations, nor does it accept any\n\
liabilities with  respect to the programs or applications. \n\n *)\n"
}], "Input",
  Evaluatable->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell["8. Electrostatics", "Title",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Off[General::spell ];  
Off[General::spell1];
 \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Commands for All Sections"
}], "Section",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["VEPlot", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField`\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(\(VEPlot[potential_, xlim_, ylim_, opts___] := 
        Module[{plot1, plot2}, \[IndentingNewLine]plot1 = 
            PlotGradientField[\(-potential\), xlim, ylim, 
              ScaleFunction \[Rule] \((1 &)\), 
              DisplayFunction \[Rule] Identity]; \[IndentingNewLine]plot2 = 
            ContourPlot[potential, xlim, ylim, ContourShading \[Rule] False, 
              ContourSmoothing \[Rule] True, 
              DisplayFunction \[Rule] Identity, 
              PlotPoints \[Rule] 50]; \[IndentingNewLine]\ 
          Show[{plot1, plot2}, opts, 
            DisplayFunction \[Rule] $DisplayFunction\ ]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(VEPlot[potential_, opts___] := 
      VEPlot[potential, {x, 1.1, \(-1.1\)}, {y, 1.1, \(-1.1\)}, 
        opts]\)}], "Input",
  Hyphenation->False],

Cell["Protect[VEPlot];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Example:  Equipotential surface and electric field of two-point \
charges\
\>", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"dipole", "=", 
        FormBox[\(1\/\@\(x\^2 + \((\(-y\) - 1\/2)\)\^2\) - 
            1\/\@\(x\^2 + \((1\/2 - y)\)\^2\)\),
          "TraditionalForm"]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(VEPlot[dipole, 
        Epilog \[Rule] {{Hue[ .3], \ Disk[{0, 1/2}, 0.1]}, {Hue[0.95], \ 
              Disk[{0, \(-1\)/2}, 0.1]}}];\)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell["8.1 Point Charges, Multipoles, and Image Charges", "Section",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Overview of Point Charges, Multipoles, and Image Charges", "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Commands for Section 8.1"
}], "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Monopole", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Monopole[q_:1,r0_:{0,0,0},r_:{x,y,z}]:=
q/Sqrt[ Sum[(r0[[i]]-r[[i]])^2,{i,1,Length[r0]}] ]; \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Example", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Monopole[q,{x0,y0},{x,y}]", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Monopole[q,{x0,y0}]", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
dipole= ( Monopole[+1,{0,0,-a/2}] + 
          Monopole[-1,{0,0,+a/2}] )\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["TrigToY", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
TrigToY[expression_,terms_:2]:= 
Module[{el,m,result}, 
  result=
    Sum[
       Integrate[ (-1)^(m) SphericalHarmonicY[el,-m,\[Theta],\[Phi]]
                  * expression  Sin[\[Theta]]
               ,{\[Theta],0,\[Pi]},{\[Phi],0,2 \[Pi]}]
    * Y[el,m,\[Theta],\[Phi]]
   ,{el,0,terms},{m,-el,el}];
  Return[result]
];\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Example", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["eq1= Cos[\[Theta]]^2  //TrigToY", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1 //. Y \[Rule] SphericalHarmonicY // Simplify\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[" TrigToP", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
TrigToP[expression_,terms_:2]:= 
Module[{el,result}, 
  result=
    Sum[ Integrate[ LegendreP[el,Cos[\[Theta]]] expression  Sin[\[Theta]]
               ,{\[Theta],0,\[Pi]}]
        * (2 el+1)/2 P[el,Cos[\[Theta]]]
   ,{el,0,terms}];
  Return[result]
];\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Example", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1 = Sin[\[Theta]]\^2 // TrigToP\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 //. P \[Rule] LegendreP // Simplify\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell["\<\
Protect[Monopole,TrigToY,TrigToP];
 \
\>", "Input",
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 1: Superposition of point charges", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Needs[\"Calculus`VectorAnalysis`\"]
Needs[\"Graphics`PlotField`\"] 
Needs[\"Graphics`PlotField3D`\"]\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell["\<\
quad=( Monopole[2 q,{0,0,   0} ]+
       Monopole[ -q,{0,0, d/2} ]+
       Monopole[ -q,{0,0,-d/2} ]) 
      \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
triangle=( Monopole[+2q, {   0,0,   0} ]+
           Monopole[ -q, {+d/2,0,-d/2} ]+
           Monopole[ -q, {-d/2,0,-d/2} ]) ;\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
square=( Monopole[+q,{+d/2,0, d/2} ]+
         Monopole[-q,{+d/2,0,-d/2} ]+
         Monopole[+q,{-d/2,0,-d/2} ]+
         Monopole[-q,{-d/2,0, d/2} ]) ;\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Plot3D[
        square\  /. {y \[Rule] 0, q \[Rule] 1, 
            d \[Rule] 1}\[IndentingNewLine], {x, \(-1\), 1}, {z, \(-1\), 
          1}\[IndentingNewLine], 
        AxesLabel \[Rule] {"\<x\>", "\<z\>", "\<\>"}];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(charges = \ {{Hue[0.3], \ 
            Disk[{0, 1/2}, 
              0.1]}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
{Hue[0.95], 
            Disk[{0, 0}, 
              0.2]}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {Hue[
              0.3], \ Disk[{0, \(-1\)/2}, 0.1]}};\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(p1 = 
        PlotGradientField[\(-quad\) //. {q \[Rule] 1, d \[Rule] 1, 
              y \[Rule] 0}\[IndentingNewLine], {x, \(-1.1\), 
            1.1}, {z, \(-1.1\), 1.1}\[IndentingNewLine], 
          ScaleFunction \[Rule] \((1 &)\), 
          Epilog \[Rule] charges];\)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[BoxData[
    \(\(p2 = 
        ContourPlot[
          quad //. {q \[Rule] 1, d \[Rule] 1, 
              y \[Rule] 0}, \[IndentingNewLine]{x, \(-1.1\), 
            1.1}, {z, \(-1.1\), 
            1.1}, \[IndentingNewLine]ContourShading \[Rule] 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            50, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity\[IndentingNewLine]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Show[p1, p2];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(VEPlot[
        quad //. {q \[Rule] 1, d \[Rule] 1, 
            y \[Rule] 0}, \[IndentingNewLine]{x, \(-1.1\), 
          1.1}, {z, \(-1.1\), 1.1}, \[IndentingNewLine]Epilog \[Rule] 
          charges];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(charges = \ {{Hue[0.3], \ 
            Disk[{\(-1\)/2, \(-1\)/2}, 
              0.1]}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
{Hue[0.95], 
            Disk[{0, 0}, 
              0.2]}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {Hue[
              0.3], \ Disk[{1/2, \(-1\)/2}, 0.1]}};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(VEPlot[
        triangle /. {q \[Rule] 1, d \[Rule] 1, 
            y \[Rule] 0}, \[IndentingNewLine]{x, \(-1.1\), 
          1.1}, {z, \(-1.1\), 1.1}, \[IndentingNewLine]Epilog \[Rule] 
          charges];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(charges = \ {{Hue[0.95], \ 
            Disk[{\(-1\)/2, \(-1\)/2}, 
              0.1]}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
{Hue[0.95], 
            Disk[{1/2, 1/2}, 
              0.1]}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
{Hue[0.3], \ 
            Disk[{\(-1\)/2, \ 1/2}, 
              0.1]}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {Hue[
              0.3], \ Disk[{\ 1/2, \(-\ 1\)/2}, 0.1]}};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(VEPlot[
        square /. {q \[Rule] 1, d \[Rule] 1, y \[Rule] 0}, {x, \(-1.1\), 
          1.1}, {z, \(-1.1\), 1.1}, Epilog \[Rule] charges];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(x2rRule = 
      Thread[{x, y, z} \[Rule] 
          CoordinatesToCartesian[{r, \[Theta], \[Phi]}, 
            Spherical]]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(seriesQuad = \ \(Series[quad\  //. x2rRule\ , {r, \[Infinity], 2}]\  // 
          Simplify\) // Normal\)], "Input",
  Hyphenation->False],

Cell[" seriesQuad //TrigToP //Simplify", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(seriesSquare = \ \(Series[
            square\  //. x2rRule\ , {r, \[Infinity], 2}]\ \  // Simplify\)\  // 
        Normal\)], "Input",
  Hyphenation->False],

Cell[" seriesSquare //TrigToY //Simplify", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(seriesTriangle = \ \(Series[
            triangle\  //. x2rRule\ , {r, \[Infinity], 2}]\ \  // 
          FullSimplify\) // Normal\)], "Input",
  Hyphenation->False],

Cell["seriesTriangle //TrigToY//Simplify  ", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(p1 = 
        PlotGradientField3D[
          quad //. {q \[Rule] 1, d \[Rule] 1}, {x, \(-1\), 1}, {y, \(-1\), 
            1}, {z, \(-1\), 
            1}, \[IndentingNewLine]ScaleFunction \[Rule] \((1 &)\), \
\[IndentingNewLine]VectorHeads \[Rule] 
            True, \[IndentingNewLine]PlotPoints \[Rule] 
            6, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
              2}, \[IndentingNewLine]ViewPoint \[Rule] {1.3, \(-2.4\), 
              1}];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Point charges and grounded plane", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Needs[\"Calculus`VectorAnalysis`\"]
Needs[\"Graphics`PlotField`\"] \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell["\<\
dipole= ( Monopole[+q,{0,0,+d}] + 
          Monopole[-q,{0,0,-d}] )\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[" dipole/.z->0", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(x2rRule = 
      Thread[{x, y, z} \[Rule] 
          CoordinatesToCartesian[{r, \[Theta], phi}, Spherical]]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(dipoleR = \ \(Series[dipole //. x2rRule\ , {r, \[Infinity], 2}]\  // 
          Normal\) // Simplify\)], "Input",
  Hyphenation->False],

Cell["dipoleR//TrigToP", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
efieldR= -Grad[dipoleR,Spherical[r,\[Theta],\[Phi]]]\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(charge = \(-1\)/\((4\ \[Pi])\)\ D[dipole, z] //. z \[Rule] 0\)], "Input",\

  Hyphenation->False],

Cell["\<\
Integrate[charge,{y,-\[Infinity],+\[Infinity]},{x,-\[Infinity],+\
\[Infinity]}]//PowerExpand\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ContourPlot[
        charge /. {d \[Rule] 1, q \[Rule] 1}, {y, \(-1\), 1}, {x, \(-1\), 
          1}];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: Point charges and grounded sphere", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Needs[\"Calculus`VectorAnalysis`\"]
Needs[\"Graphics`PlotField`\"] \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(eq1 = {q\/\(a + d\) + q1\/\(a + d1\) == 0, 
          q\/\(\(-a\) + d\) + q1\/\(a - d1\) == 0};\)\)], "Input",
  Hyphenation->False],

Cell["imageRule= Solve[eq1,{d1,q1}] //ExpandAll //Flatten ", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(potential = \((Monopole[q, {0, 0, d}] + Monopole[q1, {0, 0, d1}])\) //. 
        imageRule\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell["\<\
x2rRule=Thread[{x,y,z}-> \
CoordinatesToCartesian[{r,\[Theta],\[Phi]},Spherical]]\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[" potentialR= potential //.x2rRule //Simplify //Expand", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(potentialR //. r \[Rule] a // Simplify\) // PowerExpand\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Series[potentialR, {r, \[Infinity], 2}]\  // Normal\)\ \  // 
      Collect[#, {\ Cos[\[Theta]], r, \ a\ }] &\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(VEPlot[
        potential /. {a \[Rule] 0.2, d \[Rule] 0.4, q \[Rule] 1, 
            y \[Rule] 0}, {x, \(-1\), 1}, {z, \(-1\), 1}, 
        Epilog \[Rule] {\ {Hue[0.3], 
              Disk[{0, 0.1\ }, 
                0.05]}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
{Thickness[0.01], 
              Circle[{0, 0}, 
                0.2]}\ \ , \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ {Hue[0.95], Disk[{0, 0.4}, 0.1]}}];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"chargedensity", "=", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{
                  FormBox[\(-\(1\/\(4\ \[Pi]\)\)\),
                    "TraditionalForm"], " ", \(D[potentialR, r]\)}], 
                "/.", \({r \[Rule] a}\)}], "//", "Simplify"}], "//", 
            "PowerExpand"}], "//", "Simplify"}], ")"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(totalcharge = \[IndentingNewLine]Integrate[
          chargedensity\ \ 2\ \[Pi]\ a^2  Sin[\[Theta]], {\[Theta], 
            0, \[Pi]}]\  // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(rule = {1\/\@\((a - d)\)\^2 \[Rule] 
            1\/\(\(-a\) + d\), \@\((a - d)\)\^2 \[Rule] \(-a\) + 
              d};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(totalcharge\  //. rule // PowerExpand\)\  // Simplify\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    \(\(\(\[Theta]Min = \(+\((FindMinimum[\(+chargedensity\) /. {a \[Rule] 1, 
                    q \[Rule] 1, d \[Rule] 2}, {\[Theta], 1}] // 
              First)\)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Theta]Max = \(-\((FindMinimum[\(-chargedensity\) /. {a \[Rule] 1, 
                    q \[Rule] 1, d \[Rule] 2}, {\[Theta], 1}] // 
              First)\)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(gray[\[Theta]_] = \((\((chargedensity - \
\[Theta]Min)\)/\((\[Theta]Max - \[Theta]Min)\) /. {a \[Rule] 1, q \[Rule] 1, 
              d \[Rule] 2})\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \({\[Theta]Min, \[Theta]Max}\)}], "Input",
  Hyphenation->False],

Cell["\<\
radius=1;
ParametricPlot3D[{radius Sin[\[Theta]] Cos[\[Phi]]
                ,radius Sin[\[Theta]] Sin[\[Phi]]
                ,radius Cos[\[Theta]]
                ,GrayLevel[gray[\[Theta]]]}
          ,{\[Theta],0,\[Pi]}
          ,{\[Phi],0,2 \[Pi]}
          ,Lighting->False
          ,Axes->False
          ,Boxed->False];\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 4: Line charge and grounded plane", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Needs[\"Calculus`VectorAnalysis`\"]
Needs[\"Graphics`PlotField`\"] \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(potential = \(-q\)\ Log[x\^2 + \((y - y0)\)\^2] + 
          q\ Log[x\^2 + \((y + y0)\)\^2];\)\)], "Input",
  Hyphenation->False],

Cell["potential //.{y->0}", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(VEPlot[
        potential //. {q \[Rule] 1, y0 \[Rule] 1}, {x, \(-1.1\), 
          1.1}, {y, \(-2\), 2}, 
        Epilog \[Rule] {\ {Thickness[ .03], 
              Line[{{\(-1.1\), 0}, {1.1, 
                    0}}]\ }, \[IndentingNewLine]\ {Hue[ .35], 
              Disk[{0, \ \(-1\)\ },  .1]}\ , \[IndentingNewLine]\ \ {Hue[ \
.95], Disk[{0, \ 1\ },  .1]}}];\)\)], "Input",
  Hyphenation->False],

Cell["Laplacian[ potential,Cartesian[x,y,z]]//Together", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"charge", "=", 
      RowBox[{
        RowBox[{
          FormBox[\(-\(1\/\(4\ \[Pi]\)\)\),
            "TraditionalForm"], " ", \(D[potential, y]\)}], 
        "/.", \({y \[Rule] 0}\)}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(ContourPlot[
        charge /. {q \[Rule] 1, y0 \[Rule] 1}, {x, \(-2\), 2}, {y, \(-2\), 
          2}];\)\)], "Input",
  Hyphenation->False],

Cell["\<\
Integrate[charge,{x,-\[Infinity],+\[Infinity]}] //PowerExpand\
\>", \
"Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell["eField= -Grad[potential,Cartesian[x,y,z]] //Simplify", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PlotVectorField[
        eField[\([{1, 2}]\)] //. {q \[Rule] 1, 
            y0 \[Rule] 1}, \[IndentingNewLine]{x, \(-5\), 5}, {y, 0, 
          3}, \[IndentingNewLine]PlotPoints \[Rule] 
          10, \[IndentingNewLine]ScaleFunction \[Rule] \((1 &)\)\ , \
\[IndentingNewLine]AspectRatio \[Rule] 8/10\ , 
        Prolog \[Rule] {\ {Thickness[ .03], 
              Line[{{\(-5\), 0}, {5, 0}}]\ }, {Hue[ .95], 
              Disk[{0, \ 1\ },  .2]}}];\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 5: Multipole expansion of a charge distribution", \
"Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["MultipoleSH", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        RowBox[{\(MultipoleSH[distribution_, rlimit_, n_]\), ":=", 
          RowBox[{"Module", "[", 
            RowBox[{\({q, V}\), ",", 
              RowBox[{
                RowBox[{"q", ":=", 
                  RowBox[{"Integrate", "[", 
                    RowBox[{
                      
                      RowBox[{\((Integrate[
                            distribution\ r\^2, {r, 0, rlimit}])\), "*", 
                        
                        FormBox[\(\((\(-1\))\)\^m\ \(sin(\[Theta])\)\ \
\(\(Y\_el\%\(-m\)\)(\[Theta], \[Phi])\)\),
                          "TraditionalForm"]}], ",", \({\[Theta], 0, \[Pi]}\),
                       ",", \({\[Phi], 0, 2\ \[Pi]}\)}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"V", "=", 
                  RowBox[{"Sum", "[", 
                    RowBox[{
                      
                      FormBox[\(\(4\ \[Pi]\ q\ \((rlimit\/r)\)\^el\ \(Y(el, 
                                m, \[Theta], \[Phi])\)\)\/\(\((2\ el + 
                                  1)\)\ r\)\),
                        "TraditionalForm"], ",", \({el, 0, n}\), 
                      ",", \({m, \(-el\), el}\)}], "]"}]}], ";", 
                "\[IndentingNewLine]", \(Return[V]\)}]}], "]"}]}], 
        ";"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"density", "=", 
        FormBox[\(\(Q\ \((r - 
                    a)\)\ \(\(sin\^2\)(\[Theta])\)\ \
\(\(sin\^2\)(\[Phi])\)\)\/a\^4\),
          "TraditionalForm"]}], ";"}]], "Input",
  Hyphenation->False],

Cell["  MultipoleSH[density,a,2] //Simplify //Apart  ", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MultipoleP", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(MultipoleP[distribution_, rlimit_, n_]\), ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({q, pot}\), ",", 
            RowBox[{
              RowBox[{"q", ":=", 
                RowBox[{"Integrate", "[", 
                  RowBox[{
                    RowBox[{
                    "2", " ", "\[Pi]", 
                      "*", \((Integrate[distribution\ r^2, {r, 0, rlimit}])\),
                       "*", 
                      FormBox[\(\@\(2\ el + 1\)\/\(2\ \@\[Pi]\)\),
                        "TraditionalForm"], 
                      " ", \(LegendreP[el, Cos[\[Theta]]]\), 
                      "*", \(Sin[\[Theta]]\)}], 
                    ",", \({\[Theta], 0, \[Pi]}\)}], "]"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"pot", "=", 
                RowBox[{"Sum", "[", 
                  RowBox[{
                    
                    FormBox[\(\(2\ \@\(1\/\(2\ el + 1\)\)\ \@\[Pi]\ q\ \
\((rlimit\/r)\)\^el\ \(P(el, cos(\[Theta]))\)\)\/r\),
                      "TraditionalForm"], ",", \({el, 0, n}\)}], "]"}]}], ";",
               "\[IndentingNewLine]", \(Return[pot]\)}]}], "]"}]}], 
      ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"density", "=", 
        FormBox[\(\(Q\ \((r - a\ \(\(cos\^2\)(\[Theta])\))\)\)\/a\^4\),
          "TraditionalForm"]}], ";"}]], "Input",
  Hyphenation->False],

Cell["eq1= MultipoleP[density,a,2] ", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["eq2= MultipoleSH[density,a,2]", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1 \[Equal] eq2 //. {P \[Rule] LegendreP, 
          Y \[Rule] SphericalHarmonicY} // Simplify\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Needs[\"Calculus`VectorAnalysis`\"]
Needs[\"Graphics`PlotField`\"] \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[{
    RowBox[{
      RowBox[{"chargeDensity1", "=", 
        FormBox[\(\(q0\ \((a - r)\)\ \((sin(\[Theta]) - \[Pi]\/4)\)\)\/a\^4\),
          
          "TraditionalForm"]}], ";"}], "\n", 
    RowBox[{
      RowBox[{"chargeDensity2", "=", 
        FormBox[\(\(\[ExponentialE]\^\(\(a - r\)\/a\)\ q0\ \((a - 
                    r)\)\ \(cos(\[Theta])\)\)\/a\^4\),
          "TraditionalForm"]}], ";"}], "\n", 
    RowBox[{
      RowBox[{"chargeDensity3", "=", 
        FormBox[\(\(q0\ \((a - r)\)\^2\ \(\(sin\^2\)(\[Theta])\)\ \(sin(
                  2\ \[Phi])\)\)\/a\^5\),
          "TraditionalForm"]}], ";"}]}], "Input",
  Hyphenation->False],

Cell["\<\
r2xRule=Thread[{r,\[Theta],\[Phi]}->
            CoordinatesFromCartesian[{x,y,z},Spherical]]\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values = {q0 \[Rule] 1, a \[Rule] 1};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(ContourPlot[\(\(chargeDensity1 /. r2xRule\) //. 
            values\) /. {y \[Rule] 0}, {x, \(-1\), 1}, {z, \(-1\), 1}, 
        PlotPoints \[Rule] 40];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(ContourPlot[\(\(chargeDensity2 /. r2xRule\) //. 
            values\) /. {y \[Rule] 0}, {x, \(-1\), 1}, {z, \(-1\), 1}, 
        PlotPoints \[Rule] 40];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(ContourPlot[\(\(chargeDensity3 /. r2xRule\) //. 
            values\) /. {z \[Rule] 0}, {x, \(-1\), 1}, {y, \(-1\), 1}, 
        PlotPoints \[Rule] 40];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell["multi1= MultipoleP[chargeDensity1,a,2]", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["multi2= MultipoleP[chargeDensity2,a,2] //Simplify", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["multi3= MultipoleSH[chargeDensity3,a,2] //Simplify", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(eField1 = \(-Grad[multi1, Spherical[r, \[Theta], \[Phi]]]\)\)], "Input",\

  Hyphenation->False],

Cell[BoxData[
    \(eField1 //. P \[Rule] LegendreP // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eField2 = \(-Grad[multi2, Spherical[r, \[Theta], \[Phi]]]\) //. 
          P \[Rule] LegendreP // Simplify\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(eField3 = \(-Grad[multi3, 
            Spherical[r, \[Theta], \[Phi]]]\);\)\), "\n", 
    \(\(eField3 /. {Y \[Rule] SphericalHarmonicY} // ExpToTrig\) // 
      Simplify\)}], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(pot1 = \ \(\(\(multi1 /. r2xRule\) /. {P \[Rule] LegendreP, 
                Y \[Rule] SphericalHarmonicY}\) /. 
            values\) /. {y \[Rule] 0}\  // Simplify\)], "Input",
  Hyphenation->False],

Cell["VEPlot[pot1,{x,1.1,-1.1},{z,1.1,-1.1}];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(pot2 = \ \(\(\(multi2 /. r2xRule\) /. {P \[Rule] LegendreP, 
              Y \[Rule] SphericalHarmonicY}\) /. 
          values\) /. {y \[Rule] 0}\)], "Input",
  Hyphenation->False],

Cell["VEPlot[pot2,{x,-1.1,1.1},{z,-1.1,1.1}];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(pot3 = \ \(\(\(\(\(multi3 /. r2xRule\) //. {P \[Rule] LegendreP, 
                Y \[Rule] SphericalHarmonicY}\) //. 
            values\) /. {z \[Rule] 
              0}\)\(\ \)\(//\)\(FullSimplify\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell["VEPlot[pot3];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell["\<\
8.2 Laplace's Equation in Cartesian and Cylindrical Coordinates \
\
\>", "Section",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Overview of Cartesian and Cylindrical Coordinates", "Subsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["\<\
Problem 1: Separation of variables in Cartesian and cylindrical \
coordinates\
\>", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Needs[\"Calculus`VectorAnalysis`\"] ", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell["potential= Vx[x] Vy[y] Vz[z];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["SetCoordinates[Cartesian[x,y,z]];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[" lapEq= Laplacian[potential]", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[BoxData[
    \(eq1 = lapEq\/\(Vx[x]\ Vy[y]\ Vz[z]\) // Expand\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(eq2 = eq1 /. Plus \[Rule] List\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"  ", 
      RowBox[{"fieldEq", "=", 
        RowBox[{
          RowBox[{"eq2", "==", 
            FormBox[\({\(-Cx\^2\), \(-Cy\^2\), Cz\^2}\),
              "TraditionalForm"]}], "//", "Thread"}]}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(\(MapThread[
          DSolve, {fieldEq, {Vx[x], Vy[y], Vz[z]}, \ {x, y, z}}, 1] // 
        Flatten\)\(//\)\(ColumnForm\)\(\ \ \)\)\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell["potential= R[r] P[\[Phi]] Z[z];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetCoordinates[Cylindrical[r, \[Phi], z]];\)\)], "Input",
  Hyphenation->False],

Cell["lapEq= Laplacian[potential] //Expand", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1 = \(lapEq\/\(R[r]\ P[\[Phi]]\ Z[z]\) // Expand\) // 
        Collect[#, r] &\)], "Input",
  Hyphenation->False],

Cell["zEq= Select[eq1,(!FreeQ[#,z])&] == +Cz^2", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\ \)\(DSolve[zEq, Z[z], z] // Flatten\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(DSolve[zEq /. Cz \[Rule] 0, Z[z], z] // 
      Flatten\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq2 = \ eq1 /. {zEq /. Equal \[Rule] Rule}\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq3 = r\^2\ eq2 // Expand\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\[Phi]Eq = 
      Select[eq3, \((\(! FreeQ[#, \[Phi]]\))\) &] \[Equal] \
\(-C\[Phi]\^2\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(DSolve[\[Phi]Eq, \ P[\[Phi]]\ , \[Phi]] // Flatten\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(DSolve[\[Phi]Eq /. C\[Phi]\^2 \[Rule] 0, \ P[\[Phi]]\ , \[Phi]] // 
      Flatten\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq4 = \(\(eq3\)\(/.\)\((\ \[Phi]Eq /. 
            Equal \[Rule] Rule)\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell["DSolve[eq4==0, R[r] ,r]//Flatten", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\((\ DSolve[eq4 \[Equal] 0 /. Cz \[Rule] 0, R[r], r] // Flatten\ )\) /. 
          C[1] \[Rule] A + B\) /. C[2] \[Rule] I \((A - B)\)\  // 
      FullSimplify\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Potential in a rectangular groove ", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell["\<\
A[V_,m_]:= 2/a Integrate[V Sin[\[Pi] m x/a],{x,0,a}];\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(pot[V_, n_]\), ":=", 
        RowBox[{"Sum", "[", 
          RowBox[{
            RowBox[{\(A[V, m]\), " ", 
              
              FormBox[\(\[ExponentialE]\^\(-\(\(m\ \[Pi]\ y\)\/a\)\)\ \
\(sin(\(m\ \[Pi]\ x\)\/a)\)\),
                "TraditionalForm"]}], ",", \({m, 1, n}\)}], "]"}]}], 
      ";"}]], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell["\<\
  pot[Sin[x],3] 
 \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\ \)\(Plot3D[
        pot[Sin[x], 30] /. a \[Rule] 1 // Evaluate, \[IndentingNewLine]{x, 0, 
          1}, {y, 0, 0.5}, 
        AxesLabel \[Rule] {\ x\ , y\ , V\ }];\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pot15 = pot[Sin[x], 15] /. a \[Rule] 1;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(VEPlot[pot15, {x, 0, 1}, {y, 0, 0.5}\ ];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell["eq1=pot[V0,\[Infinity]] ", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"potV0", "=", " ", 
      RowBox[{
        RowBox[{"eq1", "//.", " ", 
          RowBox[{"{", 
            
            FormBox[\(log(1 - a_) \[Rule] 
                log(\(1 - a\)\/\(a + 1\)) + log(a + 1)\),
              "TraditionalForm"], "}"}]}], " ", "//", " ", "FullSimplify", 
        " "}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Plot3D[\(potV0 /. a \[Rule] 1\) /. V0 \[Rule] 1\ , {x, 0.0001, 
          0.9999}, {y, 0, 0.5}, 
        AxesLabel \[Rule] {\ x\ , y\ , V\ }];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem  3:   Rectangular conduit", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Needs[\"Calculus`VectorAnalysis`\"]
Needs[\"Graphics`PlotField`\"] \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(term[m_]\), "=", 
        FormBox[\(\(A(
              m)\)\ \(cosh(\(m\ \[Pi]\ x\)\/b)\)\ \(sin(\(m\ \[Pi]\ y\)\/b)\)\
\),
          "TraditionalForm"]}], 
      ";"}], "\n", \(pot[n_] = 
        Sum[term[m] // Evaluate, {m, 1, n}];\), "\n", \(pot[n]\)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(check = \ D[\ pot[n]\ , x]\  // MapAll[Evaluate, #] &\)], "Input",
  InitializationCell->False,
  Hyphenation->False],

Cell[BoxData[
    \(check\  /. {x -> 0}\)], "Input",
  InitializationCell->False,
  Hyphenation->False],

Cell[BoxData[
    \(pot[n] /. {x \[Rule] a}\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eq1 = V0 \[Equal] term[m] /. {x \[Rule] a}\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(rhs = \((\((Integrate[eq1[\([2]\)]\ Sin[m\ \[Pi]\ y/b], {y, 0, b}] // 
              Simplify)\) //. {Sin[2\ m\ \[Pi]] \[Rule] 0})\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(lhs = \((\((Integrate[
                eq1[\([1]\)]\ Sin[m\ \[Pi]\ y/b], {y, 0, b}])\) //. {Cos[
                  m\ \[Pi]] \[Rule] \((\(-1\))\)^m})\) // Simplify\)], "Input",\

  Hyphenation->False],

Cell["\<\
aSol= Solve[rhs==lhs,A[m]][[1]] //Simplify;
A[m_]= A[m] /. aSol \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["pot[n] ", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Plot[
        Table[pot[n], {n, 2, 8, 2}] //. {b \[Rule] 1, V0 \[Rule] 1, 
              a \[Rule] 1, x \[Rule] a} // Evaluate, \[IndentingNewLine]{y, 
          0, 1}, \[IndentingNewLine]PlotRange \[Rule] {0, 2}];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Plot3D[
        pot[4] //. {b \[Rule] 1, V0 \[Rule] 1, 
            a \[Rule] 1}, \[IndentingNewLine]{y, 0, 1}, {x, 0, 
          1}, \[IndentingNewLine]ViewPoint \[Rule] {2, 2, 1}];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(VEPlot[
        pot[4] //. {b \[Rule] 1, V0 \[Rule] 1, 
            a \[Rule] 1}, \[IndentingNewLine]{x, 0, 1}, {y, 0, 
          1}];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 4: Potential inside a rectangular box with five sides at \
zero potential \
\>", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"mzRule", "=", 
        RowBox[{"{", 
          FormBox[\(mz \[Rule] c\ \@\(mx\^2\/a\^2 + my\^2\/b\^2\)\),
            "TraditionalForm"], "}"}]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(A[mx_, my_]\), "   ", "=", " ", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              FormBox[\(\(4\ V0\ \(csch(mz\ \[Pi])\)\)\/\(a\ b\)\),
                "TraditionalForm"], 
              RowBox[{"Integrate", "[", "  ", 
                RowBox[{
                  
                  FormBox[\(\(sin(\(mx\ \[Pi]\ x\)\/a)\)\ \(sin(\(my\ \[Pi]\ \
y\)\/b)\)\),
                    "TraditionalForm"], ",", \({x, 0, a}\), 
                  ",", \({y, 0, b}\)}], "]"}]}], " ", 
            "//", \(Simplify[#, Element[{my, \ mx}, Integers]] &\)}], " ", 
          ")"}], "/.", "mzRule"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(pot[nx_, ny_]\), "=", 
      RowBox[{
        RowBox[{"Sum", "[", 
          RowBox[{
            RowBox[{\(A[mx, my]\), " ", 
              
              FormBox[\(\(sin(\(mx\ \[Pi]\ x\)\/a)\)\ \(sin(\(my\ \[Pi]\ \
y\)\/b)\)\ \(sinh(\(mz\ \[Pi]\ z\)\/c)\)\),
                "TraditionalForm"]}], ",", \({mx, 1, nx}\), 
            ",", \({my, 1, ny}\)}], "]"}], "/.", "mzRule"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(pot[1, 1]\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {a \[Rule] 1, b \[Rule] 1, c \[Rule] 1, V0 \[Rule] 1, 
          x \[Rule] 1/2};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Plot3D[
        pot[20, 20] //. values // Evaluate, {y, 0, 1}, {z, 0, 
          1}];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(VEPlot[\(pot[10, 10] //. values\) //. {x \[Rule] 1/2}\  // 
          Evaluate, {y, 0, 1}, {z, 0, 1}];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 5: Conducting cylinder with a potential on the surface \
\
\>", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[" Needs[\"Graphics`ParametricPlot3D`\"]", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(A[n_]\), " ", "=", 
      RowBox[{
        RowBox[{
          FormBox[\(a\^\(-n\)\/\[Pi]\),
            
            "TraditionalForm"], \((Integrate[
                V0\ \ Sin[n\ \[Phi]], {\[Phi], 0, \ \[Pi]\ }]\  - 
              Integrate[
                V0\ \ Sin[n\ \[Phi]], {\[Phi], \[Pi], 2\ \[Pi]\ }]\ )\)}], 
        "//", \(Simplify[#, Element[n, Integers]] &\)}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(potIn[nf_] := 
        Sum[A[n]\ Sin[n\ \[Phi]]\ r\^n, {n, 1, nf}];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(potIn[6]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(eq1\)\(=\)\(\ \)\(potIn[Infinity]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"Vin", "=", 
      RowBox[{
        RowBox[{"eq1", "//.", " ", 
          RowBox[{"{", 
            
            FormBox[\(log(1 - aa_) \[Rule] 
                log(\(1 - aa\)\/\(aa + 1\)) + log(aa + 1)\),
              "TraditionalForm"], "}"}]}], "//", "FullSimplify", 
        "  "}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(B[\ n_]\), " ", "=", 
      RowBox[{
        RowBox[{
          FormBox[\(a\^n\/\[Pi]\),
            
            "TraditionalForm"], \((Integrate[
                V0\ \ Sin[n\ \[Phi]], {\[Phi], 
                  0, \ \[Pi]\ }]\ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \  - 
              Integrate[
                V0\ \ Sin[n\ \[Phi]], {\[Phi], \[Pi], 2\ \[Pi]\ }]\ )\)}], 
        "//", \(Simplify[#, Element[n, Integers]] &\)}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(potOut[nf_] := 
        Sum[B[n]\ Sin[n\ \[Phi]]\ r\^\(-n\), {n, 1, nf}];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(potOut[3]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"Vout", "=", 
      RowBox[{
        RowBox[{\((potOut[Infinity] // Simplify)\), "//.", " ", 
          RowBox[{"{", 
            
            FormBox[\(log(1 - aa_) \[Rule] 
                log(\(1 - aa\)\/\(aa + 1\)) + log(aa + 1)\),
              "TraditionalForm"], "}"}]}], "//", " ", "Simplify", 
        "  "}]}]], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(Off[Plot3D::plnc, Plot3D::gval]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = 
        Plot3D[\ \(Vin /. a \[Rule] 1\) /. V0 \[Rule] 1\  // 
            Evaluate, \[IndentingNewLine]{\[Phi], 0, 2  \[Pi]}, {r, 0, 
            1\ }, \[IndentingNewLine]PlotPoints \[Rule] 
            40, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt2 = 
        Plot3D[\ \(Vout /. a \[Rule] 1\) /. V0 \[Rule] 1\  // 
            Evaluate, \[IndentingNewLine]{\[Phi], 0, 2  \[Pi]}, {r, 1\ , 
            2\ }, \[IndentingNewLine]PlotPoints \[Rule] 
            40, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Off[Graphics3D::nlist3]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Show[{pt1, pt2}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Off[ParametricPlot3D::pplr]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt3 = 
        CylindricalPlot3D[\(Vin /. a \[Rule] 1\) /. V0 \[Rule] 1, {r, 0\ , 
            1}, {\[Phi], 
            0.01\ , \ \ 0.99\ \[Pi]}\ \ , \[IndentingNewLine]PlotPoints \
\[Rule] 20, DisplayFunction \[Rule] Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt4 = 
        CylindricalPlot3D[\(Vout /. a \[Rule] 1\) /. V0 \[Rule] 1, {r, 1, 
            1.75}, {\[Phi], 0.01, 
            0.99\ \[Pi]}, \[IndentingNewLine]PlotPoints \[Rule] 20, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Show[{pt3\ , pt4}, \ 
        DisplayFunction \[Rule] \ $DisplayFunction\ ];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell["8.3 Laplace's Equation in Spherical Coordinates ", "Section",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Overview of Spherical Coordinates", "Subsubsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["Problem 1: A charged ring  ", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Needs[\"Calculus`VectorAnalysis`\"] ", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"potZ", "=", 
        FormBox[\(q\/\@\(a\^2 + r\^2\)\),
          "TraditionalForm"]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(potZin[n_] := \(Series[potZ, {r, 0, n}] // PowerExpand\) // 
          Normal;\)\), "\n", 
    \(\(potZout[n_] := \(Series[potZ, {r, \[Infinity], n}] // PowerExpand\) // 
          Normal;\)\)}], "Input",
  Hyphenation->False],

Cell["potZin[9]", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["potZout[9]", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(pot[s_]\), ":=", 
      RowBox[{"Sum", "[", 
        RowBox[{
          RowBox[{
            
            FormBox[\(\(B(n)\)\ \((r\/a)\)\^n + \((a\/r)\)\^\(n + 1\)\ \(A(
                    n)\)\),
              "TraditionalForm"], \(LegendreP[n, Cos[\[Theta]]]\)}], 
          ",", \({n, 0, s}\)}], "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Vout[s_]\), "=", 
        RowBox[{"Sum", "[", 
          RowBox[{
            RowBox[{
              FormBox[\(\((a\/r)\)\^\(n + 1\)\ \(A(n)\)\),
                "TraditionalForm"], \(LegendreP[n, Cos[\[Theta]]]\)}], 
            ",", \({n, 0, s}\)}], "]"}]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(coeffOut[s_] := 
      Solve[0 \[Equal] 
            CoefficientList[\((Vout[s] - potZout[s])\) /. \[Theta] \[Rule] 0, 
              1/r]\ , A\  /@ \ Range[0, s]] // Flatten\)], "Input",
  Hyphenation->False],

Cell["coeffOut[3]", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[" potOut[s_]:=Vout[s]/. coeffOut[s]  ", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[" potOut[6]   ", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{\(Vin[s_]\), ":=", 
      RowBox[{"Sum", "[", 
        RowBox[{
          RowBox[{
            FormBox[\(\((r\/a)\)\^n\ \(B(n)\)\),
              "TraditionalForm"], \(LegendreP[n, Cos[\[Theta]]]\)}], 
          ",", \({n, 0, s}\)}], "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(coeffIn[s_] := 
      Solve[0 \[Equal] 
            CoefficientList[\((Vin[s] - potZin[s])\) /. \[Theta] \[Rule] 0, \ 
              r]\ , B /@ Range[0, s]] // Flatten\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(potIn[s_] := Vin[s] /. coeffIn[s]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(potIn[6]\)], "Input",
  Hyphenation->False],

Cell["\<\
SetCoordinates[Spherical[r, \[Theta], \[Phi]]];\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["electout[s_]:= -Grad[potOut[s]];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["electin[s_]:= -Grad[potIn[s]];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(electout[3]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(electin[3]\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(r2xRule = {r, \[Theta], \[Phi]} \[Rule] 
          CoordinatesFromCartesian[{x, y, z}, Spherical] // Thread\)], "Input",\

  Hyphenation->False],

Cell[BoxData[
    \(\(values = {a \[Rule] 1, q \[Rule] 1};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[{
    \(\(potOutXYZ[x_, y_, z_\ ]\  = \(potOut[12] //. r2xRule\) //. 
          values\ ;\)\), "\n", 
    \(\(potInXYZ[x_, y_, z_\ ]\  = \(potIn[12] //. r2xRule\) //. 
          values\ ;\)\ \)}], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(ff[x_, y_, z_]\), ":=", 
      RowBox[{"If", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"N", "[", 
              FormBox[\(\@\(x\^2 + y\^2 + z\^2\)\),
                "TraditionalForm"], "]"}], "\[GreaterEqual]", "1"}], 
          ",", \(potOutXYZ[x, y, z]\), ",", \(potInXYZ[x, y, z]\)}], 
        "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt1 = 
        Plot3D[ff[x, 0, z], {x, \(-2\), 2}, {z, \(-2\), 2}, 
          PlotPoints \[Rule] 30\ , 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt2 = 
        ContourPlot[ff[x, 0, z], {x, \(-2\), 2}, {z, \(-2\), 2}, 
          PlotPoints \[Rule] 30, \ \ ContourSmoothing \[Rule] True, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Show[GraphicsArray[{pt1, pt2}]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(VEPlot[
        ff[x, 0, z] // Evaluate, \[IndentingNewLine]{x, \(-2.1\), 
          2.1}, {z, \(-1.6\), 1.6}, 
        Epilog \[Rule] {{Hue[ .3], \ Disk[{1, 0},  .2]}, \ \ {Hue[ .3], \ 
              Disk[{\(-1\), 0\ },  .2]}}];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt3 = 
        Plot3D[ff[x, y, 0], {x, \(-2\), 2}, {y, \(-2\), 2}, 
          PlotPoints \[Rule] 30, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(pt4 = 
        ContourPlot[
          ff[x, y, 0], \[IndentingNewLine]{x, \(-2\), 2}, {y, \(-2\), 
            2}, \[IndentingNewLine]PlotPoints \[Rule] 
            30, \[IndentingNewLine]ContourSmoothing \[Rule] True, 
          Epilog \[Rule] {Hue[0.07], Thickness[ .03], 
              Circle[{0, 0}, 1]}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Show[GraphicsArray[{pt3, pt4}]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(VEPlot[
        ff[x, y, 0], \[IndentingNewLine]{x, \(-2.1\), 2.1}, {y, \(-2.1\), 
          2.1}, Epilog \[Rule] {Hue[0.05], Thickness[ .008], 
            Circle[{0, 0}, 1]}];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Grounded sphere in an electric field  ", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Calculus`VectorAnalysis`\>"]\), "\n", 
    \(Needs["\<Graphics`PlotField`\>"]\)}], "Input",
  Hyphenation->False],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(Asol = {\ A[1] \[Rule] \(-E0\)\ a, \ 
          A[i_] \[Rule] 0}\ \ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(pot[s_]\), ":=", 
      RowBox[{
        RowBox[{"Sum", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                
                FormBox[\(\(A(
                        i)\)\ \((r\/a)\)\^i + \((a\/r)\)\^\(i + 1\)\ \(B(
                        i)\)\),
                  "TraditionalForm"], " ", ")"}], \(LegendreP[i, 
                Cos[\[Theta]]]\)}], ",", \({i, 0, s}\)}], "]"}], "/.", 
        "Asol"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(Beq[
        s_]\)\(:=\)\(LogicalExpand[\((pot[s] /. r \[Rule] a)\) \[Equal] 
          0 + O[Cos[\[Theta]]]\^\(s + 1\)]\)\(\ \)\)\)], "Input",
  Hyphenation->False],

Cell["\<\
Beq[4] 
 \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\ \ \)\(Bsol[s_] := Solve[Beq[s]] // Flatten\ ;\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(Off[Solve::svars]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\(\ \)\(\(Solve[Beq[6]]\)\(//\)\(Flatten\)\(\ \)\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Bsol = {B[1] \[Rule] a\ E0, B[i_] \[Rule] 0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"potential", " ", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"Sum", "[", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    
                    FormBox[\(\(A(
                            i)\)\ \((r\/a)\)\^i + \((a\/r)\)\^\(i + 1\)\ \(B(
                            i)\)\),
                      "TraditionalForm"], ")"}], 
                  " ", \(LegendreP[i, Cos[\[Theta]]]\)}], 
                ",", \({i, 0, 3}\)}], "]"}], ")"}], "/.", "Asol"}], "/.", 
        "Bsol"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(eField = \(-Grad[potential, Spherical[r, \[Theta], \[Phi]]]\) // 
        ExpandAll\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(r2xRule = {r, \[Theta], \[Phi]} \[Rule] 
            CoordinatesFromCartesian[{x, y, z}, Spherical] // 
          Thread;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {E0 \[Rule] 1, a \[Rule] 1};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(p1 = 
        VEPlot[\(\(potential //. r2xRule\) //. 
              values\) //. {y \[Rule] 0}, \[IndentingNewLine]{x, \(-2.1\), 
            2.1}, {z, \(-2.1\), 
            2.1}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(disk = Graphics[Disk[{0, 0}, 1]];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Show[p1, disk, 
        DisplayFunction \[Rule] $DisplayFunction\ ];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 3: Sphere with an axially symmetric charge distribution  \
\
\>", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
 Needs[\"Calculus`VectorAnalysis`\"]
 Needs[\"Graphics`ParametricPlot3D`\"] \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(potInA[s_]\), ":=", 
      RowBox[{"Sum", "[", 
        RowBox[{
          RowBox[{
            FormBox[\(\((r\/a)\)\^i\ \(A(i)\)\),
              "TraditionalForm"], " ", \(LegendreP[i, Cos[\[Theta]]]\)}], 
          ",", \({i, 0, s}\)}], "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(potOutA[s_]\), ":=", 
      RowBox[{"Sum", "[", 
        RowBox[{
          RowBox[{\(A[i]\), " ", 
            FormBox[\(\((a\/r)\)\^\(i + 1\)\),
              "TraditionalForm"], \(LegendreP[i, Cos[\[Theta]]]\)}], 
          ",", \({i, 0, s}\)}], "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(chargeDensity[s_]\), ":=", 
      RowBox[{
        RowBox[{
          FormBox[\(1\/\(4\ \[Pi]\)\),
            "TraditionalForm"], \((D[potInA[s], r] - D[potOutA[s], r])\)}], 
        "//.", \({r \[Rule] a}\)}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(chargeDensity[2] // Apart\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(aEquation[s_, Qdensity_] := 
      LogicalExpand[
        chargeDensity[s] \[Equal] 
          Qdensity + O[Cos[\[Theta]]]\^\(s + 1\)]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(aRule[s_, Qdensity_] := 
      Solve[aEquation[s, Qdensity], Array[A, s + 1, 0]] // Flatten\)], "Input",\

  Hyphenation->False],

Cell[BoxData[
    RowBox[{"aRule", "[", 
      RowBox[{"4", ",", 
        FormBox[\(\(Q\ \(\(cos\^2\)(\[Theta])\)\)\/a\^2\),
          "TraditionalForm"]}], "]"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(potInA[4]\), "/.", 
      RowBox[{"aRule", "[", 
        RowBox[{"4", ",", 
          FormBox[\(\(Q\ \(\(cos\^2\)(\[Theta])\)\)\/a\^2\),
            "TraditionalForm"]}], "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(potOutA[4]\), "/.", 
      RowBox[{"aRule", "[", 
        RowBox[{"4", ",", 
          FormBox[\(\(Q\ \(\(cos\^2\)(\[Theta])\)\)\/a\^2\),
            "TraditionalForm"]}], "]"}]}]], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{"surfaceQ", "=", 
      RowBox[{
        FormBox[\(\(Q\ \((\(\(cos\^2\)(\[Theta])\)\/2 + 
                    cos(\[Theta]))\)\)\/a\^2\),
          "TraditionalForm"], "//", "Expand"}]}]], "Input",
  Hyphenation->False],

Cell["potOutQ= potOutA[8] //. aRule[8,surfaceQ]", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["potInQ= potInA[8]//.aRule[8,surfaceQ]", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values = {Q \[Rule] 1, a \[Rule] 1};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(p1 = 
        CylindricalPlot3D[
          potInQ //. values, {r, 0, 1}, {\[Theta], 0, 2\ \[Pi]}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(p2 = 
        CylindricalPlot3D[
          potOutQ //. values, {r, 1, 3}, {\[Theta], 0, 2  \[Pi]}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Show[p1, 
        p2, \[IndentingNewLine]AxesLabel \[Rule] {a, b, 
            c}, \[IndentingNewLine]ViewPoint \[Rule] {\(-1.5\), \(-2\), 
            2}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 1}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(r2xRule = {r, \[Theta], \[Phi]} \[Rule] 
            CoordinatesFromCartesian[{x, y, z}, Spherical] // 
          Thread;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\( (*for\ 0 < r < 
        1*) \)\(\[IndentingNewLine]\)\(eq1[y_, 
          z_] = \(potInQ /. r2xRule\) /. {Q \[Rule] 1, a \[Rule] 1, 
              x \[Rule] 0} // Simplify;\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\( (*\ 
      for\ 1 < r\ *) \)\(\n\)\(eq2[y_, 
          z_] = \(potOutQ /. r2xRule\) /. {Q \[Rule] 1, a \[Rule] 1, 
              x \[Rule] 0}\  // Simplify;\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(pot[y_, z_]\), ":=", 
      RowBox[{"If", "[", 
        RowBox[{
          FormBox[\(y\^2 + z\^2 < 1\),
            "TraditionalForm"], ",", \(eq1[y, z]\), ",", \(eq2[y, z]\)}], 
        "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(circle = {Thickness[0.02], Circle[{0, 0}, 1]}\  // 
          Graphics;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Show[{VEPlot[pot[y, z], {y, \(-2\), 2}, {z, \(-2\), 2}, 
            DisplayFunction \[Rule] 
              Identity], \[IndentingNewLine]circle}, \
\[IndentingNewLine]DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 4: Sphere with a given axially symmetric potential ", \
"Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Needs[\"Calculus`VectorAnalysis`\"]
Needs[\"Graphics`ParametricPlot3D`\"] 
 \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(potIn[V_, s_]\), ":=", 
      RowBox[{"Sum", "[", 
        RowBox[{
          RowBox[{
            FormBox[\(\((r\/r0)\)\^n\ \(B(V, n)\)\),
              "TraditionalForm"], " ", \(P[n, Cos[\[Theta]]]\)}], 
          ",", \({n, 0, s}\)}], "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(potOut[V_, s_]\), ":=", 
      RowBox[{"Sum", "[", 
        RowBox[{
          RowBox[{
            FormBox[\(\((r0\/r)\)\^\(n + 1\)\ \(B(V, n)\)\),
              "TraditionalForm"], " ", \(P[n, Cos[\[Theta]]]\)}], 
          ",", \({n, 0, s}\)}], "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(B[V_, n_]\), ":=", 
      RowBox[{
        FormBox[\(1\/2\ \((2\ n + 1)\)\),
          "TraditionalForm"], 
        " ", \(Integrate[
          V\ LegendreP[n, Cos[\[Theta]]]\ Sin[\[Theta]], {\[Theta], 
            0, \[Pi]}]\)}]}]], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(pOut = potOut[V0\ Cos[\[Theta]]\^2, 4]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(pIn = potIn[V0\ Cos[\[Theta]]\^2, 4]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {r0 \[Rule] 1, V0 \[Rule] 1, 
          P \[Rule] LegendreP};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(p1 = 
        CylindricalPlot3D[pIn /. values, {r, 0, 1}, {\[Theta], 0, 2  \[Pi]}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(p2 = 
        CylindricalPlot3D[pOut /. values, {r, 1, 3}, {\[Theta], 0, 2  \[Pi]}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Show[p1, p2, BoxRatios \[Rule] {1, 1, 1}, 
        ViewPoint \[Rule] {\(-1.5\), \(-2\), 2}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  Hyphenation->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"surfacePot", "=", 
        FormBox[\(\(cos(\[Theta])\)\/\(1.1\[InvisibleSpace] - 
                cos(\[Theta])\)\),
          "TraditionalForm"]}], ";"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\({pIn2, 
          pOut2} = \((\({potIn[surfacePot, 3], potOut[surfacePot, 3]} /. 
                P \[Rule] LegendreP\) //. {r0 \[Rule] 1} // 
            Simplify)\);\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(p1 = 
        CylindricalPlot3D[pIn2, {r, 0, 1}, {\[Theta], 0, 2  \[Pi]}, 
          PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(p2 = 
        CylindricalPlot3D[pOut2, {r, 1, 3}, {\[Theta], 0, 2  \[Pi]}, 
          PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(Show[p1, 
        p2, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
            1}, \[IndentingNewLine]ViewPoint \[Rule] {\(-1.5\), \(-2\), 2}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 5: Sphere with upper hemisphere V0 and lower hemisphere -V0\
\
\>", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Needs[\"Calculus`VectorAnalysis`\"]
Needs[\"Graphics`ParametricPlot3D`\"] \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(potIn[s_]\), ":=", 
      RowBox[{"Sum", "[", 
        RowBox[{
          RowBox[{
            FormBox[\(\((r\/r0)\)\^n\ \(B(n)\)\),
              "TraditionalForm"], " ", \(P[n, Cos[\[Theta]]]\)}], 
          ",", \({n, 0, s}\)}], "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(potOut[s_]\), ":=", 
      RowBox[{"Sum", "[", 
        RowBox[{
          RowBox[{
            FormBox[\(\((r0\/r)\)\^\(n + 1\)\ \(B(n)\)\),
              "TraditionalForm"], " ", \(P[n, Cos[\[Theta]]]\)}], 
          ",", \({n, 0, s}\)}], "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{\(B[n_]\), ":=", 
        RowBox[{
          FormBox[\(1\/2\ \((2\ n + 1)\)\),
            
            "TraditionalForm"], \((\(+Integrate[
                  V0\ LegendreP[n, Cos[\[Theta]]] Sin[\[Theta]], {\[Theta], 
                    0, \[Pi]/2}]\) + 
              Integrate[\(-V0\)\ LegendreP[n, Cos[\[Theta]]] 
                  Sin[\[Theta]], {\[Theta], \[Pi]/2, \[Pi]}])\)}]}], 
      ";"}]], "Input",
  Hyphenation->False],

Cell[" potOut[5] ", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    \(\(values = {r0 \[Rule] 1, V0 \[Rule] 1, x -> 0};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(r2xRule = {r, \[Theta], \[Phi]} \[Rule] 
            CoordinatesFromCartesian[{x, y, z}, Spherical] // 
          Thread;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(allRules = \ {P \[Rule] LegendreP\ , \ r2xRule, values} // 
          Flatten\ ;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(eq1 = \ potIn[11] //. allRules;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(eq2 = potOut[11] //. allRules;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"potTot", "=", 
        RowBox[{"If", "[", 
          RowBox[{
            FormBox[\(y\^2 + z\^2 \[LessEqual] 1\),
              "TraditionalForm"], ",", "eq1", ",", "eq2"}], "]"}]}], 
      ";"}]], "Input",
  Hyphenation->False],

Cell["circle= Graphics[{Thickness[0.02],Circle[{0,0},1]}];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Show[{\[IndentingNewLine]ContourPlot[
            potTot // Evaluate, \[IndentingNewLine]{y, \(-2\), 
              2}, {z, \(-2\), 2}, \[IndentingNewLine]PlotPoints \[Rule] 
              20, \[IndentingNewLine]DisplayFunction \[Rule] 
              Identity], \[IndentingNewLine]circle}, \
\[IndentingNewLine]DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  Hyphenation->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["8.4 Exercises ", "Section",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 1 Parallel plates and strips  ", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 2 Parallel plates and a point charge", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 3 Cylinder divided into segments ", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 4 Elliptical cylinder in a uniform electric field", \
"Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 5 Cylindrical box and n charges", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 6 Distorted sphere with a potential", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
Exercise 7 Concentric spheres with different potentials on the two \
hemispheres   \
\>", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 8 Ring charge  ", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Exercise 9 Laplace's equations in other coordinates", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Closed]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{827, 688},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 116, 2, 42, "Subsubsection"],
Cell[1846, 56, 1886, 33, 657, "Input",
  Evaluatable->False]
}, Closed]],
Cell[3747, 92, 133, 4, 81, "Title",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[3905, 100, 130, 4, 60, "Section",
  Evaluatable->False,
  InitializationCell->False],
Cell[4038, 106, 149, 7, 57, "Input",
  InitializationCell->False]
}, Closed]],
Cell[4202, 116, 212, 8, 40, "Section",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[4439, 128, 130, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[4572, 134, 87, 2, 27, "Input"],
Cell[4662, 138, 856, 17, 123, "Input"],
Cell[5521, 157, 81, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5639, 164, 205, 7, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[5847, 173, 236, 6, 69, "Input"],
Cell[6086, 181, 201, 4, 27, "Input"]
}, Closed]],
Cell[6302, 188, 166, 4, 40, "Section",
  Evaluatable->False,
  InitializationCell->False],
Cell[6471, 194, 148, 3, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[6644, 201, 217, 8, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[6886, 213, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[7021, 219, 194, 6, 42, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[7240, 229, 131, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[7374, 235, 119, 3, 27, "Input",
  InitializationCell->False],
Cell[7496, 240, 113, 3, 24, "Input",
  InitializationCell->False],
Cell[7612, 245, 174, 6, 39, "Input",
  InitializationCell->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7835, 257, 131, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[7969, 263, 426, 15, 177, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[8420, 282, 131, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[8554, 288, 125, 3, 27, "Input",
  InitializationCell->False],
Cell[8682, 293, 103, 2, 24, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8834, 301, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[8969, 307, 355, 13, 147, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[9349, 324, 131, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[9483, 330, 88, 2, 29, "Input"],
Cell[9574, 334, 94, 2, 24, "Input"]
}, Closed]]
}, Closed]],
Cell[9695, 340, 109, 5, 42, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9841, 350, 165, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[10009, 356, 143, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[10177, 364, 141, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[10321, 370, 202, 7, 57, "Input",
  InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{
Cell[10560, 382, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[10695, 388, 114, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[10834, 395, 53, 1, 42, "Subsubsection"],
Cell[10890, 398, 211, 8, 72, "Input",
  InitializationCell->False],
Cell[11104, 408, 229, 7, 54, "Input",
  InitializationCell->False],
Cell[11336, 417, 255, 8, 72, "Input",
  InitializationCell->False],
Cell[11594, 427, 277, 6, 59, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11908, 438, 53, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[11986, 443, 383, 8, 75, "Input"],
Cell[12372, 453, 358, 7, 75, "Input"]
}, Closed]],
Cell[12745, 463, 448, 10, 107, "Input"],
Cell[13196, 475, 72, 2, 27, "Input"],
Cell[13271, 479, 262, 6, 56, "Input"],
Cell[13536, 487, 370, 8, 56, "Input"],
Cell[13909, 497, 265, 6, 59, "Input"],
Cell[14177, 505, 508, 11, 72, "Input"],
Cell[14688, 518, 201, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14926, 527, 53, 1, 42, "Subsubsection"],
Cell[14982, 530, 178, 5, 27, "Input"],
Cell[15163, 537, 158, 3, 24, "Input"],
Cell[15324, 542, 126, 3, 24, "Input",
  InitializationCell->False],
Cell[15453, 547, 177, 4, 24, "Input"],
Cell[15633, 553, 128, 3, 24, "Input",
  InitializationCell->False],
Cell[15764, 558, 185, 4, 24, "Input"],
Cell[15952, 564, 130, 3, 27, "Input",
  InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{
Cell[16119, 572, 53, 1, 42, "Subsubsection"],
Cell[16175, 575, 516, 11, 107, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[16752, 593, 167, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[16922, 599, 143, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[17090, 607, 141, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[17234, 613, 169, 6, 42, "Input",
  InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{
Cell[17440, 624, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[17575, 630, 114, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[17714, 637, 53, 1, 42, "Subsubsection"],
Cell[17770, 640, 170, 6, 42, "Input",
  InitializationCell->False],
Cell[17943, 648, 107, 3, 24, "Input",
  InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{
Cell[18087, 656, 53, 1, 42, "Subsubsection"],
Cell[18143, 659, 162, 4, 27, "Input"],
Cell[18308, 665, 155, 3, 24, "Input"],
Cell[18466, 670, 110, 3, 24, "Input",
  InitializationCell->False],
Cell[18579, 675, 154, 5, 24, "Input",
  InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{
Cell[18770, 685, 53, 1, 42, "Subsubsection"],
Cell[18826, 688, 117, 3, 27, "Input"],
Cell[18946, 693, 194, 6, 24, "Input",
  InitializationCell->False],
Cell[19143, 701, 161, 4, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19365, 712, 168, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[19536, 718, 143, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[19682, 724, 141, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[19826, 730, 169, 6, 42, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[20020, 740, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[20155, 746, 114, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[20294, 753, 53, 1, 42, "Subsubsection"],
Cell[20350, 756, 154, 3, 44, "Input"],
Cell[20507, 761, 146, 3, 27, "Input",
  InitializationCell->False],
Cell[20656, 766, 145, 3, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[20838, 774, 53, 1, 42, "Subsubsection"],
Cell[20894, 777, 183, 6, 27, "Input",
  InitializationCell->False],
Cell[21080, 785, 147, 3, 24, "Input",
  InitializationCell->False],
Cell[21230, 790, 112, 2, 24, "Input"],
Cell[21345, 794, 166, 3, 24, "Input"],
Cell[21514, 799, 509, 11, 72, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[22060, 815, 53, 1, 42, "Subsubsection"],
Cell[22116, 818, 455, 12, 44, "Input"],
Cell[22574, 832, 204, 4, 43, "Input"],
Cell[22781, 838, 179, 4, 47, "Input"],
Cell[22963, 844, 110, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23110, 851, 53, 1, 42, "Subsubsection"],
Cell[23166, 854, 712, 14, 123, "Input"],
Cell[23881, 870, 430, 14, 159, "Input",
  InitializationCell->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24372, 891, 165, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[24540, 897, 143, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[24708, 905, 141, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[24852, 911, 169, 6, 42, "Input",
  InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{
Cell[25058, 922, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[25193, 928, 114, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[25332, 935, 53, 1, 42, "Subsubsection"],
Cell[25388, 938, 151, 3, 31, "Input"],
Cell[25542, 943, 113, 3, 27, "Input",
  InitializationCell->False],
Cell[25658, 948, 423, 9, 72, "Input"],
Cell[26084, 959, 142, 3, 24, "Input",
  InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{
Cell[26263, 967, 53, 1, 42, "Subsubsection"],
Cell[26319, 970, 247, 7, 44, "Input"],
Cell[26569, 979, 162, 4, 24, "Input"],
Cell[26734, 985, 165, 6, 24, "Input",
  InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{
Cell[26936, 996, 53, 1, 42, "Subsubsection"],
Cell[26992, 999, 146, 3, 27, "Input",
  InitializationCell->False],
Cell[27141, 1004, 486, 9, 88, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[27688, 1020, 181, 5, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[27872, 1027, 114, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[28011, 1034, 143, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[28179, 1042, 135, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[28317, 1048, 1362, 30, 113, "Input"],
Cell[29682, 1080, 247, 7, 46, "Input"],
Cell[29932, 1089, 141, 3, 27, "Input",
  InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{
Cell[30110, 1097, 134, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[30247, 1103, 1232, 28, 178, "Input"],
Cell[31482, 1133, 200, 5, 46, "Input"],
Cell[31685, 1140, 123, 3, 27, "Input",
  InitializationCell->False],
Cell[31811, 1145, 123, 3, 24, "Input",
  InitializationCell->False],
Cell[31937, 1150, 150, 3, 24, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[32136, 1159, 141, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[32280, 1165, 169, 6, 42, "Input",
  InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{
Cell[32486, 1176, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[32643, 1184, 53, 1, 42, "Subsubsection"],
Cell[32699, 1187, 658, 16, 132, "Input"],
Cell[33360, 1205, 195, 6, 42, "Input",
  InitializationCell->False],
Cell[33558, 1213, 96, 2, 24, "Input"],
Cell[33657, 1217, 211, 4, 27, "Input"],
Cell[33871, 1223, 211, 4, 24, "Input"],
Cell[34085, 1229, 211, 4, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[34333, 1238, 53, 1, 42, "Subsubsection"],
Cell[34389, 1241, 132, 3, 27, "Input",
  InitializationCell->False],
Cell[34524, 1246, 143, 3, 24, "Input",
  InitializationCell->False],
Cell[34670, 1251, 144, 3, 24, "Input",
  InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{
Cell[34851, 1259, 53, 1, 42, "Subsubsection"],
Cell[34907, 1262, 116, 3, 27, "Input"],
Cell[35026, 1267, 98, 2, 24, "Input"],
Cell[35127, 1271, 161, 3, 24, "Input"],
Cell[35291, 1276, 228, 5, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[35556, 1286, 53, 1, 42, "Subsubsection"],
Cell[35612, 1289, 219, 4, 27, "Input"],
Cell[35834, 1295, 133, 3, 24, "Input",
  InitializationCell->False],
Cell[35970, 1300, 201, 4, 24, "Input"],
Cell[36174, 1306, 133, 3, 24, "Input",
  InitializationCell->False],
Cell[36310, 1311, 264, 5, 24, "Input"],
Cell[36577, 1318, 107, 3, 24, "Input",
  InitializationCell->False]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[36723, 1326, 192, 7, 40, "Section",
  Evaluatable->False,
  InitializationCell->False],
Cell[36918, 1335, 93, 1, 45, "Subsection"],

Cell[CellGroupData[{
Cell[37036, 1340, 209, 7, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[37270, 1351, 141, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[37414, 1357, 130, 3, 27, "Input",
  InitializationCell->False]
}, Closed]],
Cell[37559, 1363, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[37694, 1369, 114, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[37833, 1376, 53, 1, 42, "Subsubsection"],
Cell[37889, 1379, 123, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[38037, 1386, 127, 3, 27, "Input",
  InitializationCell->False],
Cell[38167, 1391, 122, 3, 27, "Input",
  InitializationCell->False]
}, Closed]],
Cell[38304, 1397, 101, 2, 47, "Input"],
Cell[38408, 1401, 99, 2, 24, "Input"],
Cell[38510, 1405, 259, 7, 28, "Input"],
Cell[38772, 1414, 199, 4, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[39008, 1423, 53, 1, 42, "Subsubsection"],
Cell[39064, 1426, 125, 3, 27, "Input",
  InitializationCell->False],
Cell[39192, 1431, 101, 2, 27, "Input"],
Cell[39296, 1435, 130, 3, 27, "Input",
  InitializationCell->False],
Cell[39429, 1440, 135, 3, 43, "Input"],
Cell[39567, 1445, 134, 3, 24, "Input",
  InitializationCell->False],
Cell[39704, 1450, 100, 2, 24, "Input"],
Cell[39807, 1454, 123, 3, 24, "Input"],
Cell[39933, 1459, 97, 2, 24, "Input"],
Cell[40033, 1463, 80, 2, 26, "Input"],
Cell[40116, 1467, 143, 4, 26, "Input"],
Cell[40262, 1473, 105, 2, 24, "Input"],
Cell[40370, 1477, 136, 3, 28, "Input"],
Cell[40509, 1482, 135, 3, 24, "Input"],
Cell[40647, 1487, 126, 3, 24, "Input",
  InitializationCell->False],
Cell[40776, 1492, 215, 4, 24, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[41040, 1502, 169, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[41234, 1510, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[41369, 1516, 114, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[41508, 1523, 53, 1, 42, "Subsubsection"],
Cell[41564, 1526, 155, 5, 27, "Input",
  InitializationCell->False],
Cell[41722, 1533, 384, 11, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[42143, 1549, 53, 1, 42, "Subsubsection"],
Cell[42199, 1552, 120, 6, 42, "Input",
  InitializationCell->False],
Cell[42322, 1560, 229, 5, 40, "Input"],
Cell[42554, 1567, 98, 2, 24, "Input"],
Cell[42655, 1571, 99, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[42791, 1578, 53, 1, 42, "Subsubsection"],
Cell[42847, 1581, 118, 3, 27, "Input",
  InitializationCell->False],
Cell[42968, 1586, 359, 10, 41, "Input"],
Cell[43330, 1598, 201, 4, 24, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[43592, 1609, 157, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[43752, 1615, 143, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[43898, 1621, 141, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[44042, 1627, 169, 6, 42, "Input",
  InitializationCell->False],
Cell[44214, 1635, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[44349, 1641, 114, 3, 27, "Input",
  InitializationCell->False],
Cell[44466, 1646, 331, 9, 74, "Input"],
Cell[44800, 1657, 137, 3, 24, "Input",
  InitializationCell->False],
Cell[44940, 1662, 103, 3, 27, "Input",
  InitializationCell->False],
Cell[45046, 1667, 78, 2, 24, "Input"],
Cell[45127, 1671, 97, 2, 24, "Input"],
Cell[45227, 1675, 187, 3, 24, "Input"],
Cell[45417, 1680, 220, 5, 24, "Input"],
Cell[45640, 1687, 166, 6, 39, "Input",
  InitializationCell->False],
Cell[45809, 1695, 101, 3, 24, "Input",
  InitializationCell->False],
Cell[45913, 1700, 273, 5, 56, "Input"],
Cell[46189, 1707, 241, 5, 56, "Input"],
Cell[46433, 1714, 193, 5, 40, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[46663, 1724, 214, 7, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[46902, 1735, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[47037, 1741, 114, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[47176, 1748, 53, 1, 42, "Subsubsection"],
Cell[47232, 1751, 227, 6, 50, "Input"],
Cell[47462, 1759, 686, 17, 62, "Input"],
Cell[48151, 1778, 444, 11, 41, "Input"],
Cell[48598, 1791, 64, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[48699, 1798, 53, 1, 42, "Subsubsection"],
Cell[48755, 1801, 148, 3, 27, "Input"],
Cell[48906, 1806, 144, 4, 27, "Input"],
Cell[49053, 1812, 161, 3, 27, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[49275, 1822, 197, 7, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[49475, 1831, 141, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[49619, 1837, 132, 3, 27, "Input",
  InitializationCell->False],
Cell[49754, 1842, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[49889, 1848, 114, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[50028, 1855, 53, 1, 42, "Subsubsection"],
Cell[50084, 1858, 437, 11, 44, "Input"],
Cell[50524, 1871, 126, 3, 24, "Input"],
Cell[50653, 1876, 63, 2, 27, "Input"],
Cell[50719, 1880, 102, 2, 24, "Input"],
Cell[50824, 1884, 347, 10, 41, "Input"],
Cell[51174, 1896, 514, 13, 59, "Input"],
Cell[51691, 1911, 132, 3, 24, "Input"],
Cell[51826, 1916, 64, 2, 27, "Input"],
Cell[51893, 1920, 378, 10, 41, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52308, 1935, 53, 1, 42, "Subsubsection"],
Cell[52364, 1938, 86, 2, 27, "Input"],
Cell[52453, 1942, 339, 7, 75, "Input"],
Cell[52795, 1951, 342, 7, 75, "Input"],
Cell[53140, 1960, 78, 2, 27, "Input"],
Cell[53221, 1964, 127, 3, 27, "Input"],
Cell[53351, 1969, 82, 2, 24, "Input"],
Cell[53436, 1973, 288, 6, 43, "Input"],
Cell[53727, 1981, 289, 6, 43, "Input"],
Cell[54019, 1989, 135, 3, 27, "Input"]
}, Closed]]
}, Closed]],
Cell[54181, 1996, 166, 4, 40, "Section",
  Evaluatable->False,
  InitializationCell->False],
Cell[54350, 2002, 80, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[54455, 2007, 151, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[54631, 2015, 141, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[54775, 2021, 130, 3, 27, "Input",
  InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{
Cell[54942, 2029, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[55077, 2035, 114, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[55216, 2042, 53, 1, 42, "Subsubsection"],
Cell[55272, 2045, 167, 5, 46, "Input"],
Cell[55442, 2052, 249, 5, 43, "Input"],
Cell[55694, 2059, 103, 3, 27, "Input",
  InitializationCell->False],
Cell[55800, 2064, 104, 3, 24, "Input",
  InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{
Cell[55941, 2072, 53, 1, 42, "Subsubsection"],
Cell[55997, 2075, 368, 10, 42, "Input"],
Cell[56368, 2087, 342, 9, 42, "Input"],
Cell[56713, 2098, 229, 5, 27, "Input"],
Cell[56945, 2105, 105, 3, 27, "Input",
  InitializationCell->False],
Cell[57053, 2110, 130, 3, 24, "Input",
  InitializationCell->False],
Cell[57186, 2115, 107, 3, 27, "Input",
  InitializationCell->False],
Cell[57296, 2120, 300, 8, 38, "Input"],
Cell[57599, 2130, 222, 5, 27, "Input"],
Cell[57824, 2137, 88, 2, 27, "Input"],
Cell[57915, 2141, 63, 2, 27, "Input"],
Cell[57981, 2145, 149, 5, 24, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[58155, 2154, 126, 3, 27, "Input",
  InitializationCell->False],
Cell[58284, 2159, 124, 3, 27, "Input",
  InitializationCell->False],
Cell[58411, 2164, 66, 2, 27, "Input"],
Cell[58480, 2168, 65, 2, 24, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[58594, 2176, 53, 1, 42, "Subsubsection"],
Cell[58650, 2179, 164, 4, 27, "Input"],
Cell[58817, 2185, 95, 2, 24, "Input"],
Cell[58915, 2189, 240, 5, 43, "Input"],
Cell[59158, 2196, 386, 10, 36, "Input"],
Cell[59547, 2208, 207, 5, 27, "Input"],
Cell[59757, 2215, 245, 5, 27, "Input"],
Cell[60005, 2222, 91, 2, 27, "Input"],
Cell[60099, 2226, 288, 6, 40, "Input"],
Cell[60390, 2234, 205, 5, 24, "Input"],
Cell[60598, 2241, 435, 9, 91, "Input"],
Cell[61036, 2252, 91, 2, 27, "Input"],
Cell[61130, 2256, 236, 5, 40, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[61427, 2268, 173, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[61603, 2274, 141, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[61747, 2280, 143, 3, 43, "Input"],
Cell[61893, 2285, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[62028, 2291, 114, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[62167, 2298, 53, 1, 42, "Subsubsection"],
Cell[62223, 2301, 128, 3, 27, "Input"],
Cell[62354, 2306, 501, 14, 42, "Input"],
Cell[62858, 2322, 189, 4, 31, "Input"],
Cell[63050, 2328, 111, 6, 42, "Input",
  InitializationCell->False],
Cell[63164, 2336, 110, 2, 27, "Input"],
Cell[63277, 2340, 72, 2, 27, "Input"],
Cell[63352, 2344, 109, 2, 27, "Input"],
Cell[63464, 2348, 104, 2, 24, "Input"],
Cell[63571, 2352, 624, 17, 42, "Input"],
Cell[64198, 2371, 138, 3, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[64373, 2379, 53, 1, 42, "Subsubsection"],
Cell[64429, 2382, 180, 4, 27, "Input"],
Cell[64612, 2388, 96, 2, 27, "Input"],
Cell[64711, 2392, 306, 7, 59, "Input"],
Cell[65020, 2401, 92, 2, 27, "Input"],
Cell[65115, 2405, 127, 3, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[65291, 2414, 199, 7, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[65515, 2425, 141, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[65659, 2431, 178, 6, 42, "Input",
  InitializationCell->False]
}, Closed]],
Cell[65852, 2440, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[65987, 2446, 114, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[66126, 2453, 53, 1, 42, "Subsubsection"],
Cell[66182, 2456, 308, 8, 42, "Input"],
Cell[66493, 2466, 317, 8, 42, "Input"],
Cell[66813, 2476, 273, 7, 44, "Input"],
Cell[67089, 2485, 80, 2, 27, "Input"],
Cell[67172, 2489, 189, 5, 28, "Input"],
Cell[67364, 2496, 148, 4, 27, "Input"],
Cell[67515, 2502, 195, 5, 46, "Input"],
Cell[67713, 2509, 239, 6, 43, "Input"],
Cell[67955, 2517, 240, 6, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[68232, 2528, 53, 1, 42, "Subsubsection"],
Cell[68288, 2531, 245, 6, 55, "Input"],
Cell[68536, 2539, 135, 3, 24, "Input",
  InitializationCell->False],
Cell[68674, 2544, 131, 3, 24, "Input",
  InitializationCell->False],
Cell[68808, 2549, 95, 2, 24, "Input"],
Cell[68906, 2553, 202, 5, 27, "Input"],
Cell[69111, 2560, 203, 5, 27, "Input"],
Cell[69317, 2567, 314, 6, 75, "Input"],
Cell[69634, 2575, 180, 4, 24, "Input"],
Cell[69817, 2581, 236, 5, 43, "Input"],
Cell[70056, 2588, 220, 5, 43, "Input"],
Cell[70279, 2595, 255, 7, 31, "Input"],
Cell[70537, 2604, 130, 3, 27, "Input"],
Cell[70670, 2609, 269, 5, 59, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[70988, 2620, 185, 5, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[71176, 2627, 141, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[71320, 2633, 178, 7, 57, "Input",
  InitializationCell->False],
Cell[71501, 2642, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[71636, 2648, 114, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[71775, 2655, 53, 1, 42, "Subsubsection"],
Cell[71831, 2658, 307, 8, 41, "Input"],
Cell[72141, 2668, 316, 8, 45, "Input"],
Cell[72460, 2678, 292, 8, 44, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[72789, 2691, 53, 1, 42, "Subsubsection"],
Cell[72845, 2694, 93, 2, 31, "Input"],
Cell[72941, 2698, 91, 2, 28, "Input"],
Cell[73035, 2702, 129, 3, 24, "Input"],
Cell[73167, 2707, 187, 4, 27, "Input"],
Cell[73357, 2713, 188, 4, 27, "Input"],
Cell[73548, 2719, 202, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[73787, 2728, 53, 1, 42, "Subsubsection"],
Cell[73843, 2731, 229, 6, 45, "Input"],
Cell[74075, 2739, 226, 5, 27, "Input"],
Cell[74304, 2746, 212, 5, 27, "Input"],
Cell[74519, 2753, 213, 5, 27, "Input"],
Cell[74735, 2760, 253, 5, 59, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[75037, 2771, 201, 7, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[75241, 2780, 141, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[75385, 2786, 176, 6, 42, "Input",
  InitializationCell->False],
Cell[75564, 2794, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[75699, 2800, 114, 3, 27, "Input",
  InitializationCell->False],

Cell[CellGroupData[{
Cell[75838, 2807, 53, 1, 42, "Subsubsection"],
Cell[75894, 2810, 300, 8, 41, "Input"],
Cell[76197, 2820, 309, 8, 45, "Input"],
Cell[76509, 2830, 473, 12, 44, "Input"],
Cell[76985, 2844, 105, 3, 27, "Input",
  InitializationCell->False]
}, Closed]],

Cell[CellGroupData[{
Cell[77127, 2852, 53, 1, 42, "Subsubsection"],
Cell[77183, 2855, 105, 2, 27, "Input"],
Cell[77291, 2859, 180, 4, 27, "Input"],
Cell[77474, 2865, 139, 3, 27, "Input"],
Cell[77616, 2870, 90, 2, 27, "Input"],
Cell[77709, 2874, 89, 2, 27, "Input"],
Cell[77801, 2878, 270, 8, 31, "Input"],
Cell[78074, 2888, 146, 3, 27, "Input",
  InitializationCell->False],
Cell[78223, 2893, 412, 7, 123, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[78684, 2906, 132, 4, 40, "Section",
  Evaluatable->False,
  InitializationCell->False],
Cell[78819, 2912, 163, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[78985, 2918, 169, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[79157, 2924, 166, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[79326, 2930, 184, 5, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[79513, 2937, 164, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[79680, 2943, 168, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[79851, 2949, 215, 7, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[80069, 2958, 148, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[80220, 2964, 175, 4, 28, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

