(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     63811,       2038]*)
(*NotebookOutlinePosition[     64505,       2063]*)
(*  CellTagsIndexPosition[     64461,       2059]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Legal Notice, Disclaimer, and Book Ordering Information:", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "(* Legal Notice, Disclaimer, and Book Ordering Information:\n\nLast \
Modified: FIO June 8, 2002\n\n",
  StyleBox["Mathematica For Physics: 2nd Edition",
    FontColor->RGBColor[1, 0, 0]],
  "\n\nRobert L. Zimmerman and Fredrick I. Olness\n",
  "\nWebSite:  \n",
  StyleBox["  www.physics.smu.edu/~olness\n  darkwing.uoregon.edu/~phys600/\n\
\n",
    FontColor->RGBColor[1, 0, 0]],
  "MathSource Number: 0206-862",
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  "\nISBN 0-201-53796-6\nFor ordering information, call 1-800-282-0693\n\
Addison-Wesley Publishing Company\n",
  "\nCommunication with the authors:\nFredrick I. Olness:  \
olness@mail.physics.smu.edu\nRobert L. Zimmerman: bob@zim.uoregon.edu\n\n\
Copyright 2002, Addison-Wesley Publishing Company, Inc. The material in\nthis \
file may be distributed freely  so long as the content remains\nunchanged, \
and the copyright and  reference notices are included. The\npublisher grants \
permission for the noncommercial use of these programs\nand program segments. \
 All other uses require the prior written consent\nof the publisher.    \n\n\
All rights are reserved with regard to the  material in the\n\"Mathematica \
For Physics\" text, and may not be reproduced, stored in a\nretrieval system, \
or transmitted,  in any form or by any means,\nelectronic, mechanical, \
photocopying,  recording, or otherwise, without\nthe prior written permission \
 of the publisher. \n\nThe programs and applications presented in this book \
have been included\nfor  their instructional value. They have been tested \
with care but are\nnot  guaranteed for any particular purpose. The publisher \
does not\noffer any  warranties or representations, nor does it accept any\n\
liabilities with  respect to the programs or applications. \n\n *)\n"
}], "Input",
  Evaluatable->False,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[" 9. Quantum Mechanics", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[" Introduction", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\ \(Off[General::"\<spell\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Off[General::"\<spell1\>"];\)\)}], "Input"]
}, Closed]],

Cell["9.1 One-Dimensional Schroedinger's Equation ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Problem 1: Particle bound in an Infinite Potential Well", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[" Needs[\"Graphics`Legend`\"]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution: ", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq1", "=", " ", 
        FormBox[
          RowBox[{"0", "==", 
            RowBox[{\(\((V - En)\)\ \[Psi][x]\), "-", 
              FractionBox[
                RowBox[{\(\[HBar]\^2\), " ", 
                  RowBox[{
                    SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
                      MultilineFunction->None], "[", "x", 
                    "]"}]}], \(2\ m\)]}]}],
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(eq2 = eq1 /. V \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(\(krule = \ En \[Rule] \(\[HBar]\^2\ k\^2\)\/\(2\ m\);\)\)], "Input"],

Cell[BoxData[
    \(schrod = \(Solve[eq2 /. krule, \(\[Psi]''\)[x]\ ]\)[\([1, 1]\)] /. 
        Rule \[Rule] Equal\)], "Input"],

Cell["\<\
dsol= DSolve[schrod,\[Psi],x][[1,1]]\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(sol1 = 
      Reduce[{\[Psi][0] \[Equal] 0, \[Psi][a] \[Equal] 0} /. dsol]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"En", "\[Equal]", 
        FormBox[\(\(k\^2\ \[HBar]\^2\)\/\(2\ m\)\),
          "TraditionalForm"]}], "/.", 
      FormBox[\(k \[Rule] \(n\ \[Pi]\)\/a\),
        "TraditionalForm"]}]], "Input"],

Cell[BoxData[
    RowBox[{\(\[Psi][x_, n_]\), " ", "=", 
      RowBox[{\(\[Psi][x\ ]\  /. dsol\), "/.", 
        RowBox[{"{", 
          RowBox[{\(C[1] \[Rule] 0\), ",", " ", 
            FormBox[\(k \[Rule] \(n\ \[Pi]\)\/a\),
              "TraditionalForm"]}], "}"}]}]}]], "Input"],

Cell[BoxData[
    \(normEq = \ \(1\  \[Equal] \ Integrate[\[Psi][x, n]\^2, {x, 0, a}] // 
          Simplify[#, Element[n, Integers]] &\) // \(Solve[#, C[2]]\)[\([2, 
              1\ ]\)] &\)], "Input"],

Cell[BoxData[
    \(\[Psi][x_, n_]\  = \[Psi][x, n] /. normEq // Simplify\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell["\<\
table= \
Table[Integrate[\[Psi][x,i]\[Psi][x,j],{x,0,a}],{i,4},{j,4}];\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[table, 
      TableHeadings \[Rule] {Table[\[Psi][i], {i, 4}], 
          Table[\[Psi][j], {j, 4}]}]\)], "Input"],

Cell[BoxData[
    \(\(Plot[\ 
        Table[\[Psi][n, x], {n, 4}] /. {a \[Rule] 1} // 
          Evaluate, \[IndentingNewLine]{x, 0, 1}, 
        PlotStyle \[Rule] {{}, Dashing[{ .05}], Dashing[{ .03}], 
            Dashing[{ .01}]}, \[IndentingNewLine]PlotLabel \[Rule] 
          StyleForm[\[Psi], FontSize \[Rule] 14, 
            FontWeight \[Rule] 
              Bold], \[IndentingNewLine]PlotLegend \[Rule] {"\<n=1\>", "\<n=2\
\>", "\<n=3\>", "\<n=4\>"\ }, 
        LegendPosition \[Rule] {1, \(-1\)/2}];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 2: Particle bound in a Finite Potential Well", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"schrodeq", "=", 
        FormBox[
          RowBox[{"0", "==", 
            RowBox[{\(\((V - En)\)\ \[Psi][x]\), "-", 
              FractionBox[
                RowBox[{\(\[HBar]\^2\), " ", 
                  RowBox[{
                    SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
                      MultilineFunction->None], "[", "x", 
                    "]"}]}], \(2\ m\)]}]}],
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"EWrule", "=", 
        FormBox[\({En \[Rule] \(kW\^2\ \[HBar]\^2\)\/\(2\ m\) + V}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(\(\(\[Psi][x] /. \(DSolve[schrodeq, \[Psi][x], x]\)[\([1, 1]\)]\) /. 
            EWrule // ExpToTrig\)\  // Simplify\)\  // PowerExpand\)], "Input"],

Cell[BoxData[
    RowBox[{"kWrule", "=", " ", 
      RowBox[{
        RowBox[{
          FormBox[\(kW \[Rule] \(\@2\ \@\(m\ \((En - V)\)\)\)\/\[HBar]\),
            "TraditionalForm"], "/.", \(V \[Rule] \(-V0\)\)}], 
        "/.", \(En \[Rule] \(-Wn\)\)}]}]], "Input"],

Cell[BoxData[
    \(\(\[Psi]W[x_] = cSym\ Cos[kW\ x] + cAsym\ Sin[kW\ x];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ELRrule", "=", 
        FormBox[\({En \[Rule] \(kLR\^2\ \[HBar]\^2\)\/\(2\ m\)}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(\(\(\(\[Psi][x] /. \(DSolve[schrodeq, \[Psi][x], x]\)[\([1, 1]\)]\) /. 
            V \[Rule] 0\) /. ELRrule\  // 
        Simplify\)\(//\)\(\ \)\(PowerExpand\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{"kLRrule", "=", " ", 
      RowBox[{
        RowBox[{
          FormBox[\(kLR \[Rule] \(\@2\ \@\(En\ m\)\)\/\[HBar]\),
            "TraditionalForm"], " ", "/.", \(En \[Rule] \(-Wn\)\)}], " ", "//",
         "PowerExpand"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"qLRrule", "=", " ", 
        FormBox[\(qLR \[Rule] \(\@2\ \@\(m\ Wn\)\)\/\[HBar]\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(\(\(\(\(\[Psi][
                  x] /. \(DSolve[schrodeq, \[Psi][x], x]\)[\([1, 1]\)]\) /. 
              V \[Rule] 0\) /. ELRrule\)\  /. kLR \[Rule] I\ qLR // 
        Simplify\)\(//\)\(\ \)\(PowerExpand\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Psi]R[x_] = \ 
        cR\ E\^\(\(-qLR\)\ x\)\ \ \ ;\)\(\ \ \ \ \ \ \ \ \ \ \ \)\( (*x > 
        a*) \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Psi]L[x_] = \ 
        cL\ E\^\(\(+qLR\)\ x\)\ ;\)\(\ \ \ \ \ \ \)\( (*x < \(-a\)*) \)\)\)], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell["\<\
eq1= {  (\[Psi]L[ x]-\[Psi]W[ x]==0)  /. {x-> -a}, 
        (\[Psi]W[ x]-\[Psi]R[ x]==0)  /. {x-> +a},
        (\[Psi]L'[x]-\[Psi]W'[x]==0)  /. {x-> -a},
        (\[Psi]W'[x]-\[Psi]R'[x]==0)  /. {x-> +a}  } \
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((eq2 = eq1 /. cAsym \[Rule] 0\ )\) // ColumnForm\)], "Input"],

Cell[BoxData[
    \(eq3 = 
      Reduce[{\ eq2\ , \ cL \[NotEqual] 0, cR \[NotEqual] 0, 
            kW \[NotEqual] 0, qLR\  \[NotEqual] 0, \ cSym \[NotEqual] 0, 
            Cos[\ a\ kW] \[NotEqual] 0\ } // Flatten\ \ , {cL, 
          cR}\ ]\ ; \(\(eq3\)\(\ \)\(//\)\(ColumnForm\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(symSol = \ \(\(Solve[eq3\ \ , {cL, cR}\ ]\  // 
          Simplify\)\(//\)\(Flatten\)\(\ \ \)\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(symEn = Tan[a\ kW] \[Equal] \ \ qLR/kW;\)\)\)], "Input"],

Cell[BoxData[{
    \(\(eq4 = 
        Reduce[{\ eq1 /. cSym \[Rule] 0\ , \ cL \[NotEqual] 0, 
              cR \[NotEqual] 0, kW \[NotEqual] 0, qLR \[NotEqual] 0, 
              cAsym \[NotEqual] 0, Cos[\ a\ kW] \[NotEqual] 0\ } // 
            Flatten\ \ , {cL, cR}\ ]\ ;\)\), "\[IndentingNewLine]", 
    \(eq4 // ColumnForm\)}], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(asymSol = \ \(\(Solve[eq4\ , {cL, cR}\ ]\  // 
          Simplify\)\(//\)\(Flatten\)\(\ \)\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(asymEn = Tan[a\ kW] \[Equal] \ \(-\ kW\)/qLR;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c ", "Subsubsection"],

Cell[BoxData[
    \(\(values = {a \[Rule] 1, m \[Rule] 1, \[HBar] \[Rule] 1, 
          V0\  \[Rule] {\ 100, \ 200, \ 500, \[Infinity]}}\ ;\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"nRule", "=", 
        FormBox[\(Wn \[Rule] 
            V0 - \(n\^2\ \[Pi]\^2\ \[HBar]\^2\)\/\(8\ a\^2\ m\)\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(kRules = {kW \[Rule] \(\(\ \)\(\@\(2\ m\ \((V0 - Wn\ )\)\)\)\)\/\
\[HBar], qLR \[Rule] \(\(\ \)\(\@\(2\ \((Wn)\)\ m\)\)\)\/\[HBar]};\)\)], \
"Input"],

Cell["eq5 =symEn/.kRules /.nRule//PowerExpand ", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(pt1 = 
        Plot[{ArcTan[eq5[\([1]\)]], ArcTan[eq5[\([2]\)]]} /. values // 
            Evaluate, \[IndentingNewLine]{n, 0, 
            9\ }, \[IndentingNewLine]Frame \[Rule] True, 
          FrameTicks \[Rule] {{{1, "\<n=1\>"}, {3, "\<n=3\>"}, {5, \
"\<n=5\>"}, {7, "\<n=7\>"}, {9, "\<n=9\>"}}, {0, 0.5, 1, 
                1.5}}, \[IndentingNewLine]PlotRange \[Rule] { .4, 
              1.6}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"text", "=", 
        RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{"Text", "[", " ", 
              RowBox[{"\"\<V0=\!\(
\*InterpretationBox[\(\[Infinity]\),
DirectedInfinity[ 1]]\)\>\"", ",", "  ", \({6, 1.5}\)}], "]"}], ",", 
            "\[IndentingNewLine]", \(Text[\ "\<V0=500\>", \ {6, 1.3}]\), ",", 
            "\[IndentingNewLine]", \(Text[\ "\<V0=200\>", \ {6, 1.1}]\), ",", 
            "\[IndentingNewLine]", \(Text[\ "\<V0=100\>", \ {6, 0.8}]\)}], 
          "}"}]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(Show[pt1, Graphics[text]\ , GridLines \[Rule] Automatic, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell["eq6 =asymEn/.kRules /.nRule//PowerExpand ", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"text", "=", 
        RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{"Text", "[", " ", 
              RowBox[{"\"\<V0=\!\(
\*InterpretationBox[\(\[Infinity]\),
DirectedInfinity[ 1]]\)\>\"", ",", "  ", \({7, 0}\)}], "]"}], ",", 
            "\[IndentingNewLine]", \(Text[\ "\<V0=500\>", \ {7, \(- .4\)}]\), 
            ",", "\[IndentingNewLine]", \(Text[\ "\<V0=200\>", \ {7, \(- \
.7\)}]\), ",", \(Text[\ "\<V0=100\>", \ {7, \(- .9\)\ }]\)}], "}"}]}], 
      ";"}]], "Input"],

Cell[BoxData[
    \(\(Plot[{ArcTan[eq6[\([1]\)]], ArcTan[\ eq6[\([2]\)]]}\  /. values // 
          Evaluate, \[IndentingNewLine]{n, 0.0\ , 
          9}, \[IndentingNewLine]Frame \[Rule] True, \ 
        FrameTicks \[Rule] {{{2, "\<n=2\>"}, {4, "\<n=4\>"}, {6, "\<n=6\>"}, \
{8, "\<n=8\>"}}, {\(-1.5\), \(-1\), 0, 0.5, 1, 
              1.5}}, \[IndentingNewLine]PlotRange \[Rule] {\(-1\)\ , \  .1}, \
\ \[IndentingNewLine]GridLines \[Rule] 
          Automatic, \[IndentingNewLine]Epilog \[Rule] \ 
          text\ \ ];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection"],

Cell[BoxData[
    \(nValues[eq_, potential_, 
        guess_] := \((n /. \(FindRoot[
              eq /. {m \[Rule] 1, a \[Rule] 1, \[HBar] \[Rule] 1, 
                    V0 \[Rule] potential} // Evaluate, {n, 
                guess}]\)[\([1]\)])\)\)], "Input"],

Cell["symGuess= {0.9, 2.9, 4.9, 6.9, 8.9};", "Input",
  AspectRatioFixed->True],

Cell["\<\
symValues= {nValues[eq5,100,#]
           ,nValues[eq5,200,#]
           ,nValues[eq5,500,#]}&  /@  symGuess;  \
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(asymGuess = {1.9\ , 3.9\ , 5.9, 7.9\ };\)\)], "Input"],

Cell["\<\
asymValues={nValues[eq6,100,#]
           ,nValues[eq6,200,#]
           ,nValues[eq6,500,#]}& /@  asymGuess;   \
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((Partition[Sort[{symValues, asymValues} // Flatten], 3] // 
        TableForm[#, TableSpacing \[Rule] {0, 2}, 
            TableHeadings \[Rule] {{"\<n=1\>", "\<n=2\>", "\<n=3\>", \
"\<n=4\>", "\<n=5\>", "\<n=6\>", "\<n=7\>", "\<n=8\>", "\<n=9\>"}, {"\<V0=100\
\>", "\<V0=200\>", "\<V0=500\>"}}] &)\)\)], "Input"],

Cell[BoxData[
    \(Partition[Sort[{symValues, asymValues} // Flatten], 3] // \ 
      TableForm[#, \[IndentingNewLine]TableSpacing \[Rule] {0, 2}, 
          TableHeadings \[Rule] {{"\<n=1\>", "\<n=2\>", "\<n=3\>", "\<n=4\>", \
"\<n=5\>", "\<n=6\>", "\<n=7\>", "\<n=8\>", "\<n=9\>"}, {"\<V0=100\>", \
"\<V0=200\>", "\<V0=500\>"}}\[IndentingNewLine]] &\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part e", "Subsubsection"],

Cell[BoxData[
    \(\(\(symRules = {kRules, nRule, symSol, a \[Rule] 1, \[HBar] \[Rule] 1, 
          m \[Rule] 1, V0 \[Rule] 100, cSym \[Rule] 100, cAsym \[Rule] 0} // 
        Flatten\)\(\n\)
    \)\)], "Input"],

Cell["\<\
Clear[s\[Psi],a\[Psi]];
(* Symmetric*) 
s\[Psi][x_ /;x<-1,n0_]:= (\[Psi]L[x]//.symRules//.{n->n0});
s\[Psi][x_ /;-1<=x<1,n0_]:= (\[Psi]W[x]//.symRules//.{n->n0});
s\[Psi][x_ /;x>=1,n0_]:= (\[Psi]R[x]//.symRules//.{n->n0});\
\>", "Input",
  AspectRatioFixed->True],

Cell["symEnergy= nValues[eq5, 100,#]&/@symGuess;  ", "Input",
  AspectRatioFixed->True],

Cell["\<\
plotsym= 
Plot[ s\[Psi][x,#] //.symRules //Evaluate
        ,{x,-2,2}
        ,PlotLabel->  NumberForm[#,2]
        ,Axes->None
        ,DisplayFunction->Identity ]&  /@  symEnergy;\
\>", "Input",
  AspectRatioFixed->True],

Cell["Show[GraphicsArray[{plotsym[[{1,2,3}]],plotsym[[{4,5}]]}]];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(asymRules = {kRules, nRule, asymSol, a \[Rule] 1, \[HBar] \[Rule] 1, 
          m \[Rule] 1, V0 \[Rule] 100, cAsym \[Rule] 100, cSym \[Rule] 0} // 
        Flatten\)], "Input"],

Cell["\<\
 (* Asymmetric*) 
a\[Psi][x_ /;x<-1,n0_]:= (\[Psi]L[x]//.asymRules//.{n->n0});
a\[Psi][x_ /; -1<=x<1,n0_]:= (\[Psi]W[x]//.asymRules//.{n->n0});
a\[Psi][x_ /;x>=1,n0_]:= (\[Psi]R[x]//.asymRules//.{n->n0});\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(asymEnergy = \(nValues[eq6, 100, #] &\) /@ asymGuess\ ;\)\)], "Input"],

Cell["\<\
 plotasym= 
  Plot[ a\[Psi][x,#] //.asymRules //Evaluate
          ,{x,-2,2}
          ,PlotLabel->NumberForm[#,2]
          ,Axes->None
          ,DisplayFunction->Identity]& /@ asymEnergy;              
              \
\>", "Input",
  AspectRatioFixed->True],

Cell["Show[GraphicsArray[{plotasym[[{1,2}]],plotasym[[{3,4}]]}]];", "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: Particle Hitting a Finite Step Potential", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[" Needs[\"Graphics`Legend`\"]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(\(\[Psi]L[
          x_] = \[ExponentialE]\^\(\[ImaginaryI]\ kL\ x\) + \[ExponentialE]\^\
\(\(-\[ImaginaryI]\)\ kL\ x\)\ R;\)\)], "Input"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        RowBox[{"kLRule", "=", 
          FormBox[\(kL \[Rule] \@2\ \@\(En\ m\)\/\[HBar]\),
            "TraditionalForm"]}], ";"}]}]], "Input"],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \)\(\[Psi]R[
          x_] = \[ExponentialE]\^\(\[ImaginaryI]\ kR\ x\)\ T;\)\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"kRRule", "=", 
        RowBox[{"kR", "\[Rule]", 
          FractionBox[
            FormBox[\(\@2\ \@\(m\ \((En - V0)\)\)\),
              "TraditionalForm"], 
            StyleBox["\[HBar]",
              FontFamily->"Courier"]]}]}], ";"}]], "Input"],

Cell[BoxData[
    \(boundary = {\[Psi]L[x] \[Equal] \[Psi]R[x], \(\[Psi]L'\)[
              x] \[Equal] \(\[Psi]R'\)[x]} //. x \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(RTrule = \(Solve[boundary, {R, T}] // Flatten\) // Simplify\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(\(\ \ \)\(\(exp_\^*\) := \(\(exp\)\(\ \)\(/.\)\({Complex[a_, 
              b_] \[RuleDelayed] Complex[a, \(-b\)]}\)\(\ \)\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\((a - \[ImaginaryI]\ b + \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\[Theta]\))\)\^*\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(Conjugate[
      a - \[ImaginaryI]\ b + \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\[Theta]\)]\)], "Input"],

Cell[BoxData[
    \(\[Del]f_ := \(\(\(D[f, #\ ] &\)\ \  /@ \ \ {x, y, 
          z}\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\[Del]\[Psi][x\ \ ]\)], "Input"],

Cell[BoxData[
    \(flux[\[Psi]_] := \(\[HBar]\/\(2  \[ImaginaryI]\ m\)\) \((\(\[Psi]\^*\)\ \
\[Del]\[Psi]\  - \ \[Del]\(\[Psi]\^*\)\ \[Psi])\)\  // Simplify\)], "Input"],

Cell[BoxData[
    \(\(\(\[Psi]L[x] // flux\)\(//\)\(Simplify\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(incFlux = \(\(flux[\[Psi]L[x]]\)\(\ \)\(/.\)\({R \[Rule] 
            0}\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(Rflux = \((incFlux - flux[\[Psi]L[x]])\) // Simplify\)], "Input"],

Cell[BoxData[
    \(Tflux = flux[\[Psi]R[x]]\)], "Input"],

Cell["\<\
{RR,TT}= { Rflux[[1]] /incFlux[[1]],
           Tflux[[1]] /incFlux[[1]] }\
\>", "Input",
  AspectRatioFixed->True],

Cell["{RR,TT}={RR,TT}/. RTrule", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(RR + TT\  // Simplify\)], "Input"],

Cell[BoxData[
    \(\(values = {m \[Rule] 1, \[HBar] \[Rule] 1, V0 \[Rule] 1};\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\(\(\({RR, TT, TT + RR} /. RTrule\) /. kLRule\) /. kRRule\) /. 
            values // Evaluate, \[IndentingNewLine]{En, 1, 
          2}, \[IndentingNewLine]AxesLabel \[Rule] {"\<E\>", \
"\<Coefficient\>"}, \[IndentingNewLine]PlotStyle \[Rule] {Dashing[{0.06, 
                0.02}], 
            Dashing[{0.02}], {}}, \[IndentingNewLine]PlotLegend \[Rule] \
{"\<RR\>", "\<TT\>", "\<TT+RR\>"}, \[IndentingNewLine]LegendPosition \[Rule] \
{1, \(-1\)/2}, \[IndentingNewLine]PlotRange \[Rule] {0, 1}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(kRule = {kLRule, kRRule};\)\)], "Input"],

Cell[BoxData[
    \(\(\(wave[x_, 
          En_] = \(\({\[Psi]L[x], \[Psi]R[x]} /. RTrule\) /. kRule\) /. 
            values\  // Simplify\ ;\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(\[Psi][x_, En_] := 
      Which[\ x \[LessEqual] 0, \(wave[x, En]\)[\([1]\)], 
        x > 0, \(wave[x, En]\)[\([2]\)]]\)], "Input"],

Cell[BoxData[
    \(\(waveplot2D[Energy_] := 
        Plot[{\[Psi][x, Energy] // Re, \[Psi][x, Energy] // 
              Im}, \[IndentingNewLine]{x, \(-10\), 
            10}, \[IndentingNewLine]PlotStyle \[Rule] {{}, Dashing[{0.02}]}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\)], "Input"],

Cell[BoxData[
    \(\(waveplot2D[1.1];\)\)], "Input"],

Cell[BoxData[
    \(\(waveplot2D[0.9];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection"],

Cell[BoxData[
    \(\(Plot3D[\[Psi][x, Energy] // Re, {x, \(-10\), 10}, {Energy,  .5, 1.5}, 
        PlotPoints \[Rule] 50, 
        AxesLabel \[Rule] {"\<x\>", "\<Energy\>", "\<\[Psi]\>"}];\)\)], \
"Input"],

Cell[BoxData[
    \(\(Plot3D[\[Psi][x, Energy] // Im, {x, \(-10\), 10}, {Energy,  .5, 1.5}, 
        PlotPoints \[Rule] 50, 
        AxesLabel \[Rule] {"\<x\>", "\<Energy\>", "\<\[Psi]\>"}];\)\)], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part e", "Subsubsection"],

Cell[BoxData[
    \(\(timePlot[time_, En_] := 
        Plot[{Exp[\(-I\)\ En\ time] \[Psi][x, En] // Re, 
            Exp[\(-I\)\ En\ time] \[Psi][x, En] // 
              Im}, \[IndentingNewLine]{x, \(-10\), 
            10}, \[IndentingNewLine]PlotStyle \[Rule] {{}, {Thickness[
                  0.008]}}, \[IndentingNewLine]PlotRange \[Rule] {\(-2\), 
              2}];\)\)], "Input"],

Cell[BoxData[
    \(\(\(timePlot[1. , 0.9];\)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[BoxData[{
    \(\(frames = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Energy = 0.9;\)\), "\n", 
    \(\(timestep = \(2  \[Pi]\)\/\(\((frames)\) Energy\);\)\), "\n", 
    \(Do[\[IndentingNewLine]\(timePlot[n\ timestep\ , 
          Energy];\)\[IndentingNewLine], {n, 1, 
        frames}\n]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(frames = 1;\)\), "\n", 
    \(\(Energy = 1.1;\)\), "\n", 
    \(\(timestep = \(2  \[Pi]\)\/\(\((frames)\) Energy\);\)\), "\n", 
    \(Do[\[IndentingNewLine]\(timePlot[n\ timestep\ , 
          Energy];\)\[IndentingNewLine], {n, 1, 
        frames}\n]\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 4: Particle Propagating Towards a Rectangular \
Potential\
\>", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(\(\[Psi]L[
          x_] = \[ExponentialE]\^\(\[ImaginaryI]\ kLR\ x\) + \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ kLR\ x\)\ R;\)\)], "Input"],

Cell[BoxData[
    \(\(\[Psi]R[
          x_] = \[ExponentialE]\^\(\[ImaginaryI]\ kLR\ x\)\ T;\)\)], "Input"],

Cell[BoxData[
    \(\(\[Psi]W[x_] = 
        B\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ kW\ x\) + 
          A\ \[ExponentialE]\^\(\[ImaginaryI]\ kW\ x\);\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"kRules", "=", 
        FormBox[
          RowBox[{"{", 
            
            RowBox[{\(kW \[Rule] \@2\ \@\(m\ \((En - V0)\)\)\/\[HBar]\), ",", 
              
              RowBox[{"kLR", "\[Rule]", 
                RowBox[{\(\@2\), " ", 
                  FractionBox[\(\@\(En\ m\)\), 
                    StyleBox["\[HBar]",
                      FontFamily->"Courier"]]}]}]}], "}"}],
          "TraditionalForm"]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(eq1 = {\((\[Psi]L[x] - \[Psi]W[x] \[Equal] 
                  0)\) /. {x \[Rule] \(-a\)}, \[IndentingNewLine]\ \ \ \ \ \
\((\[Psi]W[x] - \[Psi]R[x] \[Equal] 
                  0)\) /. {x \[Rule] \(+a\)}, \[IndentingNewLine]\ \ \ \ \ \
\((\(\[Psi]L'\)[x] - \(\[Psi]W'\)[x] \[Equal] 
                  0)\) /. {x \[Rule] \(-a\)}, \[IndentingNewLine]\ \ \ \ \ \
\((\(\[Psi]W'\)[x] - \(\[Psi]R'\)[x] \[Equal] 0)\) /. {x \[Rule] \(+a\)}} // 
          Simplify\ ;\)\)], "Input"],

Cell[BoxData[{
    \(\(ABRTrule = \(Solve[eq1, {A, B, R, T}] // FullSimplify\) // 
          Flatten;\)\), "\[IndentingNewLine]", 
    \(ABRTrule // ColumnForm\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(\(\ \ \)\(\(exp_\^*\) := \(\(exp\)\(\ \)\(/.\)\({Complex[a_, 
              b_] \[RuleDelayed] Complex[a, \(-b\)]}\)\(\ \)\)\)\)\)], "Input"],

Cell[BoxData[
    \(\[Del]f_ := \(\(\(D[f, #\ ] &\)\  /@ \ {x, y, z}\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(flux[\[Psi]_] := \(\[HBar]\/\(2  \[ImaginaryI]\ m\)\) \((\(\[Psi]\^*\)\ \
\[Del]\[Psi]\  - \ \[Del]\(\[Psi]\^*\)\ \[Psi])\)\  // Simplify\)], "Input"],

Cell[BoxData[
    \(\(\(incFlux\)\(=\)\(flux[\(\[Psi]L[x] /. R \[Rule] 0\) /. 
          ABRTrule\ ]\)\(\ \ \)\)\)], "Input"],

Cell["\<\
Rflux=  (incFlux-flux[\[Psi]L[x]/.ABRTrule]) //ExpToTrig //Simplify \
 \
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Tflux = \(\(flux[\[Psi]R[x] /. ABRTrule] // 
          ExpToTrig\)\(\ \)\(//\)\(Simplify\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[{
    \(\({RR, TT} = {Rflux[\([1]\)]/incFlux[\([1]\)], 
          Tflux[\([1]\)]/incFlux[\([1]\)]};\)\), "\[IndentingNewLine]", 
    \({RR, TT} // ColumnForm\)}], "Input"],

Cell[BoxData[
    \(TT + RR == 1\ \  // Simplify\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection"],

Cell[BoxData[
    \(\(values = {\[HBar] \[Rule] 1, m \[Rule] 1, 
          a \[Rule] 1\ };\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\(\({RR, TT} /. kRules\) /. {V0 \[Rule] \(-100\)}\) /. values // 
          Evaluate, \ {En, 1, 
          200}, \ \[IndentingNewLine]AxesLabel \[Rule] {"\<En\>", "\<RR, \
TT\>"}, PlotStyle \[Rule] {{}, Dashing[{0.02, 0.02}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\(\({RR, TT} /. kRules\) /. {V0 \[Rule] \(+1\)}\) /. values // 
          Evaluate, \ {En, 0, 
          5}, \ \[IndentingNewLine]AxesLabel \[Rule] {"\<En\>", "\<RR, \
TT\>"}, PlotStyle \[Rule] {{}, 
            Dashing[{0.02, 0.02}]}, \[IndentingNewLine]PlotPoints \[Rule] 
          50\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part e", "Subsubsection"],

Cell[BoxData[
    \(\(Plot3D[\(\(TT /. kRules\)\  /. values\) /. a \[Rule] 1 // 
          Evaluate, {En, 0, 10}, {V0, \(-20\), 
          0}, \ \[IndentingNewLine]PlotPoints \[Rule] 
          40, \[IndentingNewLine]\ 
        Ticks \[Rule] {Range[0, 10, 5], 
            Range[\(-20\), 0, 10], {0, 1/2, 
              1}\ \ }, \[IndentingNewLine]AxesLabel \[Rule] {"\<Energy\>", \
"\<Potential\>", "\<TT\>"}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[\(\(\(RR /. kRules\) /. ABRTrule\) /. values\) /. a \[Rule] 1 // 
          Evaluate, {En, 0, 10}, {V0, \(-20\), 
          0}, \[IndentingNewLine]PlotPoints \[Rule] 40, \[IndentingNewLine]\ 
        Ticks \[Rule] {Range[0, 10, 5], 
            Range[\(-20\), 0, 10], {0, 1/2, 
              1}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<Energy\>", \
"\<Potential\>", "\<RR\>"}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part f", "Subsubsection"],

Cell[BoxData[
    \(\({\[Psi]L[x_, aa_], \[Psi]W[x_, aa_], \[Psi]R[x_, 
            aa_]} = \ \(\({\[Psi]L[x], \[Psi]W[x], \[Psi]R[x]}\  /. 
                ABRTrule\) /. kRules\) //. {\[HBar] \[Rule] 1, \ m \[Rule] 1, 
              a \[Rule] aa}\  // Simplify;\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[Psi][x_, a_]\)\(:=\)\(Which[
        x\  \[LessEqual] \ \(-a\), \ \[Psi]L[x, a], \(-a\) < x \[LessEqual] \ 
          a, \ \[Psi]W[x, a], a < x, \ \[Psi]R[x, a]]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(Plot[\ \ \[Psi][x, 2]\  /. {\ En \[Rule] 1, \ 
              V0 \[Rule] \(-12\)} // Re, {x, \(-15\), 15}, 
        Epilog \[Rule] {Thickness[0.02], 
            Line[{{\(-2\), 0}, {2, 0}}]}];\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(Plot[\ \[Psi][x, 2] \(\[Psi][x, 2]\^*\)\  //. {\ 
            En \[Rule] 1, \ V0 \[Rule] \(-12\)}\ , {x, \(-15\), 15}, 
        Epilog \[Rule] {Thickness[0.02], 
            Line[{{\(-2\), 0}, {2, 0}}]}]\ ;\)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part g", "Subsubsection"],

Cell[BoxData[
    \(\(timePlot[t_, En_, 
          V0_] := \[IndentingNewLine]Plot[\ {\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ En\ t/\[HBar]\)\ \[Psi][x, 2\ ]\  // 
                  Re, \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ En\ t/\[HBar]\)\ \
\[Psi][x, 2] // Im} //. {\ \[HBar] \[Rule] 1}\  // 
            Evaluate, \[IndentingNewLine]{x, \(-15\), 15}, 
          PlotStyle \[Rule] {{}, {Dashing[{0.02}], 
                Thickness[
                  0.008]}}, \[IndentingNewLine]PlotRange \[Rule] {\(-2\), 
              2}, \[IndentingNewLine]Epilog \[Rule] {Thickness[0.02], 
              Line[{{\(-2\), 0}, {2, 0}}]}];\)\)], "Input"],

Cell["\<\
 frames=1;
 V0=1.1;
 En=1;
 timestep=2 \[Pi]/(frames En);
 Do[timePlot[n timestep ,En,V0],{n,1,frames}]\
\>", "Input",
  AspectRatioFixed->True,
  AnimationDisplayTime->0.13]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 5: The One-Dimensional Harmonic Oscillator  ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{"eq1", "=", 
      RowBox[{
        FormBox[
          RowBox[{"0", "==", 
            RowBox[{\(\((V - En)\)\ \(\[Psi](x)\)\), "-", 
              FractionBox[
                RowBox[{\(\[HBar]\^2\), " ", 
                  RowBox[{
                    SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
                      MultilineFunction->None], "(", "x", 
                    ")"}]}], \(2\ m\)]}]}],
          "TraditionalForm"], " ", "/.", 
        RowBox[{"V", "\[Rule]", 
          FormBox[\(\(k\ x\^2\)\/2\),
            "TraditionalForm"]}]}]}]], "Input"],

Cell[BoxData[
    \(eq2 = \(\(DSolve[eq1, \[Psi][x], x]\)[\([1]\)]\  // PowerExpand\)\  // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(\(notation = {k \[Rule] \(\[Omega]\^2\) m, \ 
          En\ \  \[Rule] \ \((1\/2 + 
                  n)\)\ \[HBar]\ \[Omega], \ \[Omega] \[Rule] \[HBar]\/\(m\ \
\[Alpha]\^2\)};\)\)], "Input"],

Cell[BoxData[
    \(dsol\  = \(eq2[\([1]\)]\  //. notation // PowerExpand\) // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(\[Psi]0[x_, n_] = \(\(\[Psi][x] /. dsol\)\  /. C[2] \[Rule] 0\) /. 
        C[1] \[Rule] 1\)], "Input"],

Cell[BoxData[
    RowBox[{"energylevels", "=", 
      RowBox[{\(En /. notation\), "/.", 
        RowBox[{"{", 
          RowBox[{"\[Omega]", "\[Rule]", 
            FormBox[\(\@\(k\/m\)\),
              "TraditionalForm"]}], "}"}]}]}]], "Input"],

Cell[BoxData[
    \(energylevels /. n \[Rule] Range[0, 3, 1]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(norm[n_]\ \  := 
      Integrate[\[Psi]0[x\ , n] \[Psi]0[x\ , 
              n]\ , {x, \(-\[Infinity]\), \[Infinity]}, 
          Assumptions \[Rule] {\ \[Alpha] > 0\ , Element[n, Integers]}\ ] // 
        Sqrt\)], "Input"],

Cell[BoxData[
    \(Table[
      norm[n] == \ \ \ \ Sqrt[\ \ 2^
              n\ \ \ \(n!\)\ \ \[Alpha]\ Sqrt[\[Pi]]\ \ ]\ , {n, 0, 
        5}]\)], "Input"],

Cell[BoxData[
    RowBox[{\(\[Psi][x_, n_]\), "=", "  ", 
      FractionBox[\(\[Psi]0[x, n]\), 
        FormBox[\(\@\[Pi]\%4\ \@\(2\^n\ \[Alpha]\ \(n!\)\)\),
          "TraditionalForm"]]}]], "Input"],

Cell[BoxData[
    \(Table[
        Integrate[\[Psi][x, n]\^2\ , {x, \(-\[Infinity]\), \[Infinity]}, \ 
          Assumptions \[Rule] {\ \[Alpha] > 0}], {n, 0, 3}]\  // 
      PowerExpand\)], "Input"],

Cell[BoxData[
    \(TableForm[
      table, \[IndentingNewLine]TableHeadings \[Rule] {{\ "\<\[Psi][x,0]\>", \
"\<\[Psi][x,1]\>", "\<\[Psi][x,2]\>", "\<\[Psi][x,3]\>"\ \ \ }}]\)], "Input"],

Cell[BoxData[
    \(\(Plot[\ \ Table[\[Psi][x, n]/2\  + \ \ n, {n, 0, 
                7}]\ \  /. {\[Alpha] \[Rule] 1}\  // 
          Evaluate\ , \[IndentingNewLine]{x, \(-6\), 
          6}\ , \[IndentingNewLine]Epilog \[Rule] \(Plot[
              0.6\ \ z^2, {z, \(-6\), 
                6}, \[IndentingNewLine]PlotStyle \[Rule] 
                Thickness[ .01], \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\[IndentingNewLine]]\)[\([1]\)]\ \ \
\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\ \ Table[\[Psi][x, n]\^2 + \ n, {n, 0, 
                7}]\ \  /. {\[Alpha] \[Rule] 1}\  // Evaluate\ , {x, \(-5\), 
          5}, \[IndentingNewLine]Epilog \[Rule] \(Plot[
              0.6\ \ z^2, {z, \(-6\), 
                6}, \[IndentingNewLine]PlotStyle \[Rule] 
                Thickness[ .01], \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity\[IndentingNewLine]]\)[\([1]\)]\ \
\[IndentingNewLine]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell["9.2 Three-Dimensional Schroedinger's Equation  ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Problem 1:  Three-Dimensional Harmonic Oscillator in Cartesian \
Coordinates \
\>", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Needs[\"Calculus`VectorAnalysis`\"]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    \(\(SetCoordinates[Cartesian[x, y, z]];\)\)], "Input"],

Cell["\[Psi][x_,y_,z_] = X[x] Y[y] Z[z]; ", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1 = \ \(-\[HBar]\^2\)\/\(2  m\)\ Laplacian[\[Psi][x, y, 
              z]] + \ \((Vx[x] + Vy[y] + Vz[z]\  - \ En)\) \[Psi][x, y, 
            z]\)], "Input"],

Cell[BoxData[
    \(eq2 = eq1/\[Psi][x, y, z] // ExpandAll\)], "Input"],

Cell[BoxData[
    \(\(Enrule = {En -> Ex + Ey + Ez}\ ;\)\)], "Input"],

Cell["\<\
select[eq_,Ei_,var_]:= Select[eq,(!FreeQ[#,var]|| !FreeQ[#,Ei \
])&]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(fieldEq = \[IndentingNewLine]0 \[Equal] {\ 
            select[eq2 /. Enrule, Ex, x], \ \ select[eq2 /. Enrule, Ey, y], 
            select[eq2 /. Enrule, Ez, z]} // Thread; 
    fieldEq\  // ColumnForm\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"potential", "=", 
        FormBox[\({Vx(x) \[Rule] \(kx\ x\^2\)\/2, 
            Vy(y) \[Rule] \(ky\ y\^2\)\/2, Vz(z) \[Rule] \(kz\ z\^2\)\/2}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[{
    \(\({xEq, yEq, zEq} = fieldEq /. potential;\)\), "\[IndentingNewLine]", 
    \({xEq, yEq, zEq} // ColumnForm\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"notation", "=", 
        FormBox[\({kx \[Rule] m\ \[Omega]x\^2, 
            Ex \[Rule] \((nx + 
                    1\/2)\)\ \[Omega]x\ \[HBar], \[Omega]x \[Rule] \
\[HBar]\/\(m\ \[Alpha]x\^2\)}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(xSol = \ \(DSolve[xEq //. notation, X[x], x]\)[\([1]\)] // 
        Simplify\)], "Input"],

Cell[BoxData[
    RowBox[{\(X[x_, nx_]\), " ", "=", 
      RowBox[{\(X[x]\ \  /. xSol\), "//.", 
        FormBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                SubscriptBox[
                  TagBox["c",
                    C], "2"], "\[Rule]", "0"}], ",", 
              RowBox[{
                SubscriptBox[
                  TagBox["c",
                    C], "1"], 
                "\[Rule]", \(1\/\(\@\[Pi]\%4\ \@\(2\^nx\ \[Alpha]x\ \(nx!\)\)\
\)\)}]}], "}"}],
          "TraditionalForm"]}]}]], "Input"],

Cell[BoxData[
    \(\(\(Table[\ 
        Integrate[X[x, nx]\^2\ \ , {x, \(-\[Infinity]\), \[Infinity]}, 
          GenerateConditions \[Rule] False]\ , {nx, 0, 
          5}]\)\(//\)\(PowerExpand\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(Y[y_, ny_] = X[y, ny]\  /. {\[Alpha]x \[Rule] \[Alpha]y}\)], "Input"],

Cell[BoxData[
    \(Z[z_, nz_] = X[z, nz] /. {\[Alpha]x \[Rule] \[Alpha]z}\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(\[Alpha]Rule = \ {\[Alpha]x \[Rule] 1, \ \[Alpha]y \[Rule] 
            1};\)\)], "Input"],

Cell[BoxData[
    \(\(wavePlot = 
        Plot3D[X[x, 3]\ Y[y, 
                2] /. \[Alpha]Rule, \[IndentingNewLine]{x, \(-4\), 
            4}, {y, \(-4\), 4}, \[IndentingNewLine]PlotPoints \[Rule] 
            35, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"vPlot", "=", 
        RowBox[{"Plot3D", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"0.15", " ", 
                RowBox[{"(", 
                  FormBox[\(x\^2 + y\^2\),
                    "TraditionalForm"], ")"}]}], "-", "2"}], ",", 
            "\[IndentingNewLine]", \({x, \(-4\), 4}\), 
            ",", \({y, \(-4\), 4}\), ",", 
            "\[IndentingNewLine]", \(PlotPoints \[Rule] 35\), ",", 
            "\[IndentingNewLine]", \(DisplayFunction \[Rule] Identity\)}], 
          "]"}]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(Show[{vPlot, wavePlot}, 
        DisplayFunction \[Rule] $DisplayFunction\ ];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Problem 2:  Schroedinger's Equation for Spherically Symmetric \
Potentials \
\>", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Needs[\"Calculus`VectorAnalysis`\"] ", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part a ",
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(SetCoordinates[Spherical[r, \[Theta], \[Phi]]];\)\)], "Input"],

Cell["\[Psi][r,\[Theta],\[Phi]] =R[r] \[CapitalTheta][\[Theta]] \
\[CapitalPhi][\[Phi]];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"eq1", "=", " ", 
      RowBox[{
        RowBox[{
          FormBox[\(-\(\[HBar]\^2\/\(2\ m\)\)\),
            "TraditionalForm"], 
          "  ", \(Laplacian[\[Psi][r, \[Theta], \[Phi]]]\)}], "+", 
        " ", \(\((V\  - \ En)\) \[Psi][r, \[Theta], \[Phi]]\)}]}]], "Input"],

Cell[BoxData[
    RowBox[{"eq2", "=", 
      RowBox[{
        RowBox[{"eq1", " ", 
          
          FormBox[\(\(r\^2\ \(\(sin\^2\)(\[Theta])\)\)\/\[Psi][
                  r, \[Theta], \[Phi]]\),
            "TraditionalForm"]}], "//", "ExpandAll"}]}]], "Input"],

Cell["select[eq_,var_]:= Select[eq,(!FreeQ[#,var])&]", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"eq3", "=", 
      RowBox[{\(select[eq2, \[Phi]]\), "\[Equal]", 
        FormBox[\(\(\(\ \)\(\(\[HBar]\^2\) m\[Phi]\^2\)\)\/\(2\ m\)\),
          "TraditionalForm"]}]}]], "Input"],

Cell["\<\
\[Phi]Eq=Solve[eq3,\[CapitalPhi]''[\[Phi]] ][[1,1]] /.Rule->Equal\
\
\>", "Input",
  AspectRatioFixed->True],

Cell["eq4=DSolve[\[Phi]Eq,\[CapitalPhi][\[Phi]],\[Phi]][[1]] ", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\ \)\(\(\(eq4 /. {C[1] \[Rule] 1, \ C[2] \[Rule] {I, \(-I\)}} // 
          MapAll[TrigToExp, #] &\)\  // Map[Thread, #, 2] &\)\  // 
      Flatten\)\)\)], "Input"],

Cell[BoxData[
    RowBox[{"       ", 
      RowBox[{
        RowBox[{"\[Phi]Rule", "=", 
          RowBox[{\(\[CapitalPhi][\[Phi]]\), "\[Rule]", 
            FormBox[\(\[ExponentialE]\^\(\[ImaginaryI]\ m\[Phi]\ \[Phi]\)\),
              "TraditionalForm"]}]}], ";"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part b",
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]]
}], "Subsubsection"],

Cell[BoxData[
    \(eq5 = \ \(\(\((eq2 /. \((\[Phi]Eq /. Equal \[Rule] Rule\ )\))\)/
          Sin[\[Theta]]\^2\)\(//\)\(Expand\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{"eq6", "=", 
      RowBox[{\(select[eq5, r]\), "\[Equal]", 
        FormBox[\(-\(\(\[ScriptL]\ \((\[ScriptL] + 
                      1)\)\ \[HBar]\^2\)\/\(2\ m\)\)\),
          "TraditionalForm"]}]}]], "Input"],

Cell["\<\
rEq= Solve[eq6,R''[r] ][[1,1]] /. Rule->Equal // ExpandAll    \
\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"eq7", "=", " ", 
      RowBox[{\(select[eq5, \[Theta]]\), "\[Equal]", " ", 
        FormBox[\(\(\[ScriptL]\ \((\[ScriptL] + 
                    1)\)\ \[HBar]\^2\)\/\(2\ m\)\),
          "TraditionalForm"]}]}]], "Input"],

Cell[BoxData[
    \(\[Theta]Eq = \ \(\(\(Solve[
              eq7, \(\[CapitalTheta]''\)[\[Theta]]]\)[\([1, 1]\)]\  /. 
          Rule \[Rule] Equal\)\(//\)\(ExpandAll\)\(\ \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part c",
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]]
}], "Subsubsection"],

Cell[BoxData[
    \(vChange[\ Eq_, \[Psi]_, x_, z_, f_] := \ 
      Eq /. {D[\[Psi][x], {x, 
                n_}] \[RuleDelayed] \[IndentingNewLine]Nest[\((\ \((1/
                        D[f, z])\)\ \ D[#, z])\) &, \[Psi][z], n], \[Psi][
              x] \[RuleDelayed] \[Psi][z], x \[RuleDelayed] f}\)], "Input"],

Cell[BoxData[
    \(eq8 = \ \(\(vChange[\[Theta]Eq, \[CapitalTheta], \[Theta], z, 
            ArcCos[z]]\  // 
          ExpandAll\)\(//\)\(\ \)\(Simplify\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[
    \(eq9 = DSolve[eq8\ , \[CapitalTheta][z]\ , z] // Flatten\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(LegendreQ[2\ , 1, z]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\[Theta]Rule = 
      eq9 /. {C[1] \[Rule] 1, \ C[2] \[Rule] 0}\  // Simplify\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part d", "Subsubsection"],

Cell[BoxData[
    \(\(\(\(norm[\[ScriptL], m]\ \ \[CapitalTheta][
                z]\ \[CapitalPhi][\[Phi]]\  /. \[Theta]Rule\) /. \[Phi]Rule\) \
/. \ z \[Rule] 
          Cos[\[Theta]]\) /. \(\(m\[Phi]\)\(\[Rule]\)\(m\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(norm[\[ScriptL]_, m_]\), "=", 
        FormBox[\(1\/\(2\ \@\[Pi]\)\ \@\(\(\((2\ \[ScriptL] + 1)\)\ \(\((\
\[ScriptL] - m)\)!\)\)\/\(\((m + \[ScriptL])\)!\)\)\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(Y[\[ScriptL]_, 
        m_, \[Theta]_, \[Phi]_] = \(\(\(norm[\[ScriptL], m]\ \[CapitalTheta][
                  z]\ \[CapitalPhi][\[Phi]]\  /. \[Theta]Rule\) /. \[Phi]Rule\
\) /. \ z \[Rule] 
            Cos[\[Theta]]\) /. \(\(m\[Phi]\)\(\[Rule]\)\(m\)\(\ \)\)\)], \
"Input"],

Cell[BoxData[
    \(\(\(Table[\ 
          SphericalHarmonicY[\[ScriptL], m, \[Theta], \[Phi]] == 
            Y[\[ScriptL], m, \[Theta], \[Phi]], {\[ScriptL], 0, 
            4}, {m, \(-\[ScriptL]\), \[ScriptL]}] // 
        Simplify\)\(//\)\(PowerExpand\)\(\ \ \)\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 3: Particle in an Infinite, Spherical Well ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
 Needs[\"NumericalMath`BesselZeros`\"]
 Needs[\"Graphics`Legend`\"]\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{"rEq", "=", 
      RowBox[{
        RowBox[{"0", "==", 
          FormBox[
            
            RowBox[{\(\(2\ m\ \(R(r)\)\ \((En - V(r))\)\ r\^2\)\/\[HBar]\^2\),
               "+", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["R", "\[Prime]\[Prime]",
                    MultilineFunction->None], "(", "r", ")"}], 
                " ", \(r\^2\)}], "+", 
              RowBox[{"2", " ", 
                RowBox[{
                  SuperscriptBox["R", "\[Prime]",
                    MultilineFunction->None], "(", "r", ")"}], " ", "r"}], 
              "-", \(\[ScriptL]\ \((\[ScriptL] + 1)\)\ \(R(r)\)\)}],
            "TraditionalForm"]}], " ", "/.", 
        FormBox[\({V(r) \[Rule] 0, 
            En \[Rule] \(k\^2\ \[HBar]\^2\)\/\(2\ m\)}\),
          "TraditionalForm"]}]}]], "Input"],

Cell[BoxData[
    \(dsol = \ \(DSolve[rEq\ , R[r], r] // Flatten\) // Simplify\)], "Input"],

Cell[BoxData[
    \(R[r_, \[ScriptL]_, 
        k_:  1]\  = \ \(R[r]\  /. 
          dsol\)\  /. {C[1] \[Rule] \@\(1 + 2  \[ScriptL]\), \ 
          C[2] \[Rule] 0}\)], "Input"],

Cell[BoxData[
    \(Integrate[\ R[r, \[ScriptL], k]^2\ , {r, 0, \[Infinity]}\ , 
      Assumptions \[Rule] {\ k > 0, \[ScriptL] > \(-1\)/2}]\)], "Input"],

Cell[BoxData[
    \(\(TableForm[\ \(R[r, #, k] &\) /@ 
            Range[0, 
              3], \[IndentingNewLine]TableHeadings \[Rule] {\ {\ \
"\<\[ScriptL]=0\>", "\<\[ScriptL]=1\>", "\<\[ScriptL]=2\>", \
"\<\[ScriptL]=3\>"\ \ }}\ ]\  // Simplify\) // PowerExpand\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(\(?BesselJZeros\)\)], "Input"],

Cell[BoxData[
    \(zeros = \(\(\(BesselJZeros[1/2 + #, 5] &\)\  /@ \ \ Range[0, 
          4]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TableForm[zeros, \ 
      TableSpacing \[Rule] \ 
        1\ , \ \ \ TableHeadings \[Rule] {{"\<S-Wave\>", "\<P-Wave\>", \
"\<D-Wave\>", "\<F-Wave\>", "\<G-Wave\>"}, \[IndentingNewLine]{"\<First\>", "\
\<Second\>", "\<Third\>", "\<Fourth\>", "\<Fifth\>"}}]\)], "Input"],

Cell[BoxData[
    \(\(levels = 
        Table[\[IndentingNewLine]{{i - 0.4, zeros[\([i, j]\)]}, {i + 0.4, 
              zeros[\([i, j]\)]}}, \[IndentingNewLine]{i, 1, 
            Length[zeros]}, {j, 1, Length[zeros[\([1]\)]]}]\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Show[\[IndentingNewLine]{Graphics[{Thickness[0.01], 
              Map[Line, levels, {2}]}], \[IndentingNewLine]Graphics[
            Text["\<S\>", {1, 1}]], Graphics[Text["\<P\>", {2, 1}]], 
          Graphics[Text["\<D\>", {3, 1}]], \[IndentingNewLine]Graphics[
            Text["\<F\>", {4, 1}]], 
          Graphics[
            Text["\<G\>", {5, 
                1}]]\[IndentingNewLine]}, \[IndentingNewLine]Frame \[Rule] 
          True, \[IndentingNewLine]PlotRange \[Rule] {{0, 5.9}, {\(-1\), 
              25}}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(\(\ \)\(Plot[
        R[r, 0, k] /. {k \[Rule] \((zeros[\([0 + 
                        1]\)])\)}\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \  // Evaluate, \[IndentingNewLine]{r, \ 0\ , 
          1}, \ \ PlotStyle \[Rule] {{}, Dashing[{0.01}], Dashing[{0.02}], 
            Dashing[{ .03}], 
            Dashing[{ .05}]}\ , \[IndentingNewLine]PlotLabel \[Rule] 
          StyleForm["\<\[Psi]\>", 
            FontSize \[Rule] 
              14], \[IndentingNewLine]PlotLegend \[Rule] \ \ {k1, k2, k3, k4, 
            k5}\ \ , \[IndentingNewLine]LegendPosition \[Rule] {1, \(-1\)/
              2}, \[IndentingNewLine]Epilog \[Rule] 
          Text[StyleForm["\<S(\[ScriptL]=0)-State\>", 
              FontSize \[Rule] 14], {0.6, 
              2}]\ \[IndentingNewLine]];\)\)\)], "Input"],

Cell[BoxData[
    \(\(rPlots = \[IndentingNewLine]Table[\[IndentingNewLine]Plot[\ 
            R[r, \[ScriptL], zeros[\([\(+1\) + \[ScriptL], n]\)]] // 
              Evaluate, {r, 0.01, 1}, \ Ticks \[Rule] None, \ 
            PlotRange \[Rule] 
              All, \[IndentingNewLine]PlotLabel \[Rule] {n, \[ScriptL]}, \
\[IndentingNewLine]DisplayFunction \[Rule] 
              Identity\[IndentingNewLine]], \ {n, 1, 5}, {\[ScriptL], 0, 
            4}];\)\)], "Input"],

Cell[BoxData[
    \(\(\(rPlots // GraphicsArray\)\  // Show;\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem 4: Particle in a Finite, Spherical Well  ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[" Needs[\"Graphics`Legend`\"]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{"rEq", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"0", "\[Equal]", 
            FormBox[
              RowBox[{\(k\^2\ \(R(r)\)\ r\^2\), "+", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["R", "\[Prime]\[Prime]",
                      MultilineFunction->None], "(", "r", ")"}], 
                  " ", \(r\^2\)}], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["R", "\[Prime]",
                      MultilineFunction->None], "(", "r", ")"}], " ", "r"}], 
                "-", \(\[ScriptL]\ \((\[ScriptL] + 1)\)\ \(R(r)\)\)}],
              "TraditionalForm"]}], " ", "/.", \(En \[Rule] \(-Wn\)\)}], 
        "/.", \(V \[Rule] \(-V0\)\)}]}]], "Input"],

Cell[BoxData[
    \(rRule = \ \(DSolve[rEq\ , R[r], r]\  // Flatten\) // 
        ExpandAll\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"kRule", "=", 
        FormBox[\({kIn \[Rule] \(\@2\ \@m\ \@\(V0 - Wn\)\)\/\[HBar], 
            kOut \[Rule] \(\[ImaginaryI]\ \@2\ \@m\ \@Wn\)\/\[HBar]}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(Series[\ \(R[r] /. rRule\) /. \[ScriptL] \[Rule] #\ , {r, 0, 
              1}] &\)\ \  /@ \ \ Range[0, 3] // ColumnForm\)], "Input"],

Cell[BoxData[
    \(waveIn[kIn_, \[ScriptL]_, 
        r_] = \(\(R[r] /. rRule\) /. {C[1] \[Rule] cIn, C[2] \[Rule] 0, 
              k \[Rule] kIn} // Simplify\) // PowerExpand\)], "Input"],

Cell[BoxData[
    \(\(TableForm[\(waveIn[kIn\ , #, r\ ] &\) /@ 
            Range[0, 
              3], \[IndentingNewLine]TableHeadings \[Rule] {\ {\ \
"\<\[ScriptL]=0\>", "\<\[ScriptL]=1\>", "\<\[ScriptL]=2\>", \
"\<\[ScriptL]=3\>"\ \ }}\ ]\  // Simplify\) // PowerExpand\)], "Input"],

Cell[BoxData[
    \(eq1 = \(R[r] /. rRule\) /. k\  \[Rule] I\ qOut // 
        PowerExpand\)], "Input"],

Cell[BoxData[
    \(\(\(\(\(eq1 /. \[ScriptL] \[Rule] 0 // TrigToExp\) // Simplify\) // 
        PowerExpand\)\(//\)\(Collect[#, {\ 
            Exp[a_]\ \ }] &\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(eq2 = eq1 /. C[2] \[Rule] \(\(1\)\(\ \)\(C[1]\)\(\ \)\)\)], "Input"],

Cell["\<\
waveOut[qOut_,\[ScriptL]_,r_]= eq1 /.rRule /.{C[1]\[Rule] cOut,C[2]\
\[Rule] +I cOut} \
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(TableForm[\(\((\(\(waveOut[qOut\ , #, r\ ] // TrigToExp\)\  // 
                Simplify\) // PowerExpand\ \ )\) &\) /@ 
        Range[0, 
          3], \[IndentingNewLine]TableHeadings \[Rule] {\ {\ \
"\<\[ScriptL]=0\>", "\<\[ScriptL]=1\>", "\<\[ScriptL]=2\>", \
"\<\[ScriptL]=3\>"\ \ }}\ ]\)\(\ \ \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(bc1 = \(\((waveIn[kIn, \[ScriptL], r] \[Equal] 
            waveOut[qOut, \[ScriptL], r])\)\(//.\)\({r \[Rule] 
            a}\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(cOutRule = \ \(Solve[bc1, cOut] /. cIn \[Rule] 1\  // Flatten\) // 
        Simplify\)], "Input"],

Cell["\<\
bc2= (D[waveIn[kIn,\[ScriptL],r],r] == \
D[waveOut[qOut,\[ScriptL],r],r]) //.{r->a}//Simplify;\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(allRules = {kIn \[Rule] \(\@2\ \@\(m\ \((V0 - Wn)\)\)\)\/\[HBar], 
            qOut \[Rule] \@2\ \@\(\(m\ Wn\)\/\[HBar]\^2\), \ \ cOutRule, \ \
\[HBar] \[Rule] 1, a \[Rule] 1, m \[Rule] 1, V0 \[Rule] 110, cIn \[Rule] 1} // 
          Flatten\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(bc2Sol[\[ScriptL]_] = \ \(\(\(bc2 //. cOutRule\) /. cIn \[Rule] 1\) //. 
              allRules\)\  //. allRules\  // Simplify;\)\)], "Input"],

Cell[BoxData[
    \(eq3 = bc2Sol[0] // Simplify\)], "Input"],

Cell[BoxData[
    \(\(Plot[eq3[\([1]\)]\  // Evaluate, {Wn, 0, 110}];\)\)], "Input"],

Cell[BoxData[
    \(sValues = \ \(FindRoot[\ eq3\ , {Wn, #}] &\)\ \  /@ \ \ {10, 40, 70, 
          90}\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(eq4\  = \ bc2Sol[1]\  // Simplify\ \ ;\)\)\)], "Input"],

Cell[BoxData[
    \(\(eq5 = \ bc2Sol[2]\  // Simplify\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[{eq4[\([1]\)], eq5[\([1]\)]} // 
          Evaluate, \[IndentingNewLine]{Wn, 0, 
          110}, \[IndentingNewLine]PlotStyle \[Rule] {{}, 
            Dashing[{0.01}]}\ ];\)\)], "Input"],

Cell[BoxData[
    \(pValues = \ \ \(FindRoot[\ eq4\ , {Wn, #}] &\)\ \  /@ \ \ {20, 60, 80, 
          100}\)], "Input"],

Cell[BoxData[
    \(dValues = \ \ \(FindRoot[\ eq5, {Wn, #}] &\)\ \  /@ \ \ {10, 40, 70, 
          90}\)], "Input"],

Cell[BoxData[
    \(TableForm[{sValues, pValues, dValues}, \ 
      TableSpacing \[Rule] \ 
        1\ , \ \ \ TableHeadings \[Rule] {{"\<S-Wave\>", "\<P-Wave\>", \
"\<D-Wave\>"\ \ }, {"\<First\>", "\<Second\>", "\<Third\>", "\<Fourth\>"\ }}]\
\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\({in[r_, \[ScriptL]_, Wn_], 
          out[r_, \[ScriptL]_, Wn_]} = {waveIn[kIn, \[ScriptL], r], 
            waveOut[qOut, \[ScriptL], r]} //. allRules;\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(wave[r_, \[ScriptL]_, Wn_] = 
        Which[r \[LessEqual] 1\ , in[r, \[ScriptL], Wn], r > 1\ , 
          out[r, \[ScriptL], Wn]];\)\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[\ \(wave[r, 0, Wn]\  /. sValues\  // Re\) // 
          Evaluate\ , \[IndentingNewLine]{r, 0, 1.3}, \ 
        PlotStyle \[Rule] {{}, Dashing[{0.01}], Dashing[{0.02}], 
            Dashing[{ .03}]}, \ \[IndentingNewLine]PlotLegend \[Rule] \ 
          Evaluate[\ \(Wn /. sValues[\([#]\)] &\) /@ 
              Range[4]]\ , \[IndentingNewLine]LegendPosition \[Rule] {1, \(-1\
\)/2}, \[IndentingNewLine]Epilog \[Rule] 
          Line[{{1, \(-3\)}, {1, 3}}]]\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(Plot[\ \(wave[r, 1, Wn]\  /. pValues // Re\) // 
          Evaluate\ \ \ \ , \[IndentingNewLine]{r, 0, 1.3}, \ 
        PlotStyle \[Rule] {{}, Dashing[{0.01}], Dashing[{0.02}], 
            Dashing[{ .03}]}, \[IndentingNewLine]PlotLegend \[Rule] \ 
          Evaluate[\ \(Wn /. pValues[\([#]\)] &\) /@ 
              Range[4]]\ , \[IndentingNewLine]LegendPosition \[Rule] {1, \(-1\
\)/2}, \[IndentingNewLine]Epilog \[Rule] 
          Line[{{1, \(-3\)}, {1, 3}}]\[IndentingNewLine]];\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(Plot[\ \(wave[r, 2, Wn]\  /. dValues // Re\) // 
          Evaluate\ \ \ \ , \[IndentingNewLine]{r, 0, 1.3}, \ 
        PlotStyle \[Rule] {{}, Dashing[{0.01}], Dashing[{0.02}], 
            Dashing[{0.03}]}, \[IndentingNewLine]PlotLegend \[Rule] \ 
          Evaluate[\ \(Wn /. dValues[\([#]\)] &\) /@ 
              Range[3]]\ , \[IndentingNewLine]LegendPosition \[Rule] {1, \(-1\
\)/2}, \[IndentingNewLine]Epilog \[Rule] 
          Line[{{1, \(-3\)}, {1, 3}}]\[IndentingNewLine]];\)\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 5: The Hydrogen Atom in Spherical Coordinates",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[" Needs[\"Graphics`ParametricPlot3D`\"]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[BoxData[
    RowBox[{"eq1", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"0", "\[Equal]", 
            FormBox[
              
              RowBox[{\(\(2\ m\ \(R(
                        r)\)\ \((En - V(r))\)\ r\^2\)\/\[HBar]\^2\), "+", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["R", "\[Prime]\[Prime]",
                      MultilineFunction->None], "(", "r", ")"}], 
                  " ", \(r\^2\)}], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["R", "\[Prime]",
                      MultilineFunction->None], "(", "r", ")"}], " ", "r"}], 
                "-", \(\[ScriptL]\ \((\[ScriptL] + 1)\)\ \(R(r)\)\)}],
              "TraditionalForm"]}], "/.", 
          RowBox[{\(V[r]\), "\[Rule]", 
            FormBox[\(-\(e\^2\/\(4\ \[Pi]\ r\ \[Epsilon]0\)\)\),
              "TraditionalForm"]}]}], 
        "/.", \(En \[Rule] \(-Wn\)\)}]}]], "Input"],

Cell["eq2=DSolve[eq1,{R[r]},r][[1]] ", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"substitutions", "=", 
        FormBox[\({m \[Rule] \(4\ \[Pi]\ \[Epsilon]0\ \[HBar]\^2\)\/\(a0\ \
e\^2\), Wn \[Rule] \(e\^4\ m\)\/\(32\ n\^2\ \[Pi]\^2\ \[Epsilon]0\^2\ \[HBar]\
\^2\)}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(eq3 = \(eq2 //. substitutions\ \  // PowerExpand\) // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(eq4 = eq3 /. {C[1] \[Rule] 0\ }\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"rNorm", "=", 
        FormBox[\(2\^\(\[ScriptL] + 1\)\ \((1\/\(a0\ n\))\)\^\[ScriptL]\ \@\(\
\(\((n - \[ScriptL] - 1)\)!\)\/\(a0\^3\ n\^4\ \(\((n + \[ScriptL])\)!\)\)\)\),
          
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[BoxData[
    \(rwave[n_, \[ScriptL]_, 
        r_]\  = \(\(R[r] /. eq4[\([1]\)]\) /. C[2] \[Rule] rNorm // 
          PowerExpand\) // Simplify\)], "Input"],

Cell[BoxData[
    \(Integrate[\ \(r\^2\) {\ \ rwave[1, 0, r\ ], rwave[2, 0, r\ ], rwave[2, \
1, r\ ]}\^2, {r, 0, \[Infinity]}, 
      Assumptions \[Rule] {Re[a0] > 0}]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[BoxData[
    \(eq5 = \(\(Table[
          rwave[n, \[ScriptL], r], \ {n, 1, 3}, {\[ScriptL], 0, 
            n - 1}\ ]\)\(//\)\(\ \)\(TableForm[#, \ 
            TableHeadings \[Rule] {{"\<n=1\>", "\<n=2\>", "\<n=3\>"}, {"\<\
\[ScriptL]=0\>", "\<\[ScriptL]=1\>", "\<\[ScriptL]=2\>"}}] &\)\(\ \)\)\)], \
"Input"],

Cell[BoxData[
    \(\(plot[n_, \[ScriptL]_, rmax_] := \[IndentingNewLine]Plot[
          r\^2\ rwave[n, \[ScriptL], r]\^2 /. a0 \[Rule] 1 // 
            Evaluate, \[IndentingNewLine]{r, 0.01, 
            rmax}, \[IndentingNewLine]Ticks \[Rule] {{1, 4, 8, 14, 20}, {0.1, 
                0.3, 0.5}}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell["\<\
Show[GraphicsArray[ \
Table[plot[n,\[ScriptL],n*7],{n,1,3},{\[ScriptL],0,n-1}]]];\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(plot[\[ScriptL]_, 
          m_] := \[IndentingNewLine]SphericalPlot3D[\[IndentingNewLine]\(\
SphericalHarmonicY[\[ScriptL], m, \[Theta], \[Phi]]\  // Abs\) // 
            Evaluate, \[IndentingNewLine]{\[Theta], 0, \[Pi]}, {\[Phi], 0, 
            2\ \[Pi]}, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell["\<\
pt1=Table[plot[\[ScriptL],m] ,{\[ScriptL],0,2} ,{m,-\[ScriptL],\
\[ScriptL]}];
Show[GraphicsArray[pt1]];
 \
\>", "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.3 Exercises", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Exercise 1:  Infinite Potential Well with Rectangular \
Perturbation\
\>", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 2:  Tilted Square Well", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 3: The Wentzel-Kramers-Brillouin Approximation", \
"Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 4: Plot of the Electron Probability Density", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 5: Perturbed Harmonic Oscillator", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Exercise 6: Perturbation Theory", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Exercise 7:  Separation of variables in Cylindrical \
Coordinates\
\>", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{742, 688},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 116, 2, 42, "Subsubsection"],
Cell[1846, 56, 1886, 33, 657, "Input",
  Evaluatable->False]
}, Closed]],
Cell[3747, 92, 86, 2, 81, "Title",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3858, 98, 80, 2, 60, "Section",
  Evaluatable->False],
Cell[3941, 102, 134, 2, 43, "Input"]
}, Closed]],
Cell[4090, 107, 111, 2, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4226, 113, 125, 2, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4376, 119, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[4469, 123, 71, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4577, 129, 83, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[4663, 133, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4763, 139, 31, 0, 42, "Subsubsection"],
Cell[4797, 141, 477, 12, 46, "Input"],
Cell[5277, 155, 57, 1, 27, "Input"],
Cell[5337, 158, 89, 1, 46, "Input"],
Cell[5429, 161, 127, 2, 27, "Input"],
Cell[5559, 165, 87, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5683, 173, 31, 0, 42, "Subsubsection"],
Cell[5717, 175, 107, 2, 27, "Input"],
Cell[5827, 179, 235, 6, 46, "Input"],
Cell[6065, 187, 283, 6, 41, "Input"],
Cell[6351, 195, 203, 3, 31, "Input"],
Cell[6557, 200, 86, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6680, 206, 31, 0, 42, "Subsubsection"],
Cell[6714, 208, 121, 4, 27, "Input"],
Cell[6838, 214, 143, 3, 27, "Input"],
Cell[6984, 219, 525, 10, 75, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7558, 235, 122, 2, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[7705, 241, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[7789, 245, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7889, 251, 31, 0, 42, "Subsubsection"],
Cell[7923, 253, 477, 12, 46, "Input"],
Cell[8403, 267, 175, 4, 46, "Input"],
Cell[8581, 273, 171, 2, 27, "Input"],
Cell[8755, 277, 268, 6, 48, "Input"],
Cell[9026, 285, 88, 1, 27, "Input"],
Cell[9117, 288, 173, 4, 46, "Input"],
Cell[9293, 294, 203, 3, 27, "Input"],
Cell[9499, 299, 262, 6, 48, "Input"],
Cell[9764, 307, 174, 4, 48, "Input"],
Cell[9941, 313, 250, 4, 27, "Input"],
Cell[10194, 319, 145, 3, 28, "Input"],
Cell[10342, 324, 129, 3, 28, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10508, 332, 31, 0, 42, "Subsubsection"],
Cell[10542, 334, 258, 6, 72, "Input"],
Cell[10803, 342, 83, 1, 27, "Input"],
Cell[10889, 345, 303, 5, 27, "Input"],
Cell[11195, 352, 142, 2, 27, "Input"],
Cell[11340, 356, 86, 1, 27, "Input"],
Cell[11429, 359, 339, 6, 43, "Input"],
Cell[11771, 367, 139, 2, 27, "Input"],
Cell[11913, 371, 82, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[12032, 377, 32, 0, 42, "Subsubsection"],
Cell[12067, 379, 154, 2, 27, "Input"],
Cell[12224, 383, 201, 5, 46, "Input"],
Cell[12428, 390, 171, 3, 48, "Input"],
Cell[12602, 395, 83, 1, 27, "Input"],
Cell[12688, 398, 503, 9, 91, "Input"],
Cell[13194, 409, 569, 12, 91, "Input"],
Cell[13766, 423, 145, 2, 27, "Input"],
Cell[13914, 427, 84, 1, 27, "Input"],
Cell[14001, 430, 546, 12, 75, "Input"],
Cell[14550, 444, 536, 9, 107, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15123, 458, 31, 0, 42, "Subsubsection"],
Cell[15157, 460, 262, 5, 27, "Input"],
Cell[15422, 467, 79, 1, 27, "Input"],
Cell[15504, 470, 162, 5, 57, "Input"],
Cell[15669, 477, 76, 1, 27, "Input"],
Cell[15748, 480, 163, 5, 57, "Input"],
Cell[15914, 487, 335, 5, 59, "Input"],
Cell[16252, 494, 365, 5, 75, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16654, 504, 31, 0, 42, "Subsubsection"],
Cell[16688, 506, 213, 4, 43, "Input"],
Cell[16904, 512, 273, 7, 87, "Input"],
Cell[17180, 521, 87, 1, 27, "Input"],
Cell[17270, 524, 232, 8, 102, "Input"],
Cell[17505, 534, 102, 1, 27, "Input"],
Cell[17610, 537, 196, 3, 27, "Input"],
Cell[17809, 542, 255, 6, 72, "Input"],
Cell[18067, 550, 92, 1, 27, "Input"],
Cell[18162, 553, 270, 9, 117, "Input"],
Cell[18435, 564, 102, 1, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[18586, 571, 121, 2, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[18732, 577, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[18825, 581, 71, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18933, 587, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[19017, 591, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19117, 597, 31, 0, 42, "Subsubsection"],
Cell[19151, 599, 158, 3, 30, "Input"],
Cell[19312, 604, 191, 5, 48, "Input"],
Cell[19506, 611, 125, 2, 30, "Input"],
Cell[19634, 615, 293, 8, 48, "Input"],
Cell[19930, 625, 149, 2, 27, "Input"],
Cell[20082, 629, 92, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[20211, 635, 31, 0, 42, "Subsubsection"],
Cell[20245, 637, 163, 2, 27, "Input"],
Cell[20411, 641, 130, 2, 32, "Input"],
Cell[20544, 645, 125, 3, 32, "Input"],
Cell[20672, 650, 108, 2, 27, "Input"],
Cell[20783, 654, 52, 1, 27, "Input"],
Cell[20838, 657, 170, 2, 43, "Input"],
Cell[21011, 661, 85, 1, 27, "Input"],
Cell[21099, 664, 115, 2, 27, "Input"],
Cell[21217, 668, 85, 1, 27, "Input"],
Cell[21305, 671, 57, 1, 27, "Input"],
Cell[21365, 674, 125, 4, 42, "Input"],
Cell[21493, 680, 67, 1, 27, "Input"],
Cell[21563, 683, 54, 1, 27, "Input"],
Cell[21620, 686, 93, 1, 27, "Input"],
Cell[21716, 689, 541, 8, 123, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[22294, 702, 31, 0, 42, "Subsubsection"],
Cell[22328, 704, 62, 1, 27, "Input"],
Cell[22393, 707, 167, 3, 27, "Input"],
Cell[22563, 712, 152, 3, 27, "Input"],
Cell[22718, 717, 300, 5, 59, "Input"],
Cell[23021, 724, 53, 1, 27, "Input"],
Cell[23077, 727, 53, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23167, 733, 31, 0, 42, "Subsubsection"],
Cell[23201, 735, 207, 4, 27, "Input"],
Cell[23411, 741, 207, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23655, 750, 31, 0, 42, "Subsubsection"],
Cell[23689, 752, 388, 7, 75, "Input"],
Cell[24080, 761, 88, 2, 43, "Input"],
Cell[24171, 765, 340, 7, 163, "Input"],
Cell[24514, 774, 321, 7, 163, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24884, 787, 143, 5, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[25052, 796, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[25136, 800, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[25236, 806, 31, 0, 42, "Subsubsection"],
Cell[25270, 808, 160, 3, 30, "Input"],
Cell[25433, 813, 108, 2, 30, "Input"],
Cell[25544, 817, 168, 3, 30, "Input"],
Cell[25715, 822, 481, 13, 48, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[26233, 840, 31, 0, 42, "Subsubsection"],
Cell[26267, 842, 495, 8, 75, "Input"],
Cell[26765, 852, 173, 3, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[26975, 860, 31, 0, 42, "Subsubsection"],
Cell[27009, 862, 163, 2, 27, "Input"],
Cell[27175, 866, 93, 1, 27, "Input"],
Cell[27271, 869, 170, 2, 43, "Input"],
Cell[27444, 873, 125, 2, 27, "Input"],
Cell[27572, 877, 122, 4, 27, "Input"],
Cell[27697, 883, 133, 2, 27, "Input"],
Cell[27833, 887, 184, 3, 43, "Input"],
Cell[28020, 892, 61, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[28118, 898, 31, 0, 42, "Subsubsection"],
Cell[28152, 900, 105, 2, 27, "Input"],
Cell[28260, 904, 269, 4, 43, "Input"],
Cell[28532, 910, 350, 6, 75, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[28919, 921, 31, 0, 42, "Subsubsection"],
Cell[28953, 923, 426, 8, 75, "Input"],
Cell[29382, 933, 423, 7, 75, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[29842, 945, 31, 0, 42, "Subsubsection"],
Cell[29876, 947, 277, 4, 27, "Input"],
Cell[30156, 953, 210, 3, 27, "Input"],
Cell[30369, 958, 238, 4, 27, "Input"],
Cell[30610, 964, 253, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[30900, 973, 31, 0, 42, "Subsubsection"],
Cell[30934, 975, 641, 11, 100, "Input"],
Cell[31578, 988, 184, 8, 87, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[31811, 1002, 122, 2, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[31958, 1008, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[32042, 1012, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[32142, 1018, 31, 0, 42, "Subsubsection"],
Cell[32176, 1020, 588, 15, 46, "Input"],
Cell[32767, 1037, 121, 2, 27, "Input"],
Cell[32891, 1041, 212, 4, 44, "Input"],
Cell[33106, 1047, 109, 2, 27, "Input"],
Cell[33218, 1051, 123, 2, 27, "Input"],
Cell[33344, 1055, 245, 6, 50, "Input"],
Cell[33592, 1063, 73, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[33702, 1069, 31, 0, 42, "Subsubsection"],
Cell[33736, 1071, 243, 5, 27, "Input"],
Cell[33982, 1078, 157, 4, 27, "Input"],
Cell[34142, 1084, 200, 4, 52, "Input"],
Cell[34345, 1090, 199, 4, 31, "Input"],
Cell[34547, 1096, 187, 3, 43, "Input"],
Cell[34737, 1101, 508, 9, 123, "Input"],
Cell[35248, 1112, 471, 8, 115, "Input"]
}, Closed]]
}, Closed]],
Cell[35746, 1124, 114, 2, 40, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[35885, 1130, 155, 5, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[36065, 1139, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[36158, 1143, 78, 1, 27, "Input"]
}, Closed]],
Cell[36251, 1147, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[36335, 1151, 63, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[36423, 1156, 31, 0, 42, "Subsubsection"],
Cell[36457, 1158, 72, 1, 27, "Input"],
Cell[36532, 1161, 78, 1, 27, "Input"],
Cell[36613, 1164, 179, 3, 46, "Input"],
Cell[36795, 1169, 71, 1, 27, "Input"],
Cell[36869, 1172, 69, 1, 27, "Input"],
Cell[36941, 1175, 119, 4, 27, "Input"],
Cell[37063, 1181, 235, 4, 59, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[37335, 1190, 31, 0, 42, "Subsubsection"],
Cell[37369, 1192, 236, 5, 46, "Input"],
Cell[37608, 1199, 141, 2, 43, "Input"],
Cell[37752, 1203, 289, 7, 44, "Input"],
Cell[38044, 1212, 109, 2, 27, "Input"],
Cell[38156, 1216, 549, 16, 52, "Input"],
Cell[38708, 1234, 218, 4, 31, "Input"],
Cell[38929, 1240, 89, 1, 27, "Input"],
Cell[39021, 1243, 87, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[39145, 1249, 31, 0, 42, "Subsubsection"],
Cell[39179, 1251, 112, 2, 27, "Input"],
Cell[39294, 1255, 300, 6, 75, "Input"],
Cell[39597, 1263, 582, 14, 83, "Input"],
Cell[40182, 1279, 114, 2, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[40345, 1287, 153, 5, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[40523, 1296, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[40616, 1300, 79, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[40732, 1306, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[40816, 1310, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[40916, 1316, 99, 4, 42, "Subsubsection"],
Cell[41018, 1322, 84, 1, 27, "Input"],
Cell[41105, 1325, 125, 2, 27, "Input"],
Cell[41233, 1329, 302, 7, 46, "Input"],
Cell[41538, 1338, 266, 7, 48, "Input"],
Cell[41807, 1347, 89, 1, 27, "Input"],
Cell[41899, 1350, 205, 4, 46, "Input"],
Cell[42107, 1356, 118, 4, 27, "Input"],
Cell[42228, 1362, 98, 1, 27, "Input"],
Cell[42329, 1365, 188, 3, 27, "Input"],
Cell[42520, 1370, 279, 6, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[42836, 1381, 98, 4, 42, "Subsubsection"],
Cell[42937, 1387, 150, 2, 29, "Input"],
Cell[43090, 1391, 237, 5, 46, "Input"],
Cell[43330, 1398, 115, 4, 27, "Input"],
Cell[43448, 1404, 247, 5, 46, "Input"],
Cell[43698, 1411, 190, 3, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[43925, 1419, 98, 4, 42, "Subsubsection"],
Cell[44026, 1425, 314, 5, 43, "Input"],
Cell[44343, 1432, 180, 3, 27, "Input"],
Cell[44526, 1437, 88, 1, 27, "Input"],
Cell[44617, 1440, 73, 1, 27, "Input"],
Cell[44693, 1443, 110, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[44840, 1450, 31, 0, 42, "Subsubsection"],
Cell[44874, 1452, 241, 4, 27, "Input"],
Cell[45118, 1458, 252, 5, 62, "Input"],
Cell[45373, 1465, 295, 6, 27, "Input"],
Cell[45671, 1473, 280, 5, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[46000, 1484, 121, 2, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[46146, 1490, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[46239, 1494, 118, 4, 42, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[46394, 1503, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[46478, 1507, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[46578, 1513, 31, 0, 42, "Subsubsection"],
Cell[46612, 1515, 859, 21, 46, "Input"],
Cell[47474, 1538, 91, 1, 27, "Input"],
Cell[47568, 1541, 177, 4, 33, "Input"],
Cell[47748, 1547, 153, 2, 27, "Input"],
Cell[47904, 1551, 277, 5, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[48218, 1561, 31, 0, 42, "Subsubsection"],
Cell[48252, 1563, 50, 1, 27, "Input"],
Cell[48305, 1566, 117, 2, 27, "Input"],
Cell[48425, 1570, 289, 5, 43, "Input"],
Cell[48717, 1577, 246, 4, 59, "Input"],
Cell[48966, 1583, 559, 10, 123, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[49562, 1598, 31, 0, 42, "Subsubsection"],
Cell[49596, 1600, 820, 15, 139, "Input"],
Cell[50419, 1617, 471, 8, 107, "Input"],
Cell[50893, 1627, 75, 1, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[51017, 1634, 119, 2, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[51161, 1640, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[51254, 1644, 71, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[51362, 1650, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[51446, 1654, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[51546, 1660, 31, 0, 42, "Subsubsection"],
Cell[51580, 1662, 788, 18, 29, "Input"],
Cell[52371, 1682, 104, 2, 27, "Input"],
Cell[52478, 1686, 246, 5, 48, "Input"],
Cell[52727, 1693, 155, 2, 27, "Input"],
Cell[52885, 1697, 190, 3, 27, "Input"],
Cell[53078, 1702, 286, 5, 43, "Input"],
Cell[53367, 1709, 103, 2, 27, "Input"],
Cell[53473, 1713, 183, 3, 27, "Input"],
Cell[53659, 1718, 88, 1, 27, "Input"],
Cell[53750, 1721, 137, 4, 27, "Input"],
Cell[53890, 1727, 340, 6, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[54267, 1738, 31, 0, 42, "Subsubsection"],
Cell[54301, 1740, 169, 3, 27, "Input"],
Cell[54473, 1745, 117, 2, 27, "Input"],
Cell[54593, 1749, 145, 4, 27, "Input"],
Cell[54741, 1755, 281, 4, 50, "Input"],
Cell[55025, 1761, 164, 2, 27, "Input"],
Cell[55192, 1765, 60, 1, 27, "Input"],
Cell[55255, 1768, 84, 1, 27, "Input"],
Cell[55342, 1771, 116, 2, 27, "Input"],
Cell[55461, 1775, 85, 1, 27, "Input"],
Cell[55549, 1778, 71, 1, 27, "Input"],
Cell[55623, 1781, 214, 4, 59, "Input"],
Cell[55840, 1787, 119, 2, 27, "Input"],
Cell[55962, 1791, 116, 2, 27, "Input"],
Cell[56081, 1795, 257, 5, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[56375, 1805, 31, 0, 42, "Subsubsection"],
Cell[56409, 1807, 189, 3, 27, "Input"],
Cell[56601, 1812, 178, 3, 27, "Input"],
Cell[56782, 1817, 500, 8, 91, "Input"],
Cell[57285, 1827, 529, 8, 107, "Input"],
Cell[57817, 1837, 529, 8, 107, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[58395, 1851, 190, 6, 29, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[58610, 1861, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[58703, 1865, 81, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[58821, 1871, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[58905, 1875, 63, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[59005, 1881, 31, 0, 42, "Subsubsection"],
Cell[59039, 1883, 975, 23, 46, "Input"],
Cell[60017, 1908, 73, 1, 27, "Input"],
Cell[60093, 1911, 277, 6, 47, "Input"],
Cell[60373, 1919, 104, 2, 27, "Input"],
Cell[60480, 1923, 64, 1, 27, "Input"],
Cell[60547, 1926, 273, 6, 62, "Input"],
Cell[60823, 1934, 161, 3, 27, "Input"],
Cell[60987, 1939, 180, 3, 31, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[61204, 1947, 31, 0, 42, "Subsubsection"],
Cell[61238, 1949, 316, 6, 43, "Input"],
Cell[61557, 1957, 382, 6, 99, "Input"],
Cell[61942, 1965, 132, 4, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[62111, 1974, 31, 0, 42, "Subsubsection"],
Cell[62145, 1976, 468, 8, 123, "Input"],
Cell[62616, 1986, 157, 6, 57, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[62822, 1998, 80, 2, 40, "Section",
  Evaluatable->False],
Cell[62905, 2002, 149, 5, 42, "Subsubsection",
  Evaluatable->False],
Cell[63057, 2009, 104, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[63164, 2013, 130, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[63297, 2018, 125, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[63425, 2022, 114, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[63542, 2026, 104, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[63649, 2030, 146, 5, 42, "Subsubsection",
  Evaluatable->False]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

